#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1033
#define LARGE_STATE_COUNT 400
#define SYMBOL_COUNT 514
#define ALIAS_COUNT 3
#define TOKEN_COUNT 321
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 37
#define MAX_ALIAS_SEQUENCE_LENGTH 12
#define PRODUCTION_ID_COUNT 114

enum {
  sym_identifier = 1,
  anon_sym_pragma = 2,
  anon_sym_PIPE_PIPE = 3,
  anon_sym_DASH = 4,
  anon_sym_solidity = 5,
  aux_sym_pragma_value_token1 = 6,
  sym_solidity_version = 7,
  anon_sym_LT_EQ = 8,
  anon_sym_LT = 9,
  anon_sym_CARET = 10,
  anon_sym_GT = 11,
  anon_sym_GT_EQ = 12,
  anon_sym_TILDE = 13,
  anon_sym_EQ = 14,
  anon_sym_import = 15,
  anon_sym_from = 16,
  anon_sym_STAR = 17,
  anon_sym_LBRACE = 18,
  anon_sym_COMMA = 19,
  anon_sym_RBRACE = 20,
  anon_sym_as = 21,
  anon_sym_type = 22,
  anon_sym_is = 23,
  anon_sym_constant = 24,
  anon_sym_abstract = 25,
  anon_sym_contract = 26,
  anon_sym_error = 27,
  anon_sym_LPAREN = 28,
  anon_sym_RPAREN = 29,
  anon_sym_interface = 30,
  anon_sym_library = 31,
  anon_sym_struct = 32,
  anon_sym_enum = 33,
  anon_sym_event = 34,
  anon_sym_anonymous = 35,
  anon_sym_indexed = 36,
  anon_sym_using = 37,
  anon_sym_for = 38,
  anon_sym_global = 39,
  anon_sym_AMP = 40,
  anon_sym_PIPE = 41,
  anon_sym_PLUS = 42,
  anon_sym_SLASH = 43,
  anon_sym_PERCENT = 44,
  anon_sym_EQ_EQ = 45,
  anon_sym_BANG_EQ = 46,
  anon_sym_assembly = 47,
  anon_sym_DQUOTEevmasm_DQUOTE = 48,
  anon_sym_COLON = 49,
  sym_yul_leave = 50,
  anon_sym_break = 51,
  anon_sym_continue = 52,
  anon_sym_DOT = 53,
  sym_yul_decimal_number = 54,
  sym_yul_hex_number = 55,
  anon_sym_true = 56,
  anon_sym_false = 57,
  anon_sym_let = 58,
  anon_sym_COLON_EQ = 59,
  anon_sym_if = 60,
  anon_sym_switch = 61,
  anon_sym_default = 62,
  anon_sym_case = 63,
  anon_sym_function = 64,
  anon_sym_DASH_GT = 65,
  anon_sym_stop = 66,
  anon_sym_add = 67,
  anon_sym_sub = 68,
  anon_sym_mul = 69,
  anon_sym_div = 70,
  anon_sym_sdiv = 71,
  anon_sym_mod = 72,
  anon_sym_smod = 73,
  anon_sym_exp = 74,
  anon_sym_not = 75,
  anon_sym_lt = 76,
  anon_sym_gt = 77,
  anon_sym_slt = 78,
  anon_sym_sgt = 79,
  anon_sym_eq = 80,
  anon_sym_iszero = 81,
  anon_sym_and = 82,
  anon_sym_or = 83,
  anon_sym_xor = 84,
  anon_sym_byte = 85,
  anon_sym_shl = 86,
  anon_sym_shr = 87,
  anon_sym_sar = 88,
  anon_sym_addmod = 89,
  anon_sym_mulmod = 90,
  anon_sym_signextend = 91,
  anon_sym_keccak256 = 92,
  anon_sym_pop = 93,
  anon_sym_mload = 94,
  anon_sym_mstore = 95,
  anon_sym_mstore8 = 96,
  anon_sym_sload = 97,
  anon_sym_sstore = 98,
  anon_sym_msize = 99,
  anon_sym_gas = 100,
  anon_sym_address = 101,
  anon_sym_balance = 102,
  anon_sym_selfbalance = 103,
  anon_sym_caller = 104,
  anon_sym_callvalue = 105,
  anon_sym_calldataload = 106,
  anon_sym_calldatasize = 107,
  anon_sym_calldatacopy = 108,
  anon_sym_extcodesize = 109,
  anon_sym_extcodecopy = 110,
  anon_sym_returndatasize = 111,
  anon_sym_returndatacopy = 112,
  anon_sym_extcodehash = 113,
  anon_sym_create = 114,
  anon_sym_create2 = 115,
  anon_sym_call = 116,
  anon_sym_callcode = 117,
  anon_sym_delegatecall = 118,
  anon_sym_staticcall = 119,
  anon_sym_return = 120,
  anon_sym_revert = 121,
  anon_sym_selfdestruct = 122,
  anon_sym_invalid = 123,
  anon_sym_log0 = 124,
  anon_sym_log1 = 125,
  anon_sym_log2 = 126,
  anon_sym_log3 = 127,
  anon_sym_log4 = 128,
  anon_sym_chainid = 129,
  anon_sym_origin = 130,
  anon_sym_gasprice = 131,
  anon_sym_blockhash = 132,
  anon_sym_coinbase = 133,
  anon_sym_timestamp = 134,
  anon_sym_number = 135,
  anon_sym_difficulty = 136,
  anon_sym_gaslimit = 137,
  sym__unchecked = 138,
  anon_sym_memory = 139,
  anon_sym_storage = 140,
  anon_sym_calldata = 141,
  anon_sym_var = 142,
  anon_sym_else = 143,
  anon_sym_while = 144,
  anon_sym_do = 145,
  anon_sym_try = 146,
  anon_sym_returns = 147,
  anon_sym_catch = 148,
  anon_sym_emit = 149,
  anon_sym_public = 150,
  anon_sym_internal = 151,
  anon_sym_private = 152,
  anon_sym_external = 153,
  anon_sym_pure = 154,
  anon_sym_view = 155,
  anon_sym_payable = 156,
  sym_immutable = 157,
  anon_sym_override = 158,
  anon_sym_modifier = 159,
  anon_sym_constructor = 160,
  anon_sym_fallback = 161,
  anon_sym_receive = 162,
  sym_virtual = 163,
  anon_sym_QMARK = 164,
  anon_sym_new = 165,
  anon_sym_LBRACK = 166,
  anon_sym_RBRACK = 167,
  anon_sym_AMP_AMP = 168,
  anon_sym_GT_GT = 169,
  anon_sym_GT_GT_GT = 170,
  anon_sym_LT_LT = 171,
  anon_sym_STAR_STAR = 172,
  anon_sym_BANG_EQ_EQ = 173,
  anon_sym_BANG = 174,
  anon_sym_delete = 175,
  anon_sym_PLUS_PLUS = 176,
  anon_sym_DASH_DASH = 177,
  anon_sym_PLUS_EQ = 178,
  anon_sym_DASH_EQ = 179,
  anon_sym_STAR_EQ = 180,
  anon_sym_SLASH_EQ = 181,
  anon_sym_PERCENT_EQ = 182,
  anon_sym_CARET_EQ = 183,
  anon_sym_AMP_EQ = 184,
  anon_sym_PIPE_EQ = 185,
  anon_sym_GT_GT_EQ = 186,
  anon_sym_GT_GT_GT_EQ = 187,
  anon_sym_LT_LT_EQ = 188,
  anon_sym_mapping = 189,
  anon_sym_EQ_GT = 190,
  anon_sym_bool = 191,
  anon_sym_string = 192,
  anon_sym_int = 193,
  anon_sym_int8 = 194,
  anon_sym_int16 = 195,
  anon_sym_int24 = 196,
  anon_sym_int32 = 197,
  anon_sym_int40 = 198,
  anon_sym_int48 = 199,
  anon_sym_int56 = 200,
  anon_sym_int64 = 201,
  anon_sym_int72 = 202,
  anon_sym_int80 = 203,
  anon_sym_int88 = 204,
  anon_sym_int96 = 205,
  anon_sym_int104 = 206,
  anon_sym_int112 = 207,
  anon_sym_int120 = 208,
  anon_sym_int128 = 209,
  anon_sym_int136 = 210,
  anon_sym_int144 = 211,
  anon_sym_int152 = 212,
  anon_sym_int160 = 213,
  anon_sym_int168 = 214,
  anon_sym_int176 = 215,
  anon_sym_int184 = 216,
  anon_sym_int192 = 217,
  anon_sym_int200 = 218,
  anon_sym_int208 = 219,
  anon_sym_int216 = 220,
  anon_sym_int224 = 221,
  anon_sym_int232 = 222,
  anon_sym_int240 = 223,
  anon_sym_int248 = 224,
  anon_sym_int256 = 225,
  anon_sym_uint = 226,
  anon_sym_uint8 = 227,
  anon_sym_uint16 = 228,
  anon_sym_uint24 = 229,
  anon_sym_uint32 = 230,
  anon_sym_uint40 = 231,
  anon_sym_uint48 = 232,
  anon_sym_uint56 = 233,
  anon_sym_uint64 = 234,
  anon_sym_uint72 = 235,
  anon_sym_uint80 = 236,
  anon_sym_uint88 = 237,
  anon_sym_uint96 = 238,
  anon_sym_uint104 = 239,
  anon_sym_uint112 = 240,
  anon_sym_uint120 = 241,
  anon_sym_uint128 = 242,
  anon_sym_uint136 = 243,
  anon_sym_uint144 = 244,
  anon_sym_uint152 = 245,
  anon_sym_uint160 = 246,
  anon_sym_uint168 = 247,
  anon_sym_uint176 = 248,
  anon_sym_uint184 = 249,
  anon_sym_uint192 = 250,
  anon_sym_uint200 = 251,
  anon_sym_uint208 = 252,
  anon_sym_uint216 = 253,
  anon_sym_uint224 = 254,
  anon_sym_uint232 = 255,
  anon_sym_uint240 = 256,
  anon_sym_uint248 = 257,
  anon_sym_uint256 = 258,
  anon_sym_bytes = 259,
  anon_sym_bytes1 = 260,
  anon_sym_bytes2 = 261,
  anon_sym_bytes3 = 262,
  anon_sym_bytes4 = 263,
  anon_sym_bytes5 = 264,
  anon_sym_bytes6 = 265,
  anon_sym_bytes7 = 266,
  anon_sym_bytes8 = 267,
  anon_sym_bytes9 = 268,
  anon_sym_bytes10 = 269,
  anon_sym_bytes11 = 270,
  anon_sym_bytes12 = 271,
  anon_sym_bytes13 = 272,
  anon_sym_bytes14 = 273,
  anon_sym_bytes15 = 274,
  anon_sym_bytes16 = 275,
  anon_sym_bytes17 = 276,
  anon_sym_bytes18 = 277,
  anon_sym_bytes19 = 278,
  anon_sym_bytes20 = 279,
  anon_sym_bytes21 = 280,
  anon_sym_bytes22 = 281,
  anon_sym_bytes23 = 282,
  anon_sym_bytes24 = 283,
  anon_sym_bytes25 = 284,
  anon_sym_bytes26 = 285,
  anon_sym_bytes27 = 286,
  anon_sym_bytes28 = 287,
  anon_sym_bytes29 = 288,
  anon_sym_bytes30 = 289,
  anon_sym_bytes31 = 290,
  anon_sym_bytes32 = 291,
  anon_sym_fixed = 292,
  aux_sym__fixed_token1 = 293,
  anon_sym_ufixed = 294,
  aux_sym__ufixed_token1 = 295,
  sym__semicolon = 296,
  aux_sym__decimal_number_token1 = 297,
  aux_sym__decimal_number_token2 = 298,
  aux_sym__hex_number_token1 = 299,
  sym__hex_digit = 300,
  anon_sym_wei = 301,
  anon_sym_szabo = 302,
  anon_sym_finney = 303,
  anon_sym_gwei = 304,
  anon_sym_ether = 305,
  anon_sym_seconds = 306,
  anon_sym_minutes = 307,
  anon_sym_hours = 308,
  anon_sym_days = 309,
  anon_sym_weeks = 310,
  anon_sym_years = 311,
  anon_sym_hex = 312,
  anon_sym_DQUOTE = 313,
  anon_sym__ = 314,
  anon_sym_SQUOTE = 315,
  sym__escape_sequence = 316,
  aux_sym__single_quoted_unicode_char_token1 = 317,
  aux_sym__double_quoted_unicode_char_token1 = 318,
  anon_sym_unicode = 319,
  sym_comment = 320,
  sym_source_file = 321,
  sym__source_unit = 322,
  sym__directive = 323,
  sym_pragma_directive = 324,
  sym_solidity_pragma_token = 325,
  sym_any_pragma_token = 326,
  sym__solidity = 327,
  sym_pragma_value = 328,
  sym__pragma_version_constraint = 329,
  sym_solidity_version_comparison_operator = 330,
  sym_import_directive = 331,
  sym__source_import = 332,
  sym__import_clause = 333,
  sym__from_clause = 334,
  sym__single_import = 335,
  sym__multiple_import = 336,
  sym__import_declaration = 337,
  sym__import_alias = 338,
  sym__declaration = 339,
  sym_user_defined_type_definition = 340,
  sym_constant_variable_declaration = 341,
  sym_contract_declaration = 342,
  sym_error_declaration = 343,
  sym_error_parameter = 344,
  sym_interface_declaration = 345,
  sym_library_declaration = 346,
  sym__class_heritage = 347,
  sym_inheritance_specifier = 348,
  sym_contract_body = 349,
  sym__contract_member = 350,
  sym_struct_declaration = 351,
  sym_struct_member = 352,
  sym_enum_declaration = 353,
  sym_event_definition = 354,
  sym__event_parameter_list = 355,
  sym_event_paramater = 356,
  sym_using_directive = 357,
  sym_any_source_type = 358,
  sym_user_definable_operator = 359,
  sym__statement = 360,
  sym_assembly_statement = 361,
  sym__assembly_flags = 362,
  sym__yul_statement = 363,
  sym_yul_label = 364,
  sym_yul_break = 365,
  sym_yul_continue = 366,
  sym_yul_identifier = 367,
  sym__yul_expression = 368,
  sym_yul_path = 369,
  sym__yul_literal = 370,
  sym_yul_string_literal = 371,
  sym_yul_boolean = 372,
  sym_yul_block = 373,
  sym_yul_variable_declaration = 374,
  sym__yul_assignment_operator = 375,
  sym_yul_assignment = 376,
  sym_yul_function_call = 377,
  sym_yul_if_statement = 378,
  sym_yul_for_statement = 379,
  sym_yul_switch_statement = 380,
  sym_yul_function_definition = 381,
  sym_yul_evm_builtin = 382,
  sym_block_statement = 383,
  sym_variable_declaration_statement = 384,
  sym_variable_declaration = 385,
  sym_variable_declaration_tuple = 386,
  sym_expression_statement = 387,
  sym_if_statement = 388,
  sym_for_statement = 389,
  sym_while_statement = 390,
  sym_do_while_statement = 391,
  sym_continue_statement = 392,
  sym_break_statement = 393,
  sym_revert_statement = 394,
  sym_try_statement = 395,
  sym_catch_clause = 396,
  sym_return_statement = 397,
  sym_emit_statement = 398,
  sym_state_variable_declaration = 399,
  sym_visibility = 400,
  sym_state_mutability = 401,
  sym_override_specifier = 402,
  sym_modifier_definition = 403,
  sym_constructor_definition = 404,
  sym_fallback_definition = 405,
  sym_receive_definition = 406,
  sym_function_definition = 407,
  sym_return_type_definition = 408,
  sym_modifier_invocation = 409,
  sym__call_arguments = 410,
  sym_call_argument = 411,
  sym_call_struct_argument = 412,
  sym_function_body = 413,
  sym__expression = 414,
  sym__primary_expression = 415,
  sym_type_cast_expression = 416,
  sym_ternary_expression = 417,
  sym_new_expression = 418,
  sym_tuple_expression = 419,
  sym_inline_array_expression = 420,
  sym_binary_expression = 421,
  sym_unary_expression = 422,
  sym_update_expression = 423,
  sym_member_expression = 424,
  sym_array_access = 425,
  sym_slice_access = 426,
  sym_struct_expression = 427,
  sym_struct_field_assignment = 428,
  sym_parenthesized_expression = 429,
  sym_assignment_expression = 430,
  sym_augmented_assignment_expression = 431,
  sym_call_expression = 432,
  sym_payable_conversion_expression = 433,
  sym_meta_type_expression = 434,
  sym_type_name = 435,
  sym__array_type = 436,
  sym__function_type = 437,
  sym__parameter_list = 438,
  sym__return_parameters = 439,
  sym__nameless_parameter = 440,
  sym_parameter = 441,
  sym__storage_location = 442,
  sym_user_defined_type = 443,
  sym__identifier_path = 444,
  sym__mapping = 445,
  sym__mapping_key = 446,
  sym_primitive_type = 447,
  sym__int = 448,
  sym__uint = 449,
  sym__bytes = 450,
  sym__fixed = 451,
  sym__ufixed = 452,
  sym__literal = 453,
  sym_string_literal = 454,
  sym_number_literal = 455,
  sym__decimal_number = 456,
  sym__hex_number = 457,
  sym_number_unit = 458,
  sym_true = 459,
  sym_false = 460,
  sym_boolean_literal = 461,
  sym_hex_string_literal = 462,
  sym__single_quoted_unicode_char = 463,
  sym__double_quoted_unicode_char = 464,
  sym_unicode_string_literal = 465,
  sym_string = 466,
  sym__string_immediate_elt_inside_double_quote = 467,
  sym__string_immediate_elt_inside_quote = 468,
  aux_sym_source_file_repeat1 = 469,
  aux_sym_solidity_pragma_token_repeat1 = 470,
  aux_sym__multiple_import_repeat1 = 471,
  aux_sym_error_declaration_repeat1 = 472,
  aux_sym__class_heritage_repeat1 = 473,
  aux_sym_contract_body_repeat1 = 474,
  aux_sym_struct_declaration_repeat1 = 475,
  aux_sym_enum_declaration_repeat1 = 476,
  aux_sym__event_parameter_list_repeat1 = 477,
  aux_sym_using_directive_repeat1 = 478,
  aux_sym_assembly_statement_repeat1 = 479,
  aux_sym__assembly_flags_repeat1 = 480,
  aux_sym_yul_path_repeat1 = 481,
  aux_sym_yul_variable_declaration_repeat1 = 482,
  aux_sym_yul_assignment_repeat1 = 483,
  aux_sym_yul_function_call_repeat1 = 484,
  aux_sym_yul_switch_statement_repeat1 = 485,
  aux_sym_block_statement_repeat1 = 486,
  aux_sym_variable_declaration_tuple_repeat1 = 487,
  aux_sym_variable_declaration_tuple_repeat2 = 488,
  aux_sym_try_statement_repeat1 = 489,
  aux_sym_state_variable_declaration_repeat1 = 490,
  aux_sym_override_specifier_repeat1 = 491,
  aux_sym_modifier_definition_repeat1 = 492,
  aux_sym_constructor_definition_repeat1 = 493,
  aux_sym_fallback_definition_repeat1 = 494,
  aux_sym_receive_definition_repeat1 = 495,
  aux_sym_function_definition_repeat1 = 496,
  aux_sym__call_arguments_repeat1 = 497,
  aux_sym_call_argument_repeat1 = 498,
  aux_sym_tuple_expression_repeat1 = 499,
  aux_sym_inline_array_expression_repeat1 = 500,
  aux_sym_struct_expression_repeat1 = 501,
  aux_sym__function_type_repeat1 = 502,
  aux_sym__parameter_list_repeat1 = 503,
  aux_sym__return_parameters_repeat1 = 504,
  aux_sym__identifier_path_repeat1 = 505,
  aux_sym_string_literal_repeat1 = 506,
  aux_sym_hex_string_literal_repeat1 = 507,
  aux_sym_hex_string_literal_repeat2 = 508,
  aux_sym_unicode_string_literal_repeat1 = 509,
  aux_sym_unicode_string_literal_repeat2 = 510,
  aux_sym_unicode_string_literal_repeat3 = 511,
  aux_sym_string_repeat1 = 512,
  aux_sym_string_repeat2 = 513,
  alias_sym_enum_value = 514,
  alias_sym_revert_arguments = 515,
  alias_sym_type_alias = 516,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_pragma] = "pragma",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DASH] = "-",
  [anon_sym_solidity] = "solidity",
  [aux_sym_pragma_value_token1] = "pragma_value_token1",
  [sym_solidity_version] = "solidity_version",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_CARET] = "^",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_TILDE] = "~",
  [anon_sym_EQ] = "=",
  [anon_sym_import] = "import",
  [anon_sym_from] = "from",
  [anon_sym_STAR] = "*",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_RBRACE] = "}",
  [anon_sym_as] = "as",
  [anon_sym_type] = "type",
  [anon_sym_is] = "is",
  [anon_sym_constant] = "constant",
  [anon_sym_abstract] = "abstract",
  [anon_sym_contract] = "contract",
  [anon_sym_error] = "error",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_interface] = "interface",
  [anon_sym_library] = "library",
  [anon_sym_struct] = "struct",
  [anon_sym_enum] = "enum",
  [anon_sym_event] = "event",
  [anon_sym_anonymous] = "anonymous",
  [anon_sym_indexed] = "indexed",
  [anon_sym_using] = "using",
  [anon_sym_for] = "for",
  [anon_sym_global] = "global",
  [anon_sym_AMP] = "&",
  [anon_sym_PIPE] = "|",
  [anon_sym_PLUS] = "+",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_assembly] = "assembly",
  [anon_sym_DQUOTEevmasm_DQUOTE] = "\"evmasm\"",
  [anon_sym_COLON] = ":",
  [sym_yul_leave] = "yul_leave",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_DOT] = ".",
  [sym_yul_decimal_number] = "yul_decimal_number",
  [sym_yul_hex_number] = "yul_hex_number",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_let] = "let",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_if] = "if",
  [anon_sym_switch] = "switch",
  [anon_sym_default] = "default",
  [anon_sym_case] = "case",
  [anon_sym_function] = "function",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_stop] = "stop",
  [anon_sym_add] = "add",
  [anon_sym_sub] = "sub",
  [anon_sym_mul] = "mul",
  [anon_sym_div] = "div",
  [anon_sym_sdiv] = "sdiv",
  [anon_sym_mod] = "mod",
  [anon_sym_smod] = "smod",
  [anon_sym_exp] = "exp",
  [anon_sym_not] = "not",
  [anon_sym_lt] = "lt",
  [anon_sym_gt] = "gt",
  [anon_sym_slt] = "slt",
  [anon_sym_sgt] = "sgt",
  [anon_sym_eq] = "eq",
  [anon_sym_iszero] = "iszero",
  [anon_sym_and] = "and",
  [anon_sym_or] = "or",
  [anon_sym_xor] = "xor",
  [anon_sym_byte] = "byte",
  [anon_sym_shl] = "shl",
  [anon_sym_shr] = "shr",
  [anon_sym_sar] = "sar",
  [anon_sym_addmod] = "addmod",
  [anon_sym_mulmod] = "mulmod",
  [anon_sym_signextend] = "signextend",
  [anon_sym_keccak256] = "keccak256",
  [anon_sym_pop] = "pop",
  [anon_sym_mload] = "mload",
  [anon_sym_mstore] = "mstore",
  [anon_sym_mstore8] = "mstore8",
  [anon_sym_sload] = "sload",
  [anon_sym_sstore] = "sstore",
  [anon_sym_msize] = "msize",
  [anon_sym_gas] = "gas",
  [anon_sym_address] = "address",
  [anon_sym_balance] = "balance",
  [anon_sym_selfbalance] = "selfbalance",
  [anon_sym_caller] = "caller",
  [anon_sym_callvalue] = "callvalue",
  [anon_sym_calldataload] = "calldataload",
  [anon_sym_calldatasize] = "calldatasize",
  [anon_sym_calldatacopy] = "calldatacopy",
  [anon_sym_extcodesize] = "extcodesize",
  [anon_sym_extcodecopy] = "extcodecopy",
  [anon_sym_returndatasize] = "returndatasize",
  [anon_sym_returndatacopy] = "returndatacopy",
  [anon_sym_extcodehash] = "extcodehash",
  [anon_sym_create] = "create",
  [anon_sym_create2] = "create2",
  [anon_sym_call] = "call",
  [anon_sym_callcode] = "callcode",
  [anon_sym_delegatecall] = "delegatecall",
  [anon_sym_staticcall] = "staticcall",
  [anon_sym_return] = "return",
  [anon_sym_revert] = "revert",
  [anon_sym_selfdestruct] = "selfdestruct",
  [anon_sym_invalid] = "invalid",
  [anon_sym_log0] = "log0",
  [anon_sym_log1] = "log1",
  [anon_sym_log2] = "log2",
  [anon_sym_log3] = "log3",
  [anon_sym_log4] = "log4",
  [anon_sym_chainid] = "chainid",
  [anon_sym_origin] = "origin",
  [anon_sym_gasprice] = "gasprice",
  [anon_sym_blockhash] = "blockhash",
  [anon_sym_coinbase] = "coinbase",
  [anon_sym_timestamp] = "timestamp",
  [anon_sym_number] = "number",
  [anon_sym_difficulty] = "difficulty",
  [anon_sym_gaslimit] = "gaslimit",
  [sym__unchecked] = "_unchecked",
  [anon_sym_memory] = "memory",
  [anon_sym_storage] = "storage",
  [anon_sym_calldata] = "calldata",
  [anon_sym_var] = "var",
  [anon_sym_else] = "else",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_try] = "try",
  [anon_sym_returns] = "returns",
  [anon_sym_catch] = "catch",
  [anon_sym_emit] = "emit",
  [anon_sym_public] = "public",
  [anon_sym_internal] = "internal",
  [anon_sym_private] = "private",
  [anon_sym_external] = "external",
  [anon_sym_pure] = "pure",
  [anon_sym_view] = "view",
  [anon_sym_payable] = "payable",
  [sym_immutable] = "immutable",
  [anon_sym_override] = "override",
  [anon_sym_modifier] = "modifier",
  [anon_sym_constructor] = "constructor",
  [anon_sym_fallback] = "fallback",
  [anon_sym_receive] = "receive",
  [sym_virtual] = "virtual",
  [anon_sym_QMARK] = "\?",
  [anon_sym_new] = "new",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_GT_GT_GT] = ">>>",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_BANG_EQ_EQ] = "!==",
  [anon_sym_BANG] = "!",
  [anon_sym_delete] = "delete",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_GT_GT_GT_EQ] = ">>>=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_mapping] = "mapping",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_bool] = "bool",
  [anon_sym_string] = "string",
  [anon_sym_int] = "int",
  [anon_sym_int8] = "int8",
  [anon_sym_int16] = "int16",
  [anon_sym_int24] = "int24",
  [anon_sym_int32] = "int32",
  [anon_sym_int40] = "int40",
  [anon_sym_int48] = "int48",
  [anon_sym_int56] = "int56",
  [anon_sym_int64] = "int64",
  [anon_sym_int72] = "int72",
  [anon_sym_int80] = "int80",
  [anon_sym_int88] = "int88",
  [anon_sym_int96] = "int96",
  [anon_sym_int104] = "int104",
  [anon_sym_int112] = "int112",
  [anon_sym_int120] = "int120",
  [anon_sym_int128] = "int128",
  [anon_sym_int136] = "int136",
  [anon_sym_int144] = "int144",
  [anon_sym_int152] = "int152",
  [anon_sym_int160] = "int160",
  [anon_sym_int168] = "int168",
  [anon_sym_int176] = "int176",
  [anon_sym_int184] = "int184",
  [anon_sym_int192] = "int192",
  [anon_sym_int200] = "int200",
  [anon_sym_int208] = "int208",
  [anon_sym_int216] = "int216",
  [anon_sym_int224] = "int224",
  [anon_sym_int232] = "int232",
  [anon_sym_int240] = "int240",
  [anon_sym_int248] = "int248",
  [anon_sym_int256] = "int256",
  [anon_sym_uint] = "uint",
  [anon_sym_uint8] = "uint8",
  [anon_sym_uint16] = "uint16",
  [anon_sym_uint24] = "uint24",
  [anon_sym_uint32] = "uint32",
  [anon_sym_uint40] = "uint40",
  [anon_sym_uint48] = "uint48",
  [anon_sym_uint56] = "uint56",
  [anon_sym_uint64] = "uint64",
  [anon_sym_uint72] = "uint72",
  [anon_sym_uint80] = "uint80",
  [anon_sym_uint88] = "uint88",
  [anon_sym_uint96] = "uint96",
  [anon_sym_uint104] = "uint104",
  [anon_sym_uint112] = "uint112",
  [anon_sym_uint120] = "uint120",
  [anon_sym_uint128] = "uint128",
  [anon_sym_uint136] = "uint136",
  [anon_sym_uint144] = "uint144",
  [anon_sym_uint152] = "uint152",
  [anon_sym_uint160] = "uint160",
  [anon_sym_uint168] = "uint168",
  [anon_sym_uint176] = "uint176",
  [anon_sym_uint184] = "uint184",
  [anon_sym_uint192] = "uint192",
  [anon_sym_uint200] = "uint200",
  [anon_sym_uint208] = "uint208",
  [anon_sym_uint216] = "uint216",
  [anon_sym_uint224] = "uint224",
  [anon_sym_uint232] = "uint232",
  [anon_sym_uint240] = "uint240",
  [anon_sym_uint248] = "uint248",
  [anon_sym_uint256] = "uint256",
  [anon_sym_bytes] = "bytes",
  [anon_sym_bytes1] = "bytes1",
  [anon_sym_bytes2] = "bytes2",
  [anon_sym_bytes3] = "bytes3",
  [anon_sym_bytes4] = "bytes4",
  [anon_sym_bytes5] = "bytes5",
  [anon_sym_bytes6] = "bytes6",
  [anon_sym_bytes7] = "bytes7",
  [anon_sym_bytes8] = "bytes8",
  [anon_sym_bytes9] = "bytes9",
  [anon_sym_bytes10] = "bytes10",
  [anon_sym_bytes11] = "bytes11",
  [anon_sym_bytes12] = "bytes12",
  [anon_sym_bytes13] = "bytes13",
  [anon_sym_bytes14] = "bytes14",
  [anon_sym_bytes15] = "bytes15",
  [anon_sym_bytes16] = "bytes16",
  [anon_sym_bytes17] = "bytes17",
  [anon_sym_bytes18] = "bytes18",
  [anon_sym_bytes19] = "bytes19",
  [anon_sym_bytes20] = "bytes20",
  [anon_sym_bytes21] = "bytes21",
  [anon_sym_bytes22] = "bytes22",
  [anon_sym_bytes23] = "bytes23",
  [anon_sym_bytes24] = "bytes24",
  [anon_sym_bytes25] = "bytes25",
  [anon_sym_bytes26] = "bytes26",
  [anon_sym_bytes27] = "bytes27",
  [anon_sym_bytes28] = "bytes28",
  [anon_sym_bytes29] = "bytes29",
  [anon_sym_bytes30] = "bytes30",
  [anon_sym_bytes31] = "bytes31",
  [anon_sym_bytes32] = "bytes32",
  [anon_sym_fixed] = "fixed",
  [aux_sym__fixed_token1] = "_fixed_token1",
  [anon_sym_ufixed] = "ufixed",
  [aux_sym__ufixed_token1] = "_ufixed_token1",
  [sym__semicolon] = "_semicolon",
  [aux_sym__decimal_number_token1] = "_decimal_number_token1",
  [aux_sym__decimal_number_token2] = "_decimal_number_token2",
  [aux_sym__hex_number_token1] = "_hex_number_token1",
  [sym__hex_digit] = "_hex_digit",
  [anon_sym_wei] = "wei",
  [anon_sym_szabo] = "szabo",
  [anon_sym_finney] = "finney",
  [anon_sym_gwei] = "gwei",
  [anon_sym_ether] = "ether",
  [anon_sym_seconds] = "seconds",
  [anon_sym_minutes] = "minutes",
  [anon_sym_hours] = "hours",
  [anon_sym_days] = "days",
  [anon_sym_weeks] = "weeks",
  [anon_sym_years] = "years",
  [anon_sym_hex] = "hex",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym__] = "_",
  [anon_sym_SQUOTE] = "'",
  [sym__escape_sequence] = "_escape_sequence",
  [aux_sym__single_quoted_unicode_char_token1] = "_single_quoted_unicode_char_token1",
  [aux_sym__double_quoted_unicode_char_token1] = "_double_quoted_unicode_char_token1",
  [anon_sym_unicode] = "unicode",
  [sym_comment] = "comment",
  [sym_source_file] = "source_file",
  [sym__source_unit] = "_source_unit",
  [sym__directive] = "_directive",
  [sym_pragma_directive] = "pragma_directive",
  [sym_solidity_pragma_token] = "solidity_pragma_token",
  [sym_any_pragma_token] = "any_pragma_token",
  [sym__solidity] = "_solidity",
  [sym_pragma_value] = "pragma_value",
  [sym__pragma_version_constraint] = "_pragma_version_constraint",
  [sym_solidity_version_comparison_operator] = "solidity_version_comparison_operator",
  [sym_import_directive] = "import_directive",
  [sym__source_import] = "_source_import",
  [sym__import_clause] = "_import_clause",
  [sym__from_clause] = "_from_clause",
  [sym__single_import] = "_single_import",
  [sym__multiple_import] = "_multiple_import",
  [sym__import_declaration] = "_import_declaration",
  [sym__import_alias] = "_import_alias",
  [sym__declaration] = "_declaration",
  [sym_user_defined_type_definition] = "user_defined_type_definition",
  [sym_constant_variable_declaration] = "constant_variable_declaration",
  [sym_contract_declaration] = "contract_declaration",
  [sym_error_declaration] = "error_declaration",
  [sym_error_parameter] = "error_parameter",
  [sym_interface_declaration] = "interface_declaration",
  [sym_library_declaration] = "library_declaration",
  [sym__class_heritage] = "_class_heritage",
  [sym_inheritance_specifier] = "inheritance_specifier",
  [sym_contract_body] = "contract_body",
  [sym__contract_member] = "_contract_member",
  [sym_struct_declaration] = "struct_declaration",
  [sym_struct_member] = "struct_member",
  [sym_enum_declaration] = "enum_declaration",
  [sym_event_definition] = "event_definition",
  [sym__event_parameter_list] = "_event_parameter_list",
  [sym_event_paramater] = "event_paramater",
  [sym_using_directive] = "using_directive",
  [sym_any_source_type] = "any_source_type",
  [sym_user_definable_operator] = "user_definable_operator",
  [sym__statement] = "_statement",
  [sym_assembly_statement] = "assembly_statement",
  [sym__assembly_flags] = "_assembly_flags",
  [sym__yul_statement] = "_yul_statement",
  [sym_yul_label] = "yul_label",
  [sym_yul_break] = "yul_break",
  [sym_yul_continue] = "yul_continue",
  [sym_yul_identifier] = "yul_identifier",
  [sym__yul_expression] = "_yul_expression",
  [sym_yul_path] = "yul_path",
  [sym__yul_literal] = "_yul_literal",
  [sym_yul_string_literal] = "yul_string_literal",
  [sym_yul_boolean] = "yul_boolean",
  [sym_yul_block] = "yul_block",
  [sym_yul_variable_declaration] = "yul_variable_declaration",
  [sym__yul_assignment_operator] = "_yul_assignment_operator",
  [sym_yul_assignment] = "yul_assignment",
  [sym_yul_function_call] = "yul_function_call",
  [sym_yul_if_statement] = "yul_if_statement",
  [sym_yul_for_statement] = "yul_for_statement",
  [sym_yul_switch_statement] = "yul_switch_statement",
  [sym_yul_function_definition] = "yul_function_definition",
  [sym_yul_evm_builtin] = "yul_evm_builtin",
  [sym_block_statement] = "block_statement",
  [sym_variable_declaration_statement] = "variable_declaration_statement",
  [sym_variable_declaration] = "variable_declaration",
  [sym_variable_declaration_tuple] = "variable_declaration_tuple",
  [sym_expression_statement] = "expression_statement",
  [sym_if_statement] = "if_statement",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_do_while_statement] = "do_while_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [sym_revert_statement] = "revert_statement",
  [sym_try_statement] = "try_statement",
  [sym_catch_clause] = "catch_clause",
  [sym_return_statement] = "return_statement",
  [sym_emit_statement] = "emit_statement",
  [sym_state_variable_declaration] = "state_variable_declaration",
  [sym_visibility] = "visibility",
  [sym_state_mutability] = "state_mutability",
  [sym_override_specifier] = "override_specifier",
  [sym_modifier_definition] = "modifier_definition",
  [sym_constructor_definition] = "constructor_definition",
  [sym_fallback_definition] = "fallback_definition",
  [sym_receive_definition] = "receive_definition",
  [sym_function_definition] = "function_definition",
  [sym_return_type_definition] = "return_type_definition",
  [sym_modifier_invocation] = "modifier_invocation",
  [sym__call_arguments] = "_call_arguments",
  [sym_call_argument] = "call_argument",
  [sym_call_struct_argument] = "call_struct_argument",
  [sym_function_body] = "function_body",
  [sym__expression] = "_expression",
  [sym__primary_expression] = "_primary_expression",
  [sym_type_cast_expression] = "type_cast_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_new_expression] = "new_expression",
  [sym_tuple_expression] = "tuple_expression",
  [sym_inline_array_expression] = "inline_array_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_update_expression] = "update_expression",
  [sym_member_expression] = "member_expression",
  [sym_array_access] = "array_access",
  [sym_slice_access] = "slice_access",
  [sym_struct_expression] = "struct_expression",
  [sym_struct_field_assignment] = "struct_field_assignment",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_augmented_assignment_expression] = "augmented_assignment_expression",
  [sym_call_expression] = "call_expression",
  [sym_payable_conversion_expression] = "payable_conversion_expression",
  [sym_meta_type_expression] = "meta_type_expression",
  [sym_type_name] = "type_name",
  [sym__array_type] = "_array_type",
  [sym__function_type] = "_function_type",
  [sym__parameter_list] = "_parameter_list",
  [sym__return_parameters] = "_return_parameters",
  [sym__nameless_parameter] = "return_parameter",
  [sym_parameter] = "parameter",
  [sym__storage_location] = "_storage_location",
  [sym_user_defined_type] = "user_defined_type",
  [sym__identifier_path] = "_identifier_path",
  [sym__mapping] = "_mapping",
  [sym__mapping_key] = "_mapping_key",
  [sym_primitive_type] = "primitive_type",
  [sym__int] = "_int",
  [sym__uint] = "_uint",
  [sym__bytes] = "_bytes",
  [sym__fixed] = "_fixed",
  [sym__ufixed] = "_ufixed",
  [sym__literal] = "_literal",
  [sym_string_literal] = "string_literal",
  [sym_number_literal] = "number_literal",
  [sym__decimal_number] = "_decimal_number",
  [sym__hex_number] = "_hex_number",
  [sym_number_unit] = "number_unit",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_boolean_literal] = "boolean_literal",
  [sym_hex_string_literal] = "hex_string_literal",
  [sym__single_quoted_unicode_char] = "_single_quoted_unicode_char",
  [sym__double_quoted_unicode_char] = "_double_quoted_unicode_char",
  [sym_unicode_string_literal] = "unicode_string_literal",
  [sym_string] = "string",
  [sym__string_immediate_elt_inside_double_quote] = "_string_immediate_elt_inside_double_quote",
  [sym__string_immediate_elt_inside_quote] = "_string_immediate_elt_inside_quote",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_solidity_pragma_token_repeat1] = "solidity_pragma_token_repeat1",
  [aux_sym__multiple_import_repeat1] = "_multiple_import_repeat1",
  [aux_sym_error_declaration_repeat1] = "error_declaration_repeat1",
  [aux_sym__class_heritage_repeat1] = "_class_heritage_repeat1",
  [aux_sym_contract_body_repeat1] = "contract_body_repeat1",
  [aux_sym_struct_declaration_repeat1] = "struct_declaration_repeat1",
  [aux_sym_enum_declaration_repeat1] = "enum_declaration_repeat1",
  [aux_sym__event_parameter_list_repeat1] = "_event_parameter_list_repeat1",
  [aux_sym_using_directive_repeat1] = "using_directive_repeat1",
  [aux_sym_assembly_statement_repeat1] = "assembly_statement_repeat1",
  [aux_sym__assembly_flags_repeat1] = "_assembly_flags_repeat1",
  [aux_sym_yul_path_repeat1] = "yul_path_repeat1",
  [aux_sym_yul_variable_declaration_repeat1] = "yul_variable_declaration_repeat1",
  [aux_sym_yul_assignment_repeat1] = "yul_assignment_repeat1",
  [aux_sym_yul_function_call_repeat1] = "yul_function_call_repeat1",
  [aux_sym_yul_switch_statement_repeat1] = "yul_switch_statement_repeat1",
  [aux_sym_block_statement_repeat1] = "block_statement_repeat1",
  [aux_sym_variable_declaration_tuple_repeat1] = "variable_declaration_tuple_repeat1",
  [aux_sym_variable_declaration_tuple_repeat2] = "variable_declaration_tuple_repeat2",
  [aux_sym_try_statement_repeat1] = "try_statement_repeat1",
  [aux_sym_state_variable_declaration_repeat1] = "state_variable_declaration_repeat1",
  [aux_sym_override_specifier_repeat1] = "override_specifier_repeat1",
  [aux_sym_modifier_definition_repeat1] = "modifier_definition_repeat1",
  [aux_sym_constructor_definition_repeat1] = "constructor_definition_repeat1",
  [aux_sym_fallback_definition_repeat1] = "fallback_definition_repeat1",
  [aux_sym_receive_definition_repeat1] = "receive_definition_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym__call_arguments_repeat1] = "_call_arguments_repeat1",
  [aux_sym_call_argument_repeat1] = "call_argument_repeat1",
  [aux_sym_tuple_expression_repeat1] = "tuple_expression_repeat1",
  [aux_sym_inline_array_expression_repeat1] = "inline_array_expression_repeat1",
  [aux_sym_struct_expression_repeat1] = "struct_expression_repeat1",
  [aux_sym__function_type_repeat1] = "_function_type_repeat1",
  [aux_sym__parameter_list_repeat1] = "_parameter_list_repeat1",
  [aux_sym__return_parameters_repeat1] = "_return_parameters_repeat1",
  [aux_sym__identifier_path_repeat1] = "_identifier_path_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym_hex_string_literal_repeat1] = "hex_string_literal_repeat1",
  [aux_sym_hex_string_literal_repeat2] = "hex_string_literal_repeat2",
  [aux_sym_unicode_string_literal_repeat1] = "unicode_string_literal_repeat1",
  [aux_sym_unicode_string_literal_repeat2] = "unicode_string_literal_repeat2",
  [aux_sym_unicode_string_literal_repeat3] = "unicode_string_literal_repeat3",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_string_repeat2] = "string_repeat2",
  [alias_sym_enum_value] = "enum_value",
  [alias_sym_revert_arguments] = "revert_arguments",
  [alias_sym_type_alias] = "type_alias",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_pragma] = anon_sym_pragma,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_solidity] = anon_sym_solidity,
  [aux_sym_pragma_value_token1] = aux_sym_pragma_value_token1,
  [sym_solidity_version] = sym_solidity_version,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_from] = anon_sym_from,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_is] = anon_sym_is,
  [anon_sym_constant] = anon_sym_constant,
  [anon_sym_abstract] = anon_sym_abstract,
  [anon_sym_contract] = anon_sym_contract,
  [anon_sym_error] = anon_sym_error,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_library] = anon_sym_library,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_event] = anon_sym_event,
  [anon_sym_anonymous] = anon_sym_anonymous,
  [anon_sym_indexed] = anon_sym_indexed,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_assembly] = anon_sym_assembly,
  [anon_sym_DQUOTEevmasm_DQUOTE] = anon_sym_DQUOTEevmasm_DQUOTE,
  [anon_sym_COLON] = anon_sym_COLON,
  [sym_yul_leave] = sym_yul_leave,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_DOT] = anon_sym_DOT,
  [sym_yul_decimal_number] = sym_yul_decimal_number,
  [sym_yul_hex_number] = sym_yul_hex_number,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_stop] = anon_sym_stop,
  [anon_sym_add] = anon_sym_add,
  [anon_sym_sub] = anon_sym_sub,
  [anon_sym_mul] = anon_sym_mul,
  [anon_sym_div] = anon_sym_div,
  [anon_sym_sdiv] = anon_sym_sdiv,
  [anon_sym_mod] = anon_sym_mod,
  [anon_sym_smod] = anon_sym_smod,
  [anon_sym_exp] = anon_sym_exp,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_lt] = anon_sym_lt,
  [anon_sym_gt] = anon_sym_gt,
  [anon_sym_slt] = anon_sym_slt,
  [anon_sym_sgt] = anon_sym_sgt,
  [anon_sym_eq] = anon_sym_eq,
  [anon_sym_iszero] = anon_sym_iszero,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_xor] = anon_sym_xor,
  [anon_sym_byte] = anon_sym_byte,
  [anon_sym_shl] = anon_sym_shl,
  [anon_sym_shr] = anon_sym_shr,
  [anon_sym_sar] = anon_sym_sar,
  [anon_sym_addmod] = anon_sym_addmod,
  [anon_sym_mulmod] = anon_sym_mulmod,
  [anon_sym_signextend] = anon_sym_signextend,
  [anon_sym_keccak256] = anon_sym_keccak256,
  [anon_sym_pop] = anon_sym_pop,
  [anon_sym_mload] = anon_sym_mload,
  [anon_sym_mstore] = anon_sym_mstore,
  [anon_sym_mstore8] = anon_sym_mstore8,
  [anon_sym_sload] = anon_sym_sload,
  [anon_sym_sstore] = anon_sym_sstore,
  [anon_sym_msize] = anon_sym_msize,
  [anon_sym_gas] = anon_sym_gas,
  [anon_sym_address] = anon_sym_address,
  [anon_sym_balance] = anon_sym_balance,
  [anon_sym_selfbalance] = anon_sym_selfbalance,
  [anon_sym_caller] = anon_sym_caller,
  [anon_sym_callvalue] = anon_sym_callvalue,
  [anon_sym_calldataload] = anon_sym_calldataload,
  [anon_sym_calldatasize] = anon_sym_calldatasize,
  [anon_sym_calldatacopy] = anon_sym_calldatacopy,
  [anon_sym_extcodesize] = anon_sym_extcodesize,
  [anon_sym_extcodecopy] = anon_sym_extcodecopy,
  [anon_sym_returndatasize] = anon_sym_returndatasize,
  [anon_sym_returndatacopy] = anon_sym_returndatacopy,
  [anon_sym_extcodehash] = anon_sym_extcodehash,
  [anon_sym_create] = anon_sym_create,
  [anon_sym_create2] = anon_sym_create2,
  [anon_sym_call] = anon_sym_call,
  [anon_sym_callcode] = anon_sym_callcode,
  [anon_sym_delegatecall] = anon_sym_delegatecall,
  [anon_sym_staticcall] = anon_sym_staticcall,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_revert] = anon_sym_revert,
  [anon_sym_selfdestruct] = anon_sym_selfdestruct,
  [anon_sym_invalid] = anon_sym_invalid,
  [anon_sym_log0] = anon_sym_log0,
  [anon_sym_log1] = anon_sym_log1,
  [anon_sym_log2] = anon_sym_log2,
  [anon_sym_log3] = anon_sym_log3,
  [anon_sym_log4] = anon_sym_log4,
  [anon_sym_chainid] = anon_sym_chainid,
  [anon_sym_origin] = anon_sym_origin,
  [anon_sym_gasprice] = anon_sym_gasprice,
  [anon_sym_blockhash] = anon_sym_blockhash,
  [anon_sym_coinbase] = anon_sym_coinbase,
  [anon_sym_timestamp] = anon_sym_timestamp,
  [anon_sym_number] = anon_sym_number,
  [anon_sym_difficulty] = anon_sym_difficulty,
  [anon_sym_gaslimit] = anon_sym_gaslimit,
  [sym__unchecked] = sym__unchecked,
  [anon_sym_memory] = anon_sym_memory,
  [anon_sym_storage] = anon_sym_storage,
  [anon_sym_calldata] = anon_sym_calldata,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_returns] = anon_sym_returns,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_emit] = anon_sym_emit,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_internal] = anon_sym_internal,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_external] = anon_sym_external,
  [anon_sym_pure] = anon_sym_pure,
  [anon_sym_view] = anon_sym_view,
  [anon_sym_payable] = anon_sym_payable,
  [sym_immutable] = sym_immutable,
  [anon_sym_override] = anon_sym_override,
  [anon_sym_modifier] = anon_sym_modifier,
  [anon_sym_constructor] = anon_sym_constructor,
  [anon_sym_fallback] = anon_sym_fallback,
  [anon_sym_receive] = anon_sym_receive,
  [sym_virtual] = sym_virtual,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_GT_GT_GT] = anon_sym_GT_GT_GT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_BANG_EQ_EQ] = anon_sym_BANG_EQ_EQ,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_delete] = anon_sym_delete,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_GT_GT_GT_EQ] = anon_sym_GT_GT_GT_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_mapping] = anon_sym_mapping,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_bool] = anon_sym_bool,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_int8] = anon_sym_int8,
  [anon_sym_int16] = anon_sym_int16,
  [anon_sym_int24] = anon_sym_int24,
  [anon_sym_int32] = anon_sym_int32,
  [anon_sym_int40] = anon_sym_int40,
  [anon_sym_int48] = anon_sym_int48,
  [anon_sym_int56] = anon_sym_int56,
  [anon_sym_int64] = anon_sym_int64,
  [anon_sym_int72] = anon_sym_int72,
  [anon_sym_int80] = anon_sym_int80,
  [anon_sym_int88] = anon_sym_int88,
  [anon_sym_int96] = anon_sym_int96,
  [anon_sym_int104] = anon_sym_int104,
  [anon_sym_int112] = anon_sym_int112,
  [anon_sym_int120] = anon_sym_int120,
  [anon_sym_int128] = anon_sym_int128,
  [anon_sym_int136] = anon_sym_int136,
  [anon_sym_int144] = anon_sym_int144,
  [anon_sym_int152] = anon_sym_int152,
  [anon_sym_int160] = anon_sym_int160,
  [anon_sym_int168] = anon_sym_int168,
  [anon_sym_int176] = anon_sym_int176,
  [anon_sym_int184] = anon_sym_int184,
  [anon_sym_int192] = anon_sym_int192,
  [anon_sym_int200] = anon_sym_int200,
  [anon_sym_int208] = anon_sym_int208,
  [anon_sym_int216] = anon_sym_int216,
  [anon_sym_int224] = anon_sym_int224,
  [anon_sym_int232] = anon_sym_int232,
  [anon_sym_int240] = anon_sym_int240,
  [anon_sym_int248] = anon_sym_int248,
  [anon_sym_int256] = anon_sym_int256,
  [anon_sym_uint] = anon_sym_uint,
  [anon_sym_uint8] = anon_sym_uint8,
  [anon_sym_uint16] = anon_sym_uint16,
  [anon_sym_uint24] = anon_sym_uint24,
  [anon_sym_uint32] = anon_sym_uint32,
  [anon_sym_uint40] = anon_sym_uint40,
  [anon_sym_uint48] = anon_sym_uint48,
  [anon_sym_uint56] = anon_sym_uint56,
  [anon_sym_uint64] = anon_sym_uint64,
  [anon_sym_uint72] = anon_sym_uint72,
  [anon_sym_uint80] = anon_sym_uint80,
  [anon_sym_uint88] = anon_sym_uint88,
  [anon_sym_uint96] = anon_sym_uint96,
  [anon_sym_uint104] = anon_sym_uint104,
  [anon_sym_uint112] = anon_sym_uint112,
  [anon_sym_uint120] = anon_sym_uint120,
  [anon_sym_uint128] = anon_sym_uint128,
  [anon_sym_uint136] = anon_sym_uint136,
  [anon_sym_uint144] = anon_sym_uint144,
  [anon_sym_uint152] = anon_sym_uint152,
  [anon_sym_uint160] = anon_sym_uint160,
  [anon_sym_uint168] = anon_sym_uint168,
  [anon_sym_uint176] = anon_sym_uint176,
  [anon_sym_uint184] = anon_sym_uint184,
  [anon_sym_uint192] = anon_sym_uint192,
  [anon_sym_uint200] = anon_sym_uint200,
  [anon_sym_uint208] = anon_sym_uint208,
  [anon_sym_uint216] = anon_sym_uint216,
  [anon_sym_uint224] = anon_sym_uint224,
  [anon_sym_uint232] = anon_sym_uint232,
  [anon_sym_uint240] = anon_sym_uint240,
  [anon_sym_uint248] = anon_sym_uint248,
  [anon_sym_uint256] = anon_sym_uint256,
  [anon_sym_bytes] = anon_sym_bytes,
  [anon_sym_bytes1] = anon_sym_bytes1,
  [anon_sym_bytes2] = anon_sym_bytes2,
  [anon_sym_bytes3] = anon_sym_bytes3,
  [anon_sym_bytes4] = anon_sym_bytes4,
  [anon_sym_bytes5] = anon_sym_bytes5,
  [anon_sym_bytes6] = anon_sym_bytes6,
  [anon_sym_bytes7] = anon_sym_bytes7,
  [anon_sym_bytes8] = anon_sym_bytes8,
  [anon_sym_bytes9] = anon_sym_bytes9,
  [anon_sym_bytes10] = anon_sym_bytes10,
  [anon_sym_bytes11] = anon_sym_bytes11,
  [anon_sym_bytes12] = anon_sym_bytes12,
  [anon_sym_bytes13] = anon_sym_bytes13,
  [anon_sym_bytes14] = anon_sym_bytes14,
  [anon_sym_bytes15] = anon_sym_bytes15,
  [anon_sym_bytes16] = anon_sym_bytes16,
  [anon_sym_bytes17] = anon_sym_bytes17,
  [anon_sym_bytes18] = anon_sym_bytes18,
  [anon_sym_bytes19] = anon_sym_bytes19,
  [anon_sym_bytes20] = anon_sym_bytes20,
  [anon_sym_bytes21] = anon_sym_bytes21,
  [anon_sym_bytes22] = anon_sym_bytes22,
  [anon_sym_bytes23] = anon_sym_bytes23,
  [anon_sym_bytes24] = anon_sym_bytes24,
  [anon_sym_bytes25] = anon_sym_bytes25,
  [anon_sym_bytes26] = anon_sym_bytes26,
  [anon_sym_bytes27] = anon_sym_bytes27,
  [anon_sym_bytes28] = anon_sym_bytes28,
  [anon_sym_bytes29] = anon_sym_bytes29,
  [anon_sym_bytes30] = anon_sym_bytes30,
  [anon_sym_bytes31] = anon_sym_bytes31,
  [anon_sym_bytes32] = anon_sym_bytes32,
  [anon_sym_fixed] = anon_sym_fixed,
  [aux_sym__fixed_token1] = aux_sym__fixed_token1,
  [anon_sym_ufixed] = anon_sym_ufixed,
  [aux_sym__ufixed_token1] = aux_sym__ufixed_token1,
  [sym__semicolon] = sym__semicolon,
  [aux_sym__decimal_number_token1] = aux_sym__decimal_number_token1,
  [aux_sym__decimal_number_token2] = aux_sym__decimal_number_token2,
  [aux_sym__hex_number_token1] = aux_sym__hex_number_token1,
  [sym__hex_digit] = sym__hex_digit,
  [anon_sym_wei] = anon_sym_wei,
  [anon_sym_szabo] = anon_sym_szabo,
  [anon_sym_finney] = anon_sym_finney,
  [anon_sym_gwei] = anon_sym_gwei,
  [anon_sym_ether] = anon_sym_ether,
  [anon_sym_seconds] = anon_sym_seconds,
  [anon_sym_minutes] = anon_sym_minutes,
  [anon_sym_hours] = anon_sym_hours,
  [anon_sym_days] = anon_sym_days,
  [anon_sym_weeks] = anon_sym_weeks,
  [anon_sym_years] = anon_sym_years,
  [anon_sym_hex] = anon_sym_hex,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym__] = anon_sym__,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym__escape_sequence] = sym__escape_sequence,
  [aux_sym__single_quoted_unicode_char_token1] = aux_sym__single_quoted_unicode_char_token1,
  [aux_sym__double_quoted_unicode_char_token1] = aux_sym__double_quoted_unicode_char_token1,
  [anon_sym_unicode] = anon_sym_unicode,
  [sym_comment] = sym_comment,
  [sym_source_file] = sym_source_file,
  [sym__source_unit] = sym__source_unit,
  [sym__directive] = sym__directive,
  [sym_pragma_directive] = sym_pragma_directive,
  [sym_solidity_pragma_token] = sym_solidity_pragma_token,
  [sym_any_pragma_token] = sym_any_pragma_token,
  [sym__solidity] = sym__solidity,
  [sym_pragma_value] = sym_pragma_value,
  [sym__pragma_version_constraint] = sym__pragma_version_constraint,
  [sym_solidity_version_comparison_operator] = sym_solidity_version_comparison_operator,
  [sym_import_directive] = sym_import_directive,
  [sym__source_import] = sym__source_import,
  [sym__import_clause] = sym__import_clause,
  [sym__from_clause] = sym__from_clause,
  [sym__single_import] = sym__single_import,
  [sym__multiple_import] = sym__multiple_import,
  [sym__import_declaration] = sym__import_declaration,
  [sym__import_alias] = sym__import_alias,
  [sym__declaration] = sym__declaration,
  [sym_user_defined_type_definition] = sym_user_defined_type_definition,
  [sym_constant_variable_declaration] = sym_constant_variable_declaration,
  [sym_contract_declaration] = sym_contract_declaration,
  [sym_error_declaration] = sym_error_declaration,
  [sym_error_parameter] = sym_error_parameter,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_library_declaration] = sym_library_declaration,
  [sym__class_heritage] = sym__class_heritage,
  [sym_inheritance_specifier] = sym_inheritance_specifier,
  [sym_contract_body] = sym_contract_body,
  [sym__contract_member] = sym__contract_member,
  [sym_struct_declaration] = sym_struct_declaration,
  [sym_struct_member] = sym_struct_member,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_event_definition] = sym_event_definition,
  [sym__event_parameter_list] = sym__event_parameter_list,
  [sym_event_paramater] = sym_event_paramater,
  [sym_using_directive] = sym_using_directive,
  [sym_any_source_type] = sym_any_source_type,
  [sym_user_definable_operator] = sym_user_definable_operator,
  [sym__statement] = sym__statement,
  [sym_assembly_statement] = sym_assembly_statement,
  [sym__assembly_flags] = sym__assembly_flags,
  [sym__yul_statement] = sym__yul_statement,
  [sym_yul_label] = sym_yul_label,
  [sym_yul_break] = sym_yul_break,
  [sym_yul_continue] = sym_yul_continue,
  [sym_yul_identifier] = sym_yul_identifier,
  [sym__yul_expression] = sym__yul_expression,
  [sym_yul_path] = sym_yul_path,
  [sym__yul_literal] = sym__yul_literal,
  [sym_yul_string_literal] = sym_yul_string_literal,
  [sym_yul_boolean] = sym_yul_boolean,
  [sym_yul_block] = sym_yul_block,
  [sym_yul_variable_declaration] = sym_yul_variable_declaration,
  [sym__yul_assignment_operator] = sym__yul_assignment_operator,
  [sym_yul_assignment] = sym_yul_assignment,
  [sym_yul_function_call] = sym_yul_function_call,
  [sym_yul_if_statement] = sym_yul_if_statement,
  [sym_yul_for_statement] = sym_yul_for_statement,
  [sym_yul_switch_statement] = sym_yul_switch_statement,
  [sym_yul_function_definition] = sym_yul_function_definition,
  [sym_yul_evm_builtin] = sym_yul_evm_builtin,
  [sym_block_statement] = sym_block_statement,
  [sym_variable_declaration_statement] = sym_variable_declaration_statement,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_variable_declaration_tuple] = sym_variable_declaration_tuple,
  [sym_expression_statement] = sym_expression_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_do_while_statement] = sym_do_while_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_revert_statement] = sym_revert_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_catch_clause] = sym_catch_clause,
  [sym_return_statement] = sym_return_statement,
  [sym_emit_statement] = sym_emit_statement,
  [sym_state_variable_declaration] = sym_state_variable_declaration,
  [sym_visibility] = sym_visibility,
  [sym_state_mutability] = sym_state_mutability,
  [sym_override_specifier] = sym_override_specifier,
  [sym_modifier_definition] = sym_modifier_definition,
  [sym_constructor_definition] = sym_constructor_definition,
  [sym_fallback_definition] = sym_fallback_definition,
  [sym_receive_definition] = sym_receive_definition,
  [sym_function_definition] = sym_function_definition,
  [sym_return_type_definition] = sym_return_type_definition,
  [sym_modifier_invocation] = sym_modifier_invocation,
  [sym__call_arguments] = sym__call_arguments,
  [sym_call_argument] = sym_call_argument,
  [sym_call_struct_argument] = sym_call_struct_argument,
  [sym_function_body] = sym_function_body,
  [sym__expression] = sym__expression,
  [sym__primary_expression] = sym__primary_expression,
  [sym_type_cast_expression] = sym_type_cast_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_new_expression] = sym_new_expression,
  [sym_tuple_expression] = sym_tuple_expression,
  [sym_inline_array_expression] = sym_inline_array_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_member_expression] = sym_member_expression,
  [sym_array_access] = sym_array_access,
  [sym_slice_access] = sym_slice_access,
  [sym_struct_expression] = sym_struct_expression,
  [sym_struct_field_assignment] = sym_struct_field_assignment,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_augmented_assignment_expression] = sym_augmented_assignment_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_payable_conversion_expression] = sym_payable_conversion_expression,
  [sym_meta_type_expression] = sym_meta_type_expression,
  [sym_type_name] = sym_type_name,
  [sym__array_type] = sym__array_type,
  [sym__function_type] = sym__function_type,
  [sym__parameter_list] = sym__parameter_list,
  [sym__return_parameters] = sym__return_parameters,
  [sym__nameless_parameter] = sym__nameless_parameter,
  [sym_parameter] = sym_parameter,
  [sym__storage_location] = sym__storage_location,
  [sym_user_defined_type] = sym_user_defined_type,
  [sym__identifier_path] = sym__identifier_path,
  [sym__mapping] = sym__mapping,
  [sym__mapping_key] = sym__mapping_key,
  [sym_primitive_type] = sym_primitive_type,
  [sym__int] = sym__int,
  [sym__uint] = sym__uint,
  [sym__bytes] = sym__bytes,
  [sym__fixed] = sym__fixed,
  [sym__ufixed] = sym__ufixed,
  [sym__literal] = sym__literal,
  [sym_string_literal] = sym_string_literal,
  [sym_number_literal] = sym_number_literal,
  [sym__decimal_number] = sym__decimal_number,
  [sym__hex_number] = sym__hex_number,
  [sym_number_unit] = sym_number_unit,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym_hex_string_literal] = sym_hex_string_literal,
  [sym__single_quoted_unicode_char] = sym__single_quoted_unicode_char,
  [sym__double_quoted_unicode_char] = sym__double_quoted_unicode_char,
  [sym_unicode_string_literal] = sym_unicode_string_literal,
  [sym_string] = sym_string,
  [sym__string_immediate_elt_inside_double_quote] = sym__string_immediate_elt_inside_double_quote,
  [sym__string_immediate_elt_inside_quote] = sym__string_immediate_elt_inside_quote,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_solidity_pragma_token_repeat1] = aux_sym_solidity_pragma_token_repeat1,
  [aux_sym__multiple_import_repeat1] = aux_sym__multiple_import_repeat1,
  [aux_sym_error_declaration_repeat1] = aux_sym_error_declaration_repeat1,
  [aux_sym__class_heritage_repeat1] = aux_sym__class_heritage_repeat1,
  [aux_sym_contract_body_repeat1] = aux_sym_contract_body_repeat1,
  [aux_sym_struct_declaration_repeat1] = aux_sym_struct_declaration_repeat1,
  [aux_sym_enum_declaration_repeat1] = aux_sym_enum_declaration_repeat1,
  [aux_sym__event_parameter_list_repeat1] = aux_sym__event_parameter_list_repeat1,
  [aux_sym_using_directive_repeat1] = aux_sym_using_directive_repeat1,
  [aux_sym_assembly_statement_repeat1] = aux_sym_assembly_statement_repeat1,
  [aux_sym__assembly_flags_repeat1] = aux_sym__assembly_flags_repeat1,
  [aux_sym_yul_path_repeat1] = aux_sym_yul_path_repeat1,
  [aux_sym_yul_variable_declaration_repeat1] = aux_sym_yul_variable_declaration_repeat1,
  [aux_sym_yul_assignment_repeat1] = aux_sym_yul_assignment_repeat1,
  [aux_sym_yul_function_call_repeat1] = aux_sym_yul_function_call_repeat1,
  [aux_sym_yul_switch_statement_repeat1] = aux_sym_yul_switch_statement_repeat1,
  [aux_sym_block_statement_repeat1] = aux_sym_block_statement_repeat1,
  [aux_sym_variable_declaration_tuple_repeat1] = aux_sym_variable_declaration_tuple_repeat1,
  [aux_sym_variable_declaration_tuple_repeat2] = aux_sym_variable_declaration_tuple_repeat2,
  [aux_sym_try_statement_repeat1] = aux_sym_try_statement_repeat1,
  [aux_sym_state_variable_declaration_repeat1] = aux_sym_state_variable_declaration_repeat1,
  [aux_sym_override_specifier_repeat1] = aux_sym_override_specifier_repeat1,
  [aux_sym_modifier_definition_repeat1] = aux_sym_modifier_definition_repeat1,
  [aux_sym_constructor_definition_repeat1] = aux_sym_constructor_definition_repeat1,
  [aux_sym_fallback_definition_repeat1] = aux_sym_fallback_definition_repeat1,
  [aux_sym_receive_definition_repeat1] = aux_sym_receive_definition_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym__call_arguments_repeat1] = aux_sym__call_arguments_repeat1,
  [aux_sym_call_argument_repeat1] = aux_sym_call_argument_repeat1,
  [aux_sym_tuple_expression_repeat1] = aux_sym_tuple_expression_repeat1,
  [aux_sym_inline_array_expression_repeat1] = aux_sym_inline_array_expression_repeat1,
  [aux_sym_struct_expression_repeat1] = aux_sym_struct_expression_repeat1,
  [aux_sym__function_type_repeat1] = aux_sym__function_type_repeat1,
  [aux_sym__parameter_list_repeat1] = aux_sym__parameter_list_repeat1,
  [aux_sym__return_parameters_repeat1] = aux_sym__return_parameters_repeat1,
  [aux_sym__identifier_path_repeat1] = aux_sym__identifier_path_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym_hex_string_literal_repeat1] = aux_sym_hex_string_literal_repeat1,
  [aux_sym_hex_string_literal_repeat2] = aux_sym_hex_string_literal_repeat2,
  [aux_sym_unicode_string_literal_repeat1] = aux_sym_unicode_string_literal_repeat1,
  [aux_sym_unicode_string_literal_repeat2] = aux_sym_unicode_string_literal_repeat2,
  [aux_sym_unicode_string_literal_repeat3] = aux_sym_unicode_string_literal_repeat3,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_string_repeat2] = aux_sym_string_repeat2,
  [alias_sym_enum_value] = alias_sym_enum_value,
  [alias_sym_revert_arguments] = alias_sym_revert_arguments,
  [alias_sym_type_alias] = alias_sym_type_alias,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_pragma] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_solidity] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_pragma_value_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_solidity_version] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constant] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abstract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_contract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_error] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_library] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_event] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_anonymous] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_indexed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assembly] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEevmasm_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_yul_leave] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [sym_yul_decimal_number] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_hex_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_stop] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_add] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sub] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mul] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_div] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sdiv] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_smod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_slt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sgt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_iszero] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_byte] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_shl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_shr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sar] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_addmod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mulmod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_signextend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_keccak256] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pop] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mload] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mstore] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mstore8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sload] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sstore] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_msize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gas] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_address] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_balance] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_selfbalance] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_caller] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_callvalue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_calldataload] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_calldatasize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_calldatacopy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extcodesize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extcodecopy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_returndatasize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_returndatacopy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extcodehash] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_create] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_create2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_call] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_callcode] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delegatecall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_staticcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_revert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_selfdestruct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_invalid] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_log0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_log1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_log2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_log3] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_log4] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_chainid] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_origin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gasprice] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_blockhash] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_coinbase] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_timestamp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_number] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_difficulty] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gaslimit] = {
    .visible = true,
    .named = false,
  },
  [sym__unchecked] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_memory] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_storage] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_calldata] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_returns] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_emit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_internal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_external] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pure] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_view] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_payable] = {
    .visible = true,
    .named = false,
  },
  [sym_immutable] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_modifier] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constructor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fallback] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_receive] = {
    .visible = true,
    .named = false,
  },
  [sym_virtual] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mapping] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int16] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int24] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int32] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int40] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int48] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int56] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int64] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int72] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int80] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int88] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int96] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int104] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int112] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int120] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int128] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int136] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int144] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int152] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int160] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int168] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int176] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int184] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int192] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int200] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int208] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int216] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int224] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int232] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int240] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int248] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int256] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint16] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint24] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint32] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint40] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint48] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint56] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint64] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint72] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint80] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint88] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint96] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint104] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint112] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint120] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint128] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint136] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint144] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint152] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint160] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint168] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint176] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint184] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint192] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint200] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint208] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint216] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint224] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint232] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint240] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint248] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint256] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes3] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes4] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes5] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes6] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes7] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes9] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes10] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes11] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes12] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes13] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes14] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes15] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes16] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes17] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes18] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes19] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes20] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes21] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes22] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes23] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes24] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes25] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes26] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes27] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes28] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes29] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes30] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes31] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bytes32] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fixed] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__fixed_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_ufixed] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__ufixed_token1] = {
    .visible = false,
    .named = false,
  },
  [sym__semicolon] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__decimal_number_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__decimal_number_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hex_number_token1] = {
    .visible = false,
    .named = false,
  },
  [sym__hex_digit] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_wei] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_szabo] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finney] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gwei] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ether] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_seconds] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_minutes] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_hours] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_days] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_weeks] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_years] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_hex] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__escape_sequence] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__single_quoted_unicode_char_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__double_quoted_unicode_char_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_unicode] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym__source_unit] = {
    .visible = false,
    .named = true,
  },
  [sym__directive] = {
    .visible = false,
    .named = true,
  },
  [sym_pragma_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_solidity_pragma_token] = {
    .visible = true,
    .named = true,
  },
  [sym_any_pragma_token] = {
    .visible = true,
    .named = true,
  },
  [sym__solidity] = {
    .visible = false,
    .named = true,
  },
  [sym_pragma_value] = {
    .visible = true,
    .named = true,
  },
  [sym__pragma_version_constraint] = {
    .visible = false,
    .named = true,
  },
  [sym_solidity_version_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_import_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__source_import] = {
    .visible = false,
    .named = true,
  },
  [sym__import_clause] = {
    .visible = false,
    .named = true,
  },
  [sym__from_clause] = {
    .visible = false,
    .named = true,
  },
  [sym__single_import] = {
    .visible = false,
    .named = true,
  },
  [sym__multiple_import] = {
    .visible = false,
    .named = true,
  },
  [sym__import_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym__import_alias] = {
    .visible = false,
    .named = true,
  },
  [sym__declaration] = {
    .visible = false,
    .named = true,
  },
  [sym_user_defined_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_contract_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_error_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_error_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_library_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__class_heritage] = {
    .visible = false,
    .named = true,
  },
  [sym_inheritance_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_contract_body] = {
    .visible = true,
    .named = true,
  },
  [sym__contract_member] = {
    .visible = false,
    .named = true,
  },
  [sym_struct_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_member] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_event_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__event_parameter_list] = {
    .visible = false,
    .named = true,
  },
  [sym_event_paramater] = {
    .visible = true,
    .named = true,
  },
  [sym_using_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_any_source_type] = {
    .visible = true,
    .named = true,
  },
  [sym_user_definable_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym_assembly_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__assembly_flags] = {
    .visible = false,
    .named = true,
  },
  [sym__yul_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_yul_label] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_break] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_continue] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__yul_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_yul_path] = {
    .visible = true,
    .named = true,
  },
  [sym__yul_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_yul_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_block] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__yul_assignment_operator] = {
    .visible = false,
    .named = true,
  },
  [sym_yul_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_yul_evm_builtin] = {
    .visible = true,
    .named = true,
  },
  [sym_block_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration_tuple] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_revert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_emit_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_state_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_visibility] = {
    .visible = true,
    .named = true,
  },
  [sym_state_mutability] = {
    .visible = true,
    .named = true,
  },
  [sym_override_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_modifier_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_fallback_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_receive_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_return_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_modifier_invocation] = {
    .visible = true,
    .named = true,
  },
  [sym__call_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_call_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_call_struct_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_function_body] = {
    .visible = true,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym__primary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_type_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_array_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_access] = {
    .visible = true,
    .named = true,
  },
  [sym_slice_access] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_field_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_augmented_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_payable_conversion_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_meta_type_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_name] = {
    .visible = true,
    .named = true,
  },
  [sym__array_type] = {
    .visible = false,
    .named = true,
  },
  [sym__function_type] = {
    .visible = false,
    .named = true,
  },
  [sym__parameter_list] = {
    .visible = false,
    .named = true,
  },
  [sym__return_parameters] = {
    .visible = false,
    .named = true,
  },
  [sym__nameless_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__storage_location] = {
    .visible = false,
    .named = true,
  },
  [sym_user_defined_type] = {
    .visible = true,
    .named = true,
  },
  [sym__identifier_path] = {
    .visible = false,
    .named = true,
  },
  [sym__mapping] = {
    .visible = false,
    .named = true,
  },
  [sym__mapping_key] = {
    .visible = false,
    .named = true,
  },
  [sym_primitive_type] = {
    .visible = true,
    .named = true,
  },
  [sym__int] = {
    .visible = false,
    .named = true,
  },
  [sym__uint] = {
    .visible = false,
    .named = true,
  },
  [sym__bytes] = {
    .visible = false,
    .named = true,
  },
  [sym__fixed] = {
    .visible = false,
    .named = true,
  },
  [sym__ufixed] = {
    .visible = false,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_number_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__decimal_number] = {
    .visible = false,
    .named = true,
  },
  [sym__hex_number] = {
    .visible = false,
    .named = true,
  },
  [sym_number_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_hex_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quoted_unicode_char] = {
    .visible = false,
    .named = true,
  },
  [sym__double_quoted_unicode_char] = {
    .visible = false,
    .named = true,
  },
  [sym_unicode_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym__string_immediate_elt_inside_double_quote] = {
    .visible = false,
    .named = true,
  },
  [sym__string_immediate_elt_inside_quote] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_solidity_pragma_token_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__multiple_import_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_error_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__class_heritage_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_contract_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__event_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_using_directive_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assembly_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__assembly_flags_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_yul_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_yul_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_yul_assignment_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_yul_function_call_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_yul_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_tuple_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_tuple_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_override_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modifier_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constructor_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fallback_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_receive_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__call_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_call_argument_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inline_array_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__return_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__identifier_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hex_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hex_string_literal_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_unicode_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_unicode_string_literal_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_unicode_string_literal_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat2] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_enum_value] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_revert_arguments] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_alias] = {
    .visible = true,
    .named = true,
  },
};

enum {
  field_alias = 1,
  field_ancestor = 2,
  field_ancestor_arguments = 3,
  field_argument = 4,
  field_attempt = 5,
  field_base = 6,
  field_body = 7,
  field_condition = 8,
  field_else = 9,
  field_error = 10,
  field_flags = 11,
  field_from = 12,
  field_function = 13,
  field_import_name = 14,
  field_index = 15,
  field_initial = 16,
  field_key_name = 17,
  field_key_type = 18,
  field_left = 19,
  field_location = 20,
  field_name = 21,
  field_object = 22,
  field_operator = 23,
  field_parameters = 24,
  field_property = 25,
  field_return_type = 26,
  field_right = 27,
  field_source = 28,
  field_state_mutability = 29,
  field_to = 30,
  field_type = 31,
  field_update = 32,
  field_value = 33,
  field_value_name = 34,
  field_value_type = 35,
  field_version_constraint = 36,
  field_visibility = 37,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_ancestor] = "ancestor",
  [field_ancestor_arguments] = "ancestor_arguments",
  [field_argument] = "argument",
  [field_attempt] = "attempt",
  [field_base] = "base",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_else] = "else",
  [field_error] = "error",
  [field_flags] = "flags",
  [field_from] = "from",
  [field_function] = "function",
  [field_import_name] = "import_name",
  [field_index] = "index",
  [field_initial] = "initial",
  [field_key_name] = "key_name",
  [field_key_type] = "key_type",
  [field_left] = "left",
  [field_location] = "location",
  [field_name] = "name",
  [field_object] = "object",
  [field_operator] = "operator",
  [field_parameters] = "parameters",
  [field_property] = "property",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_source] = "source",
  [field_state_mutability] = "state_mutability",
  [field_to] = "to",
  [field_type] = "type",
  [field_update] = "update",
  [field_value] = "value",
  [field_value_name] = "value_name",
  [field_value_type] = "value_type",
  [field_version_constraint] = "version_constraint",
  [field_visibility] = "visibility",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 3},
  [2] = {.index = 3, .length = 4},
  [3] = {.index = 7, .length = 1},
  [4] = {.index = 8, .length = 2},
  [5] = {.index = 10, .length = 1},
  [6] = {.index = 11, .length = 1},
  [7] = {.index = 12, .length = 1},
  [8] = {.index = 13, .length = 1},
  [9] = {.index = 14, .length = 1},
  [10] = {.index = 15, .length = 2},
  [11] = {.index = 17, .length = 2},
  [12] = {.index = 19, .length = 2},
  [13] = {.index = 21, .length = 2},
  [14] = {.index = 23, .length = 1},
  [15] = {.index = 24, .length = 1},
  [16] = {.index = 25, .length = 1},
  [17] = {.index = 26, .length = 3},
  [18] = {.index = 29, .length = 2},
  [19] = {.index = 31, .length = 1},
  [20] = {.index = 32, .length = 2},
  [21] = {.index = 34, .length = 1},
  [22] = {.index = 35, .length = 3},
  [23] = {.index = 38, .length = 2},
  [24] = {.index = 40, .length = 1},
  [25] = {.index = 41, .length = 2},
  [26] = {.index = 43, .length = 1},
  [27] = {.index = 44, .length = 2},
  [28] = {.index = 46, .length = 2},
  [29] = {.index = 48, .length = 4},
  [30] = {.index = 52, .length = 2},
  [31] = {.index = 54, .length = 2},
  [32] = {.index = 56, .length = 1},
  [33] = {.index = 57, .length = 4},
  [34] = {.index = 61, .length = 4},
  [35] = {.index = 65, .length = 2},
  [36] = {.index = 67, .length = 2},
  [37] = {.index = 43, .length = 1},
  [39] = {.index = 69, .length = 2},
  [40] = {.index = 71, .length = 1},
  [41] = {.index = 72, .length = 3},
  [42] = {.index = 75, .length = 2},
  [43] = {.index = 77, .length = 3},
  [44] = {.index = 80, .length = 3},
  [45] = {.index = 83, .length = 4},
  [46] = {.index = 87, .length = 2},
  [47] = {.index = 89, .length = 3},
  [48] = {.index = 92, .length = 2},
  [49] = {.index = 94, .length = 1},
  [50] = {.index = 95, .length = 1},
  [51] = {.index = 96, .length = 2},
  [53] = {.index = 98, .length = 4},
  [54] = {.index = 102, .length = 5},
  [55] = {.index = 107, .length = 2},
  [56] = {.index = 109, .length = 2},
  [57] = {.index = 111, .length = 3},
  [58] = {.index = 114, .length = 2},
  [59] = {.index = 116, .length = 1},
  [60] = {.index = 117, .length = 1},
  [61] = {.index = 118, .length = 2},
  [62] = {.index = 120, .length = 2},
  [63] = {.index = 122, .length = 3},
  [64] = {.index = 125, .length = 3},
  [65] = {.index = 128, .length = 1},
  [66] = {.index = 129, .length = 1},
  [68] = {.index = 130, .length = 1},
  [69] = {.index = 131, .length = 2},
  [70] = {.index = 133, .length = 3},
  [71] = {.index = 136, .length = 3},
  [72] = {.index = 139, .length = 2},
  [73] = {.index = 141, .length = 2},
  [74] = {.index = 143, .length = 2},
  [75] = {.index = 145, .length = 2},
  [76] = {.index = 147, .length = 3},
  [77] = {.index = 150, .length = 4},
  [78] = {.index = 154, .length = 1},
  [79] = {.index = 155, .length = 2},
  [80] = {.index = 157, .length = 3},
  [81] = {.index = 160, .length = 1},
  [82] = {.index = 161, .length = 2},
  [83] = {.index = 163, .length = 1},
  [84] = {.index = 164, .length = 1},
  [85] = {.index = 130, .length = 1},
  [86] = {.index = 165, .length = 2},
  [87] = {.index = 167, .length = 1},
  [88] = {.index = 168, .length = 4},
  [89] = {.index = 172, .length = 3},
  [90] = {.index = 175, .length = 2},
  [91] = {.index = 177, .length = 4},
  [92] = {.index = 181, .length = 2},
  [93] = {.index = 183, .length = 2},
  [94] = {.index = 185, .length = 2},
  [95] = {.index = 187, .length = 1},
  [96] = {.index = 188, .length = 2},
  [97] = {.index = 190, .length = 1},
  [98] = {.index = 191, .length = 2},
  [99] = {.index = 193, .length = 3},
  [100] = {.index = 196, .length = 3},
  [101] = {.index = 199, .length = 3},
  [102] = {.index = 202, .length = 2},
  [103] = {.index = 204, .length = 2},
  [104] = {.index = 206, .length = 3},
  [105] = {.index = 209, .length = 4},
  [106] = {.index = 213, .length = 4},
  [107] = {.index = 217, .length = 3},
  [108] = {.index = 220, .length = 4},
  [109] = {.index = 224, .length = 2},
  [110] = {.index = 226, .length = 4},
  [111] = {.index = 230, .length = 5},
  [112] = {.index = 235, .length = 5},
  [113] = {.index = 240, .length = 6},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_parameters, 0, .inherited = true},
    {field_state_mutability, 0, .inherited = true},
    {field_visibility, 0, .inherited = true},
  [3] =
    {field_key_name, 0, .inherited = true},
    {field_key_type, 0, .inherited = true},
    {field_value_name, 0, .inherited = true},
    {field_value_type, 0, .inherited = true},
  [7] =
    {field_import_name, 0},
  [8] =
    {field_alias, 0, .inherited = true},
    {field_import_name, 0, .inherited = true},
  [10] =
    {field_source, 0},
  [11] =
    {field_parameters, 1},
  [12] =
    {field_version_constraint, 0},
  [13] =
    {field_version_constraint, 1, .inherited = true},
  [14] =
    {field_alias, 1, .inherited = true},
  [15] =
    {field_alias, 1, .inherited = true},
    {field_import_name, 0},
  [17] =
    {field_alias, 1, .inherited = true},
    {field_source, 1, .inherited = true},
  [19] =
    {field_alias, 1, .inherited = true},
    {field_source, 0},
  [21] =
    {field_body, 2},
    {field_name, 1},
  [23] =
    {field_type, 0},
  [24] =
    {field_visibility, 0},
  [25] =
    {field_state_mutability, 0},
  [26] =
    {field_parameters, 1},
    {field_state_mutability, 2, .inherited = true},
    {field_visibility, 2, .inherited = true},
  [29] =
    {field_version_constraint, 0, .inherited = true},
    {field_version_constraint, 1, .inherited = true},
  [31] =
    {field_alias, 1},
  [32] =
    {field_alias, 1, .inherited = true},
    {field_import_name, 1, .inherited = true},
  [34] =
    {field_source, 1},
  [35] =
    {field_alias, 1, .inherited = true},
    {field_import_name, 1, .inherited = true},
    {field_source, 2, .inherited = true},
  [38] =
    {field_body, 3},
    {field_name, 2},
  [40] =
    {field_ancestor, 0},
  [41] =
    {field_body, 3},
    {field_name, 1},
  [43] =
    {field_name, 1},
  [44] =
    {field_name, 1},
    {field_type, 0},
  [46] =
    {field_location, 1},
    {field_type, 0},
  [48] =
    {field_state_mutability, 0, .inherited = true},
    {field_state_mutability, 1, .inherited = true},
    {field_visibility, 0, .inherited = true},
    {field_visibility, 1, .inherited = true},
  [52] =
    {field_argument, 1},
    {field_operator, 0},
  [54] =
    {field_argument, 0},
    {field_operator, 1},
  [56] =
    {field_function, 0},
  [57] =
    {field_alias, 1, .inherited = true},
    {field_alias, 2, .inherited = true},
    {field_import_name, 1, .inherited = true},
    {field_import_name, 2, .inherited = true},
  [61] =
    {field_alias, 0, .inherited = true},
    {field_alias, 1, .inherited = true},
    {field_import_name, 0, .inherited = true},
    {field_import_name, 1, .inherited = true},
  [65] =
    {field_body, 4},
    {field_name, 2},
  [67] =
    {field_ancestor, 0},
    {field_ancestor_arguments, 1},
  [69] =
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
  [71] =
    {field_source, 3},
  [72] =
    {field_location, 1},
    {field_name, 2},
    {field_type, 0},
  [75] =
    {field_name, 1},
    {field_return_type, 3},
  [77] =
    {field_body, 4},
    {field_name, 1},
    {field_return_type, 3},
  [80] =
    {field_name, 1},
    {field_state_mutability, 3, .inherited = true},
    {field_visibility, 3, .inherited = true},
  [83] =
    {field_body, 4},
    {field_name, 1},
    {field_state_mutability, 3, .inherited = true},
    {field_visibility, 3, .inherited = true},
  [87] =
    {field_object, 0},
    {field_property, 2},
  [89] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [92] =
    {field_left, 0},
    {field_right, 2},
  [94] =
    {field_base, 0},
  [95] =
    {field_body, 2},
  [96] =
    {field_visibility, 0, .inherited = true},
    {field_visibility, 1, .inherited = true},
  [98] =
    {field_name, 1},
    {field_return_type, 4},
    {field_state_mutability, 3, .inherited = true},
    {field_visibility, 3, .inherited = true},
  [102] =
    {field_body, 5},
    {field_name, 1},
    {field_return_type, 4},
    {field_state_mutability, 3, .inherited = true},
    {field_visibility, 3, .inherited = true},
  [107] =
    {field_location, 2, .inherited = true},
    {field_type, 2, .inherited = true},
  [109] =
    {field_key_type, 2},
    {field_value_type, 4},
  [111] =
    {field_name, 2},
    {field_type, 0},
    {field_value, 4},
  [114] =
    {field_base, 0},
    {field_index, 2},
  [116] =
    {field_body, 3},
  [117] =
    {field_return_type, 2},
  [118] =
    {field_body, 3},
    {field_return_type, 2},
  [120] =
    {field_state_mutability, 2, .inherited = true},
    {field_visibility, 2, .inherited = true},
  [122] =
    {field_body, 3},
    {field_state_mutability, 2, .inherited = true},
    {field_visibility, 2, .inherited = true},
  [125] =
    {field_name, 2},
    {field_type, 0},
    {field_visibility, 1, .inherited = true},
  [128] =
    {field_operator, 3},
  [129] =
    {field_source, 5},
  [130] =
    {field_error, 1},
  [131] =
    {field_location, 1, .inherited = true},
    {field_type, 1, .inherited = true},
  [133] =
    {field_key_type, 2},
    {field_value_name, 5},
    {field_value_type, 4},
  [136] =
    {field_key_name, 3},
    {field_key_type, 2},
    {field_value_type, 5},
  [139] =
    {field_name, 0},
    {field_value, 2},
  [141] =
    {field_base, 0},
    {field_to, 3},
  [143] =
    {field_base, 0},
    {field_from, 2},
  [145] =
    {field_body, 4},
    {field_name, 1},
  [147] =
    {field_return_type, 3},
    {field_state_mutability, 2, .inherited = true},
    {field_visibility, 2, .inherited = true},
  [150] =
    {field_body, 4},
    {field_return_type, 3},
    {field_state_mutability, 2, .inherited = true},
    {field_visibility, 2, .inherited = true},
  [154] =
    {field_visibility, 3, .inherited = true},
  [155] =
    {field_body, 4},
    {field_visibility, 3, .inherited = true},
  [157] =
    {field_name, 1},
    {field_type, 0},
    {field_value, 3},
  [160] =
    {field_source, 6},
  [161] =
    {field_operator, 3, .inherited = true},
    {field_source, 6},
  [163] =
    {field_left, 1},
  [164] =
    {field_flags, 1},
  [165] =
    {field_attempt, 1},
    {field_body, 2},
  [167] =
    {field_value, 2},
  [168] =
    {field_key_name, 3},
    {field_key_type, 2},
    {field_value_name, 6},
    {field_value_type, 5},
  [172] =
    {field_base, 0},
    {field_from, 2},
    {field_to, 4},
  [175] =
    {field_name, 2},
    {field_type, 0},
  [177] =
    {field_name, 2},
    {field_type, 0},
    {field_value, 4},
    {field_visibility, 1, .inherited = true},
  [181] =
    {field_operator, 4},
    {field_source, 7},
  [183] =
    {field_operator, 3, .inherited = true},
    {field_source, 7},
  [185] =
    {field_left, 1},
    {field_left, 2},
  [187] =
    {field_flags, 2},
  [188] =
    {field_body, 4},
    {field_condition, 2},
  [190] =
    {field_body, 1},
  [191] =
    {field_operator, 4},
    {field_source, 8},
  [193] =
    {field_operator, 4},
    {field_operator, 5, .inherited = true},
    {field_source, 8},
  [196] =
    {field_body, 5},
    {field_condition, 3},
    {field_initial, 2},
  [199] =
    {field_left, 1},
    {field_left, 2},
    {field_left, 3},
  [202] =
    {field_left, 1},
    {field_right, 3},
  [204] =
    {field_attempt, 1},
    {field_body, 4},
  [206] =
    {field_operator, 4},
    {field_operator, 5, .inherited = true},
    {field_source, 9},
  [209] =
    {field_body, 6},
    {field_condition, 3},
    {field_initial, 2},
    {field_update, 4},
  [213] =
    {field_left, 1},
    {field_left, 2},
    {field_left, 3},
    {field_left, 4},
  [217] =
    {field_left, 1},
    {field_left, 2},
    {field_right, 4},
  [220] =
    {field_body, 4},
    {field_body, 6},
    {field_condition, 2},
    {field_else, 5},
  [224] =
    {field_body, 1},
    {field_condition, 4},
  [226] =
    {field_left, 1},
    {field_left, 2},
    {field_left, 3},
    {field_right, 5},
  [230] =
    {field_left, 1},
    {field_left, 2},
    {field_left, 3},
    {field_left, 4},
    {field_left, 5},
  [235] =
    {field_left, 1},
    {field_left, 2},
    {field_left, 3},
    {field_left, 4},
    {field_right, 6},
  [240] =
    {field_left, 1},
    {field_left, 2},
    {field_left, 3},
    {field_left, 4},
    {field_left, 5},
    {field_right, 7},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [37] = {
    [3] = alias_sym_enum_value,
  },
  [38] = {
    [1] = alias_sym_type_alias,
  },
  [40] = {
    [1] = alias_sym_type_alias,
  },
  [52] = {
    [1] = alias_sym_enum_value,
  },
  [65] = {
    [1] = alias_sym_type_alias,
  },
  [66] = {
    [2] = alias_sym_type_alias,
  },
  [67] = {
    [1] = alias_sym_revert_arguments,
  },
  [81] = {
    [2] = alias_sym_type_alias,
  },
  [82] = {
    [2] = alias_sym_type_alias,
  },
  [85] = {
    [2] = alias_sym_revert_arguments,
  },
  [92] = {
    [2] = alias_sym_type_alias,
  },
  [93] = {
    [2] = alias_sym_type_alias,
  },
  [98] = {
    [2] = alias_sym_type_alias,
  },
  [99] = {
    [2] = alias_sym_type_alias,
  },
  [104] = {
    [2] = alias_sym_type_alias,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__call_arguments, 2,
    sym__call_arguments,
    alias_sym_revert_arguments,
  sym_user_defined_type, 2,
    sym_user_defined_type,
    alias_sym_type_alias,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 5,
  [10] = 10,
  [11] = 10,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 111,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 117,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 116,
  [125] = 125,
  [126] = 119,
  [127] = 127,
  [128] = 128,
  [129] = 123,
  [130] = 130,
  [131] = 131,
  [132] = 128,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 125,
  [139] = 115,
  [140] = 140,
  [141] = 141,
  [142] = 141,
  [143] = 134,
  [144] = 114,
  [145] = 130,
  [146] = 127,
  [147] = 121,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 172,
  [217] = 175,
  [218] = 218,
  [219] = 190,
  [220] = 220,
  [221] = 200,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 198,
  [227] = 197,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 193,
  [234] = 199,
  [235] = 235,
  [236] = 153,
  [237] = 237,
  [238] = 189,
  [239] = 184,
  [240] = 212,
  [241] = 209,
  [242] = 242,
  [243] = 243,
  [244] = 210,
  [245] = 205,
  [246] = 161,
  [247] = 247,
  [248] = 191,
  [249] = 215,
  [250] = 195,
  [251] = 251,
  [252] = 204,
  [253] = 214,
  [254] = 213,
  [255] = 201,
  [256] = 256,
  [257] = 257,
  [258] = 187,
  [259] = 168,
  [260] = 206,
  [261] = 173,
  [262] = 183,
  [263] = 263,
  [264] = 207,
  [265] = 265,
  [266] = 194,
  [267] = 155,
  [268] = 268,
  [269] = 269,
  [270] = 169,
  [271] = 271,
  [272] = 163,
  [273] = 160,
  [274] = 165,
  [275] = 182,
  [276] = 166,
  [277] = 181,
  [278] = 278,
  [279] = 156,
  [280] = 180,
  [281] = 203,
  [282] = 171,
  [283] = 283,
  [284] = 185,
  [285] = 176,
  [286] = 179,
  [287] = 170,
  [288] = 288,
  [289] = 289,
  [290] = 289,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 413,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 370,
  [424] = 361,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 340,
  [429] = 429,
  [430] = 430,
  [431] = 344,
  [432] = 362,
  [433] = 377,
  [434] = 369,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 506,
  [507] = 507,
  [508] = 508,
  [509] = 509,
  [510] = 510,
  [511] = 511,
  [512] = 512,
  [513] = 513,
  [514] = 514,
  [515] = 515,
  [516] = 516,
  [517] = 517,
  [518] = 518,
  [519] = 519,
  [520] = 520,
  [521] = 521,
  [522] = 426,
  [523] = 523,
  [524] = 524,
  [525] = 524,
  [526] = 526,
  [527] = 526,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 531,
  [532] = 532,
  [533] = 531,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 537,
  [538] = 538,
  [539] = 539,
  [540] = 540,
  [541] = 541,
  [542] = 542,
  [543] = 543,
  [544] = 544,
  [545] = 545,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 553,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 559,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 567,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 574,
  [575] = 575,
  [576] = 576,
  [577] = 574,
  [578] = 578,
  [579] = 576,
  [580] = 580,
  [581] = 581,
  [582] = 582,
  [583] = 583,
  [584] = 578,
  [585] = 585,
  [586] = 586,
  [587] = 581,
  [588] = 588,
  [589] = 589,
  [590] = 590,
  [591] = 591,
  [592] = 592,
  [593] = 588,
  [594] = 592,
  [595] = 591,
  [596] = 596,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 600,
  [601] = 601,
  [602] = 602,
  [603] = 603,
  [604] = 604,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 614,
  [615] = 615,
  [616] = 589,
  [617] = 617,
  [618] = 618,
  [619] = 614,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 625,
  [626] = 626,
  [627] = 615,
  [628] = 628,
  [629] = 629,
  [630] = 630,
  [631] = 631,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 635,
  [636] = 633,
  [637] = 622,
  [638] = 609,
  [639] = 620,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 676,
  [677] = 677,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 659,
  [699] = 654,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 651,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 695,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 674,
  [734] = 670,
  [735] = 735,
  [736] = 702,
  [737] = 737,
  [738] = 707,
  [739] = 739,
  [740] = 740,
  [741] = 741,
  [742] = 742,
  [743] = 743,
  [744] = 661,
  [745] = 745,
  [746] = 676,
  [747] = 705,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 732,
  [764] = 764,
  [765] = 765,
  [766] = 715,
  [767] = 767,
  [768] = 739,
  [769] = 769,
  [770] = 770,
  [771] = 728,
  [772] = 765,
  [773] = 773,
  [774] = 655,
  [775] = 678,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 769,
  [781] = 781,
  [782] = 745,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 800,
  [805] = 792,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 806,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 807,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 811,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 808,
  [835] = 835,
  [836] = 810,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 852,
  [853] = 827,
  [854] = 801,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 812,
  [860] = 832,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 864,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 857,
  [871] = 871,
  [872] = 872,
  [873] = 848,
  [874] = 843,
  [875] = 875,
  [876] = 837,
  [877] = 830,
  [878] = 878,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 882,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 887,
  [888] = 888,
  [889] = 889,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 917,
  [918] = 918,
  [919] = 919,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 931,
  [935] = 924,
  [936] = 936,
  [937] = 937,
  [938] = 938,
  [939] = 894,
  [940] = 940,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 905,
  [946] = 946,
  [947] = 947,
  [948] = 902,
  [949] = 949,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 911,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 932,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 949,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 969,
  [970] = 952,
  [971] = 954,
  [972] = 972,
  [973] = 973,
  [974] = 966,
  [975] = 975,
  [976] = 976,
  [977] = 972,
  [978] = 975,
  [979] = 979,
  [980] = 980,
  [981] = 981,
  [982] = 982,
  [983] = 907,
  [984] = 968,
  [985] = 963,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 990,
  [991] = 991,
  [992] = 992,
  [993] = 993,
  [994] = 994,
  [995] = 986,
  [996] = 996,
  [997] = 997,
  [998] = 998,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1000,
  [1008] = 998,
  [1009] = 996,
  [1010] = 994,
  [1011] = 922,
  [1012] = 904,
  [1013] = 903,
  [1014] = 914,
  [1015] = 915,
  [1016] = 940,
  [1017] = 941,
  [1018] = 951,
  [1019] = 937,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 979,
  [1023] = 982,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1005,
  [1027] = 1021,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1020,
  [1031] = 1031,
  [1032] = 1032,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(53);
      if (lookahead == '!') ADVANCE(120);
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(88);
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '*') ADVANCE(81);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(83);
      if (lookahead == '-') ADVANCE(57);
      if (lookahead == '.') ADVANCE(104);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == '0') ADVANCE(105);
      if (lookahead == ':') ADVANCE(103);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(79);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '?') ADVANCE(110);
      if (lookahead == '[') ADVANCE(111);
      if (lookahead == '\\') ADVANCE(33);
      if (lookahead == ']') ADVANCE(112);
      if (lookahead == '^') ADVANCE(72);
      if (lookahead == '_') ADVANCE(151);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '|') ADVANCE(90);
      if (lookahead == '}') ADVANCE(84);
      if (lookahead == '~') ADVANCE(76);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(51)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(106);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(16)
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '/') ADVANCE(160);
      if (lookahead == '\\') ADVANCE(2);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(163);
      if (lookahead != 0) ADVANCE(164);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(158);
      if (lookahead == '\r') ADVANCE(154);
      if (lookahead == 'u') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(157);
      if (lookahead != 0) ADVANCE(153);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(14)
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '/') ADVANCE(167);
      if (lookahead == '\\') ADVANCE(4);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(170);
      if (lookahead != 0) ADVANCE(171);
      END_STATE();
    case 4:
      if (lookahead == '\n') ADVANCE(165);
      if (lookahead == '\r') ADVANCE(155);
      if (lookahead == 'u') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(157);
      if (lookahead != 0) ADVANCE(153);
      END_STATE();
    case 5:
      if (lookahead == ' ') ADVANCE(5);
      if (lookahead == '"') ADVANCE(7);
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      if (lookahead == '-') ADVANCE(55);
      if (lookahead == '.') ADVANCE(6);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '<') ADVANCE(70);
      if (lookahead == '=') ADVANCE(77);
      if (lookahead == '>') ADVANCE(73);
      if (lookahead == '^') ADVANCE(71);
      if (lookahead == '|') ADVANCE(36);
      if (lookahead == '~') ADVANCE(76);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(5)
      END_STATE();
    case 6:
      if (lookahead == ' ') ADVANCE(38);
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 7:
      if (lookahead == ' ') ADVANCE(38);
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      if (lookahead == '.') ADVANCE(6);
      END_STATE();
    case 8:
      if (lookahead == ' ') ADVANCE(39);
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 9:
      if (lookahead == '!') ADVANCE(23);
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(88);
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '*') ADVANCE(81);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(83);
      if (lookahead == '-') ADVANCE(57);
      if (lookahead == '.') ADVANCE(104);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == ':') ADVANCE(102);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(78);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '?') ADVANCE(110);
      if (lookahead == '[') ADVANCE(111);
      if (lookahead == ']') ADVANCE(112);
      if (lookahead == '^') ADVANCE(72);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '|') ADVANCE(90);
      if (lookahead == '}') ADVANCE(84);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(9)
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 10:
      if (lookahead == '!') ADVANCE(23);
      if (lookahead == '"') ADVANCE(29);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(88);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '*') ADVANCE(81);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(83);
      if (lookahead == '-') ADVANCE(57);
      if (lookahead == '.') ADVANCE(104);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == ':') ADVANCE(102);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(79);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '?') ADVANCE(110);
      if (lookahead == '[') ADVANCE(111);
      if (lookahead == ']') ADVANCE(112);
      if (lookahead == '^') ADVANCE(72);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '|') ADVANCE(90);
      if (lookahead == '}') ADVANCE(84);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(10)
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 11:
      if (lookahead == '!') ADVANCE(119);
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == ',') ADVANCE(83);
      if (lookahead == '-') ADVANCE(56);
      if (lookahead == '.') ADVANCE(41);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '0') ADVANCE(141);
      if (lookahead == ':') ADVANCE(102);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '=') ADVANCE(26);
      if (lookahead == '[') ADVANCE(111);
      if (lookahead == ']') ADVANCE(112);
      if (lookahead == '_') ADVANCE(137);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '}') ADVANCE(84);
      if (lookahead == '~') ADVANCE(76);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(11)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(140);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 12:
      if (lookahead == '!') ADVANCE(25);
      if (lookahead == '%') ADVANCE(96);
      if (lookahead == '&') ADVANCE(87);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '*') ADVANCE(80);
      if (lookahead == '+') ADVANCE(91);
      if (lookahead == ',') ADVANCE(83);
      if (lookahead == '-') ADVANCE(55);
      if (lookahead == '.') ADVANCE(104);
      if (lookahead == '/') ADVANCE(94);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '<') ADVANCE(70);
      if (lookahead == '=') ADVANCE(24);
      if (lookahead == '>') ADVANCE(73);
      if (lookahead == '[') ADVANCE(111);
      if (lookahead == '^') ADVANCE(71);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '|') ADVANCE(89);
      if (lookahead == '}') ADVANCE(84);
      if (lookahead == '~') ADVANCE(76);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(12)
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 13:
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '-') ADVANCE(27);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '_') ADVANCE(150);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(13)
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(49);
      END_STATE();
    case 14:
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(14)
      END_STATE();
    case 15:
      if (lookahead == '"') ADVANCE(101);
      END_STATE();
    case 16:
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(16)
      END_STATE();
    case 17:
      if (lookahead == '*') ADVANCE(19);
      if (lookahead == '/') ADVANCE(174);
      END_STATE();
    case 18:
      if (lookahead == '*') ADVANCE(18);
      if (lookahead == '/') ADVANCE(172);
      if (lookahead != 0) ADVANCE(19);
      END_STATE();
    case 19:
      if (lookahead == '*') ADVANCE(18);
      if (lookahead != 0) ADVANCE(19);
      END_STATE();
    case 20:
      if (lookahead == '-') ADVANCE(43);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(143);
      END_STATE();
    case 21:
      if (lookahead == '-') ADVANCE(44);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(145);
      END_STATE();
    case 22:
      if (lookahead == '/') ADVANCE(58);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(61);
      if (lookahead != 0 &&
          lookahead != ';') ADVANCE(62);
      END_STATE();
    case 23:
      if (lookahead == '=') ADVANCE(100);
      END_STATE();
    case 24:
      if (lookahead == '=') ADVANCE(98);
      if (lookahead == '>') ADVANCE(134);
      END_STATE();
    case 25:
      if (lookahead == '=') ADVANCE(99);
      END_STATE();
    case 26:
      if (lookahead == '>') ADVANCE(134);
      END_STATE();
    case 27:
      if (lookahead == '>') ADVANCE(109);
      END_STATE();
    case 28:
      if (lookahead == 'a') ADVANCE(32);
      END_STATE();
    case 29:
      if (lookahead == 'e') ADVANCE(34);
      END_STATE();
    case 30:
      if (lookahead == 'm') ADVANCE(28);
      END_STATE();
    case 31:
      if (lookahead == 'm') ADVANCE(15);
      END_STATE();
    case 32:
      if (lookahead == 's') ADVANCE(31);
      END_STATE();
    case 33:
      if (lookahead == 'u') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(157);
      if (lookahead != 0) ADVANCE(153);
      END_STATE();
    case 34:
      if (lookahead == 'v') ADVANCE(30);
      END_STATE();
    case 35:
      if (lookahead == '{') ADVANCE(47);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(45);
      END_STATE();
    case 36:
      if (lookahead == '|') ADVANCE(54);
      END_STATE();
    case 37:
      if (lookahead == '}') ADVANCE(153);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(37);
      END_STATE();
    case 38:
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 39:
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 40:
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 41:
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(144);
      END_STATE();
    case 42:
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(142);
      END_STATE();
    case 43:
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(143);
      END_STATE();
    case 44:
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(145);
      END_STATE();
    case 45:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(50);
      END_STATE();
    case 46:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(153);
      END_STATE();
    case 47:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(37);
      END_STATE();
    case 48:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(146);
      END_STATE();
    case 49:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(148);
      END_STATE();
    case 50:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(46);
      END_STATE();
    case 51:
      if (eof) ADVANCE(53);
      if (lookahead == '!') ADVANCE(120);
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(88);
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '*') ADVANCE(81);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(83);
      if (lookahead == '-') ADVANCE(57);
      if (lookahead == '.') ADVANCE(104);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == '0') ADVANCE(105);
      if (lookahead == ':') ADVANCE(103);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(79);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '?') ADVANCE(110);
      if (lookahead == '[') ADVANCE(111);
      if (lookahead == ']') ADVANCE(112);
      if (lookahead == '^') ADVANCE(72);
      if (lookahead == '_') ADVANCE(151);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '|') ADVANCE(90);
      if (lookahead == '}') ADVANCE(84);
      if (lookahead == '~') ADVANCE(76);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(51)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(106);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 52:
      if (eof) ADVANCE(53);
      if (lookahead == '!') ADVANCE(23);
      if (lookahead == '"') ADVANCE(149);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(88);
      if (lookahead == '\'') ADVANCE(152);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '*') ADVANCE(81);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(83);
      if (lookahead == '-') ADVANCE(57);
      if (lookahead == '.') ADVANCE(104);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == '0') ADVANCE(105);
      if (lookahead == ':') ADVANCE(103);
      if (lookahead == ';') ADVANCE(135);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(78);
      if (lookahead == '>') ADVANCE(74);
      if (lookahead == '?') ADVANCE(110);
      if (lookahead == '[') ADVANCE(111);
      if (lookahead == ']') ADVANCE(112);
      if (lookahead == '^') ADVANCE(72);
      if (lookahead == '{') ADVANCE(82);
      if (lookahead == '|') ADVANCE(90);
      if (lookahead == '}') ADVANCE(84);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(52)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(106);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(122);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(122);
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(aux_sym_pragma_value_token1);
      if (lookahead == '*') ADVANCE(60);
      if (lookahead == '/') ADVANCE(173);
      if (lookahead != 0 &&
          lookahead != ';') ADVANCE(62);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(aux_sym_pragma_value_token1);
      if (lookahead == '*') ADVANCE(59);
      if (lookahead == '/') ADVANCE(172);
      if (lookahead == ';') ADVANCE(19);
      if (lookahead != 0) ADVANCE(60);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(aux_sym_pragma_value_token1);
      if (lookahead == '*') ADVANCE(59);
      if (lookahead == ';') ADVANCE(19);
      if (lookahead != 0) ADVANCE(60);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(aux_sym_pragma_value_token1);
      if (lookahead == '/') ADVANCE(58);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(61);
      if (lookahead != 0 &&
          lookahead != ';') ADVANCE(62);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(aux_sym_pragma_value_token1);
      if (lookahead != 0 &&
          lookahead != ';') ADVANCE(62);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(sym_solidity_version);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_solidity_version);
      if (lookahead == ' ') ADVANCE(65);
      if (lookahead == '"') ADVANCE(63);
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      if (lookahead == '.') ADVANCE(40);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_solidity_version);
      if (lookahead == '"') ADVANCE(63);
      if (lookahead == '.') ADVANCE(40);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_solidity_version);
      if (lookahead == '"') ADVANCE(63);
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      if (lookahead == '.') ADVANCE(8);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_solidity_version);
      if (lookahead == '"') ADVANCE(63);
      if (lookahead == '*' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(116);
      if (lookahead == '=') ADVANCE(68);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(68);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(128);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(75);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(75);
      if (lookahead == '>') ADVANCE(114);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(98);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(98);
      if (lookahead == '>') ADVANCE(134);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(117);
      if (lookahead == '=') ADVANCE(125);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(113);
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '|') ADVANCE(54);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(121);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(121);
      if (lookahead == '=') ADVANCE(123);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(19);
      if (lookahead == '/') ADVANCE(174);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(19);
      if (lookahead == '/') ADVANCE(174);
      if (lookahead == '=') ADVANCE(126);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(127);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      if (lookahead == '=') ADVANCE(118);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_DQUOTEevmasm_DQUOTE);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(108);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(sym_yul_decimal_number);
      if (lookahead == 'x') ADVANCE(107);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(sym_yul_decimal_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(106);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(sym_yul_hex_number);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(107);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '>') ADVANCE(115);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      if (lookahead == '=') ADVANCE(132);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(133);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_BANG_EQ_EQ);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(100);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT_EQ);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym__semicolon);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(43);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(138);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(42);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(137);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(136);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(138);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(aux_sym__decimal_number_token1);
      if (lookahead == '.') ADVANCE(42);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(140);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(aux_sym__decimal_number_token1);
      if (lookahead == '.') ADVANCE(42);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(140);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(48);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(aux_sym__decimal_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(142);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(20);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(aux_sym__decimal_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(143);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(aux_sym__decimal_number_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(144);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(21);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(aux_sym__decimal_number_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(145);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(aux_sym__hex_number_token1);
      if (lookahead == '_') ADVANCE(147);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(146);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(aux_sym__hex_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(146);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(sym__hex_digit);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym__);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(139);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(sym__escape_sequence);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym__escape_sequence);
      if (lookahead == '\n') ADVANCE(158);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym__escape_sequence);
      if (lookahead == '\n') ADVANCE(165);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym__escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(153);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym__escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(156);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(aux_sym__single_quoted_unicode_char_token1);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(aux_sym__single_quoted_unicode_char_token1);
      if (lookahead == '\r') ADVANCE(164);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(159);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(aux_sym__single_quoted_unicode_char_token1);
      if (lookahead == '*') ADVANCE(162);
      if (lookahead == '/') ADVANCE(159);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(164);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(aux_sym__single_quoted_unicode_char_token1);
      if (lookahead == '*') ADVANCE(161);
      if (lookahead == '/') ADVANCE(164);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(162);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(aux_sym__single_quoted_unicode_char_token1);
      if (lookahead == '*') ADVANCE(161);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(162);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(aux_sym__single_quoted_unicode_char_token1);
      if (lookahead == '/') ADVANCE(160);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(163);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(164);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(aux_sym__single_quoted_unicode_char_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(164);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(aux_sym__double_quoted_unicode_char_token1);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(aux_sym__double_quoted_unicode_char_token1);
      if (lookahead == '\r') ADVANCE(171);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(166);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(aux_sym__double_quoted_unicode_char_token1);
      if (lookahead == '*') ADVANCE(169);
      if (lookahead == '/') ADVANCE(166);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(171);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(aux_sym__double_quoted_unicode_char_token1);
      if (lookahead == '*') ADVANCE(168);
      if (lookahead == '/') ADVANCE(171);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(169);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(aux_sym__double_quoted_unicode_char_token1);
      if (lookahead == '*') ADVANCE(168);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(169);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(aux_sym__double_quoted_unicode_char_token1);
      if (lookahead == '/') ADVANCE(167);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(170);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(171);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(aux_sym__double_quoted_unicode_char_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(171);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == ';') ADVANCE(174);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(173);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(174);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'a') ADVANCE(1);
      if (lookahead == 'b') ADVANCE(2);
      if (lookahead == 'c') ADVANCE(3);
      if (lookahead == 'd') ADVANCE(4);
      if (lookahead == 'e') ADVANCE(5);
      if (lookahead == 'f') ADVANCE(6);
      if (lookahead == 'g') ADVANCE(7);
      if (lookahead == 'h') ADVANCE(8);
      if (lookahead == 'i') ADVANCE(9);
      if (lookahead == 'k') ADVANCE(10);
      if (lookahead == 'l') ADVANCE(11);
      if (lookahead == 'm') ADVANCE(12);
      if (lookahead == 'n') ADVANCE(13);
      if (lookahead == 'o') ADVANCE(14);
      if (lookahead == 'p') ADVANCE(15);
      if (lookahead == 'r') ADVANCE(16);
      if (lookahead == 's') ADVANCE(17);
      if (lookahead == 't') ADVANCE(18);
      if (lookahead == 'u') ADVANCE(19);
      if (lookahead == 'v') ADVANCE(20);
      if (lookahead == 'w') ADVANCE(21);
      if (lookahead == 'x') ADVANCE(22);
      if (lookahead == 'y') ADVANCE(23);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ' ||
          lookahead == 160 ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(0)
      END_STATE();
    case 1:
      if (lookahead == 'b') ADVANCE(24);
      if (lookahead == 'd') ADVANCE(25);
      if (lookahead == 'n') ADVANCE(26);
      if (lookahead == 's') ADVANCE(27);
      END_STATE();
    case 2:
      if (lookahead == 'a') ADVANCE(28);
      if (lookahead == 'l') ADVANCE(29);
      if (lookahead == 'o') ADVANCE(30);
      if (lookahead == 'r') ADVANCE(31);
      if (lookahead == 'y') ADVANCE(32);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(33);
      if (lookahead == 'h') ADVANCE(34);
      if (lookahead == 'o') ADVANCE(35);
      if (lookahead == 'r') ADVANCE(36);
      END_STATE();
    case 4:
      if (lookahead == 'a') ADVANCE(37);
      if (lookahead == 'e') ADVANCE(38);
      if (lookahead == 'i') ADVANCE(39);
      if (lookahead == 'o') ADVANCE(40);
      END_STATE();
    case 5:
      if (lookahead == 'l') ADVANCE(41);
      if (lookahead == 'm') ADVANCE(42);
      if (lookahead == 'n') ADVANCE(43);
      if (lookahead == 'q') ADVANCE(44);
      if (lookahead == 'r') ADVANCE(45);
      if (lookahead == 't') ADVANCE(46);
      if (lookahead == 'v') ADVANCE(47);
      if (lookahead == 'x') ADVANCE(48);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(49);
      if (lookahead == 'i') ADVANCE(50);
      if (lookahead == 'o') ADVANCE(51);
      if (lookahead == 'r') ADVANCE(52);
      if (lookahead == 'u') ADVANCE(53);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(54);
      if (lookahead == 'l') ADVANCE(55);
      if (lookahead == 't') ADVANCE(56);
      if (lookahead == 'w') ADVANCE(57);
      END_STATE();
    case 8:
      if (lookahead == 'e') ADVANCE(58);
      if (lookahead == 'o') ADVANCE(59);
      END_STATE();
    case 9:
      if (lookahead == 'f') ADVANCE(60);
      if (lookahead == 'm') ADVANCE(61);
      if (lookahead == 'n') ADVANCE(62);
      if (lookahead == 's') ADVANCE(63);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(65);
      if (lookahead == 'i') ADVANCE(66);
      if (lookahead == 'o') ADVANCE(67);
      if (lookahead == 't') ADVANCE(68);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(69);
      if (lookahead == 'e') ADVANCE(70);
      if (lookahead == 'i') ADVANCE(71);
      if (lookahead == 'l') ADVANCE(72);
      if (lookahead == 'o') ADVANCE(73);
      if (lookahead == 's') ADVANCE(74);
      if (lookahead == 'u') ADVANCE(75);
      END_STATE();
    case 13:
      if (lookahead == 'e') ADVANCE(76);
      if (lookahead == 'o') ADVANCE(77);
      if (lookahead == 'u') ADVANCE(78);
      END_STATE();
    case 14:
      if (lookahead == 'r') ADVANCE(79);
      if (lookahead == 'v') ADVANCE(80);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(81);
      if (lookahead == 'o') ADVANCE(82);
      if (lookahead == 'r') ADVANCE(83);
      if (lookahead == 'u') ADVANCE(84);
      END_STATE();
    case 16:
      if (lookahead == 'e') ADVANCE(85);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(86);
      if (lookahead == 'd') ADVANCE(87);
      if (lookahead == 'e') ADVANCE(88);
      if (lookahead == 'g') ADVANCE(89);
      if (lookahead == 'h') ADVANCE(90);
      if (lookahead == 'i') ADVANCE(91);
      if (lookahead == 'l') ADVANCE(92);
      if (lookahead == 'm') ADVANCE(93);
      if (lookahead == 'o') ADVANCE(94);
      if (lookahead == 's') ADVANCE(95);
      if (lookahead == 't') ADVANCE(96);
      if (lookahead == 'u') ADVANCE(97);
      if (lookahead == 'w') ADVANCE(98);
      if (lookahead == 'z') ADVANCE(99);
      END_STATE();
    case 18:
      if (lookahead == 'i') ADVANCE(100);
      if (lookahead == 'r') ADVANCE(101);
      if (lookahead == 'y') ADVANCE(102);
      END_STATE();
    case 19:
      if (lookahead == 'f') ADVANCE(103);
      if (lookahead == 'i') ADVANCE(104);
      if (lookahead == 'n') ADVANCE(105);
      if (lookahead == 's') ADVANCE(106);
      END_STATE();
    case 20:
      if (lookahead == 'a') ADVANCE(107);
      if (lookahead == 'i') ADVANCE(108);
      END_STATE();
    case 21:
      if (lookahead == 'e') ADVANCE(109);
      if (lookahead == 'h') ADVANCE(110);
      END_STATE();
    case 22:
      if (lookahead == 'o') ADVANCE(111);
      END_STATE();
    case 23:
      if (lookahead == 'e') ADVANCE(112);
      END_STATE();
    case 24:
      if (lookahead == 's') ADVANCE(113);
      END_STATE();
    case 25:
      if (lookahead == 'd') ADVANCE(114);
      END_STATE();
    case 26:
      if (lookahead == 'd') ADVANCE(115);
      if (lookahead == 'o') ADVANCE(116);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(117);
      END_STATE();
    case 28:
      if (lookahead == 'l') ADVANCE(118);
      END_STATE();
    case 29:
      if (lookahead == 'o') ADVANCE(119);
      END_STATE();
    case 30:
      if (lookahead == 'o') ADVANCE(120);
      END_STATE();
    case 31:
      if (lookahead == 'e') ADVANCE(121);
      END_STATE();
    case 32:
      if (lookahead == 't') ADVANCE(122);
      END_STATE();
    case 33:
      if (lookahead == 'l') ADVANCE(123);
      if (lookahead == 's') ADVANCE(124);
      if (lookahead == 't') ADVANCE(125);
      END_STATE();
    case 34:
      if (lookahead == 'a') ADVANCE(126);
      END_STATE();
    case 35:
      if (lookahead == 'i') ADVANCE(127);
      if (lookahead == 'n') ADVANCE(128);
      END_STATE();
    case 36:
      if (lookahead == 'e') ADVANCE(129);
      END_STATE();
    case 37:
      if (lookahead == 'y') ADVANCE(130);
      END_STATE();
    case 38:
      if (lookahead == 'f') ADVANCE(131);
      if (lookahead == 'l') ADVANCE(132);
      END_STATE();
    case 39:
      if (lookahead == 'f') ADVANCE(133);
      if (lookahead == 'v') ADVANCE(134);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(135);
      END_STATE();
    case 42:
      if (lookahead == 'i') ADVANCE(136);
      END_STATE();
    case 43:
      if (lookahead == 'u') ADVANCE(137);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_eq);
      END_STATE();
    case 45:
      if (lookahead == 'r') ADVANCE(138);
      END_STATE();
    case 46:
      if (lookahead == 'h') ADVANCE(139);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(140);
      END_STATE();
    case 48:
      if (lookahead == 'p') ADVANCE(141);
      if (lookahead == 't') ADVANCE(142);
      END_STATE();
    case 49:
      if (lookahead == 'l') ADVANCE(143);
      END_STATE();
    case 50:
      if (lookahead == 'n') ADVANCE(144);
      if (lookahead == 'x') ADVANCE(145);
      END_STATE();
    case 51:
      if (lookahead == 'r') ADVANCE(146);
      END_STATE();
    case 52:
      if (lookahead == 'o') ADVANCE(147);
      END_STATE();
    case 53:
      if (lookahead == 'n') ADVANCE(148);
      END_STATE();
    case 54:
      if (lookahead == 's') ADVANCE(149);
      END_STATE();
    case 55:
      if (lookahead == 'o') ADVANCE(150);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_gt);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(151);
      END_STATE();
    case 58:
      if (lookahead == 'x') ADVANCE(152);
      END_STATE();
    case 59:
      if (lookahead == 'u') ADVANCE(153);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 61:
      if (lookahead == 'm') ADVANCE(154);
      if (lookahead == 'p') ADVANCE(155);
      END_STATE();
    case 62:
      if (lookahead == 'd') ADVANCE(156);
      if (lookahead == 't') ADVANCE(157);
      if (lookahead == 'v') ADVANCE(158);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == 'z') ADVANCE(159);
      END_STATE();
    case 64:
      if (lookahead == 'c') ADVANCE(160);
      END_STATE();
    case 65:
      if (lookahead == 'a') ADVANCE(161);
      if (lookahead == 't') ADVANCE(162);
      END_STATE();
    case 66:
      if (lookahead == 'b') ADVANCE(163);
      END_STATE();
    case 67:
      if (lookahead == 'g') ADVANCE(164);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_lt);
      END_STATE();
    case 69:
      if (lookahead == 'p') ADVANCE(165);
      END_STATE();
    case 70:
      if (lookahead == 'm') ADVANCE(166);
      END_STATE();
    case 71:
      if (lookahead == 'n') ADVANCE(167);
      END_STATE();
    case 72:
      if (lookahead == 'o') ADVANCE(168);
      END_STATE();
    case 73:
      if (lookahead == 'd') ADVANCE(169);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(170);
      if (lookahead == 't') ADVANCE(171);
      END_STATE();
    case 75:
      if (lookahead == 'l') ADVANCE(172);
      END_STATE();
    case 76:
      if (lookahead == 'w') ADVANCE(173);
      END_STATE();
    case 77:
      if (lookahead == 't') ADVANCE(174);
      END_STATE();
    case 78:
      if (lookahead == 'm') ADVANCE(175);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == 'i') ADVANCE(176);
      END_STATE();
    case 80:
      if (lookahead == 'e') ADVANCE(177);
      END_STATE();
    case 81:
      if (lookahead == 'y') ADVANCE(178);
      END_STATE();
    case 82:
      if (lookahead == 'p') ADVANCE(179);
      END_STATE();
    case 83:
      if (lookahead == 'a') ADVANCE(180);
      if (lookahead == 'i') ADVANCE(181);
      END_STATE();
    case 84:
      if (lookahead == 'b') ADVANCE(182);
      if (lookahead == 'r') ADVANCE(183);
      END_STATE();
    case 85:
      if (lookahead == 'c') ADVANCE(184);
      if (lookahead == 't') ADVANCE(185);
      if (lookahead == 'v') ADVANCE(186);
      END_STATE();
    case 86:
      if (lookahead == 'r') ADVANCE(187);
      END_STATE();
    case 87:
      if (lookahead == 'i') ADVANCE(188);
      END_STATE();
    case 88:
      if (lookahead == 'c') ADVANCE(189);
      if (lookahead == 'l') ADVANCE(190);
      END_STATE();
    case 89:
      if (lookahead == 't') ADVANCE(191);
      END_STATE();
    case 90:
      if (lookahead == 'l') ADVANCE(192);
      if (lookahead == 'r') ADVANCE(193);
      END_STATE();
    case 91:
      if (lookahead == 'g') ADVANCE(194);
      END_STATE();
    case 92:
      if (lookahead == 'o') ADVANCE(195);
      if (lookahead == 't') ADVANCE(196);
      END_STATE();
    case 93:
      if (lookahead == 'o') ADVANCE(197);
      END_STATE();
    case 94:
      if (lookahead == 'l') ADVANCE(198);
      END_STATE();
    case 95:
      if (lookahead == 't') ADVANCE(199);
      END_STATE();
    case 96:
      if (lookahead == 'a') ADVANCE(200);
      if (lookahead == 'o') ADVANCE(201);
      if (lookahead == 'r') ADVANCE(202);
      END_STATE();
    case 97:
      if (lookahead == 'b') ADVANCE(203);
      END_STATE();
    case 98:
      if (lookahead == 'i') ADVANCE(204);
      END_STATE();
    case 99:
      if (lookahead == 'a') ADVANCE(205);
      END_STATE();
    case 100:
      if (lookahead == 'm') ADVANCE(206);
      END_STATE();
    case 101:
      if (lookahead == 'u') ADVANCE(207);
      if (lookahead == 'y') ADVANCE(208);
      END_STATE();
    case 102:
      if (lookahead == 'p') ADVANCE(209);
      END_STATE();
    case 103:
      if (lookahead == 'i') ADVANCE(210);
      END_STATE();
    case 104:
      if (lookahead == 'n') ADVANCE(211);
      END_STATE();
    case 105:
      if (lookahead == 'c') ADVANCE(212);
      if (lookahead == 'i') ADVANCE(213);
      END_STATE();
    case 106:
      if (lookahead == 'i') ADVANCE(214);
      END_STATE();
    case 107:
      if (lookahead == 'r') ADVANCE(215);
      END_STATE();
    case 108:
      if (lookahead == 'e') ADVANCE(216);
      if (lookahead == 'r') ADVANCE(217);
      END_STATE();
    case 109:
      if (lookahead == 'e') ADVANCE(218);
      if (lookahead == 'i') ADVANCE(219);
      END_STATE();
    case 110:
      if (lookahead == 'i') ADVANCE(220);
      END_STATE();
    case 111:
      if (lookahead == 'r') ADVANCE(221);
      END_STATE();
    case 112:
      if (lookahead == 'a') ADVANCE(222);
      END_STATE();
    case 113:
      if (lookahead == 't') ADVANCE(223);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_add);
      if (lookahead == 'm') ADVANCE(224);
      if (lookahead == 'r') ADVANCE(225);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 116:
      if (lookahead == 'n') ADVANCE(226);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(227);
      END_STATE();
    case 118:
      if (lookahead == 'a') ADVANCE(228);
      END_STATE();
    case 119:
      if (lookahead == 'c') ADVANCE(229);
      END_STATE();
    case 120:
      if (lookahead == 'l') ADVANCE(230);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(231);
      END_STATE();
    case 122:
      if (lookahead == 'e') ADVANCE(232);
      END_STATE();
    case 123:
      if (lookahead == 'l') ADVANCE(233);
      END_STATE();
    case 124:
      if (lookahead == 'e') ADVANCE(234);
      END_STATE();
    case 125:
      if (lookahead == 'c') ADVANCE(235);
      END_STATE();
    case 126:
      if (lookahead == 'i') ADVANCE(236);
      END_STATE();
    case 127:
      if (lookahead == 'n') ADVANCE(237);
      END_STATE();
    case 128:
      if (lookahead == 's') ADVANCE(238);
      if (lookahead == 't') ADVANCE(239);
      END_STATE();
    case 129:
      if (lookahead == 'a') ADVANCE(240);
      END_STATE();
    case 130:
      if (lookahead == 's') ADVANCE(241);
      END_STATE();
    case 131:
      if (lookahead == 'a') ADVANCE(242);
      END_STATE();
    case 132:
      if (lookahead == 'e') ADVANCE(243);
      END_STATE();
    case 133:
      if (lookahead == 'f') ADVANCE(244);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_div);
      END_STATE();
    case 135:
      if (lookahead == 'e') ADVANCE(245);
      END_STATE();
    case 136:
      if (lookahead == 't') ADVANCE(246);
      END_STATE();
    case 137:
      if (lookahead == 'm') ADVANCE(247);
      END_STATE();
    case 138:
      if (lookahead == 'o') ADVANCE(248);
      END_STATE();
    case 139:
      if (lookahead == 'e') ADVANCE(249);
      END_STATE();
    case 140:
      if (lookahead == 'n') ADVANCE(250);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_exp);
      END_STATE();
    case 142:
      if (lookahead == 'c') ADVANCE(251);
      if (lookahead == 'e') ADVANCE(252);
      END_STATE();
    case 143:
      if (lookahead == 'l') ADVANCE(253);
      if (lookahead == 's') ADVANCE(254);
      END_STATE();
    case 144:
      if (lookahead == 'n') ADVANCE(255);
      END_STATE();
    case 145:
      if (lookahead == 'e') ADVANCE(256);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 147:
      if (lookahead == 'm') ADVANCE(257);
      END_STATE();
    case 148:
      if (lookahead == 'c') ADVANCE(258);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_gas);
      if (lookahead == 'l') ADVANCE(259);
      if (lookahead == 'p') ADVANCE(260);
      END_STATE();
    case 150:
      if (lookahead == 'b') ADVANCE(261);
      END_STATE();
    case 151:
      if (lookahead == 'i') ADVANCE(262);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_hex);
      END_STATE();
    case 153:
      if (lookahead == 'r') ADVANCE(263);
      END_STATE();
    case 154:
      if (lookahead == 'u') ADVANCE(264);
      END_STATE();
    case 155:
      if (lookahead == 'o') ADVANCE(265);
      END_STATE();
    case 156:
      if (lookahead == 'e') ADVANCE(266);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == '1') ADVANCE(267);
      if (lookahead == '2') ADVANCE(268);
      if (lookahead == '3') ADVANCE(269);
      if (lookahead == '4') ADVANCE(270);
      if (lookahead == '5') ADVANCE(271);
      if (lookahead == '6') ADVANCE(272);
      if (lookahead == '7') ADVANCE(273);
      if (lookahead == '8') ADVANCE(274);
      if (lookahead == '9') ADVANCE(275);
      if (lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 158:
      if (lookahead == 'a') ADVANCE(277);
      END_STATE();
    case 159:
      if (lookahead == 'e') ADVANCE(278);
      END_STATE();
    case 160:
      if (lookahead == 'c') ADVANCE(279);
      END_STATE();
    case 161:
      if (lookahead == 'v') ADVANCE(280);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_let);
      END_STATE();
    case 163:
      if (lookahead == 'r') ADVANCE(281);
      END_STATE();
    case 164:
      if (lookahead == '0') ADVANCE(282);
      if (lookahead == '1') ADVANCE(283);
      if (lookahead == '2') ADVANCE(284);
      if (lookahead == '3') ADVANCE(285);
      if (lookahead == '4') ADVANCE(286);
      END_STATE();
    case 165:
      if (lookahead == 'p') ADVANCE(287);
      END_STATE();
    case 166:
      if (lookahead == 'o') ADVANCE(288);
      END_STATE();
    case 167:
      if (lookahead == 'u') ADVANCE(289);
      END_STATE();
    case 168:
      if (lookahead == 'a') ADVANCE(290);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_mod);
      if (lookahead == 'i') ADVANCE(291);
      END_STATE();
    case 170:
      if (lookahead == 'z') ADVANCE(292);
      END_STATE();
    case 171:
      if (lookahead == 'o') ADVANCE(293);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_mul);
      if (lookahead == 'm') ADVANCE(294);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_not);
      END_STATE();
    case 175:
      if (lookahead == 'b') ADVANCE(295);
      END_STATE();
    case 176:
      if (lookahead == 'g') ADVANCE(296);
      END_STATE();
    case 177:
      if (lookahead == 'r') ADVANCE(297);
      END_STATE();
    case 178:
      if (lookahead == 'a') ADVANCE(298);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_pop);
      END_STATE();
    case 180:
      if (lookahead == 'g') ADVANCE(299);
      END_STATE();
    case 181:
      if (lookahead == 'v') ADVANCE(300);
      END_STATE();
    case 182:
      if (lookahead == 'l') ADVANCE(301);
      END_STATE();
    case 183:
      if (lookahead == 'e') ADVANCE(302);
      END_STATE();
    case 184:
      if (lookahead == 'e') ADVANCE(303);
      END_STATE();
    case 185:
      if (lookahead == 'u') ADVANCE(304);
      END_STATE();
    case 186:
      if (lookahead == 'e') ADVANCE(305);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_sar);
      END_STATE();
    case 188:
      if (lookahead == 'v') ADVANCE(306);
      END_STATE();
    case 189:
      if (lookahead == 'o') ADVANCE(307);
      END_STATE();
    case 190:
      if (lookahead == 'f') ADVANCE(308);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_sgt);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_shl);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_shr);
      END_STATE();
    case 194:
      if (lookahead == 'n') ADVANCE(309);
      END_STATE();
    case 195:
      if (lookahead == 'a') ADVANCE(310);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_slt);
      END_STATE();
    case 197:
      if (lookahead == 'd') ADVANCE(311);
      END_STATE();
    case 198:
      if (lookahead == 'i') ADVANCE(312);
      END_STATE();
    case 199:
      if (lookahead == 'o') ADVANCE(313);
      END_STATE();
    case 200:
      if (lookahead == 't') ADVANCE(314);
      END_STATE();
    case 201:
      if (lookahead == 'p') ADVANCE(315);
      if (lookahead == 'r') ADVANCE(316);
      END_STATE();
    case 202:
      if (lookahead == 'i') ADVANCE(317);
      if (lookahead == 'u') ADVANCE(318);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_sub);
      END_STATE();
    case 204:
      if (lookahead == 't') ADVANCE(319);
      END_STATE();
    case 205:
      if (lookahead == 'b') ADVANCE(320);
      END_STATE();
    case 206:
      if (lookahead == 'e') ADVANCE(321);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(322);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(323);
      END_STATE();
    case 210:
      if (lookahead == 'x') ADVANCE(324);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(325);
      END_STATE();
    case 212:
      if (lookahead == 'h') ADVANCE(326);
      END_STATE();
    case 213:
      if (lookahead == 'c') ADVANCE(327);
      END_STATE();
    case 214:
      if (lookahead == 'n') ADVANCE(328);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 216:
      if (lookahead == 'w') ADVANCE(329);
      END_STATE();
    case 217:
      if (lookahead == 't') ADVANCE(330);
      END_STATE();
    case 218:
      if (lookahead == 'k') ADVANCE(331);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_wei);
      END_STATE();
    case 220:
      if (lookahead == 'l') ADVANCE(332);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_xor);
      END_STATE();
    case 222:
      if (lookahead == 'r') ADVANCE(333);
      END_STATE();
    case 223:
      if (lookahead == 'r') ADVANCE(334);
      END_STATE();
    case 224:
      if (lookahead == 'o') ADVANCE(335);
      END_STATE();
    case 225:
      if (lookahead == 'e') ADVANCE(336);
      END_STATE();
    case 226:
      if (lookahead == 'y') ADVANCE(337);
      END_STATE();
    case 227:
      if (lookahead == 'm') ADVANCE(338);
      END_STATE();
    case 228:
      if (lookahead == 'n') ADVANCE(339);
      END_STATE();
    case 229:
      if (lookahead == 'k') ADVANCE(340);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 231:
      if (lookahead == 'k') ADVANCE(341);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_byte);
      if (lookahead == 's') ADVANCE(342);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_call);
      if (lookahead == 'c') ADVANCE(343);
      if (lookahead == 'd') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(345);
      if (lookahead == 'v') ADVANCE(346);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 235:
      if (lookahead == 'h') ADVANCE(347);
      END_STATE();
    case 236:
      if (lookahead == 'n') ADVANCE(348);
      END_STATE();
    case 237:
      if (lookahead == 'b') ADVANCE(349);
      END_STATE();
    case 238:
      if (lookahead == 't') ADVANCE(350);
      END_STATE();
    case 239:
      if (lookahead == 'i') ADVANCE(351);
      if (lookahead == 'r') ADVANCE(352);
      END_STATE();
    case 240:
      if (lookahead == 't') ADVANCE(353);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_days);
      END_STATE();
    case 242:
      if (lookahead == 'u') ADVANCE(354);
      END_STATE();
    case 243:
      if (lookahead == 'g') ADVANCE(355);
      if (lookahead == 't') ADVANCE(356);
      END_STATE();
    case 244:
      if (lookahead == 'i') ADVANCE(357);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_emit);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 248:
      if (lookahead == 'r') ADVANCE(358);
      END_STATE();
    case 249:
      if (lookahead == 'r') ADVANCE(359);
      END_STATE();
    case 250:
      if (lookahead == 't') ADVANCE(360);
      END_STATE();
    case 251:
      if (lookahead == 'o') ADVANCE(361);
      END_STATE();
    case 252:
      if (lookahead == 'r') ADVANCE(362);
      END_STATE();
    case 253:
      if (lookahead == 'b') ADVANCE(363);
      END_STATE();
    case 254:
      if (lookahead == 'e') ADVANCE(364);
      END_STATE();
    case 255:
      if (lookahead == 'e') ADVANCE(365);
      END_STATE();
    case 256:
      if (lookahead == 'd') ADVANCE(366);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 258:
      if (lookahead == 't') ADVANCE(367);
      END_STATE();
    case 259:
      if (lookahead == 'i') ADVANCE(368);
      END_STATE();
    case 260:
      if (lookahead == 'r') ADVANCE(369);
      END_STATE();
    case 261:
      if (lookahead == 'a') ADVANCE(370);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_gwei);
      END_STATE();
    case 263:
      if (lookahead == 's') ADVANCE(371);
      END_STATE();
    case 264:
      if (lookahead == 't') ADVANCE(372);
      END_STATE();
    case 265:
      if (lookahead == 'r') ADVANCE(373);
      END_STATE();
    case 266:
      if (lookahead == 'x') ADVANCE(374);
      END_STATE();
    case 267:
      if (lookahead == '0') ADVANCE(375);
      if (lookahead == '1') ADVANCE(376);
      if (lookahead == '2') ADVANCE(377);
      if (lookahead == '3') ADVANCE(378);
      if (lookahead == '4') ADVANCE(379);
      if (lookahead == '5') ADVANCE(380);
      if (lookahead == '6') ADVANCE(381);
      if (lookahead == '7') ADVANCE(382);
      if (lookahead == '8') ADVANCE(383);
      if (lookahead == '9') ADVANCE(384);
      END_STATE();
    case 268:
      if (lookahead == '0') ADVANCE(385);
      if (lookahead == '1') ADVANCE(386);
      if (lookahead == '2') ADVANCE(387);
      if (lookahead == '3') ADVANCE(388);
      if (lookahead == '4') ADVANCE(389);
      if (lookahead == '5') ADVANCE(390);
      END_STATE();
    case 269:
      if (lookahead == '2') ADVANCE(391);
      END_STATE();
    case 270:
      if (lookahead == '0') ADVANCE(392);
      if (lookahead == '8') ADVANCE(393);
      END_STATE();
    case 271:
      if (lookahead == '6') ADVANCE(394);
      END_STATE();
    case 272:
      if (lookahead == '4') ADVANCE(395);
      END_STATE();
    case 273:
      if (lookahead == '2') ADVANCE(396);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_int8);
      if (lookahead == '0') ADVANCE(397);
      if (lookahead == '8') ADVANCE(398);
      END_STATE();
    case 275:
      if (lookahead == '6') ADVANCE(399);
      END_STATE();
    case 276:
      if (lookahead == 'r') ADVANCE(400);
      END_STATE();
    case 277:
      if (lookahead == 'l') ADVANCE(401);
      END_STATE();
    case 278:
      if (lookahead == 'r') ADVANCE(402);
      END_STATE();
    case 279:
      if (lookahead == 'a') ADVANCE(403);
      END_STATE();
    case 280:
      if (lookahead == 'e') ADVANCE(404);
      END_STATE();
    case 281:
      if (lookahead == 'a') ADVANCE(405);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(anon_sym_log0);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(anon_sym_log1);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(anon_sym_log2);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(anon_sym_log3);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(anon_sym_log4);
      END_STATE();
    case 287:
      if (lookahead == 'i') ADVANCE(406);
      END_STATE();
    case 288:
      if (lookahead == 'r') ADVANCE(407);
      END_STATE();
    case 289:
      if (lookahead == 't') ADVANCE(408);
      END_STATE();
    case 290:
      if (lookahead == 'd') ADVANCE(409);
      END_STATE();
    case 291:
      if (lookahead == 'f') ADVANCE(410);
      END_STATE();
    case 292:
      if (lookahead == 'e') ADVANCE(411);
      END_STATE();
    case 293:
      if (lookahead == 'r') ADVANCE(412);
      END_STATE();
    case 294:
      if (lookahead == 'o') ADVANCE(413);
      END_STATE();
    case 295:
      if (lookahead == 'e') ADVANCE(414);
      END_STATE();
    case 296:
      if (lookahead == 'i') ADVANCE(415);
      END_STATE();
    case 297:
      if (lookahead == 'r') ADVANCE(416);
      END_STATE();
    case 298:
      if (lookahead == 'b') ADVANCE(417);
      END_STATE();
    case 299:
      if (lookahead == 'm') ADVANCE(418);
      END_STATE();
    case 300:
      if (lookahead == 'a') ADVANCE(419);
      END_STATE();
    case 301:
      if (lookahead == 'i') ADVANCE(420);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(anon_sym_pure);
      END_STATE();
    case 303:
      if (lookahead == 'i') ADVANCE(421);
      END_STATE();
    case 304:
      if (lookahead == 'r') ADVANCE(422);
      END_STATE();
    case 305:
      if (lookahead == 'r') ADVANCE(423);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(anon_sym_sdiv);
      END_STATE();
    case 307:
      if (lookahead == 'n') ADVANCE(424);
      END_STATE();
    case 308:
      if (lookahead == 'b') ADVANCE(425);
      if (lookahead == 'd') ADVANCE(426);
      END_STATE();
    case 309:
      if (lookahead == 'e') ADVANCE(427);
      END_STATE();
    case 310:
      if (lookahead == 'd') ADVANCE(428);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_smod);
      END_STATE();
    case 312:
      if (lookahead == 'd') ADVANCE(429);
      END_STATE();
    case 313:
      if (lookahead == 'r') ADVANCE(430);
      END_STATE();
    case 314:
      if (lookahead == 'i') ADVANCE(431);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(anon_sym_stop);
      END_STATE();
    case 316:
      if (lookahead == 'a') ADVANCE(432);
      END_STATE();
    case 317:
      if (lookahead == 'n') ADVANCE(433);
      END_STATE();
    case 318:
      if (lookahead == 'c') ADVANCE(434);
      END_STATE();
    case 319:
      if (lookahead == 'c') ADVANCE(435);
      END_STATE();
    case 320:
      if (lookahead == 'o') ADVANCE(436);
      END_STATE();
    case 321:
      if (lookahead == 's') ADVANCE(437);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 324:
      if (lookahead == 'e') ADVANCE(438);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(anon_sym_uint);
      if (lookahead == '1') ADVANCE(439);
      if (lookahead == '2') ADVANCE(440);
      if (lookahead == '3') ADVANCE(441);
      if (lookahead == '4') ADVANCE(442);
      if (lookahead == '5') ADVANCE(443);
      if (lookahead == '6') ADVANCE(444);
      if (lookahead == '7') ADVANCE(445);
      if (lookahead == '8') ADVANCE(446);
      if (lookahead == '9') ADVANCE(447);
      END_STATE();
    case 326:
      if (lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 327:
      if (lookahead == 'o') ADVANCE(449);
      END_STATE();
    case 328:
      if (lookahead == 'g') ADVANCE(450);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(anon_sym_view);
      END_STATE();
    case 330:
      if (lookahead == 'u') ADVANCE(451);
      END_STATE();
    case 331:
      if (lookahead == 's') ADVANCE(452);
      END_STATE();
    case 332:
      if (lookahead == 'e') ADVANCE(453);
      END_STATE();
    case 333:
      if (lookahead == 's') ADVANCE(454);
      END_STATE();
    case 334:
      if (lookahead == 'a') ADVANCE(455);
      END_STATE();
    case 335:
      if (lookahead == 'd') ADVANCE(456);
      END_STATE();
    case 336:
      if (lookahead == 's') ADVANCE(457);
      END_STATE();
    case 337:
      if (lookahead == 'm') ADVANCE(458);
      END_STATE();
    case 338:
      if (lookahead == 'b') ADVANCE(459);
      END_STATE();
    case 339:
      if (lookahead == 'c') ADVANCE(460);
      END_STATE();
    case 340:
      if (lookahead == 'h') ADVANCE(461);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(anon_sym_bytes);
      if (lookahead == '1') ADVANCE(462);
      if (lookahead == '2') ADVANCE(463);
      if (lookahead == '3') ADVANCE(464);
      if (lookahead == '4') ADVANCE(465);
      if (lookahead == '5') ADVANCE(466);
      if (lookahead == '6') ADVANCE(467);
      if (lookahead == '7') ADVANCE(468);
      if (lookahead == '8') ADVANCE(469);
      if (lookahead == '9') ADVANCE(470);
      END_STATE();
    case 343:
      if (lookahead == 'o') ADVANCE(471);
      END_STATE();
    case 344:
      if (lookahead == 'a') ADVANCE(472);
      END_STATE();
    case 345:
      if (lookahead == 'r') ADVANCE(473);
      END_STATE();
    case 346:
      if (lookahead == 'a') ADVANCE(474);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 348:
      if (lookahead == 'i') ADVANCE(475);
      END_STATE();
    case 349:
      if (lookahead == 'a') ADVANCE(476);
      END_STATE();
    case 350:
      if (lookahead == 'a') ADVANCE(477);
      if (lookahead == 'r') ADVANCE(478);
      END_STATE();
    case 351:
      if (lookahead == 'n') ADVANCE(479);
      END_STATE();
    case 352:
      if (lookahead == 'a') ADVANCE(480);
      END_STATE();
    case 353:
      if (lookahead == 'e') ADVANCE(481);
      END_STATE();
    case 354:
      if (lookahead == 'l') ADVANCE(482);
      END_STATE();
    case 355:
      if (lookahead == 'a') ADVANCE(483);
      END_STATE();
    case 356:
      if (lookahead == 'e') ADVANCE(484);
      END_STATE();
    case 357:
      if (lookahead == 'c') ADVANCE(485);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(anon_sym_error);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(anon_sym_ether);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(anon_sym_event);
      END_STATE();
    case 361:
      if (lookahead == 'd') ADVANCE(486);
      END_STATE();
    case 362:
      if (lookahead == 'n') ADVANCE(487);
      END_STATE();
    case 363:
      if (lookahead == 'a') ADVANCE(488);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 365:
      if (lookahead == 'y') ADVANCE(489);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(anon_sym_fixed);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(490);
      END_STATE();
    case 367:
      if (lookahead == 'i') ADVANCE(491);
      END_STATE();
    case 368:
      if (lookahead == 'm') ADVANCE(492);
      END_STATE();
    case 369:
      if (lookahead == 'i') ADVANCE(493);
      END_STATE();
    case 370:
      if (lookahead == 'l') ADVANCE(494);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(anon_sym_hours);
      END_STATE();
    case 372:
      if (lookahead == 'a') ADVANCE(495);
      END_STATE();
    case 373:
      if (lookahead == 't') ADVANCE(496);
      END_STATE();
    case 374:
      if (lookahead == 'e') ADVANCE(497);
      END_STATE();
    case 375:
      if (lookahead == '4') ADVANCE(498);
      END_STATE();
    case 376:
      if (lookahead == '2') ADVANCE(499);
      END_STATE();
    case 377:
      if (lookahead == '0') ADVANCE(500);
      if (lookahead == '8') ADVANCE(501);
      END_STATE();
    case 378:
      if (lookahead == '6') ADVANCE(502);
      END_STATE();
    case 379:
      if (lookahead == '4') ADVANCE(503);
      END_STATE();
    case 380:
      if (lookahead == '2') ADVANCE(504);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_int16);
      if (lookahead == '0') ADVANCE(505);
      if (lookahead == '8') ADVANCE(506);
      END_STATE();
    case 382:
      if (lookahead == '6') ADVANCE(507);
      END_STATE();
    case 383:
      if (lookahead == '4') ADVANCE(508);
      END_STATE();
    case 384:
      if (lookahead == '2') ADVANCE(509);
      END_STATE();
    case 385:
      if (lookahead == '0') ADVANCE(510);
      if (lookahead == '8') ADVANCE(511);
      END_STATE();
    case 386:
      if (lookahead == '6') ADVANCE(512);
      END_STATE();
    case 387:
      if (lookahead == '4') ADVANCE(513);
      END_STATE();
    case 388:
      if (lookahead == '2') ADVANCE(514);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(anon_sym_int24);
      if (lookahead == '0') ADVANCE(515);
      if (lookahead == '8') ADVANCE(516);
      END_STATE();
    case 390:
      if (lookahead == '6') ADVANCE(517);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_int32);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(anon_sym_int40);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_int48);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_int56);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_int64);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_int72);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(anon_sym_int80);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(anon_sym_int88);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(anon_sym_int96);
      END_STATE();
    case 400:
      if (lookahead == 'f') ADVANCE(518);
      if (lookahead == 'n') ADVANCE(519);
      END_STATE();
    case 401:
      if (lookahead == 'i') ADVANCE(520);
      END_STATE();
    case 402:
      if (lookahead == 'o') ADVANCE(521);
      END_STATE();
    case 403:
      if (lookahead == 'k') ADVANCE(522);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(sym_yul_leave);
      END_STATE();
    case 405:
      if (lookahead == 'r') ADVANCE(523);
      END_STATE();
    case 406:
      if (lookahead == 'n') ADVANCE(524);
      END_STATE();
    case 407:
      if (lookahead == 'y') ADVANCE(525);
      END_STATE();
    case 408:
      if (lookahead == 'e') ADVANCE(526);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_mload);
      END_STATE();
    case 410:
      if (lookahead == 'i') ADVANCE(527);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_msize);
      END_STATE();
    case 412:
      if (lookahead == 'e') ADVANCE(528);
      END_STATE();
    case 413:
      if (lookahead == 'd') ADVANCE(529);
      END_STATE();
    case 414:
      if (lookahead == 'r') ADVANCE(530);
      END_STATE();
    case 415:
      if (lookahead == 'n') ADVANCE(531);
      END_STATE();
    case 416:
      if (lookahead == 'i') ADVANCE(532);
      END_STATE();
    case 417:
      if (lookahead == 'l') ADVANCE(533);
      END_STATE();
    case 418:
      if (lookahead == 'a') ADVANCE(534);
      END_STATE();
    case 419:
      if (lookahead == 't') ADVANCE(535);
      END_STATE();
    case 420:
      if (lookahead == 'c') ADVANCE(536);
      END_STATE();
    case 421:
      if (lookahead == 'v') ADVANCE(537);
      END_STATE();
    case 422:
      if (lookahead == 'n') ADVANCE(538);
      END_STATE();
    case 423:
      if (lookahead == 't') ADVANCE(539);
      END_STATE();
    case 424:
      if (lookahead == 'd') ADVANCE(540);
      END_STATE();
    case 425:
      if (lookahead == 'a') ADVANCE(541);
      END_STATE();
    case 426:
      if (lookahead == 'e') ADVANCE(542);
      END_STATE();
    case 427:
      if (lookahead == 'x') ADVANCE(543);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_sload);
      END_STATE();
    case 429:
      if (lookahead == 'i') ADVANCE(544);
      END_STATE();
    case 430:
      if (lookahead == 'e') ADVANCE(545);
      END_STATE();
    case 431:
      if (lookahead == 'c') ADVANCE(546);
      END_STATE();
    case 432:
      if (lookahead == 'g') ADVANCE(547);
      END_STATE();
    case 433:
      if (lookahead == 'g') ADVANCE(548);
      END_STATE();
    case 434:
      if (lookahead == 't') ADVANCE(549);
      END_STATE();
    case 435:
      if (lookahead == 'h') ADVANCE(550);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_szabo);
      END_STATE();
    case 437:
      if (lookahead == 't') ADVANCE(551);
      END_STATE();
    case 438:
      if (lookahead == 'd') ADVANCE(552);
      END_STATE();
    case 439:
      if (lookahead == '0') ADVANCE(553);
      if (lookahead == '1') ADVANCE(554);
      if (lookahead == '2') ADVANCE(555);
      if (lookahead == '3') ADVANCE(556);
      if (lookahead == '4') ADVANCE(557);
      if (lookahead == '5') ADVANCE(558);
      if (lookahead == '6') ADVANCE(559);
      if (lookahead == '7') ADVANCE(560);
      if (lookahead == '8') ADVANCE(561);
      if (lookahead == '9') ADVANCE(562);
      END_STATE();
    case 440:
      if (lookahead == '0') ADVANCE(563);
      if (lookahead == '1') ADVANCE(564);
      if (lookahead == '2') ADVANCE(565);
      if (lookahead == '3') ADVANCE(566);
      if (lookahead == '4') ADVANCE(567);
      if (lookahead == '5') ADVANCE(568);
      END_STATE();
    case 441:
      if (lookahead == '2') ADVANCE(569);
      END_STATE();
    case 442:
      if (lookahead == '0') ADVANCE(570);
      if (lookahead == '8') ADVANCE(571);
      END_STATE();
    case 443:
      if (lookahead == '6') ADVANCE(572);
      END_STATE();
    case 444:
      if (lookahead == '4') ADVANCE(573);
      END_STATE();
    case 445:
      if (lookahead == '2') ADVANCE(574);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_uint8);
      if (lookahead == '0') ADVANCE(575);
      if (lookahead == '8') ADVANCE(576);
      END_STATE();
    case 447:
      if (lookahead == '6') ADVANCE(577);
      END_STATE();
    case 448:
      if (lookahead == 'c') ADVANCE(578);
      END_STATE();
    case 449:
      if (lookahead == 'd') ADVANCE(579);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 451:
      if (lookahead == 'a') ADVANCE(580);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_weeks);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_years);
      END_STATE();
    case 455:
      if (lookahead == 'c') ADVANCE(581);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_addmod);
      END_STATE();
    case 457:
      if (lookahead == 's') ADVANCE(582);
      END_STATE();
    case 458:
      if (lookahead == 'o') ADVANCE(583);
      END_STATE();
    case 459:
      if (lookahead == 'l') ADVANCE(584);
      END_STATE();
    case 460:
      if (lookahead == 'e') ADVANCE(585);
      END_STATE();
    case 461:
      if (lookahead == 'a') ADVANCE(586);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_bytes1);
      if (lookahead == '0') ADVANCE(587);
      if (lookahead == '1') ADVANCE(588);
      if (lookahead == '2') ADVANCE(589);
      if (lookahead == '3') ADVANCE(590);
      if (lookahead == '4') ADVANCE(591);
      if (lookahead == '5') ADVANCE(592);
      if (lookahead == '6') ADVANCE(593);
      if (lookahead == '7') ADVANCE(594);
      if (lookahead == '8') ADVANCE(595);
      if (lookahead == '9') ADVANCE(596);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_bytes2);
      if (lookahead == '0') ADVANCE(597);
      if (lookahead == '1') ADVANCE(598);
      if (lookahead == '2') ADVANCE(599);
      if (lookahead == '3') ADVANCE(600);
      if (lookahead == '4') ADVANCE(601);
      if (lookahead == '5') ADVANCE(602);
      if (lookahead == '6') ADVANCE(603);
      if (lookahead == '7') ADVANCE(604);
      if (lookahead == '8') ADVANCE(605);
      if (lookahead == '9') ADVANCE(606);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_bytes3);
      if (lookahead == '0') ADVANCE(607);
      if (lookahead == '1') ADVANCE(608);
      if (lookahead == '2') ADVANCE(609);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_bytes4);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_bytes5);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_bytes6);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_bytes7);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_bytes8);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_bytes9);
      END_STATE();
    case 471:
      if (lookahead == 'd') ADVANCE(610);
      END_STATE();
    case 472:
      if (lookahead == 't') ADVANCE(611);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_caller);
      END_STATE();
    case 474:
      if (lookahead == 'l') ADVANCE(612);
      END_STATE();
    case 475:
      if (lookahead == 'd') ADVANCE(613);
      END_STATE();
    case 476:
      if (lookahead == 's') ADVANCE(614);
      END_STATE();
    case 477:
      if (lookahead == 'n') ADVANCE(615);
      END_STATE();
    case 478:
      if (lookahead == 'u') ADVANCE(616);
      END_STATE();
    case 479:
      if (lookahead == 'u') ADVANCE(617);
      END_STATE();
    case 480:
      if (lookahead == 'c') ADVANCE(618);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_create);
      if (lookahead == '2') ADVANCE(619);
      END_STATE();
    case 482:
      if (lookahead == 't') ADVANCE(620);
      END_STATE();
    case 483:
      if (lookahead == 't') ADVANCE(621);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 485:
      if (lookahead == 'u') ADVANCE(622);
      END_STATE();
    case 486:
      if (lookahead == 'e') ADVANCE(623);
      END_STATE();
    case 487:
      if (lookahead == 'a') ADVANCE(624);
      END_STATE();
    case 488:
      if (lookahead == 'c') ADVANCE(625);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_finney);
      END_STATE();
    case 490:
      if (lookahead == 'x') ADVANCE(626);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(490);
      END_STATE();
    case 491:
      if (lookahead == 'o') ADVANCE(627);
      END_STATE();
    case 492:
      if (lookahead == 'i') ADVANCE(628);
      END_STATE();
    case 493:
      if (lookahead == 'c') ADVANCE(629);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 495:
      if (lookahead == 'b') ADVANCE(630);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 497:
      if (lookahead == 'd') ADVANCE(631);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_int104);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_int112);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_int120);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_int128);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_int136);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(anon_sym_int144);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_int152);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym_int160);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_int168);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_int176);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_int184);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_int192);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_int200);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_int208);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_int216);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_int224);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_int232);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_int240);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_int248);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_int256);
      END_STATE();
    case 518:
      if (lookahead == 'a') ADVANCE(632);
      END_STATE();
    case 519:
      if (lookahead == 'a') ADVANCE(633);
      END_STATE();
    case 520:
      if (lookahead == 'd') ADVANCE(634);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(anon_sym_iszero);
      END_STATE();
    case 522:
      if (lookahead == '2') ADVANCE(635);
      END_STATE();
    case 523:
      if (lookahead == 'y') ADVANCE(636);
      END_STATE();
    case 524:
      if (lookahead == 'g') ADVANCE(637);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_memory);
      END_STATE();
    case 526:
      if (lookahead == 's') ADVANCE(638);
      END_STATE();
    case 527:
      if (lookahead == 'e') ADVANCE(639);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_mstore);
      if (lookahead == '8') ADVANCE(640);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_mulmod);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_number);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_origin);
      END_STATE();
    case 532:
      if (lookahead == 'd') ADVANCE(641);
      END_STATE();
    case 533:
      if (lookahead == 'e') ADVANCE(642);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_pragma);
      END_STATE();
    case 535:
      if (lookahead == 'e') ADVANCE(643);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 537:
      if (lookahead == 'e') ADVANCE(644);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_return);
      if (lookahead == 'd') ADVANCE(645);
      if (lookahead == 's') ADVANCE(646);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_revert);
      END_STATE();
    case 540:
      if (lookahead == 's') ADVANCE(647);
      END_STATE();
    case 541:
      if (lookahead == 'l') ADVANCE(648);
      END_STATE();
    case 542:
      if (lookahead == 's') ADVANCE(649);
      END_STATE();
    case 543:
      if (lookahead == 't') ADVANCE(650);
      END_STATE();
    case 544:
      if (lookahead == 't') ADVANCE(651);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_sstore);
      END_STATE();
    case 546:
      if (lookahead == 'c') ADVANCE(652);
      END_STATE();
    case 547:
      if (lookahead == 'e') ADVANCE(653);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 551:
      if (lookahead == 'a') ADVANCE(654);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_ufixed);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(655);
      END_STATE();
    case 553:
      if (lookahead == '4') ADVANCE(656);
      END_STATE();
    case 554:
      if (lookahead == '2') ADVANCE(657);
      END_STATE();
    case 555:
      if (lookahead == '0') ADVANCE(658);
      if (lookahead == '8') ADVANCE(659);
      END_STATE();
    case 556:
      if (lookahead == '6') ADVANCE(660);
      END_STATE();
    case 557:
      if (lookahead == '4') ADVANCE(661);
      END_STATE();
    case 558:
      if (lookahead == '2') ADVANCE(662);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_uint16);
      if (lookahead == '0') ADVANCE(663);
      if (lookahead == '8') ADVANCE(664);
      END_STATE();
    case 560:
      if (lookahead == '6') ADVANCE(665);
      END_STATE();
    case 561:
      if (lookahead == '4') ADVANCE(666);
      END_STATE();
    case 562:
      if (lookahead == '2') ADVANCE(667);
      END_STATE();
    case 563:
      if (lookahead == '0') ADVANCE(668);
      if (lookahead == '8') ADVANCE(669);
      END_STATE();
    case 564:
      if (lookahead == '6') ADVANCE(670);
      END_STATE();
    case 565:
      if (lookahead == '4') ADVANCE(671);
      END_STATE();
    case 566:
      if (lookahead == '2') ADVANCE(672);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_uint24);
      if (lookahead == '0') ADVANCE(673);
      if (lookahead == '8') ADVANCE(674);
      END_STATE();
    case 568:
      if (lookahead == '6') ADVANCE(675);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_uint32);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_uint40);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_uint48);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_uint56);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_uint64);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_uint72);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_uint80);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_uint88);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_uint96);
      END_STATE();
    case 578:
      if (lookahead == 'k') ADVANCE(676);
      END_STATE();
    case 579:
      if (lookahead == 'e') ADVANCE(677);
      END_STATE();
    case 580:
      if (lookahead == 'l') ADVANCE(678);
      END_STATE();
    case 581:
      if (lookahead == 't') ADVANCE(679);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_address);
      END_STATE();
    case 583:
      if (lookahead == 'u') ADVANCE(680);
      END_STATE();
    case 584:
      if (lookahead == 'y') ADVANCE(681);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_balance);
      END_STATE();
    case 586:
      if (lookahead == 's') ADVANCE(682);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_bytes10);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym_bytes11);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_bytes12);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym_bytes13);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym_bytes14);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_bytes15);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_bytes16);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_bytes17);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_bytes18);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_bytes19);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_bytes20);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_bytes21);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_bytes22);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_bytes23);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_bytes24);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_bytes25);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_bytes26);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_bytes27);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_bytes28);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_bytes29);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(anon_sym_bytes30);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(anon_sym_bytes31);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_bytes32);
      END_STATE();
    case 610:
      if (lookahead == 'e') ADVANCE(683);
      END_STATE();
    case 611:
      if (lookahead == 'a') ADVANCE(684);
      END_STATE();
    case 612:
      if (lookahead == 'u') ADVANCE(685);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_chainid);
      END_STATE();
    case 614:
      if (lookahead == 'e') ADVANCE(686);
      END_STATE();
    case 615:
      if (lookahead == 't') ADVANCE(687);
      END_STATE();
    case 616:
      if (lookahead == 'c') ADVANCE(688);
      END_STATE();
    case 617:
      if (lookahead == 'e') ADVANCE(689);
      END_STATE();
    case 618:
      if (lookahead == 't') ADVANCE(690);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(anon_sym_create2);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 621:
      if (lookahead == 'e') ADVANCE(691);
      END_STATE();
    case 622:
      if (lookahead == 'l') ADVANCE(692);
      END_STATE();
    case 623:
      if (lookahead == 'c') ADVANCE(693);
      if (lookahead == 'h') ADVANCE(694);
      if (lookahead == 's') ADVANCE(695);
      END_STATE();
    case 624:
      if (lookahead == 'l') ADVANCE(696);
      END_STATE();
    case 625:
      if (lookahead == 'k') ADVANCE(697);
      END_STATE();
    case 626:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(698);
      END_STATE();
    case 627:
      if (lookahead == 'n') ADVANCE(699);
      END_STATE();
    case 628:
      if (lookahead == 't') ADVANCE(700);
      END_STATE();
    case 629:
      if (lookahead == 'e') ADVANCE(701);
      END_STATE();
    case 630:
      if (lookahead == 'l') ADVANCE(702);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym_indexed);
      END_STATE();
    case 632:
      if (lookahead == 'c') ADVANCE(703);
      END_STATE();
    case 633:
      if (lookahead == 'l') ADVANCE(704);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(anon_sym_invalid);
      END_STATE();
    case 635:
      if (lookahead == '5') ADVANCE(705);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(anon_sym_library);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(anon_sym_mapping);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(anon_sym_minutes);
      END_STATE();
    case 639:
      if (lookahead == 'r') ADVANCE(706);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(anon_sym_mstore8);
      END_STATE();
    case 641:
      if (lookahead == 'e') ADVANCE(707);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(anon_sym_payable);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(anon_sym_receive);
      END_STATE();
    case 645:
      if (lookahead == 'a') ADVANCE(708);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(anon_sym_returns);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_seconds);
      END_STATE();
    case 648:
      if (lookahead == 'a') ADVANCE(709);
      END_STATE();
    case 649:
      if (lookahead == 't') ADVANCE(710);
      END_STATE();
    case 650:
      if (lookahead == 'e') ADVANCE(711);
      END_STATE();
    case 651:
      if (lookahead == 'y') ADVANCE(712);
      END_STATE();
    case 652:
      if (lookahead == 'a') ADVANCE(713);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(anon_sym_storage);
      END_STATE();
    case 654:
      if (lookahead == 'm') ADVANCE(714);
      END_STATE();
    case 655:
      if (lookahead == 'x') ADVANCE(715);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(655);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(anon_sym_uint104);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(anon_sym_uint112);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(anon_sym_uint120);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(anon_sym_uint128);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(anon_sym_uint136);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(anon_sym_uint144);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(anon_sym_uint152);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(anon_sym_uint160);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(anon_sym_uint168);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(anon_sym_uint176);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(anon_sym_uint184);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(anon_sym_uint192);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym_uint200);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(anon_sym_uint208);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(anon_sym_uint216);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(anon_sym_uint224);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(anon_sym_uint232);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym_uint240);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(anon_sym_uint248);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(anon_sym_uint256);
      END_STATE();
    case 676:
      if (lookahead == 'e') ADVANCE(716);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(anon_sym_unicode);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(sym_virtual);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(anon_sym_abstract);
      END_STATE();
    case 680:
      if (lookahead == 's') ADVANCE(717);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(anon_sym_assembly);
      END_STATE();
    case 682:
      if (lookahead == 'h') ADVANCE(718);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(anon_sym_callcode);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(anon_sym_calldata);
      if (lookahead == 'c') ADVANCE(719);
      if (lookahead == 'l') ADVANCE(720);
      if (lookahead == 's') ADVANCE(721);
      END_STATE();
    case 685:
      if (lookahead == 'e') ADVANCE(722);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(anon_sym_coinbase);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(anon_sym_constant);
      END_STATE();
    case 688:
      if (lookahead == 't') ADVANCE(723);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(anon_sym_contract);
      END_STATE();
    case 691:
      if (lookahead == 'c') ADVANCE(724);
      END_STATE();
    case 692:
      if (lookahead == 't') ADVANCE(725);
      END_STATE();
    case 693:
      if (lookahead == 'o') ADVANCE(726);
      END_STATE();
    case 694:
      if (lookahead == 'a') ADVANCE(727);
      END_STATE();
    case 695:
      if (lookahead == 'i') ADVANCE(728);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(anon_sym_external);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(anon_sym_fallback);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(aux_sym__fixed_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(698);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(anon_sym_gaslimit);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(anon_sym_gasprice);
      END_STATE();
    case 702:
      if (lookahead == 'e') ADVANCE(729);
      END_STATE();
    case 703:
      if (lookahead == 'e') ADVANCE(730);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(anon_sym_internal);
      END_STATE();
    case 705:
      if (lookahead == '6') ADVANCE(731);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(anon_sym_modifier);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 708:
      if (lookahead == 't') ADVANCE(732);
      END_STATE();
    case 709:
      if (lookahead == 'n') ADVANCE(733);
      END_STATE();
    case 710:
      if (lookahead == 'r') ADVANCE(734);
      END_STATE();
    case 711:
      if (lookahead == 'n') ADVANCE(735);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(anon_sym_solidity);
      END_STATE();
    case 713:
      if (lookahead == 'l') ADVANCE(736);
      END_STATE();
    case 714:
      if (lookahead == 'p') ADVANCE(737);
      END_STATE();
    case 715:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(738);
      END_STATE();
    case 716:
      if (lookahead == 'd') ADVANCE(739);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(anon_sym_anonymous);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(anon_sym_blockhash);
      END_STATE();
    case 719:
      if (lookahead == 'o') ADVANCE(740);
      END_STATE();
    case 720:
      if (lookahead == 'o') ADVANCE(741);
      END_STATE();
    case 721:
      if (lookahead == 'i') ADVANCE(742);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(anon_sym_callvalue);
      END_STATE();
    case 723:
      if (lookahead == 'o') ADVANCE(743);
      END_STATE();
    case 724:
      if (lookahead == 'a') ADVANCE(744);
      END_STATE();
    case 725:
      if (lookahead == 'y') ADVANCE(745);
      END_STATE();
    case 726:
      if (lookahead == 'p') ADVANCE(746);
      END_STATE();
    case 727:
      if (lookahead == 's') ADVANCE(747);
      END_STATE();
    case 728:
      if (lookahead == 'z') ADVANCE(748);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(sym_immutable);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(anon_sym_keccak256);
      END_STATE();
    case 732:
      if (lookahead == 'a') ADVANCE(749);
      END_STATE();
    case 733:
      if (lookahead == 'c') ADVANCE(750);
      END_STATE();
    case 734:
      if (lookahead == 'u') ADVANCE(751);
      END_STATE();
    case 735:
      if (lookahead == 'd') ADVANCE(752);
      END_STATE();
    case 736:
      if (lookahead == 'l') ADVANCE(753);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(anon_sym_timestamp);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(aux_sym__ufixed_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(738);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(sym__unchecked);
      END_STATE();
    case 740:
      if (lookahead == 'p') ADVANCE(754);
      END_STATE();
    case 741:
      if (lookahead == 'a') ADVANCE(755);
      END_STATE();
    case 742:
      if (lookahead == 'z') ADVANCE(756);
      END_STATE();
    case 743:
      if (lookahead == 'r') ADVANCE(757);
      END_STATE();
    case 744:
      if (lookahead == 'l') ADVANCE(758);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(anon_sym_difficulty);
      END_STATE();
    case 746:
      if (lookahead == 'y') ADVANCE(759);
      END_STATE();
    case 747:
      if (lookahead == 'h') ADVANCE(760);
      END_STATE();
    case 748:
      if (lookahead == 'e') ADVANCE(761);
      END_STATE();
    case 749:
      if (lookahead == 'c') ADVANCE(762);
      if (lookahead == 's') ADVANCE(763);
      END_STATE();
    case 750:
      if (lookahead == 'e') ADVANCE(764);
      END_STATE();
    case 751:
      if (lookahead == 'c') ADVANCE(765);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(anon_sym_signextend);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(anon_sym_staticcall);
      END_STATE();
    case 754:
      if (lookahead == 'y') ADVANCE(766);
      END_STATE();
    case 755:
      if (lookahead == 'd') ADVANCE(767);
      END_STATE();
    case 756:
      if (lookahead == 'e') ADVANCE(768);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(anon_sym_constructor);
      END_STATE();
    case 758:
      if (lookahead == 'l') ADVANCE(769);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(anon_sym_extcodecopy);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(anon_sym_extcodehash);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(anon_sym_extcodesize);
      END_STATE();
    case 762:
      if (lookahead == 'o') ADVANCE(770);
      END_STATE();
    case 763:
      if (lookahead == 'i') ADVANCE(771);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(anon_sym_selfbalance);
      END_STATE();
    case 765:
      if (lookahead == 't') ADVANCE(772);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(anon_sym_calldatacopy);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(anon_sym_calldataload);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(anon_sym_calldatasize);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(anon_sym_delegatecall);
      END_STATE();
    case 770:
      if (lookahead == 'p') ADVANCE(773);
      END_STATE();
    case 771:
      if (lookahead == 'z') ADVANCE(774);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(anon_sym_selfdestruct);
      END_STATE();
    case 773:
      if (lookahead == 'y') ADVANCE(775);
      END_STATE();
    case 774:
      if (lookahead == 'e') ADVANCE(776);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(anon_sym_returndatacopy);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(anon_sym_returndatasize);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 52},
  [2] = {.lex_state = 11},
  [3] = {.lex_state = 11},
  [4] = {.lex_state = 11},
  [5] = {.lex_state = 11},
  [6] = {.lex_state = 11},
  [7] = {.lex_state = 11},
  [8] = {.lex_state = 11},
  [9] = {.lex_state = 11},
  [10] = {.lex_state = 11},
  [11] = {.lex_state = 11},
  [12] = {.lex_state = 11},
  [13] = {.lex_state = 11},
  [14] = {.lex_state = 11},
  [15] = {.lex_state = 11},
  [16] = {.lex_state = 11},
  [17] = {.lex_state = 11},
  [18] = {.lex_state = 11},
  [19] = {.lex_state = 11},
  [20] = {.lex_state = 11},
  [21] = {.lex_state = 11},
  [22] = {.lex_state = 11},
  [23] = {.lex_state = 11},
  [24] = {.lex_state = 11},
  [25] = {.lex_state = 11},
  [26] = {.lex_state = 11},
  [27] = {.lex_state = 11},
  [28] = {.lex_state = 11},
  [29] = {.lex_state = 11},
  [30] = {.lex_state = 11},
  [31] = {.lex_state = 11},
  [32] = {.lex_state = 11},
  [33] = {.lex_state = 11},
  [34] = {.lex_state = 11},
  [35] = {.lex_state = 11},
  [36] = {.lex_state = 11},
  [37] = {.lex_state = 11},
  [38] = {.lex_state = 11},
  [39] = {.lex_state = 11},
  [40] = {.lex_state = 11},
  [41] = {.lex_state = 11},
  [42] = {.lex_state = 11},
  [43] = {.lex_state = 11},
  [44] = {.lex_state = 11},
  [45] = {.lex_state = 11},
  [46] = {.lex_state = 11},
  [47] = {.lex_state = 11},
  [48] = {.lex_state = 11},
  [49] = {.lex_state = 11},
  [50] = {.lex_state = 11},
  [51] = {.lex_state = 11},
  [52] = {.lex_state = 11},
  [53] = {.lex_state = 11},
  [54] = {.lex_state = 11},
  [55] = {.lex_state = 11},
  [56] = {.lex_state = 11},
  [57] = {.lex_state = 11},
  [58] = {.lex_state = 11},
  [59] = {.lex_state = 11},
  [60] = {.lex_state = 11},
  [61] = {.lex_state = 11},
  [62] = {.lex_state = 11},
  [63] = {.lex_state = 11},
  [64] = {.lex_state = 11},
  [65] = {.lex_state = 11},
  [66] = {.lex_state = 11},
  [67] = {.lex_state = 11},
  [68] = {.lex_state = 11},
  [69] = {.lex_state = 52},
  [70] = {.lex_state = 52},
  [71] = {.lex_state = 11},
  [72] = {.lex_state = 11},
  [73] = {.lex_state = 11},
  [74] = {.lex_state = 11},
  [75] = {.lex_state = 11},
  [76] = {.lex_state = 52},
  [77] = {.lex_state = 11},
  [78] = {.lex_state = 11},
  [79] = {.lex_state = 52},
  [80] = {.lex_state = 11},
  [81] = {.lex_state = 11},
  [82] = {.lex_state = 52},
  [83] = {.lex_state = 11},
  [84] = {.lex_state = 11},
  [85] = {.lex_state = 11},
  [86] = {.lex_state = 11},
  [87] = {.lex_state = 11},
  [88] = {.lex_state = 11},
  [89] = {.lex_state = 11},
  [90] = {.lex_state = 11},
  [91] = {.lex_state = 11},
  [92] = {.lex_state = 11},
  [93] = {.lex_state = 11},
  [94] = {.lex_state = 11},
  [95] = {.lex_state = 11},
  [96] = {.lex_state = 11},
  [97] = {.lex_state = 11},
  [98] = {.lex_state = 11},
  [99] = {.lex_state = 11},
  [100] = {.lex_state = 11},
  [101] = {.lex_state = 11},
  [102] = {.lex_state = 11},
  [103] = {.lex_state = 11},
  [104] = {.lex_state = 11},
  [105] = {.lex_state = 11},
  [106] = {.lex_state = 11},
  [107] = {.lex_state = 11},
  [108] = {.lex_state = 52},
  [109] = {.lex_state = 52},
  [110] = {.lex_state = 52},
  [111] = {.lex_state = 52},
  [112] = {.lex_state = 52},
  [113] = {.lex_state = 52},
  [114] = {.lex_state = 52},
  [115] = {.lex_state = 52},
  [116] = {.lex_state = 52},
  [117] = {.lex_state = 52},
  [118] = {.lex_state = 52},
  [119] = {.lex_state = 52},
  [120] = {.lex_state = 52},
  [121] = {.lex_state = 52},
  [122] = {.lex_state = 52},
  [123] = {.lex_state = 52},
  [124] = {.lex_state = 52},
  [125] = {.lex_state = 52},
  [126] = {.lex_state = 52},
  [127] = {.lex_state = 52},
  [128] = {.lex_state = 52},
  [129] = {.lex_state = 52},
  [130] = {.lex_state = 52},
  [131] = {.lex_state = 52},
  [132] = {.lex_state = 52},
  [133] = {.lex_state = 52},
  [134] = {.lex_state = 52},
  [135] = {.lex_state = 52},
  [136] = {.lex_state = 52},
  [137] = {.lex_state = 52},
  [138] = {.lex_state = 52},
  [139] = {.lex_state = 52},
  [140] = {.lex_state = 52},
  [141] = {.lex_state = 52},
  [142] = {.lex_state = 52},
  [143] = {.lex_state = 52},
  [144] = {.lex_state = 52},
  [145] = {.lex_state = 52},
  [146] = {.lex_state = 52},
  [147] = {.lex_state = 52},
  [148] = {.lex_state = 52},
  [149] = {.lex_state = 52},
  [150] = {.lex_state = 52},
  [151] = {.lex_state = 52},
  [152] = {.lex_state = 52},
  [153] = {.lex_state = 52},
  [154] = {.lex_state = 52},
  [155] = {.lex_state = 52},
  [156] = {.lex_state = 52},
  [157] = {.lex_state = 52},
  [158] = {.lex_state = 52},
  [159] = {.lex_state = 52},
  [160] = {.lex_state = 52},
  [161] = {.lex_state = 52},
  [162] = {.lex_state = 52},
  [163] = {.lex_state = 52},
  [164] = {.lex_state = 52},
  [165] = {.lex_state = 52},
  [166] = {.lex_state = 52},
  [167] = {.lex_state = 52},
  [168] = {.lex_state = 52},
  [169] = {.lex_state = 52},
  [170] = {.lex_state = 52},
  [171] = {.lex_state = 52},
  [172] = {.lex_state = 52},
  [173] = {.lex_state = 52},
  [174] = {.lex_state = 52},
  [175] = {.lex_state = 52},
  [176] = {.lex_state = 52},
  [177] = {.lex_state = 52},
  [178] = {.lex_state = 52},
  [179] = {.lex_state = 52},
  [180] = {.lex_state = 52},
  [181] = {.lex_state = 52},
  [182] = {.lex_state = 52},
  [183] = {.lex_state = 52},
  [184] = {.lex_state = 52},
  [185] = {.lex_state = 52},
  [186] = {.lex_state = 52},
  [187] = {.lex_state = 52},
  [188] = {.lex_state = 52},
  [189] = {.lex_state = 52},
  [190] = {.lex_state = 52},
  [191] = {.lex_state = 52},
  [192] = {.lex_state = 52},
  [193] = {.lex_state = 52},
  [194] = {.lex_state = 52},
  [195] = {.lex_state = 52},
  [196] = {.lex_state = 52},
  [197] = {.lex_state = 52},
  [198] = {.lex_state = 52},
  [199] = {.lex_state = 52},
  [200] = {.lex_state = 52},
  [201] = {.lex_state = 52},
  [202] = {.lex_state = 52},
  [203] = {.lex_state = 52},
  [204] = {.lex_state = 52},
  [205] = {.lex_state = 52},
  [206] = {.lex_state = 52},
  [207] = {.lex_state = 52},
  [208] = {.lex_state = 52},
  [209] = {.lex_state = 52},
  [210] = {.lex_state = 52},
  [211] = {.lex_state = 52},
  [212] = {.lex_state = 52},
  [213] = {.lex_state = 52},
  [214] = {.lex_state = 52},
  [215] = {.lex_state = 52},
  [216] = {.lex_state = 52},
  [217] = {.lex_state = 52},
  [218] = {.lex_state = 52},
  [219] = {.lex_state = 52},
  [220] = {.lex_state = 52},
  [221] = {.lex_state = 52},
  [222] = {.lex_state = 52},
  [223] = {.lex_state = 52},
  [224] = {.lex_state = 52},
  [225] = {.lex_state = 52},
  [226] = {.lex_state = 52},
  [227] = {.lex_state = 52},
  [228] = {.lex_state = 52},
  [229] = {.lex_state = 52},
  [230] = {.lex_state = 52},
  [231] = {.lex_state = 52},
  [232] = {.lex_state = 52},
  [233] = {.lex_state = 52},
  [234] = {.lex_state = 52},
  [235] = {.lex_state = 52},
  [236] = {.lex_state = 52},
  [237] = {.lex_state = 52},
  [238] = {.lex_state = 52},
  [239] = {.lex_state = 52},
  [240] = {.lex_state = 52},
  [241] = {.lex_state = 52},
  [242] = {.lex_state = 52},
  [243] = {.lex_state = 52},
  [244] = {.lex_state = 52},
  [245] = {.lex_state = 52},
  [246] = {.lex_state = 52},
  [247] = {.lex_state = 52},
  [248] = {.lex_state = 52},
  [249] = {.lex_state = 52},
  [250] = {.lex_state = 52},
  [251] = {.lex_state = 52},
  [252] = {.lex_state = 52},
  [253] = {.lex_state = 52},
  [254] = {.lex_state = 52},
  [255] = {.lex_state = 52},
  [256] = {.lex_state = 52},
  [257] = {.lex_state = 52},
  [258] = {.lex_state = 52},
  [259] = {.lex_state = 52},
  [260] = {.lex_state = 52},
  [261] = {.lex_state = 52},
  [262] = {.lex_state = 52},
  [263] = {.lex_state = 52},
  [264] = {.lex_state = 52},
  [265] = {.lex_state = 52},
  [266] = {.lex_state = 52},
  [267] = {.lex_state = 52},
  [268] = {.lex_state = 52},
  [269] = {.lex_state = 52},
  [270] = {.lex_state = 52},
  [271] = {.lex_state = 52},
  [272] = {.lex_state = 52},
  [273] = {.lex_state = 52},
  [274] = {.lex_state = 52},
  [275] = {.lex_state = 52},
  [276] = {.lex_state = 52},
  [277] = {.lex_state = 52},
  [278] = {.lex_state = 52},
  [279] = {.lex_state = 52},
  [280] = {.lex_state = 52},
  [281] = {.lex_state = 52},
  [282] = {.lex_state = 52},
  [283] = {.lex_state = 52},
  [284] = {.lex_state = 52},
  [285] = {.lex_state = 52},
  [286] = {.lex_state = 52},
  [287] = {.lex_state = 52},
  [288] = {.lex_state = 52},
  [289] = {.lex_state = 52},
  [290] = {.lex_state = 52},
  [291] = {.lex_state = 52},
  [292] = {.lex_state = 52},
  [293] = {.lex_state = 52},
  [294] = {.lex_state = 52},
  [295] = {.lex_state = 52},
  [296] = {.lex_state = 52},
  [297] = {.lex_state = 52},
  [298] = {.lex_state = 52},
  [299] = {.lex_state = 52},
  [300] = {.lex_state = 52},
  [301] = {.lex_state = 52},
  [302] = {.lex_state = 52},
  [303] = {.lex_state = 52},
  [304] = {.lex_state = 52},
  [305] = {.lex_state = 52},
  [306] = {.lex_state = 52},
  [307] = {.lex_state = 52},
  [308] = {.lex_state = 52},
  [309] = {.lex_state = 52},
  [310] = {.lex_state = 52},
  [311] = {.lex_state = 52},
  [312] = {.lex_state = 52},
  [313] = {.lex_state = 52},
  [314] = {.lex_state = 52},
  [315] = {.lex_state = 52},
  [316] = {.lex_state = 52},
  [317] = {.lex_state = 52},
  [318] = {.lex_state = 52},
  [319] = {.lex_state = 52},
  [320] = {.lex_state = 52},
  [321] = {.lex_state = 52},
  [322] = {.lex_state = 52},
  [323] = {.lex_state = 52},
  [324] = {.lex_state = 52},
  [325] = {.lex_state = 52},
  [326] = {.lex_state = 52},
  [327] = {.lex_state = 52},
  [328] = {.lex_state = 52},
  [329] = {.lex_state = 52},
  [330] = {.lex_state = 52},
  [331] = {.lex_state = 52},
  [332] = {.lex_state = 52},
  [333] = {.lex_state = 52},
  [334] = {.lex_state = 52},
  [335] = {.lex_state = 52},
  [336] = {.lex_state = 52},
  [337] = {.lex_state = 52},
  [338] = {.lex_state = 52},
  [339] = {.lex_state = 52},
  [340] = {.lex_state = 52},
  [341] = {.lex_state = 52},
  [342] = {.lex_state = 52},
  [343] = {.lex_state = 52},
  [344] = {.lex_state = 52},
  [345] = {.lex_state = 52},
  [346] = {.lex_state = 52},
  [347] = {.lex_state = 52},
  [348] = {.lex_state = 52},
  [349] = {.lex_state = 52},
  [350] = {.lex_state = 52},
  [351] = {.lex_state = 52},
  [352] = {.lex_state = 52},
  [353] = {.lex_state = 52},
  [354] = {.lex_state = 52},
  [355] = {.lex_state = 52},
  [356] = {.lex_state = 52},
  [357] = {.lex_state = 52},
  [358] = {.lex_state = 52},
  [359] = {.lex_state = 52},
  [360] = {.lex_state = 52},
  [361] = {.lex_state = 52},
  [362] = {.lex_state = 52},
  [363] = {.lex_state = 52},
  [364] = {.lex_state = 52},
  [365] = {.lex_state = 52},
  [366] = {.lex_state = 52},
  [367] = {.lex_state = 52},
  [368] = {.lex_state = 52},
  [369] = {.lex_state = 52},
  [370] = {.lex_state = 52},
  [371] = {.lex_state = 52},
  [372] = {.lex_state = 52},
  [373] = {.lex_state = 52},
  [374] = {.lex_state = 52},
  [375] = {.lex_state = 52},
  [376] = {.lex_state = 52},
  [377] = {.lex_state = 52},
  [378] = {.lex_state = 52},
  [379] = {.lex_state = 52},
  [380] = {.lex_state = 52},
  [381] = {.lex_state = 52},
  [382] = {.lex_state = 52},
  [383] = {.lex_state = 52},
  [384] = {.lex_state = 52},
  [385] = {.lex_state = 52},
  [386] = {.lex_state = 10},
  [387] = {.lex_state = 9},
  [388] = {.lex_state = 9},
  [389] = {.lex_state = 10},
  [390] = {.lex_state = 9},
  [391] = {.lex_state = 9},
  [392] = {.lex_state = 9},
  [393] = {.lex_state = 9},
  [394] = {.lex_state = 9},
  [395] = {.lex_state = 9},
  [396] = {.lex_state = 9},
  [397] = {.lex_state = 9},
  [398] = {.lex_state = 9},
  [399] = {.lex_state = 10},
  [400] = {.lex_state = 10},
  [401] = {.lex_state = 10},
  [402] = {.lex_state = 10},
  [403] = {.lex_state = 9},
  [404] = {.lex_state = 9},
  [405] = {.lex_state = 9},
  [406] = {.lex_state = 9},
  [407] = {.lex_state = 9},
  [408] = {.lex_state = 9},
  [409] = {.lex_state = 9},
  [410] = {.lex_state = 9},
  [411] = {.lex_state = 9},
  [412] = {.lex_state = 9},
  [413] = {.lex_state = 9},
  [414] = {.lex_state = 9},
  [415] = {.lex_state = 9},
  [416] = {.lex_state = 9},
  [417] = {.lex_state = 9},
  [418] = {.lex_state = 9},
  [419] = {.lex_state = 9},
  [420] = {.lex_state = 9},
  [421] = {.lex_state = 9},
  [422] = {.lex_state = 9},
  [423] = {.lex_state = 9},
  [424] = {.lex_state = 9},
  [425] = {.lex_state = 9},
  [426] = {.lex_state = 9},
  [427] = {.lex_state = 9},
  [428] = {.lex_state = 9},
  [429] = {.lex_state = 9},
  [430] = {.lex_state = 9},
  [431] = {.lex_state = 9},
  [432] = {.lex_state = 9},
  [433] = {.lex_state = 9},
  [434] = {.lex_state = 9},
  [435] = {.lex_state = 9},
  [436] = {.lex_state = 9},
  [437] = {.lex_state = 9},
  [438] = {.lex_state = 9},
  [439] = {.lex_state = 9},
  [440] = {.lex_state = 9},
  [441] = {.lex_state = 9},
  [442] = {.lex_state = 9},
  [443] = {.lex_state = 9},
  [444] = {.lex_state = 9},
  [445] = {.lex_state = 9},
  [446] = {.lex_state = 9},
  [447] = {.lex_state = 9},
  [448] = {.lex_state = 9},
  [449] = {.lex_state = 9},
  [450] = {.lex_state = 9},
  [451] = {.lex_state = 9},
  [452] = {.lex_state = 9},
  [453] = {.lex_state = 9},
  [454] = {.lex_state = 9},
  [455] = {.lex_state = 9},
  [456] = {.lex_state = 9},
  [457] = {.lex_state = 9},
  [458] = {.lex_state = 9},
  [459] = {.lex_state = 9},
  [460] = {.lex_state = 9},
  [461] = {.lex_state = 9},
  [462] = {.lex_state = 9},
  [463] = {.lex_state = 9},
  [464] = {.lex_state = 9},
  [465] = {.lex_state = 9},
  [466] = {.lex_state = 9},
  [467] = {.lex_state = 9},
  [468] = {.lex_state = 9},
  [469] = {.lex_state = 9},
  [470] = {.lex_state = 9},
  [471] = {.lex_state = 9},
  [472] = {.lex_state = 9},
  [473] = {.lex_state = 9},
  [474] = {.lex_state = 9},
  [475] = {.lex_state = 9},
  [476] = {.lex_state = 9},
  [477] = {.lex_state = 9},
  [478] = {.lex_state = 9},
  [479] = {.lex_state = 9},
  [480] = {.lex_state = 9},
  [481] = {.lex_state = 9},
  [482] = {.lex_state = 9},
  [483] = {.lex_state = 9},
  [484] = {.lex_state = 9},
  [485] = {.lex_state = 52},
  [486] = {.lex_state = 52},
  [487] = {.lex_state = 9},
  [488] = {.lex_state = 52},
  [489] = {.lex_state = 52},
  [490] = {.lex_state = 52},
  [491] = {.lex_state = 52},
  [492] = {.lex_state = 52},
  [493] = {.lex_state = 52},
  [494] = {.lex_state = 9},
  [495] = {.lex_state = 52},
  [496] = {.lex_state = 52},
  [497] = {.lex_state = 52},
  [498] = {.lex_state = 52},
  [499] = {.lex_state = 52},
  [500] = {.lex_state = 52},
  [501] = {.lex_state = 52},
  [502] = {.lex_state = 52},
  [503] = {.lex_state = 52},
  [504] = {.lex_state = 52},
  [505] = {.lex_state = 52},
  [506] = {.lex_state = 52},
  [507] = {.lex_state = 52},
  [508] = {.lex_state = 52},
  [509] = {.lex_state = 52},
  [510] = {.lex_state = 52},
  [511] = {.lex_state = 52},
  [512] = {.lex_state = 52},
  [513] = {.lex_state = 52},
  [514] = {.lex_state = 9},
  [515] = {.lex_state = 52},
  [516] = {.lex_state = 52},
  [517] = {.lex_state = 52},
  [518] = {.lex_state = 52},
  [519] = {.lex_state = 52},
  [520] = {.lex_state = 52},
  [521] = {.lex_state = 52},
  [522] = {.lex_state = 12},
  [523] = {.lex_state = 12},
  [524] = {.lex_state = 52},
  [525] = {.lex_state = 52},
  [526] = {.lex_state = 52},
  [527] = {.lex_state = 52},
  [528] = {.lex_state = 52},
  [529] = {.lex_state = 52},
  [530] = {.lex_state = 52},
  [531] = {.lex_state = 12},
  [532] = {.lex_state = 12},
  [533] = {.lex_state = 12},
  [534] = {.lex_state = 52},
  [535] = {.lex_state = 52},
  [536] = {.lex_state = 52},
  [537] = {.lex_state = 52},
  [538] = {.lex_state = 52},
  [539] = {.lex_state = 52},
  [540] = {.lex_state = 52},
  [541] = {.lex_state = 52},
  [542] = {.lex_state = 52},
  [543] = {.lex_state = 52},
  [544] = {.lex_state = 52},
  [545] = {.lex_state = 52},
  [546] = {.lex_state = 5},
  [547] = {.lex_state = 52},
  [548] = {.lex_state = 5},
  [549] = {.lex_state = 5},
  [550] = {.lex_state = 5},
  [551] = {.lex_state = 52},
  [552] = {.lex_state = 5},
  [553] = {.lex_state = 52},
  [554] = {.lex_state = 52},
  [555] = {.lex_state = 52},
  [556] = {.lex_state = 52},
  [557] = {.lex_state = 52},
  [558] = {.lex_state = 52},
  [559] = {.lex_state = 52},
  [560] = {.lex_state = 52},
  [561] = {.lex_state = 5},
  [562] = {.lex_state = 52},
  [563] = {.lex_state = 52},
  [564] = {.lex_state = 52},
  [565] = {.lex_state = 52},
  [566] = {.lex_state = 52},
  [567] = {.lex_state = 52},
  [568] = {.lex_state = 52},
  [569] = {.lex_state = 52},
  [570] = {.lex_state = 52},
  [571] = {.lex_state = 52},
  [572] = {.lex_state = 1},
  [573] = {.lex_state = 52},
  [574] = {.lex_state = 3},
  [575] = {.lex_state = 52},
  [576] = {.lex_state = 1},
  [577] = {.lex_state = 3},
  [578] = {.lex_state = 3},
  [579] = {.lex_state = 1},
  [580] = {.lex_state = 52},
  [581] = {.lex_state = 1},
  [582] = {.lex_state = 3},
  [583] = {.lex_state = 52},
  [584] = {.lex_state = 3},
  [585] = {.lex_state = 13},
  [586] = {.lex_state = 52},
  [587] = {.lex_state = 1},
  [588] = {.lex_state = 13},
  [589] = {.lex_state = 13},
  [590] = {.lex_state = 52},
  [591] = {.lex_state = 13},
  [592] = {.lex_state = 13},
  [593] = {.lex_state = 13},
  [594] = {.lex_state = 13},
  [595] = {.lex_state = 13},
  [596] = {.lex_state = 52},
  [597] = {.lex_state = 3},
  [598] = {.lex_state = 0},
  [599] = {.lex_state = 52},
  [600] = {.lex_state = 1},
  [601] = {.lex_state = 52},
  [602] = {.lex_state = 52},
  [603] = {.lex_state = 0},
  [604] = {.lex_state = 52},
  [605] = {.lex_state = 0},
  [606] = {.lex_state = 52},
  [607] = {.lex_state = 52},
  [608] = {.lex_state = 52},
  [609] = {.lex_state = 52},
  [610] = {.lex_state = 52},
  [611] = {.lex_state = 52},
  [612] = {.lex_state = 52},
  [613] = {.lex_state = 52},
  [614] = {.lex_state = 52},
  [615] = {.lex_state = 52},
  [616] = {.lex_state = 13},
  [617] = {.lex_state = 13},
  [618] = {.lex_state = 10},
  [619] = {.lex_state = 52},
  [620] = {.lex_state = 52},
  [621] = {.lex_state = 0},
  [622] = {.lex_state = 52},
  [623] = {.lex_state = 0},
  [624] = {.lex_state = 3},
  [625] = {.lex_state = 1},
  [626] = {.lex_state = 0},
  [627] = {.lex_state = 52},
  [628] = {.lex_state = 0},
  [629] = {.lex_state = 0},
  [630] = {.lex_state = 0},
  [631] = {.lex_state = 52},
  [632] = {.lex_state = 52},
  [633] = {.lex_state = 52},
  [634] = {.lex_state = 1},
  [635] = {.lex_state = 3},
  [636] = {.lex_state = 52},
  [637] = {.lex_state = 52},
  [638] = {.lex_state = 52},
  [639] = {.lex_state = 52},
  [640] = {.lex_state = 0},
  [641] = {.lex_state = 52},
  [642] = {.lex_state = 52},
  [643] = {.lex_state = 52},
  [644] = {.lex_state = 0},
  [645] = {.lex_state = 0},
  [646] = {.lex_state = 0},
  [647] = {.lex_state = 0},
  [648] = {.lex_state = 52},
  [649] = {.lex_state = 52},
  [650] = {.lex_state = 52},
  [651] = {.lex_state = 0},
  [652] = {.lex_state = 0},
  [653] = {.lex_state = 52},
  [654] = {.lex_state = 52},
  [655] = {.lex_state = 0},
  [656] = {.lex_state = 0},
  [657] = {.lex_state = 0},
  [658] = {.lex_state = 13},
  [659] = {.lex_state = 0},
  [660] = {.lex_state = 52},
  [661] = {.lex_state = 0},
  [662] = {.lex_state = 52},
  [663] = {.lex_state = 0},
  [664] = {.lex_state = 52},
  [665] = {.lex_state = 52},
  [666] = {.lex_state = 0},
  [667] = {.lex_state = 0},
  [668] = {.lex_state = 0},
  [669] = {.lex_state = 52},
  [670] = {.lex_state = 52},
  [671] = {.lex_state = 0},
  [672] = {.lex_state = 52},
  [673] = {.lex_state = 0},
  [674] = {.lex_state = 52},
  [675] = {.lex_state = 0},
  [676] = {.lex_state = 0},
  [677] = {.lex_state = 52},
  [678] = {.lex_state = 0},
  [679] = {.lex_state = 0},
  [680] = {.lex_state = 0},
  [681] = {.lex_state = 0},
  [682] = {.lex_state = 0},
  [683] = {.lex_state = 52},
  [684] = {.lex_state = 0},
  [685] = {.lex_state = 52},
  [686] = {.lex_state = 0},
  [687] = {.lex_state = 52},
  [688] = {.lex_state = 0},
  [689] = {.lex_state = 0},
  [690] = {.lex_state = 0},
  [691] = {.lex_state = 0},
  [692] = {.lex_state = 52},
  [693] = {.lex_state = 52},
  [694] = {.lex_state = 0},
  [695] = {.lex_state = 0},
  [696] = {.lex_state = 0},
  [697] = {.lex_state = 0},
  [698] = {.lex_state = 0},
  [699] = {.lex_state = 52},
  [700] = {.lex_state = 0},
  [701] = {.lex_state = 0},
  [702] = {.lex_state = 52},
  [703] = {.lex_state = 0},
  [704] = {.lex_state = 0},
  [705] = {.lex_state = 0},
  [706] = {.lex_state = 52},
  [707] = {.lex_state = 52},
  [708] = {.lex_state = 52},
  [709] = {.lex_state = 0},
  [710] = {.lex_state = 52},
  [711] = {.lex_state = 0},
  [712] = {.lex_state = 0},
  [713] = {.lex_state = 0},
  [714] = {.lex_state = 0},
  [715] = {.lex_state = 52},
  [716] = {.lex_state = 0},
  [717] = {.lex_state = 52},
  [718] = {.lex_state = 52},
  [719] = {.lex_state = 0},
  [720] = {.lex_state = 13},
  [721] = {.lex_state = 0},
  [722] = {.lex_state = 0},
  [723] = {.lex_state = 0},
  [724] = {.lex_state = 0},
  [725] = {.lex_state = 0},
  [726] = {.lex_state = 52},
  [727] = {.lex_state = 52},
  [728] = {.lex_state = 52},
  [729] = {.lex_state = 0},
  [730] = {.lex_state = 0},
  [731] = {.lex_state = 0},
  [732] = {.lex_state = 52},
  [733] = {.lex_state = 52},
  [734] = {.lex_state = 52},
  [735] = {.lex_state = 52},
  [736] = {.lex_state = 52},
  [737] = {.lex_state = 0},
  [738] = {.lex_state = 52},
  [739] = {.lex_state = 52},
  [740] = {.lex_state = 52},
  [741] = {.lex_state = 0},
  [742] = {.lex_state = 52},
  [743] = {.lex_state = 0},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 52},
  [746] = {.lex_state = 0},
  [747] = {.lex_state = 0},
  [748] = {.lex_state = 0},
  [749] = {.lex_state = 52},
  [750] = {.lex_state = 52},
  [751] = {.lex_state = 52},
  [752] = {.lex_state = 0},
  [753] = {.lex_state = 52},
  [754] = {.lex_state = 0},
  [755] = {.lex_state = 0},
  [756] = {.lex_state = 52},
  [757] = {.lex_state = 52},
  [758] = {.lex_state = 0},
  [759] = {.lex_state = 52},
  [760] = {.lex_state = 0},
  [761] = {.lex_state = 52},
  [762] = {.lex_state = 52},
  [763] = {.lex_state = 52},
  [764] = {.lex_state = 0},
  [765] = {.lex_state = 52},
  [766] = {.lex_state = 52},
  [767] = {.lex_state = 13},
  [768] = {.lex_state = 52},
  [769] = {.lex_state = 0},
  [770] = {.lex_state = 13},
  [771] = {.lex_state = 52},
  [772] = {.lex_state = 52},
  [773] = {.lex_state = 52},
  [774] = {.lex_state = 0},
  [775] = {.lex_state = 0},
  [776] = {.lex_state = 0},
  [777] = {.lex_state = 52},
  [778] = {.lex_state = 0},
  [779] = {.lex_state = 0},
  [780] = {.lex_state = 0},
  [781] = {.lex_state = 0},
  [782] = {.lex_state = 52},
  [783] = {.lex_state = 0},
  [784] = {.lex_state = 0},
  [785] = {.lex_state = 0},
  [786] = {.lex_state = 0},
  [787] = {.lex_state = 52},
  [788] = {.lex_state = 0},
  [789] = {.lex_state = 0},
  [790] = {.lex_state = 52},
  [791] = {.lex_state = 22},
  [792] = {.lex_state = 52},
  [793] = {.lex_state = 52},
  [794] = {.lex_state = 52},
  [795] = {.lex_state = 52},
  [796] = {.lex_state = 0},
  [797] = {.lex_state = 0},
  [798] = {.lex_state = 0},
  [799] = {.lex_state = 0},
  [800] = {.lex_state = 0},
  [801] = {.lex_state = 0},
  [802] = {.lex_state = 0},
  [803] = {.lex_state = 0},
  [804] = {.lex_state = 0},
  [805] = {.lex_state = 52},
  [806] = {.lex_state = 52},
  [807] = {.lex_state = 52},
  [808] = {.lex_state = 52},
  [809] = {.lex_state = 52},
  [810] = {.lex_state = 52},
  [811] = {.lex_state = 52},
  [812] = {.lex_state = 52},
  [813] = {.lex_state = 52},
  [814] = {.lex_state = 0},
  [815] = {.lex_state = 0},
  [816] = {.lex_state = 52},
  [817] = {.lex_state = 52},
  [818] = {.lex_state = 0},
  [819] = {.lex_state = 0},
  [820] = {.lex_state = 0},
  [821] = {.lex_state = 0},
  [822] = {.lex_state = 52},
  [823] = {.lex_state = 0},
  [824] = {.lex_state = 0},
  [825] = {.lex_state = 52},
  [826] = {.lex_state = 52},
  [827] = {.lex_state = 52},
  [828] = {.lex_state = 0},
  [829] = {.lex_state = 52},
  [830] = {.lex_state = 52},
  [831] = {.lex_state = 0},
  [832] = {.lex_state = 52},
  [833] = {.lex_state = 0},
  [834] = {.lex_state = 52},
  [835] = {.lex_state = 12},
  [836] = {.lex_state = 52},
  [837] = {.lex_state = 52},
  [838] = {.lex_state = 0},
  [839] = {.lex_state = 52},
  [840] = {.lex_state = 0},
  [841] = {.lex_state = 0},
  [842] = {.lex_state = 0},
  [843] = {.lex_state = 13},
  [844] = {.lex_state = 0},
  [845] = {.lex_state = 52},
  [846] = {.lex_state = 0},
  [847] = {.lex_state = 0},
  [848] = {.lex_state = 13},
  [849] = {.lex_state = 52},
  [850] = {.lex_state = 0},
  [851] = {.lex_state = 0},
  [852] = {.lex_state = 0},
  [853] = {.lex_state = 52},
  [854] = {.lex_state = 0},
  [855] = {.lex_state = 52},
  [856] = {.lex_state = 0},
  [857] = {.lex_state = 52},
  [858] = {.lex_state = 0},
  [859] = {.lex_state = 52},
  [860] = {.lex_state = 52},
  [861] = {.lex_state = 0},
  [862] = {.lex_state = 0},
  [863] = {.lex_state = 52},
  [864] = {.lex_state = 52},
  [865] = {.lex_state = 0},
  [866] = {.lex_state = 52},
  [867] = {.lex_state = 0},
  [868] = {.lex_state = 52},
  [869] = {.lex_state = 0},
  [870] = {.lex_state = 52},
  [871] = {.lex_state = 0},
  [872] = {.lex_state = 0},
  [873] = {.lex_state = 13},
  [874] = {.lex_state = 13},
  [875] = {.lex_state = 0},
  [876] = {.lex_state = 52},
  [877] = {.lex_state = 52},
  [878] = {.lex_state = 0},
  [879] = {.lex_state = 0},
  [880] = {.lex_state = 0},
  [881] = {.lex_state = 0},
  [882] = {.lex_state = 52},
  [883] = {.lex_state = 52},
  [884] = {.lex_state = 52},
  [885] = {.lex_state = 52},
  [886] = {.lex_state = 0},
  [887] = {.lex_state = 0},
  [888] = {.lex_state = 0},
  [889] = {.lex_state = 0},
  [890] = {.lex_state = 52},
  [891] = {.lex_state = 0},
  [892] = {.lex_state = 0},
  [893] = {.lex_state = 0},
  [894] = {.lex_state = 0},
  [895] = {.lex_state = 52},
  [896] = {.lex_state = 0},
  [897] = {.lex_state = 0},
  [898] = {.lex_state = 0},
  [899] = {.lex_state = 0},
  [900] = {.lex_state = 0},
  [901] = {.lex_state = 0},
  [902] = {.lex_state = 0},
  [903] = {.lex_state = 52},
  [904] = {.lex_state = 52},
  [905] = {.lex_state = 0},
  [906] = {.lex_state = 0},
  [907] = {.lex_state = 0},
  [908] = {.lex_state = 0},
  [909] = {.lex_state = 52},
  [910] = {.lex_state = 52},
  [911] = {.lex_state = 0},
  [912] = {.lex_state = 52},
  [913] = {.lex_state = 52},
  [914] = {.lex_state = 52},
  [915] = {.lex_state = 52},
  [916] = {.lex_state = 52},
  [917] = {.lex_state = 11},
  [918] = {.lex_state = 0},
  [919] = {.lex_state = 0},
  [920] = {.lex_state = 52},
  [921] = {.lex_state = 52},
  [922] = {.lex_state = 52},
  [923] = {.lex_state = 0},
  [924] = {.lex_state = 0},
  [925] = {.lex_state = 0},
  [926] = {.lex_state = 11},
  [927] = {.lex_state = 13},
  [928] = {.lex_state = 52},
  [929] = {.lex_state = 52},
  [930] = {.lex_state = 0},
  [931] = {.lex_state = 0},
  [932] = {.lex_state = 0},
  [933] = {.lex_state = 0},
  [934] = {.lex_state = 0},
  [935] = {.lex_state = 0},
  [936] = {.lex_state = 52},
  [937] = {.lex_state = 52},
  [938] = {.lex_state = 52},
  [939] = {.lex_state = 0},
  [940] = {.lex_state = 52},
  [941] = {.lex_state = 52},
  [942] = {.lex_state = 0},
  [943] = {.lex_state = 52},
  [944] = {.lex_state = 0},
  [945] = {.lex_state = 0},
  [946] = {.lex_state = 0},
  [947] = {.lex_state = 52},
  [948] = {.lex_state = 0},
  [949] = {.lex_state = 0},
  [950] = {.lex_state = 0},
  [951] = {.lex_state = 52},
  [952] = {.lex_state = 0},
  [953] = {.lex_state = 0},
  [954] = {.lex_state = 0},
  [955] = {.lex_state = 52},
  [956] = {.lex_state = 0},
  [957] = {.lex_state = 52},
  [958] = {.lex_state = 0},
  [959] = {.lex_state = 0},
  [960] = {.lex_state = 0},
  [961] = {.lex_state = 0},
  [962] = {.lex_state = 11},
  [963] = {.lex_state = 0},
  [964] = {.lex_state = 52},
  [965] = {.lex_state = 0},
  [966] = {.lex_state = 0},
  [967] = {.lex_state = 52},
  [968] = {.lex_state = 0},
  [969] = {.lex_state = 52},
  [970] = {.lex_state = 0},
  [971] = {.lex_state = 0},
  [972] = {.lex_state = 0},
  [973] = {.lex_state = 52},
  [974] = {.lex_state = 0},
  [975] = {.lex_state = 0},
  [976] = {.lex_state = 5},
  [977] = {.lex_state = 0},
  [978] = {.lex_state = 0},
  [979] = {.lex_state = 0},
  [980] = {.lex_state = 52},
  [981] = {.lex_state = 5},
  [982] = {.lex_state = 0},
  [983] = {.lex_state = 0},
  [984] = {.lex_state = 0},
  [985] = {.lex_state = 0},
  [986] = {.lex_state = 0},
  [987] = {.lex_state = 0},
  [988] = {.lex_state = 0},
  [989] = {.lex_state = 0},
  [990] = {.lex_state = 52},
  [991] = {.lex_state = 52},
  [992] = {.lex_state = 52},
  [993] = {.lex_state = 0},
  [994] = {.lex_state = 52},
  [995] = {.lex_state = 0},
  [996] = {.lex_state = 0},
  [997] = {.lex_state = 0},
  [998] = {.lex_state = 0},
  [999] = {.lex_state = 52},
  [1000] = {.lex_state = 52},
  [1001] = {.lex_state = 52},
  [1002] = {.lex_state = 52},
  [1003] = {.lex_state = 0},
  [1004] = {.lex_state = 0},
  [1005] = {.lex_state = 52},
  [1006] = {.lex_state = 0},
  [1007] = {.lex_state = 52},
  [1008] = {.lex_state = 0},
  [1009] = {.lex_state = 0},
  [1010] = {.lex_state = 52},
  [1011] = {.lex_state = 52},
  [1012] = {.lex_state = 52},
  [1013] = {.lex_state = 52},
  [1014] = {.lex_state = 52},
  [1015] = {.lex_state = 52},
  [1016] = {.lex_state = 52},
  [1017] = {.lex_state = 52},
  [1018] = {.lex_state = 52},
  [1019] = {.lex_state = 52},
  [1020] = {.lex_state = 52},
  [1021] = {.lex_state = 52},
  [1022] = {.lex_state = 0},
  [1023] = {.lex_state = 0},
  [1024] = {.lex_state = 0},
  [1025] = {.lex_state = 0},
  [1026] = {.lex_state = 52},
  [1027] = {.lex_state = 52},
  [1028] = {.lex_state = 52},
  [1029] = {.lex_state = 52},
  [1030] = {.lex_state = 52},
  [1031] = {.lex_state = 52},
  [1032] = {.lex_state = 52},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_pragma] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_solidity] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_is] = ACTIONS(1),
    [anon_sym_constant] = ACTIONS(1),
    [anon_sym_abstract] = ACTIONS(1),
    [anon_sym_contract] = ACTIONS(1),
    [anon_sym_error] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_library] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_event] = ACTIONS(1),
    [anon_sym_anonymous] = ACTIONS(1),
    [anon_sym_indexed] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_assembly] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [sym_yul_leave] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [sym_yul_decimal_number] = ACTIONS(1),
    [sym_yul_hex_number] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_stop] = ACTIONS(1),
    [anon_sym_add] = ACTIONS(1),
    [anon_sym_sub] = ACTIONS(1),
    [anon_sym_mul] = ACTIONS(1),
    [anon_sym_div] = ACTIONS(1),
    [anon_sym_sdiv] = ACTIONS(1),
    [anon_sym_mod] = ACTIONS(1),
    [anon_sym_smod] = ACTIONS(1),
    [anon_sym_exp] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_lt] = ACTIONS(1),
    [anon_sym_gt] = ACTIONS(1),
    [anon_sym_slt] = ACTIONS(1),
    [anon_sym_sgt] = ACTIONS(1),
    [anon_sym_eq] = ACTIONS(1),
    [anon_sym_iszero] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_xor] = ACTIONS(1),
    [anon_sym_byte] = ACTIONS(1),
    [anon_sym_shl] = ACTIONS(1),
    [anon_sym_shr] = ACTIONS(1),
    [anon_sym_sar] = ACTIONS(1),
    [anon_sym_addmod] = ACTIONS(1),
    [anon_sym_mulmod] = ACTIONS(1),
    [anon_sym_signextend] = ACTIONS(1),
    [anon_sym_keccak256] = ACTIONS(1),
    [anon_sym_pop] = ACTIONS(1),
    [anon_sym_mload] = ACTIONS(1),
    [anon_sym_mstore] = ACTIONS(1),
    [anon_sym_mstore8] = ACTIONS(1),
    [anon_sym_sload] = ACTIONS(1),
    [anon_sym_sstore] = ACTIONS(1),
    [anon_sym_msize] = ACTIONS(1),
    [anon_sym_gas] = ACTIONS(1),
    [anon_sym_address] = ACTIONS(1),
    [anon_sym_balance] = ACTIONS(1),
    [anon_sym_selfbalance] = ACTIONS(1),
    [anon_sym_caller] = ACTIONS(1),
    [anon_sym_callvalue] = ACTIONS(1),
    [anon_sym_calldataload] = ACTIONS(1),
    [anon_sym_calldatasize] = ACTIONS(1),
    [anon_sym_calldatacopy] = ACTIONS(1),
    [anon_sym_extcodesize] = ACTIONS(1),
    [anon_sym_extcodecopy] = ACTIONS(1),
    [anon_sym_returndatasize] = ACTIONS(1),
    [anon_sym_returndatacopy] = ACTIONS(1),
    [anon_sym_extcodehash] = ACTIONS(1),
    [anon_sym_create] = ACTIONS(1),
    [anon_sym_create2] = ACTIONS(1),
    [anon_sym_call] = ACTIONS(1),
    [anon_sym_callcode] = ACTIONS(1),
    [anon_sym_delegatecall] = ACTIONS(1),
    [anon_sym_staticcall] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_revert] = ACTIONS(1),
    [anon_sym_selfdestruct] = ACTIONS(1),
    [anon_sym_invalid] = ACTIONS(1),
    [anon_sym_log0] = ACTIONS(1),
    [anon_sym_log1] = ACTIONS(1),
    [anon_sym_log2] = ACTIONS(1),
    [anon_sym_log3] = ACTIONS(1),
    [anon_sym_log4] = ACTIONS(1),
    [anon_sym_chainid] = ACTIONS(1),
    [anon_sym_origin] = ACTIONS(1),
    [anon_sym_gasprice] = ACTIONS(1),
    [anon_sym_blockhash] = ACTIONS(1),
    [anon_sym_coinbase] = ACTIONS(1),
    [anon_sym_timestamp] = ACTIONS(1),
    [anon_sym_number] = ACTIONS(1),
    [anon_sym_difficulty] = ACTIONS(1),
    [anon_sym_gaslimit] = ACTIONS(1),
    [sym__unchecked] = ACTIONS(1),
    [anon_sym_memory] = ACTIONS(1),
    [anon_sym_storage] = ACTIONS(1),
    [anon_sym_calldata] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_returns] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_emit] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_internal] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_external] = ACTIONS(1),
    [anon_sym_pure] = ACTIONS(1),
    [anon_sym_view] = ACTIONS(1),
    [anon_sym_payable] = ACTIONS(1),
    [sym_immutable] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [anon_sym_modifier] = ACTIONS(1),
    [anon_sym_constructor] = ACTIONS(1),
    [anon_sym_fallback] = ACTIONS(1),
    [anon_sym_receive] = ACTIONS(1),
    [sym_virtual] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_GT_GT_GT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_mapping] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_int8] = ACTIONS(1),
    [anon_sym_int16] = ACTIONS(1),
    [anon_sym_int24] = ACTIONS(1),
    [anon_sym_int32] = ACTIONS(1),
    [anon_sym_int40] = ACTIONS(1),
    [anon_sym_int48] = ACTIONS(1),
    [anon_sym_int56] = ACTIONS(1),
    [anon_sym_int64] = ACTIONS(1),
    [anon_sym_int72] = ACTIONS(1),
    [anon_sym_int80] = ACTIONS(1),
    [anon_sym_int88] = ACTIONS(1),
    [anon_sym_int96] = ACTIONS(1),
    [anon_sym_int104] = ACTIONS(1),
    [anon_sym_int112] = ACTIONS(1),
    [anon_sym_int120] = ACTIONS(1),
    [anon_sym_int128] = ACTIONS(1),
    [anon_sym_int136] = ACTIONS(1),
    [anon_sym_int144] = ACTIONS(1),
    [anon_sym_int152] = ACTIONS(1),
    [anon_sym_int160] = ACTIONS(1),
    [anon_sym_int168] = ACTIONS(1),
    [anon_sym_int176] = ACTIONS(1),
    [anon_sym_int184] = ACTIONS(1),
    [anon_sym_int192] = ACTIONS(1),
    [anon_sym_int200] = ACTIONS(1),
    [anon_sym_int208] = ACTIONS(1),
    [anon_sym_int216] = ACTIONS(1),
    [anon_sym_int224] = ACTIONS(1),
    [anon_sym_int232] = ACTIONS(1),
    [anon_sym_int240] = ACTIONS(1),
    [anon_sym_int248] = ACTIONS(1),
    [anon_sym_int256] = ACTIONS(1),
    [anon_sym_uint] = ACTIONS(1),
    [anon_sym_uint8] = ACTIONS(1),
    [anon_sym_uint16] = ACTIONS(1),
    [anon_sym_uint24] = ACTIONS(1),
    [anon_sym_uint32] = ACTIONS(1),
    [anon_sym_uint40] = ACTIONS(1),
    [anon_sym_uint48] = ACTIONS(1),
    [anon_sym_uint56] = ACTIONS(1),
    [anon_sym_uint64] = ACTIONS(1),
    [anon_sym_uint72] = ACTIONS(1),
    [anon_sym_uint80] = ACTIONS(1),
    [anon_sym_uint88] = ACTIONS(1),
    [anon_sym_uint96] = ACTIONS(1),
    [anon_sym_uint104] = ACTIONS(1),
    [anon_sym_uint112] = ACTIONS(1),
    [anon_sym_uint120] = ACTIONS(1),
    [anon_sym_uint128] = ACTIONS(1),
    [anon_sym_uint136] = ACTIONS(1),
    [anon_sym_uint144] = ACTIONS(1),
    [anon_sym_uint152] = ACTIONS(1),
    [anon_sym_uint160] = ACTIONS(1),
    [anon_sym_uint168] = ACTIONS(1),
    [anon_sym_uint176] = ACTIONS(1),
    [anon_sym_uint184] = ACTIONS(1),
    [anon_sym_uint192] = ACTIONS(1),
    [anon_sym_uint200] = ACTIONS(1),
    [anon_sym_uint208] = ACTIONS(1),
    [anon_sym_uint216] = ACTIONS(1),
    [anon_sym_uint224] = ACTIONS(1),
    [anon_sym_uint232] = ACTIONS(1),
    [anon_sym_uint240] = ACTIONS(1),
    [anon_sym_uint248] = ACTIONS(1),
    [anon_sym_uint256] = ACTIONS(1),
    [anon_sym_bytes] = ACTIONS(1),
    [anon_sym_bytes1] = ACTIONS(1),
    [anon_sym_bytes2] = ACTIONS(1),
    [anon_sym_bytes3] = ACTIONS(1),
    [anon_sym_bytes4] = ACTIONS(1),
    [anon_sym_bytes5] = ACTIONS(1),
    [anon_sym_bytes6] = ACTIONS(1),
    [anon_sym_bytes7] = ACTIONS(1),
    [anon_sym_bytes8] = ACTIONS(1),
    [anon_sym_bytes9] = ACTIONS(1),
    [anon_sym_bytes10] = ACTIONS(1),
    [anon_sym_bytes11] = ACTIONS(1),
    [anon_sym_bytes12] = ACTIONS(1),
    [anon_sym_bytes13] = ACTIONS(1),
    [anon_sym_bytes14] = ACTIONS(1),
    [anon_sym_bytes15] = ACTIONS(1),
    [anon_sym_bytes16] = ACTIONS(1),
    [anon_sym_bytes17] = ACTIONS(1),
    [anon_sym_bytes18] = ACTIONS(1),
    [anon_sym_bytes19] = ACTIONS(1),
    [anon_sym_bytes20] = ACTIONS(1),
    [anon_sym_bytes21] = ACTIONS(1),
    [anon_sym_bytes22] = ACTIONS(1),
    [anon_sym_bytes23] = ACTIONS(1),
    [anon_sym_bytes24] = ACTIONS(1),
    [anon_sym_bytes25] = ACTIONS(1),
    [anon_sym_bytes26] = ACTIONS(1),
    [anon_sym_bytes27] = ACTIONS(1),
    [anon_sym_bytes28] = ACTIONS(1),
    [anon_sym_bytes29] = ACTIONS(1),
    [anon_sym_bytes30] = ACTIONS(1),
    [anon_sym_bytes31] = ACTIONS(1),
    [anon_sym_bytes32] = ACTIONS(1),
    [anon_sym_fixed] = ACTIONS(1),
    [aux_sym__fixed_token1] = ACTIONS(1),
    [anon_sym_ufixed] = ACTIONS(1),
    [aux_sym__ufixed_token1] = ACTIONS(1),
    [sym__semicolon] = ACTIONS(1),
    [anon_sym_wei] = ACTIONS(1),
    [anon_sym_szabo] = ACTIONS(1),
    [anon_sym_finney] = ACTIONS(1),
    [anon_sym_gwei] = ACTIONS(1),
    [anon_sym_ether] = ACTIONS(1),
    [anon_sym_seconds] = ACTIONS(1),
    [anon_sym_minutes] = ACTIONS(1),
    [anon_sym_hours] = ACTIONS(1),
    [anon_sym_days] = ACTIONS(1),
    [anon_sym_weeks] = ACTIONS(1),
    [anon_sym_years] = ACTIONS(1),
    [anon_sym_hex] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym__escape_sequence] = ACTIONS(1),
    [anon_sym_unicode] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_source_file] = STATE(1024),
    [sym__source_unit] = STATE(70),
    [sym__directive] = STATE(70),
    [sym_pragma_directive] = STATE(70),
    [sym_import_directive] = STATE(70),
    [sym__declaration] = STATE(70),
    [sym_user_defined_type_definition] = STATE(70),
    [sym_constant_variable_declaration] = STATE(70),
    [sym_contract_declaration] = STATE(70),
    [sym_error_declaration] = STATE(70),
    [sym_interface_declaration] = STATE(70),
    [sym_library_declaration] = STATE(70),
    [sym_struct_declaration] = STATE(70),
    [sym_enum_declaration] = STATE(70),
    [sym_using_directive] = STATE(70),
    [sym_function_definition] = STATE(70),
    [sym_type_name] = STATE(790),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_source_file_repeat1] = STATE(70),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_pragma] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_type] = ACTIONS(13),
    [anon_sym_abstract] = ACTIONS(15),
    [anon_sym_contract] = ACTIONS(17),
    [anon_sym_error] = ACTIONS(19),
    [anon_sym_interface] = ACTIONS(21),
    [anon_sym_library] = ACTIONS(23),
    [anon_sym_struct] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_using] = ACTIONS(29),
    [anon_sym_function] = ACTIONS(31),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [2] = {
    [sym__statement] = STATE(7),
    [sym_assembly_statement] = STATE(7),
    [sym_block_statement] = STATE(7),
    [sym_variable_declaration_statement] = STATE(7),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(7),
    [sym_if_statement] = STATE(7),
    [sym_for_statement] = STATE(7),
    [sym_while_statement] = STATE(7),
    [sym_do_while_statement] = STATE(7),
    [sym_continue_statement] = STATE(7),
    [sym_break_statement] = STATE(7),
    [sym_revert_statement] = STATE(7),
    [sym_try_statement] = STATE(7),
    [sym_return_statement] = STATE(7),
    [sym_emit_statement] = STATE(7),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_struct_field_assignment] = STATE(741),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(7),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [3] = {
    [sym__statement] = STATE(3),
    [sym_assembly_statement] = STATE(3),
    [sym_block_statement] = STATE(3),
    [sym_variable_declaration_statement] = STATE(3),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(3),
    [sym_if_statement] = STATE(3),
    [sym_for_statement] = STATE(3),
    [sym_while_statement] = STATE(3),
    [sym_do_while_statement] = STATE(3),
    [sym_continue_statement] = STATE(3),
    [sym_break_statement] = STATE(3),
    [sym_revert_statement] = STATE(3),
    [sym_try_statement] = STATE(3),
    [sym_return_statement] = STATE(3),
    [sym_emit_statement] = STATE(3),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(3),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(107),
    [anon_sym_DASH] = ACTIONS(110),
    [anon_sym_TILDE] = ACTIONS(113),
    [anon_sym_LBRACE] = ACTIONS(116),
    [anon_sym_RBRACE] = ACTIONS(119),
    [anon_sym_type] = ACTIONS(121),
    [anon_sym_LPAREN] = ACTIONS(124),
    [anon_sym_for] = ACTIONS(127),
    [anon_sym_PLUS] = ACTIONS(110),
    [anon_sym_assembly] = ACTIONS(130),
    [anon_sym_break] = ACTIONS(133),
    [anon_sym_continue] = ACTIONS(136),
    [anon_sym_true] = ACTIONS(139),
    [anon_sym_false] = ACTIONS(142),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(148),
    [anon_sym_byte] = ACTIONS(151),
    [anon_sym_address] = ACTIONS(154),
    [anon_sym_return] = ACTIONS(157),
    [anon_sym_revert] = ACTIONS(160),
    [sym__unchecked] = ACTIONS(163),
    [anon_sym_var] = ACTIONS(166),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_do] = ACTIONS(172),
    [anon_sym_try] = ACTIONS(175),
    [anon_sym_emit] = ACTIONS(178),
    [anon_sym_payable] = ACTIONS(181),
    [anon_sym_new] = ACTIONS(184),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_BANG] = ACTIONS(113),
    [anon_sym_delete] = ACTIONS(190),
    [anon_sym_PLUS_PLUS] = ACTIONS(193),
    [anon_sym_DASH_DASH] = ACTIONS(193),
    [anon_sym_mapping] = ACTIONS(196),
    [anon_sym_bool] = ACTIONS(151),
    [anon_sym_string] = ACTIONS(151),
    [anon_sym_int] = ACTIONS(151),
    [anon_sym_int8] = ACTIONS(151),
    [anon_sym_int16] = ACTIONS(151),
    [anon_sym_int24] = ACTIONS(151),
    [anon_sym_int32] = ACTIONS(151),
    [anon_sym_int40] = ACTIONS(151),
    [anon_sym_int48] = ACTIONS(151),
    [anon_sym_int56] = ACTIONS(151),
    [anon_sym_int64] = ACTIONS(151),
    [anon_sym_int72] = ACTIONS(151),
    [anon_sym_int80] = ACTIONS(151),
    [anon_sym_int88] = ACTIONS(151),
    [anon_sym_int96] = ACTIONS(151),
    [anon_sym_int104] = ACTIONS(151),
    [anon_sym_int112] = ACTIONS(151),
    [anon_sym_int120] = ACTIONS(151),
    [anon_sym_int128] = ACTIONS(151),
    [anon_sym_int136] = ACTIONS(151),
    [anon_sym_int144] = ACTIONS(151),
    [anon_sym_int152] = ACTIONS(151),
    [anon_sym_int160] = ACTIONS(151),
    [anon_sym_int168] = ACTIONS(151),
    [anon_sym_int176] = ACTIONS(151),
    [anon_sym_int184] = ACTIONS(151),
    [anon_sym_int192] = ACTIONS(151),
    [anon_sym_int200] = ACTIONS(151),
    [anon_sym_int208] = ACTIONS(151),
    [anon_sym_int216] = ACTIONS(151),
    [anon_sym_int224] = ACTIONS(151),
    [anon_sym_int232] = ACTIONS(151),
    [anon_sym_int240] = ACTIONS(151),
    [anon_sym_int248] = ACTIONS(151),
    [anon_sym_int256] = ACTIONS(151),
    [anon_sym_uint] = ACTIONS(151),
    [anon_sym_uint8] = ACTIONS(151),
    [anon_sym_uint16] = ACTIONS(151),
    [anon_sym_uint24] = ACTIONS(151),
    [anon_sym_uint32] = ACTIONS(151),
    [anon_sym_uint40] = ACTIONS(151),
    [anon_sym_uint48] = ACTIONS(151),
    [anon_sym_uint56] = ACTIONS(151),
    [anon_sym_uint64] = ACTIONS(151),
    [anon_sym_uint72] = ACTIONS(151),
    [anon_sym_uint80] = ACTIONS(151),
    [anon_sym_uint88] = ACTIONS(151),
    [anon_sym_uint96] = ACTIONS(151),
    [anon_sym_uint104] = ACTIONS(151),
    [anon_sym_uint112] = ACTIONS(151),
    [anon_sym_uint120] = ACTIONS(151),
    [anon_sym_uint128] = ACTIONS(151),
    [anon_sym_uint136] = ACTIONS(151),
    [anon_sym_uint144] = ACTIONS(151),
    [anon_sym_uint152] = ACTIONS(151),
    [anon_sym_uint160] = ACTIONS(151),
    [anon_sym_uint168] = ACTIONS(151),
    [anon_sym_uint176] = ACTIONS(151),
    [anon_sym_uint184] = ACTIONS(151),
    [anon_sym_uint192] = ACTIONS(151),
    [anon_sym_uint200] = ACTIONS(151),
    [anon_sym_uint208] = ACTIONS(151),
    [anon_sym_uint216] = ACTIONS(151),
    [anon_sym_uint224] = ACTIONS(151),
    [anon_sym_uint232] = ACTIONS(151),
    [anon_sym_uint240] = ACTIONS(151),
    [anon_sym_uint248] = ACTIONS(151),
    [anon_sym_uint256] = ACTIONS(151),
    [anon_sym_bytes] = ACTIONS(151),
    [anon_sym_bytes1] = ACTIONS(151),
    [anon_sym_bytes2] = ACTIONS(151),
    [anon_sym_bytes3] = ACTIONS(151),
    [anon_sym_bytes4] = ACTIONS(151),
    [anon_sym_bytes5] = ACTIONS(151),
    [anon_sym_bytes6] = ACTIONS(151),
    [anon_sym_bytes7] = ACTIONS(151),
    [anon_sym_bytes8] = ACTIONS(151),
    [anon_sym_bytes9] = ACTIONS(151),
    [anon_sym_bytes10] = ACTIONS(151),
    [anon_sym_bytes11] = ACTIONS(151),
    [anon_sym_bytes12] = ACTIONS(151),
    [anon_sym_bytes13] = ACTIONS(151),
    [anon_sym_bytes14] = ACTIONS(151),
    [anon_sym_bytes15] = ACTIONS(151),
    [anon_sym_bytes16] = ACTIONS(151),
    [anon_sym_bytes17] = ACTIONS(151),
    [anon_sym_bytes18] = ACTIONS(151),
    [anon_sym_bytes19] = ACTIONS(151),
    [anon_sym_bytes20] = ACTIONS(151),
    [anon_sym_bytes21] = ACTIONS(151),
    [anon_sym_bytes22] = ACTIONS(151),
    [anon_sym_bytes23] = ACTIONS(151),
    [anon_sym_bytes24] = ACTIONS(151),
    [anon_sym_bytes25] = ACTIONS(151),
    [anon_sym_bytes26] = ACTIONS(151),
    [anon_sym_bytes27] = ACTIONS(151),
    [anon_sym_bytes28] = ACTIONS(151),
    [anon_sym_bytes29] = ACTIONS(151),
    [anon_sym_bytes30] = ACTIONS(151),
    [anon_sym_bytes31] = ACTIONS(151),
    [anon_sym_bytes32] = ACTIONS(151),
    [anon_sym_fixed] = ACTIONS(151),
    [aux_sym__fixed_token1] = ACTIONS(151),
    [anon_sym_ufixed] = ACTIONS(151),
    [aux_sym__ufixed_token1] = ACTIONS(151),
    [aux_sym__decimal_number_token1] = ACTIONS(199),
    [aux_sym__decimal_number_token2] = ACTIONS(202),
    [aux_sym__hex_number_token1] = ACTIONS(202),
    [anon_sym_hex] = ACTIONS(205),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE] = ACTIONS(211),
    [anon_sym_unicode] = ACTIONS(214),
    [sym_comment] = ACTIONS(3),
  },
  [4] = {
    [sym__statement] = STATE(7),
    [sym_assembly_statement] = STATE(7),
    [sym_block_statement] = STATE(7),
    [sym_variable_declaration_statement] = STATE(7),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(7),
    [sym_if_statement] = STATE(7),
    [sym_for_statement] = STATE(7),
    [sym_while_statement] = STATE(7),
    [sym_do_while_statement] = STATE(7),
    [sym_continue_statement] = STATE(7),
    [sym_break_statement] = STATE(7),
    [sym_revert_statement] = STATE(7),
    [sym_try_statement] = STATE(7),
    [sym_return_statement] = STATE(7),
    [sym_emit_statement] = STATE(7),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(7),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(219),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [5] = {
    [sym__statement] = STATE(11),
    [sym_assembly_statement] = STATE(11),
    [sym_block_statement] = STATE(11),
    [sym_variable_declaration_statement] = STATE(11),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(11),
    [sym_if_statement] = STATE(11),
    [sym_for_statement] = STATE(11),
    [sym_while_statement] = STATE(11),
    [sym_do_while_statement] = STATE(11),
    [sym_continue_statement] = STATE(11),
    [sym_break_statement] = STATE(11),
    [sym_revert_statement] = STATE(11),
    [sym_try_statement] = STATE(11),
    [sym_return_statement] = STATE(11),
    [sym_emit_statement] = STATE(11),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(11),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(221),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [6] = {
    [sym__statement] = STATE(3),
    [sym_assembly_statement] = STATE(3),
    [sym_block_statement] = STATE(3),
    [sym_variable_declaration_statement] = STATE(3),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(3),
    [sym_if_statement] = STATE(3),
    [sym_for_statement] = STATE(3),
    [sym_while_statement] = STATE(3),
    [sym_do_while_statement] = STATE(3),
    [sym_continue_statement] = STATE(3),
    [sym_break_statement] = STATE(3),
    [sym_revert_statement] = STATE(3),
    [sym_try_statement] = STATE(3),
    [sym_return_statement] = STATE(3),
    [sym_emit_statement] = STATE(3),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(3),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [7] = {
    [sym__statement] = STATE(3),
    [sym_assembly_statement] = STATE(3),
    [sym_block_statement] = STATE(3),
    [sym_variable_declaration_statement] = STATE(3),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(3),
    [sym_if_statement] = STATE(3),
    [sym_for_statement] = STATE(3),
    [sym_while_statement] = STATE(3),
    [sym_do_while_statement] = STATE(3),
    [sym_continue_statement] = STATE(3),
    [sym_break_statement] = STATE(3),
    [sym_revert_statement] = STATE(3),
    [sym_try_statement] = STATE(3),
    [sym_return_statement] = STATE(3),
    [sym_emit_statement] = STATE(3),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(3),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(225),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [8] = {
    [sym__statement] = STATE(6),
    [sym_assembly_statement] = STATE(6),
    [sym_block_statement] = STATE(6),
    [sym_variable_declaration_statement] = STATE(6),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(6),
    [sym_if_statement] = STATE(6),
    [sym_for_statement] = STATE(6),
    [sym_while_statement] = STATE(6),
    [sym_do_while_statement] = STATE(6),
    [sym_continue_statement] = STATE(6),
    [sym_break_statement] = STATE(6),
    [sym_revert_statement] = STATE(6),
    [sym_try_statement] = STATE(6),
    [sym_return_statement] = STATE(6),
    [sym_emit_statement] = STATE(6),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(6),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(225),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [9] = {
    [sym__statement] = STATE(10),
    [sym_assembly_statement] = STATE(10),
    [sym_block_statement] = STATE(10),
    [sym_variable_declaration_statement] = STATE(10),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(10),
    [sym_if_statement] = STATE(10),
    [sym_for_statement] = STATE(10),
    [sym_while_statement] = STATE(10),
    [sym_do_while_statement] = STATE(10),
    [sym_continue_statement] = STATE(10),
    [sym_break_statement] = STATE(10),
    [sym_revert_statement] = STATE(10),
    [sym_try_statement] = STATE(10),
    [sym_return_statement] = STATE(10),
    [sym_emit_statement] = STATE(10),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(10),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(227),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [10] = {
    [sym__statement] = STATE(3),
    [sym_assembly_statement] = STATE(3),
    [sym_block_statement] = STATE(3),
    [sym_variable_declaration_statement] = STATE(3),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(3),
    [sym_if_statement] = STATE(3),
    [sym_for_statement] = STATE(3),
    [sym_while_statement] = STATE(3),
    [sym_do_while_statement] = STATE(3),
    [sym_continue_statement] = STATE(3),
    [sym_break_statement] = STATE(3),
    [sym_revert_statement] = STATE(3),
    [sym_try_statement] = STATE(3),
    [sym_return_statement] = STATE(3),
    [sym_emit_statement] = STATE(3),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(3),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(229),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [11] = {
    [sym__statement] = STATE(3),
    [sym_assembly_statement] = STATE(3),
    [sym_block_statement] = STATE(3),
    [sym_variable_declaration_statement] = STATE(3),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(3),
    [sym_if_statement] = STATE(3),
    [sym_for_statement] = STATE(3),
    [sym_while_statement] = STATE(3),
    [sym_do_while_statement] = STATE(3),
    [sym_continue_statement] = STATE(3),
    [sym_break_statement] = STATE(3),
    [sym_revert_statement] = STATE(3),
    [sym_try_statement] = STATE(3),
    [sym_return_statement] = STATE(3),
    [sym_emit_statement] = STATE(3),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_block_statement_repeat1] = STATE(3),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_RBRACE] = ACTIONS(231),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [12] = {
    [sym__statement] = STATE(920),
    [sym_assembly_statement] = STATE(920),
    [sym_block_statement] = STATE(920),
    [sym_variable_declaration_statement] = STATE(920),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(920),
    [sym_if_statement] = STATE(920),
    [sym_for_statement] = STATE(920),
    [sym_while_statement] = STATE(920),
    [sym_do_while_statement] = STATE(920),
    [sym_continue_statement] = STATE(920),
    [sym_break_statement] = STATE(920),
    [sym_revert_statement] = STATE(920),
    [sym_try_statement] = STATE(920),
    [sym_return_statement] = STATE(920),
    [sym_emit_statement] = STATE(920),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [13] = {
    [sym__statement] = STATE(102),
    [sym_assembly_statement] = STATE(102),
    [sym_block_statement] = STATE(102),
    [sym_variable_declaration_statement] = STATE(102),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(102),
    [sym_if_statement] = STATE(102),
    [sym_for_statement] = STATE(102),
    [sym_while_statement] = STATE(102),
    [sym_do_while_statement] = STATE(102),
    [sym_continue_statement] = STATE(102),
    [sym_break_statement] = STATE(102),
    [sym_revert_statement] = STATE(102),
    [sym_try_statement] = STATE(102),
    [sym_return_statement] = STATE(102),
    [sym_emit_statement] = STATE(102),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [14] = {
    [sym__statement] = STATE(89),
    [sym_assembly_statement] = STATE(89),
    [sym_block_statement] = STATE(89),
    [sym_variable_declaration_statement] = STATE(89),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(89),
    [sym_if_statement] = STATE(89),
    [sym_for_statement] = STATE(89),
    [sym_while_statement] = STATE(89),
    [sym_do_while_statement] = STATE(89),
    [sym_continue_statement] = STATE(89),
    [sym_break_statement] = STATE(89),
    [sym_revert_statement] = STATE(89),
    [sym_try_statement] = STATE(89),
    [sym_return_statement] = STATE(89),
    [sym_emit_statement] = STATE(89),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [15] = {
    [sym__statement] = STATE(98),
    [sym_assembly_statement] = STATE(98),
    [sym_block_statement] = STATE(98),
    [sym_variable_declaration_statement] = STATE(98),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(98),
    [sym_if_statement] = STATE(98),
    [sym_for_statement] = STATE(98),
    [sym_while_statement] = STATE(98),
    [sym_do_while_statement] = STATE(98),
    [sym_continue_statement] = STATE(98),
    [sym_break_statement] = STATE(98),
    [sym_revert_statement] = STATE(98),
    [sym_try_statement] = STATE(98),
    [sym_return_statement] = STATE(98),
    [sym_emit_statement] = STATE(98),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [16] = {
    [sym__statement] = STATE(105),
    [sym_assembly_statement] = STATE(105),
    [sym_block_statement] = STATE(105),
    [sym_variable_declaration_statement] = STATE(105),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(105),
    [sym_if_statement] = STATE(105),
    [sym_for_statement] = STATE(105),
    [sym_while_statement] = STATE(105),
    [sym_do_while_statement] = STATE(105),
    [sym_continue_statement] = STATE(105),
    [sym_break_statement] = STATE(105),
    [sym_revert_statement] = STATE(105),
    [sym_try_statement] = STATE(105),
    [sym_return_statement] = STATE(105),
    [sym_emit_statement] = STATE(105),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [17] = {
    [sym__statement] = STATE(88),
    [sym_assembly_statement] = STATE(88),
    [sym_block_statement] = STATE(88),
    [sym_variable_declaration_statement] = STATE(88),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(88),
    [sym_if_statement] = STATE(88),
    [sym_for_statement] = STATE(88),
    [sym_while_statement] = STATE(88),
    [sym_do_while_statement] = STATE(88),
    [sym_continue_statement] = STATE(88),
    [sym_break_statement] = STATE(88),
    [sym_revert_statement] = STATE(88),
    [sym_try_statement] = STATE(88),
    [sym_return_statement] = STATE(88),
    [sym_emit_statement] = STATE(88),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(45),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_assembly] = ACTIONS(55),
    [anon_sym_break] = ACTIONS(57),
    [anon_sym_continue] = ACTIONS(59),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_if] = ACTIONS(65),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_revert] = ACTIONS(71),
    [sym__unchecked] = ACTIONS(73),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_while] = ACTIONS(77),
    [anon_sym_do] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(81),
    [anon_sym_emit] = ACTIONS(83),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [18] = {
    [sym_variable_declaration_statement] = STATE(32),
    [sym_variable_declaration] = STATE(890),
    [sym_variable_declaration_tuple] = STATE(895),
    [sym_expression_statement] = STATE(32),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(75),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym__semicolon] = ACTIONS(233),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [19] = {
    [sym_variable_declaration] = STATE(689),
    [sym__expression] = STATE(492),
    [sym__primary_expression] = STATE(492),
    [sym_type_cast_expression] = STATE(492),
    [sym_ternary_expression] = STATE(492),
    [sym_new_expression] = STATE(492),
    [sym_tuple_expression] = STATE(492),
    [sym_inline_array_expression] = STATE(492),
    [sym_binary_expression] = STATE(492),
    [sym_unary_expression] = STATE(492),
    [sym_update_expression] = STATE(492),
    [sym_member_expression] = STATE(492),
    [sym_array_access] = STATE(492),
    [sym_slice_access] = STATE(492),
    [sym_struct_expression] = STATE(492),
    [sym_parenthesized_expression] = STATE(492),
    [sym_assignment_expression] = STATE(492),
    [sym_augmented_assignment_expression] = STATE(492),
    [sym_call_expression] = STATE(492),
    [sym_payable_conversion_expression] = STATE(492),
    [sym_meta_type_expression] = STATE(492),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(492),
    [sym_string_literal] = STATE(492),
    [sym_number_literal] = STATE(492),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(492),
    [sym_hex_string_literal] = STATE(492),
    [sym_unicode_string_literal] = STATE(492),
    [sym_string] = STATE(429),
    [aux_sym_variable_declaration_tuple_repeat1] = STATE(694),
    [aux_sym_tuple_expression_repeat1] = STATE(647),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(235),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(239),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [20] = {
    [sym_variable_declaration] = STATE(852),
    [sym__expression] = STATE(499),
    [sym__primary_expression] = STATE(499),
    [sym_type_cast_expression] = STATE(499),
    [sym_ternary_expression] = STATE(499),
    [sym_new_expression] = STATE(499),
    [sym_tuple_expression] = STATE(499),
    [sym_inline_array_expression] = STATE(499),
    [sym_binary_expression] = STATE(499),
    [sym_unary_expression] = STATE(499),
    [sym_update_expression] = STATE(499),
    [sym_member_expression] = STATE(499),
    [sym_array_access] = STATE(499),
    [sym_slice_access] = STATE(499),
    [sym_struct_expression] = STATE(499),
    [sym_parenthesized_expression] = STATE(499),
    [sym_assignment_expression] = STATE(499),
    [sym_augmented_assignment_expression] = STATE(499),
    [sym_call_expression] = STATE(499),
    [sym_payable_conversion_expression] = STATE(499),
    [sym_meta_type_expression] = STATE(499),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(486),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(485),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(499),
    [sym_string_literal] = STATE(499),
    [sym_number_literal] = STATE(499),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(499),
    [sym_hex_string_literal] = STATE(499),
    [sym_unicode_string_literal] = STATE(499),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(241),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [21] = {
    [sym_call_argument] = STATE(721),
    [sym__expression] = STATE(490),
    [sym__primary_expression] = STATE(490),
    [sym_type_cast_expression] = STATE(490),
    [sym_ternary_expression] = STATE(490),
    [sym_new_expression] = STATE(490),
    [sym_tuple_expression] = STATE(490),
    [sym_inline_array_expression] = STATE(490),
    [sym_binary_expression] = STATE(490),
    [sym_unary_expression] = STATE(490),
    [sym_update_expression] = STATE(490),
    [sym_member_expression] = STATE(490),
    [sym_array_access] = STATE(490),
    [sym_slice_access] = STATE(490),
    [sym_struct_expression] = STATE(490),
    [sym_parenthesized_expression] = STATE(490),
    [sym_assignment_expression] = STATE(490),
    [sym_augmented_assignment_expression] = STATE(490),
    [sym_call_expression] = STATE(490),
    [sym_payable_conversion_expression] = STATE(490),
    [sym_meta_type_expression] = STATE(490),
    [sym_user_defined_type] = STATE(490),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(490),
    [sym_string_literal] = STATE(490),
    [sym_number_literal] = STATE(490),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(490),
    [sym_hex_string_literal] = STATE(490),
    [sym_unicode_string_literal] = STATE(490),
    [sym_string] = STATE(429),
    [aux_sym_tuple_expression_repeat1] = STATE(647),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_COMMA] = ACTIONS(248),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(250),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [22] = {
    [sym_call_argument] = STATE(841),
    [sym__expression] = STATE(497),
    [sym__primary_expression] = STATE(497),
    [sym_type_cast_expression] = STATE(497),
    [sym_ternary_expression] = STATE(497),
    [sym_new_expression] = STATE(497),
    [sym_tuple_expression] = STATE(497),
    [sym_inline_array_expression] = STATE(497),
    [sym_binary_expression] = STATE(497),
    [sym_unary_expression] = STATE(497),
    [sym_update_expression] = STATE(497),
    [sym_member_expression] = STATE(497),
    [sym_array_access] = STATE(497),
    [sym_slice_access] = STATE(497),
    [sym_struct_expression] = STATE(497),
    [sym_parenthesized_expression] = STATE(497),
    [sym_assignment_expression] = STATE(497),
    [sym_augmented_assignment_expression] = STATE(497),
    [sym_call_expression] = STATE(497),
    [sym_payable_conversion_expression] = STATE(497),
    [sym_meta_type_expression] = STATE(497),
    [sym_user_defined_type] = STATE(497),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(497),
    [sym_string_literal] = STATE(497),
    [sym_number_literal] = STATE(497),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(497),
    [sym_hex_string_literal] = STATE(497),
    [sym_unicode_string_literal] = STATE(497),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(252),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [23] = {
    [sym__expression] = STATE(492),
    [sym__primary_expression] = STATE(492),
    [sym_type_cast_expression] = STATE(492),
    [sym_ternary_expression] = STATE(492),
    [sym_new_expression] = STATE(492),
    [sym_tuple_expression] = STATE(492),
    [sym_inline_array_expression] = STATE(492),
    [sym_binary_expression] = STATE(492),
    [sym_unary_expression] = STATE(492),
    [sym_update_expression] = STATE(492),
    [sym_member_expression] = STATE(492),
    [sym_array_access] = STATE(492),
    [sym_slice_access] = STATE(492),
    [sym_struct_expression] = STATE(492),
    [sym_parenthesized_expression] = STATE(492),
    [sym_assignment_expression] = STATE(492),
    [sym_augmented_assignment_expression] = STATE(492),
    [sym_call_expression] = STATE(492),
    [sym_payable_conversion_expression] = STATE(492),
    [sym_meta_type_expression] = STATE(492),
    [sym_user_defined_type] = STATE(492),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(492),
    [sym_string_literal] = STATE(492),
    [sym_number_literal] = STATE(492),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(492),
    [sym_hex_string_literal] = STATE(492),
    [sym_unicode_string_literal] = STATE(492),
    [sym_string] = STATE(429),
    [aux_sym_tuple_expression_repeat1] = STATE(647),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(248),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(254),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [24] = {
    [sym_call_argument] = STATE(841),
    [sym__expression] = STATE(497),
    [sym__primary_expression] = STATE(497),
    [sym_type_cast_expression] = STATE(497),
    [sym_ternary_expression] = STATE(497),
    [sym_new_expression] = STATE(497),
    [sym_tuple_expression] = STATE(497),
    [sym_inline_array_expression] = STATE(497),
    [sym_binary_expression] = STATE(497),
    [sym_unary_expression] = STATE(497),
    [sym_update_expression] = STATE(497),
    [sym_member_expression] = STATE(497),
    [sym_array_access] = STATE(497),
    [sym_slice_access] = STATE(497),
    [sym_struct_expression] = STATE(497),
    [sym_parenthesized_expression] = STATE(497),
    [sym_assignment_expression] = STATE(497),
    [sym_augmented_assignment_expression] = STATE(497),
    [sym_call_expression] = STATE(497),
    [sym_payable_conversion_expression] = STATE(497),
    [sym_meta_type_expression] = STATE(497),
    [sym_user_defined_type] = STATE(497),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(497),
    [sym_string_literal] = STATE(497),
    [sym_number_literal] = STATE(497),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(497),
    [sym_hex_string_literal] = STATE(497),
    [sym_unicode_string_literal] = STATE(497),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(256),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [25] = {
    [sym_call_argument] = STATE(721),
    [sym__expression] = STATE(497),
    [sym__primary_expression] = STATE(497),
    [sym_type_cast_expression] = STATE(497),
    [sym_ternary_expression] = STATE(497),
    [sym_new_expression] = STATE(497),
    [sym_tuple_expression] = STATE(497),
    [sym_inline_array_expression] = STATE(497),
    [sym_binary_expression] = STATE(497),
    [sym_unary_expression] = STATE(497),
    [sym_update_expression] = STATE(497),
    [sym_member_expression] = STATE(497),
    [sym_array_access] = STATE(497),
    [sym_slice_access] = STATE(497),
    [sym_struct_expression] = STATE(497),
    [sym_parenthesized_expression] = STATE(497),
    [sym_assignment_expression] = STATE(497),
    [sym_augmented_assignment_expression] = STATE(497),
    [sym_call_expression] = STATE(497),
    [sym_payable_conversion_expression] = STATE(497),
    [sym_meta_type_expression] = STATE(497),
    [sym_user_defined_type] = STATE(497),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(497),
    [sym_string_literal] = STATE(497),
    [sym_number_literal] = STATE(497),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(497),
    [sym_hex_string_literal] = STATE(497),
    [sym_unicode_string_literal] = STATE(497),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(258),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [26] = {
    [sym__call_arguments] = STATE(919),
    [sym__expression] = STATE(507),
    [sym__primary_expression] = STATE(507),
    [sym_type_cast_expression] = STATE(507),
    [sym_ternary_expression] = STATE(507),
    [sym_new_expression] = STATE(507),
    [sym_tuple_expression] = STATE(507),
    [sym_inline_array_expression] = STATE(507),
    [sym_binary_expression] = STATE(507),
    [sym_unary_expression] = STATE(507),
    [sym_update_expression] = STATE(507),
    [sym_member_expression] = STATE(507),
    [sym_array_access] = STATE(507),
    [sym_slice_access] = STATE(507),
    [sym_struct_expression] = STATE(507),
    [sym_parenthesized_expression] = STATE(507),
    [sym_assignment_expression] = STATE(507),
    [sym_augmented_assignment_expression] = STATE(507),
    [sym_call_expression] = STATE(507),
    [sym_payable_conversion_expression] = STATE(507),
    [sym_meta_type_expression] = STATE(507),
    [sym_user_defined_type] = STATE(507),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(507),
    [sym_string_literal] = STATE(507),
    [sym_number_literal] = STATE(507),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(507),
    [sym_hex_string_literal] = STATE(507),
    [sym_unicode_string_literal] = STATE(507),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym__semicolon] = ACTIONS(262),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [27] = {
    [sym__expression] = STATE(494),
    [sym__primary_expression] = STATE(494),
    [sym_type_cast_expression] = STATE(494),
    [sym_ternary_expression] = STATE(494),
    [sym_new_expression] = STATE(494),
    [sym_tuple_expression] = STATE(494),
    [sym_inline_array_expression] = STATE(494),
    [sym_binary_expression] = STATE(494),
    [sym_unary_expression] = STATE(494),
    [sym_update_expression] = STATE(494),
    [sym_member_expression] = STATE(494),
    [sym_array_access] = STATE(494),
    [sym_slice_access] = STATE(494),
    [sym_struct_expression] = STATE(494),
    [sym_parenthesized_expression] = STATE(494),
    [sym_assignment_expression] = STATE(494),
    [sym_augmented_assignment_expression] = STATE(494),
    [sym_call_expression] = STATE(494),
    [sym_payable_conversion_expression] = STATE(494),
    [sym_meta_type_expression] = STATE(494),
    [sym_user_defined_type] = STATE(494),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(494),
    [sym_string_literal] = STATE(494),
    [sym_number_literal] = STATE(494),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(494),
    [sym_hex_string_literal] = STATE(494),
    [sym_unicode_string_literal] = STATE(494),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_COLON] = ACTIONS(264),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_RBRACK] = ACTIONS(266),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [28] = {
    [sym_call_argument] = STATE(841),
    [sym__expression] = STATE(497),
    [sym__primary_expression] = STATE(497),
    [sym_type_cast_expression] = STATE(497),
    [sym_ternary_expression] = STATE(497),
    [sym_new_expression] = STATE(497),
    [sym_tuple_expression] = STATE(497),
    [sym_inline_array_expression] = STATE(497),
    [sym_binary_expression] = STATE(497),
    [sym_unary_expression] = STATE(497),
    [sym_update_expression] = STATE(497),
    [sym_member_expression] = STATE(497),
    [sym_array_access] = STATE(497),
    [sym_slice_access] = STATE(497),
    [sym_struct_expression] = STATE(497),
    [sym_parenthesized_expression] = STATE(497),
    [sym_assignment_expression] = STATE(497),
    [sym_augmented_assignment_expression] = STATE(497),
    [sym_call_expression] = STATE(497),
    [sym_payable_conversion_expression] = STATE(497),
    [sym_meta_type_expression] = STATE(497),
    [sym_user_defined_type] = STATE(497),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(497),
    [sym_string_literal] = STATE(497),
    [sym_number_literal] = STATE(497),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(497),
    [sym_hex_string_literal] = STATE(497),
    [sym_unicode_string_literal] = STATE(497),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [29] = {
    [sym__expression] = STATE(499),
    [sym__primary_expression] = STATE(499),
    [sym_type_cast_expression] = STATE(499),
    [sym_ternary_expression] = STATE(499),
    [sym_new_expression] = STATE(499),
    [sym_tuple_expression] = STATE(499),
    [sym_inline_array_expression] = STATE(499),
    [sym_binary_expression] = STATE(499),
    [sym_unary_expression] = STATE(499),
    [sym_update_expression] = STATE(499),
    [sym_member_expression] = STATE(499),
    [sym_array_access] = STATE(499),
    [sym_slice_access] = STATE(499),
    [sym_struct_expression] = STATE(499),
    [sym_parenthesized_expression] = STATE(499),
    [sym_assignment_expression] = STATE(499),
    [sym_augmented_assignment_expression] = STATE(499),
    [sym_call_expression] = STATE(499),
    [sym_payable_conversion_expression] = STATE(499),
    [sym_meta_type_expression] = STATE(499),
    [sym_user_defined_type] = STATE(499),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(499),
    [sym_string_literal] = STATE(499),
    [sym_number_literal] = STATE(499),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(499),
    [sym_hex_string_literal] = STATE(499),
    [sym_unicode_string_literal] = STATE(499),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(268),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(270),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [30] = {
    [sym__expression] = STATE(499),
    [sym__primary_expression] = STATE(499),
    [sym_type_cast_expression] = STATE(499),
    [sym_ternary_expression] = STATE(499),
    [sym_new_expression] = STATE(499),
    [sym_tuple_expression] = STATE(499),
    [sym_inline_array_expression] = STATE(499),
    [sym_binary_expression] = STATE(499),
    [sym_unary_expression] = STATE(499),
    [sym_update_expression] = STATE(499),
    [sym_member_expression] = STATE(499),
    [sym_array_access] = STATE(499),
    [sym_slice_access] = STATE(499),
    [sym_struct_expression] = STATE(499),
    [sym_parenthesized_expression] = STATE(499),
    [sym_assignment_expression] = STATE(499),
    [sym_augmented_assignment_expression] = STATE(499),
    [sym_call_expression] = STATE(499),
    [sym_payable_conversion_expression] = STATE(499),
    [sym_meta_type_expression] = STATE(499),
    [sym_user_defined_type] = STATE(499),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(499),
    [sym_string_literal] = STATE(499),
    [sym_number_literal] = STATE(499),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(499),
    [sym_hex_string_literal] = STATE(499),
    [sym_unicode_string_literal] = STATE(499),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(268),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(268),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [31] = {
    [sym__expression] = STATE(499),
    [sym__primary_expression] = STATE(499),
    [sym_type_cast_expression] = STATE(499),
    [sym_ternary_expression] = STATE(499),
    [sym_new_expression] = STATE(499),
    [sym_tuple_expression] = STATE(499),
    [sym_inline_array_expression] = STATE(499),
    [sym_binary_expression] = STATE(499),
    [sym_unary_expression] = STATE(499),
    [sym_update_expression] = STATE(499),
    [sym_member_expression] = STATE(499),
    [sym_array_access] = STATE(499),
    [sym_slice_access] = STATE(499),
    [sym_struct_expression] = STATE(499),
    [sym_parenthesized_expression] = STATE(499),
    [sym_assignment_expression] = STATE(499),
    [sym_augmented_assignment_expression] = STATE(499),
    [sym_call_expression] = STATE(499),
    [sym_payable_conversion_expression] = STATE(499),
    [sym_meta_type_expression] = STATE(499),
    [sym_user_defined_type] = STATE(499),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(499),
    [sym_string_literal] = STATE(499),
    [sym_number_literal] = STATE(499),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(499),
    [sym_hex_string_literal] = STATE(499),
    [sym_unicode_string_literal] = STATE(499),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(268),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(272),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [32] = {
    [sym_expression_statement] = STATE(37),
    [sym__expression] = STATE(512),
    [sym__primary_expression] = STATE(512),
    [sym_type_cast_expression] = STATE(512),
    [sym_ternary_expression] = STATE(512),
    [sym_new_expression] = STATE(512),
    [sym_tuple_expression] = STATE(512),
    [sym_inline_array_expression] = STATE(512),
    [sym_binary_expression] = STATE(512),
    [sym_unary_expression] = STATE(512),
    [sym_update_expression] = STATE(512),
    [sym_member_expression] = STATE(512),
    [sym_array_access] = STATE(512),
    [sym_slice_access] = STATE(512),
    [sym_struct_expression] = STATE(512),
    [sym_parenthesized_expression] = STATE(512),
    [sym_assignment_expression] = STATE(512),
    [sym_augmented_assignment_expression] = STATE(512),
    [sym_call_expression] = STATE(512),
    [sym_payable_conversion_expression] = STATE(512),
    [sym_meta_type_expression] = STATE(512),
    [sym_user_defined_type] = STATE(512),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(512),
    [sym_string_literal] = STATE(512),
    [sym_number_literal] = STATE(512),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(512),
    [sym_hex_string_literal] = STATE(512),
    [sym_unicode_string_literal] = STATE(512),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym__semicolon] = ACTIONS(274),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [33] = {
    [sym__expression] = STATE(499),
    [sym__primary_expression] = STATE(499),
    [sym_type_cast_expression] = STATE(499),
    [sym_ternary_expression] = STATE(499),
    [sym_new_expression] = STATE(499),
    [sym_tuple_expression] = STATE(499),
    [sym_inline_array_expression] = STATE(499),
    [sym_binary_expression] = STATE(499),
    [sym_unary_expression] = STATE(499),
    [sym_update_expression] = STATE(499),
    [sym_member_expression] = STATE(499),
    [sym_array_access] = STATE(499),
    [sym_slice_access] = STATE(499),
    [sym_struct_expression] = STATE(499),
    [sym_parenthesized_expression] = STATE(499),
    [sym_assignment_expression] = STATE(499),
    [sym_augmented_assignment_expression] = STATE(499),
    [sym_call_expression] = STATE(499),
    [sym_payable_conversion_expression] = STATE(499),
    [sym_meta_type_expression] = STATE(499),
    [sym_user_defined_type] = STATE(499),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(499),
    [sym_string_literal] = STATE(499),
    [sym_number_literal] = STATE(499),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(499),
    [sym_hex_string_literal] = STATE(499),
    [sym_unicode_string_literal] = STATE(499),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(268),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(276),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [34] = {
    [sym__expression] = STATE(515),
    [sym__primary_expression] = STATE(515),
    [sym_type_cast_expression] = STATE(515),
    [sym_ternary_expression] = STATE(515),
    [sym_new_expression] = STATE(515),
    [sym_tuple_expression] = STATE(515),
    [sym_inline_array_expression] = STATE(515),
    [sym_binary_expression] = STATE(515),
    [sym_unary_expression] = STATE(515),
    [sym_update_expression] = STATE(515),
    [sym_member_expression] = STATE(515),
    [sym_array_access] = STATE(515),
    [sym_slice_access] = STATE(515),
    [sym_struct_expression] = STATE(515),
    [sym_parenthesized_expression] = STATE(515),
    [sym_assignment_expression] = STATE(515),
    [sym_augmented_assignment_expression] = STATE(515),
    [sym_call_expression] = STATE(515),
    [sym_payable_conversion_expression] = STATE(515),
    [sym_meta_type_expression] = STATE(515),
    [sym_user_defined_type] = STATE(515),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(515),
    [sym_string_literal] = STATE(515),
    [sym_number_literal] = STATE(515),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(515),
    [sym_hex_string_literal] = STATE(515),
    [sym_unicode_string_literal] = STATE(515),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_RBRACK] = ACTIONS(278),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [35] = {
    [sym__expression] = STATE(491),
    [sym__primary_expression] = STATE(491),
    [sym_type_cast_expression] = STATE(491),
    [sym_ternary_expression] = STATE(491),
    [sym_new_expression] = STATE(491),
    [sym_tuple_expression] = STATE(491),
    [sym_inline_array_expression] = STATE(491),
    [sym_binary_expression] = STATE(491),
    [sym_unary_expression] = STATE(491),
    [sym_update_expression] = STATE(491),
    [sym_member_expression] = STATE(491),
    [sym_array_access] = STATE(491),
    [sym_slice_access] = STATE(491),
    [sym_struct_expression] = STATE(491),
    [sym_parenthesized_expression] = STATE(491),
    [sym_assignment_expression] = STATE(491),
    [sym_augmented_assignment_expression] = STATE(491),
    [sym_call_expression] = STATE(491),
    [sym_payable_conversion_expression] = STATE(491),
    [sym_meta_type_expression] = STATE(491),
    [sym_user_defined_type] = STATE(491),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(491),
    [sym_string_literal] = STATE(491),
    [sym_number_literal] = STATE(491),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(491),
    [sym_hex_string_literal] = STATE(491),
    [sym_unicode_string_literal] = STATE(491),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_RBRACK] = ACTIONS(280),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [36] = {
    [sym__expression] = STATE(510),
    [sym__primary_expression] = STATE(510),
    [sym_type_cast_expression] = STATE(510),
    [sym_ternary_expression] = STATE(510),
    [sym_new_expression] = STATE(510),
    [sym_tuple_expression] = STATE(510),
    [sym_inline_array_expression] = STATE(510),
    [sym_binary_expression] = STATE(510),
    [sym_unary_expression] = STATE(510),
    [sym_update_expression] = STATE(510),
    [sym_member_expression] = STATE(510),
    [sym_array_access] = STATE(510),
    [sym_slice_access] = STATE(510),
    [sym_struct_expression] = STATE(510),
    [sym_parenthesized_expression] = STATE(510),
    [sym_assignment_expression] = STATE(510),
    [sym_augmented_assignment_expression] = STATE(510),
    [sym_call_expression] = STATE(510),
    [sym_payable_conversion_expression] = STATE(510),
    [sym_meta_type_expression] = STATE(510),
    [sym_user_defined_type] = STATE(510),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(510),
    [sym_string_literal] = STATE(510),
    [sym_number_literal] = STATE(510),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(510),
    [sym_hex_string_literal] = STATE(510),
    [sym_unicode_string_literal] = STATE(510),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym__semicolon] = ACTIONS(282),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [37] = {
    [sym__expression] = STATE(505),
    [sym__primary_expression] = STATE(505),
    [sym_type_cast_expression] = STATE(505),
    [sym_ternary_expression] = STATE(505),
    [sym_new_expression] = STATE(505),
    [sym_tuple_expression] = STATE(505),
    [sym_inline_array_expression] = STATE(505),
    [sym_binary_expression] = STATE(505),
    [sym_unary_expression] = STATE(505),
    [sym_update_expression] = STATE(505),
    [sym_member_expression] = STATE(505),
    [sym_array_access] = STATE(505),
    [sym_slice_access] = STATE(505),
    [sym_struct_expression] = STATE(505),
    [sym_parenthesized_expression] = STATE(505),
    [sym_assignment_expression] = STATE(505),
    [sym_augmented_assignment_expression] = STATE(505),
    [sym_call_expression] = STATE(505),
    [sym_payable_conversion_expression] = STATE(505),
    [sym_meta_type_expression] = STATE(505),
    [sym_user_defined_type] = STATE(505),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(505),
    [sym_string_literal] = STATE(505),
    [sym_number_literal] = STATE(505),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(505),
    [sym_hex_string_literal] = STATE(505),
    [sym_unicode_string_literal] = STATE(505),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_RPAREN] = ACTIONS(284),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [38] = {
    [sym__expression] = STATE(506),
    [sym__primary_expression] = STATE(506),
    [sym_type_cast_expression] = STATE(506),
    [sym_ternary_expression] = STATE(506),
    [sym_new_expression] = STATE(506),
    [sym_tuple_expression] = STATE(506),
    [sym_inline_array_expression] = STATE(506),
    [sym_binary_expression] = STATE(506),
    [sym_unary_expression] = STATE(506),
    [sym_update_expression] = STATE(506),
    [sym_member_expression] = STATE(506),
    [sym_array_access] = STATE(506),
    [sym_slice_access] = STATE(506),
    [sym_struct_expression] = STATE(506),
    [sym_parenthesized_expression] = STATE(506),
    [sym_assignment_expression] = STATE(506),
    [sym_augmented_assignment_expression] = STATE(506),
    [sym_call_expression] = STATE(506),
    [sym_payable_conversion_expression] = STATE(506),
    [sym_meta_type_expression] = STATE(506),
    [sym_user_defined_type] = STATE(506),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(506),
    [sym_string_literal] = STATE(506),
    [sym_number_literal] = STATE(506),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(506),
    [sym_hex_string_literal] = STATE(506),
    [sym_unicode_string_literal] = STATE(506),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_RBRACK] = ACTIONS(286),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [39] = {
    [sym__expression] = STATE(501),
    [sym__primary_expression] = STATE(501),
    [sym_type_cast_expression] = STATE(501),
    [sym_ternary_expression] = STATE(501),
    [sym_new_expression] = STATE(501),
    [sym_tuple_expression] = STATE(501),
    [sym_inline_array_expression] = STATE(501),
    [sym_binary_expression] = STATE(501),
    [sym_unary_expression] = STATE(501),
    [sym_update_expression] = STATE(501),
    [sym_member_expression] = STATE(501),
    [sym_array_access] = STATE(501),
    [sym_slice_access] = STATE(501),
    [sym_struct_expression] = STATE(501),
    [sym_parenthesized_expression] = STATE(501),
    [sym_assignment_expression] = STATE(501),
    [sym_augmented_assignment_expression] = STATE(501),
    [sym_call_expression] = STATE(501),
    [sym_payable_conversion_expression] = STATE(501),
    [sym_meta_type_expression] = STATE(501),
    [sym_user_defined_type] = STATE(501),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(501),
    [sym_string_literal] = STATE(501),
    [sym_number_literal] = STATE(501),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(501),
    [sym_hex_string_literal] = STATE(501),
    [sym_unicode_string_literal] = STATE(501),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_RBRACK] = ACTIONS(288),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [40] = {
    [sym__expression] = STATE(498),
    [sym__primary_expression] = STATE(498),
    [sym_type_cast_expression] = STATE(498),
    [sym_ternary_expression] = STATE(498),
    [sym_new_expression] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_inline_array_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_update_expression] = STATE(498),
    [sym_member_expression] = STATE(498),
    [sym_array_access] = STATE(498),
    [sym_slice_access] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_augmented_assignment_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_payable_conversion_expression] = STATE(498),
    [sym_meta_type_expression] = STATE(498),
    [sym_user_defined_type] = STATE(498),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(498),
    [sym_string_literal] = STATE(498),
    [sym_number_literal] = STATE(498),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(498),
    [sym_hex_string_literal] = STATE(498),
    [sym_unicode_string_literal] = STATE(498),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_RBRACK] = ACTIONS(290),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [41] = {
    [sym__expression] = STATE(498),
    [sym__primary_expression] = STATE(498),
    [sym_type_cast_expression] = STATE(498),
    [sym_ternary_expression] = STATE(498),
    [sym_new_expression] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_inline_array_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_update_expression] = STATE(498),
    [sym_member_expression] = STATE(498),
    [sym_array_access] = STATE(498),
    [sym_slice_access] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_augmented_assignment_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_payable_conversion_expression] = STATE(498),
    [sym_meta_type_expression] = STATE(498),
    [sym_user_defined_type] = STATE(498),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(498),
    [sym_string_literal] = STATE(498),
    [sym_number_literal] = STATE(498),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(498),
    [sym_hex_string_literal] = STATE(498),
    [sym_unicode_string_literal] = STATE(498),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_RBRACK] = ACTIONS(292),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [42] = {
    [sym__expression] = STATE(500),
    [sym__primary_expression] = STATE(500),
    [sym_type_cast_expression] = STATE(500),
    [sym_ternary_expression] = STATE(500),
    [sym_new_expression] = STATE(500),
    [sym_tuple_expression] = STATE(500),
    [sym_inline_array_expression] = STATE(500),
    [sym_binary_expression] = STATE(500),
    [sym_unary_expression] = STATE(500),
    [sym_update_expression] = STATE(500),
    [sym_member_expression] = STATE(500),
    [sym_array_access] = STATE(500),
    [sym_slice_access] = STATE(500),
    [sym_struct_expression] = STATE(500),
    [sym_parenthesized_expression] = STATE(500),
    [sym_assignment_expression] = STATE(500),
    [sym_augmented_assignment_expression] = STATE(500),
    [sym_call_expression] = STATE(500),
    [sym_payable_conversion_expression] = STATE(500),
    [sym_meta_type_expression] = STATE(500),
    [sym_user_defined_type] = STATE(500),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(500),
    [sym_string_literal] = STATE(500),
    [sym_number_literal] = STATE(500),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(500),
    [sym_hex_string_literal] = STATE(500),
    [sym_unicode_string_literal] = STATE(500),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [43] = {
    [sym__expression] = STATE(504),
    [sym__primary_expression] = STATE(504),
    [sym_type_cast_expression] = STATE(504),
    [sym_ternary_expression] = STATE(504),
    [sym_new_expression] = STATE(504),
    [sym_tuple_expression] = STATE(504),
    [sym_inline_array_expression] = STATE(504),
    [sym_binary_expression] = STATE(504),
    [sym_unary_expression] = STATE(504),
    [sym_update_expression] = STATE(504),
    [sym_member_expression] = STATE(504),
    [sym_array_access] = STATE(504),
    [sym_slice_access] = STATE(504),
    [sym_struct_expression] = STATE(504),
    [sym_parenthesized_expression] = STATE(504),
    [sym_assignment_expression] = STATE(504),
    [sym_augmented_assignment_expression] = STATE(504),
    [sym_call_expression] = STATE(504),
    [sym_payable_conversion_expression] = STATE(504),
    [sym_meta_type_expression] = STATE(504),
    [sym_user_defined_type] = STATE(504),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(504),
    [sym_string_literal] = STATE(504),
    [sym_number_literal] = STATE(504),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(504),
    [sym_hex_string_literal] = STATE(504),
    [sym_unicode_string_literal] = STATE(504),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [44] = {
    [sym__expression] = STATE(498),
    [sym__primary_expression] = STATE(498),
    [sym_type_cast_expression] = STATE(498),
    [sym_ternary_expression] = STATE(498),
    [sym_new_expression] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_inline_array_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_update_expression] = STATE(498),
    [sym_member_expression] = STATE(498),
    [sym_array_access] = STATE(498),
    [sym_slice_access] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_augmented_assignment_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_payable_conversion_expression] = STATE(498),
    [sym_meta_type_expression] = STATE(498),
    [sym_user_defined_type] = STATE(498),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(498),
    [sym_string_literal] = STATE(498),
    [sym_number_literal] = STATE(498),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(498),
    [sym_hex_string_literal] = STATE(498),
    [sym_unicode_string_literal] = STATE(498),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [45] = {
    [sym__expression] = STATE(502),
    [sym__primary_expression] = STATE(502),
    [sym_type_cast_expression] = STATE(502),
    [sym_ternary_expression] = STATE(502),
    [sym_new_expression] = STATE(502),
    [sym_tuple_expression] = STATE(502),
    [sym_inline_array_expression] = STATE(502),
    [sym_binary_expression] = STATE(502),
    [sym_unary_expression] = STATE(502),
    [sym_update_expression] = STATE(502),
    [sym_member_expression] = STATE(502),
    [sym_array_access] = STATE(502),
    [sym_slice_access] = STATE(502),
    [sym_struct_expression] = STATE(502),
    [sym_parenthesized_expression] = STATE(502),
    [sym_assignment_expression] = STATE(502),
    [sym_augmented_assignment_expression] = STATE(502),
    [sym_call_expression] = STATE(502),
    [sym_payable_conversion_expression] = STATE(502),
    [sym_meta_type_expression] = STATE(502),
    [sym_user_defined_type] = STATE(502),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(502),
    [sym_string_literal] = STATE(502),
    [sym_number_literal] = STATE(502),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(502),
    [sym_hex_string_literal] = STATE(502),
    [sym_unicode_string_literal] = STATE(502),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [46] = {
    [sym__expression] = STATE(503),
    [sym__primary_expression] = STATE(503),
    [sym_type_cast_expression] = STATE(503),
    [sym_ternary_expression] = STATE(503),
    [sym_new_expression] = STATE(503),
    [sym_tuple_expression] = STATE(503),
    [sym_inline_array_expression] = STATE(503),
    [sym_binary_expression] = STATE(503),
    [sym_unary_expression] = STATE(503),
    [sym_update_expression] = STATE(503),
    [sym_member_expression] = STATE(503),
    [sym_array_access] = STATE(503),
    [sym_slice_access] = STATE(503),
    [sym_struct_expression] = STATE(503),
    [sym_parenthesized_expression] = STATE(503),
    [sym_assignment_expression] = STATE(503),
    [sym_augmented_assignment_expression] = STATE(503),
    [sym_call_expression] = STATE(503),
    [sym_payable_conversion_expression] = STATE(503),
    [sym_meta_type_expression] = STATE(503),
    [sym_user_defined_type] = STATE(503),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(503),
    [sym_string_literal] = STATE(503),
    [sym_number_literal] = STATE(503),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(503),
    [sym_hex_string_literal] = STATE(503),
    [sym_unicode_string_literal] = STATE(503),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [47] = {
    [sym__expression] = STATE(447),
    [sym__primary_expression] = STATE(447),
    [sym_type_cast_expression] = STATE(447),
    [sym_ternary_expression] = STATE(447),
    [sym_new_expression] = STATE(447),
    [sym_tuple_expression] = STATE(447),
    [sym_inline_array_expression] = STATE(447),
    [sym_binary_expression] = STATE(447),
    [sym_unary_expression] = STATE(447),
    [sym_update_expression] = STATE(447),
    [sym_member_expression] = STATE(447),
    [sym_array_access] = STATE(447),
    [sym_slice_access] = STATE(447),
    [sym_struct_expression] = STATE(447),
    [sym_parenthesized_expression] = STATE(447),
    [sym_assignment_expression] = STATE(447),
    [sym_augmented_assignment_expression] = STATE(447),
    [sym_call_expression] = STATE(447),
    [sym_payable_conversion_expression] = STATE(447),
    [sym_meta_type_expression] = STATE(447),
    [sym_user_defined_type] = STATE(447),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(447),
    [sym_string_literal] = STATE(447),
    [sym_number_literal] = STATE(447),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(447),
    [sym_hex_string_literal] = STATE(447),
    [sym_unicode_string_literal] = STATE(447),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [48] = {
    [sym__expression] = STATE(511),
    [sym__primary_expression] = STATE(511),
    [sym_type_cast_expression] = STATE(511),
    [sym_ternary_expression] = STATE(511),
    [sym_new_expression] = STATE(511),
    [sym_tuple_expression] = STATE(511),
    [sym_inline_array_expression] = STATE(511),
    [sym_binary_expression] = STATE(511),
    [sym_unary_expression] = STATE(511),
    [sym_update_expression] = STATE(511),
    [sym_member_expression] = STATE(511),
    [sym_array_access] = STATE(511),
    [sym_slice_access] = STATE(511),
    [sym_struct_expression] = STATE(511),
    [sym_parenthesized_expression] = STATE(511),
    [sym_assignment_expression] = STATE(511),
    [sym_augmented_assignment_expression] = STATE(511),
    [sym_call_expression] = STATE(511),
    [sym_payable_conversion_expression] = STATE(511),
    [sym_meta_type_expression] = STATE(511),
    [sym_user_defined_type] = STATE(511),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(511),
    [sym_string_literal] = STATE(511),
    [sym_number_literal] = STATE(511),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(511),
    [sym_hex_string_literal] = STATE(511),
    [sym_unicode_string_literal] = STATE(511),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [49] = {
    [sym__expression] = STATE(489),
    [sym__primary_expression] = STATE(489),
    [sym_type_cast_expression] = STATE(489),
    [sym_ternary_expression] = STATE(489),
    [sym_new_expression] = STATE(489),
    [sym_tuple_expression] = STATE(489),
    [sym_inline_array_expression] = STATE(489),
    [sym_binary_expression] = STATE(489),
    [sym_unary_expression] = STATE(489),
    [sym_update_expression] = STATE(489),
    [sym_member_expression] = STATE(489),
    [sym_array_access] = STATE(489),
    [sym_slice_access] = STATE(489),
    [sym_struct_expression] = STATE(489),
    [sym_parenthesized_expression] = STATE(489),
    [sym_assignment_expression] = STATE(489),
    [sym_augmented_assignment_expression] = STATE(489),
    [sym_call_expression] = STATE(489),
    [sym_payable_conversion_expression] = STATE(489),
    [sym_meta_type_expression] = STATE(489),
    [sym_user_defined_type] = STATE(489),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(489),
    [sym_string_literal] = STATE(489),
    [sym_number_literal] = STATE(489),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(489),
    [sym_hex_string_literal] = STATE(489),
    [sym_unicode_string_literal] = STATE(489),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [50] = {
    [sym__expression] = STATE(496),
    [sym__primary_expression] = STATE(496),
    [sym_type_cast_expression] = STATE(496),
    [sym_ternary_expression] = STATE(496),
    [sym_new_expression] = STATE(496),
    [sym_tuple_expression] = STATE(496),
    [sym_inline_array_expression] = STATE(496),
    [sym_binary_expression] = STATE(496),
    [sym_unary_expression] = STATE(496),
    [sym_update_expression] = STATE(496),
    [sym_member_expression] = STATE(496),
    [sym_array_access] = STATE(496),
    [sym_slice_access] = STATE(496),
    [sym_struct_expression] = STATE(496),
    [sym_parenthesized_expression] = STATE(496),
    [sym_assignment_expression] = STATE(496),
    [sym_augmented_assignment_expression] = STATE(496),
    [sym_call_expression] = STATE(496),
    [sym_payable_conversion_expression] = STATE(496),
    [sym_meta_type_expression] = STATE(496),
    [sym_user_defined_type] = STATE(496),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(496),
    [sym_string_literal] = STATE(496),
    [sym_number_literal] = STATE(496),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(496),
    [sym_hex_string_literal] = STATE(496),
    [sym_unicode_string_literal] = STATE(496),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [51] = {
    [sym__expression] = STATE(493),
    [sym__primary_expression] = STATE(493),
    [sym_type_cast_expression] = STATE(493),
    [sym_ternary_expression] = STATE(493),
    [sym_new_expression] = STATE(493),
    [sym_tuple_expression] = STATE(493),
    [sym_inline_array_expression] = STATE(493),
    [sym_binary_expression] = STATE(493),
    [sym_unary_expression] = STATE(493),
    [sym_update_expression] = STATE(493),
    [sym_member_expression] = STATE(493),
    [sym_array_access] = STATE(493),
    [sym_slice_access] = STATE(493),
    [sym_struct_expression] = STATE(493),
    [sym_parenthesized_expression] = STATE(493),
    [sym_assignment_expression] = STATE(493),
    [sym_augmented_assignment_expression] = STATE(493),
    [sym_call_expression] = STATE(493),
    [sym_payable_conversion_expression] = STATE(493),
    [sym_meta_type_expression] = STATE(493),
    [sym_user_defined_type] = STATE(493),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(493),
    [sym_string_literal] = STATE(493),
    [sym_number_literal] = STATE(493),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(493),
    [sym_hex_string_literal] = STATE(493),
    [sym_unicode_string_literal] = STATE(493),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [52] = {
    [sym__expression] = STATE(513),
    [sym__primary_expression] = STATE(513),
    [sym_type_cast_expression] = STATE(513),
    [sym_ternary_expression] = STATE(513),
    [sym_new_expression] = STATE(513),
    [sym_tuple_expression] = STATE(513),
    [sym_inline_array_expression] = STATE(513),
    [sym_binary_expression] = STATE(513),
    [sym_unary_expression] = STATE(513),
    [sym_update_expression] = STATE(513),
    [sym_member_expression] = STATE(513),
    [sym_array_access] = STATE(513),
    [sym_slice_access] = STATE(513),
    [sym_struct_expression] = STATE(513),
    [sym_parenthesized_expression] = STATE(513),
    [sym_assignment_expression] = STATE(513),
    [sym_augmented_assignment_expression] = STATE(513),
    [sym_call_expression] = STATE(513),
    [sym_payable_conversion_expression] = STATE(513),
    [sym_meta_type_expression] = STATE(513),
    [sym_user_defined_type] = STATE(513),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(513),
    [sym_string_literal] = STATE(513),
    [sym_number_literal] = STATE(513),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(513),
    [sym_hex_string_literal] = STATE(513),
    [sym_unicode_string_literal] = STATE(513),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [53] = {
    [sym__expression] = STATE(450),
    [sym__primary_expression] = STATE(450),
    [sym_type_cast_expression] = STATE(450),
    [sym_ternary_expression] = STATE(450),
    [sym_new_expression] = STATE(450),
    [sym_tuple_expression] = STATE(450),
    [sym_inline_array_expression] = STATE(450),
    [sym_binary_expression] = STATE(450),
    [sym_unary_expression] = STATE(450),
    [sym_update_expression] = STATE(450),
    [sym_member_expression] = STATE(450),
    [sym_array_access] = STATE(450),
    [sym_slice_access] = STATE(450),
    [sym_struct_expression] = STATE(450),
    [sym_parenthesized_expression] = STATE(450),
    [sym_assignment_expression] = STATE(450),
    [sym_augmented_assignment_expression] = STATE(450),
    [sym_call_expression] = STATE(450),
    [sym_payable_conversion_expression] = STATE(450),
    [sym_meta_type_expression] = STATE(450),
    [sym_user_defined_type] = STATE(450),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(450),
    [sym_string_literal] = STATE(450),
    [sym_number_literal] = STATE(450),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(450),
    [sym_hex_string_literal] = STATE(450),
    [sym_unicode_string_literal] = STATE(450),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [54] = {
    [sym__expression] = STATE(451),
    [sym__primary_expression] = STATE(451),
    [sym_type_cast_expression] = STATE(451),
    [sym_ternary_expression] = STATE(451),
    [sym_new_expression] = STATE(451),
    [sym_tuple_expression] = STATE(451),
    [sym_inline_array_expression] = STATE(451),
    [sym_binary_expression] = STATE(451),
    [sym_unary_expression] = STATE(451),
    [sym_update_expression] = STATE(451),
    [sym_member_expression] = STATE(451),
    [sym_array_access] = STATE(451),
    [sym_slice_access] = STATE(451),
    [sym_struct_expression] = STATE(451),
    [sym_parenthesized_expression] = STATE(451),
    [sym_assignment_expression] = STATE(451),
    [sym_augmented_assignment_expression] = STATE(451),
    [sym_call_expression] = STATE(451),
    [sym_payable_conversion_expression] = STATE(451),
    [sym_meta_type_expression] = STATE(451),
    [sym_user_defined_type] = STATE(451),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(451),
    [sym_string_literal] = STATE(451),
    [sym_number_literal] = STATE(451),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(451),
    [sym_hex_string_literal] = STATE(451),
    [sym_unicode_string_literal] = STATE(451),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [55] = {
    [sym__expression] = STATE(445),
    [sym__primary_expression] = STATE(445),
    [sym_type_cast_expression] = STATE(445),
    [sym_ternary_expression] = STATE(445),
    [sym_new_expression] = STATE(445),
    [sym_tuple_expression] = STATE(445),
    [sym_inline_array_expression] = STATE(445),
    [sym_binary_expression] = STATE(445),
    [sym_unary_expression] = STATE(445),
    [sym_update_expression] = STATE(445),
    [sym_member_expression] = STATE(445),
    [sym_array_access] = STATE(445),
    [sym_slice_access] = STATE(445),
    [sym_struct_expression] = STATE(445),
    [sym_parenthesized_expression] = STATE(445),
    [sym_assignment_expression] = STATE(445),
    [sym_augmented_assignment_expression] = STATE(445),
    [sym_call_expression] = STATE(445),
    [sym_payable_conversion_expression] = STATE(445),
    [sym_meta_type_expression] = STATE(445),
    [sym_user_defined_type] = STATE(445),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(445),
    [sym_string_literal] = STATE(445),
    [sym_number_literal] = STATE(445),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(445),
    [sym_hex_string_literal] = STATE(445),
    [sym_unicode_string_literal] = STATE(445),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [56] = {
    [sym__expression] = STATE(440),
    [sym__primary_expression] = STATE(440),
    [sym_type_cast_expression] = STATE(440),
    [sym_ternary_expression] = STATE(440),
    [sym_new_expression] = STATE(440),
    [sym_tuple_expression] = STATE(440),
    [sym_inline_array_expression] = STATE(440),
    [sym_binary_expression] = STATE(440),
    [sym_unary_expression] = STATE(440),
    [sym_update_expression] = STATE(440),
    [sym_member_expression] = STATE(440),
    [sym_array_access] = STATE(440),
    [sym_slice_access] = STATE(440),
    [sym_struct_expression] = STATE(440),
    [sym_parenthesized_expression] = STATE(440),
    [sym_assignment_expression] = STATE(440),
    [sym_augmented_assignment_expression] = STATE(440),
    [sym_call_expression] = STATE(440),
    [sym_payable_conversion_expression] = STATE(440),
    [sym_meta_type_expression] = STATE(440),
    [sym_user_defined_type] = STATE(440),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(440),
    [sym_string_literal] = STATE(440),
    [sym_number_literal] = STATE(440),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(440),
    [sym_hex_string_literal] = STATE(440),
    [sym_unicode_string_literal] = STATE(440),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [57] = {
    [sym__expression] = STATE(438),
    [sym__primary_expression] = STATE(438),
    [sym_type_cast_expression] = STATE(438),
    [sym_ternary_expression] = STATE(438),
    [sym_new_expression] = STATE(438),
    [sym_tuple_expression] = STATE(438),
    [sym_inline_array_expression] = STATE(438),
    [sym_binary_expression] = STATE(438),
    [sym_unary_expression] = STATE(438),
    [sym_update_expression] = STATE(438),
    [sym_member_expression] = STATE(438),
    [sym_array_access] = STATE(438),
    [sym_slice_access] = STATE(438),
    [sym_struct_expression] = STATE(438),
    [sym_parenthesized_expression] = STATE(438),
    [sym_assignment_expression] = STATE(438),
    [sym_augmented_assignment_expression] = STATE(438),
    [sym_call_expression] = STATE(438),
    [sym_payable_conversion_expression] = STATE(438),
    [sym_meta_type_expression] = STATE(438),
    [sym_user_defined_type] = STATE(438),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(438),
    [sym_string_literal] = STATE(438),
    [sym_number_literal] = STATE(438),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(438),
    [sym_hex_string_literal] = STATE(438),
    [sym_unicode_string_literal] = STATE(438),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [58] = {
    [sym__expression] = STATE(443),
    [sym__primary_expression] = STATE(443),
    [sym_type_cast_expression] = STATE(443),
    [sym_ternary_expression] = STATE(443),
    [sym_new_expression] = STATE(443),
    [sym_tuple_expression] = STATE(443),
    [sym_inline_array_expression] = STATE(443),
    [sym_binary_expression] = STATE(443),
    [sym_unary_expression] = STATE(443),
    [sym_update_expression] = STATE(443),
    [sym_member_expression] = STATE(443),
    [sym_array_access] = STATE(443),
    [sym_slice_access] = STATE(443),
    [sym_struct_expression] = STATE(443),
    [sym_parenthesized_expression] = STATE(443),
    [sym_assignment_expression] = STATE(443),
    [sym_augmented_assignment_expression] = STATE(443),
    [sym_call_expression] = STATE(443),
    [sym_payable_conversion_expression] = STATE(443),
    [sym_meta_type_expression] = STATE(443),
    [sym_user_defined_type] = STATE(443),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(443),
    [sym_string_literal] = STATE(443),
    [sym_number_literal] = STATE(443),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(443),
    [sym_hex_string_literal] = STATE(443),
    [sym_unicode_string_literal] = STATE(443),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [59] = {
    [sym__expression] = STATE(444),
    [sym__primary_expression] = STATE(444),
    [sym_type_cast_expression] = STATE(444),
    [sym_ternary_expression] = STATE(444),
    [sym_new_expression] = STATE(444),
    [sym_tuple_expression] = STATE(444),
    [sym_inline_array_expression] = STATE(444),
    [sym_binary_expression] = STATE(444),
    [sym_unary_expression] = STATE(444),
    [sym_update_expression] = STATE(444),
    [sym_member_expression] = STATE(444),
    [sym_array_access] = STATE(444),
    [sym_slice_access] = STATE(444),
    [sym_struct_expression] = STATE(444),
    [sym_parenthesized_expression] = STATE(444),
    [sym_assignment_expression] = STATE(444),
    [sym_augmented_assignment_expression] = STATE(444),
    [sym_call_expression] = STATE(444),
    [sym_payable_conversion_expression] = STATE(444),
    [sym_meta_type_expression] = STATE(444),
    [sym_user_defined_type] = STATE(444),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(444),
    [sym_string_literal] = STATE(444),
    [sym_number_literal] = STATE(444),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(444),
    [sym_hex_string_literal] = STATE(444),
    [sym_unicode_string_literal] = STATE(444),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [60] = {
    [sym__expression] = STATE(439),
    [sym__primary_expression] = STATE(439),
    [sym_type_cast_expression] = STATE(439),
    [sym_ternary_expression] = STATE(439),
    [sym_new_expression] = STATE(439),
    [sym_tuple_expression] = STATE(439),
    [sym_inline_array_expression] = STATE(439),
    [sym_binary_expression] = STATE(439),
    [sym_unary_expression] = STATE(439),
    [sym_update_expression] = STATE(439),
    [sym_member_expression] = STATE(439),
    [sym_array_access] = STATE(439),
    [sym_slice_access] = STATE(439),
    [sym_struct_expression] = STATE(439),
    [sym_parenthesized_expression] = STATE(439),
    [sym_assignment_expression] = STATE(439),
    [sym_augmented_assignment_expression] = STATE(439),
    [sym_call_expression] = STATE(439),
    [sym_payable_conversion_expression] = STATE(439),
    [sym_meta_type_expression] = STATE(439),
    [sym_user_defined_type] = STATE(439),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(439),
    [sym_string_literal] = STATE(439),
    [sym_number_literal] = STATE(439),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(439),
    [sym_hex_string_literal] = STATE(439),
    [sym_unicode_string_literal] = STATE(439),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [61] = {
    [sym__expression] = STATE(514),
    [sym__primary_expression] = STATE(514),
    [sym_type_cast_expression] = STATE(514),
    [sym_ternary_expression] = STATE(514),
    [sym_new_expression] = STATE(514),
    [sym_tuple_expression] = STATE(514),
    [sym_inline_array_expression] = STATE(514),
    [sym_binary_expression] = STATE(514),
    [sym_unary_expression] = STATE(514),
    [sym_update_expression] = STATE(514),
    [sym_member_expression] = STATE(514),
    [sym_array_access] = STATE(514),
    [sym_slice_access] = STATE(514),
    [sym_struct_expression] = STATE(514),
    [sym_parenthesized_expression] = STATE(514),
    [sym_assignment_expression] = STATE(514),
    [sym_augmented_assignment_expression] = STATE(514),
    [sym_call_expression] = STATE(514),
    [sym_payable_conversion_expression] = STATE(514),
    [sym_meta_type_expression] = STATE(514),
    [sym_user_defined_type] = STATE(514),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(514),
    [sym_string_literal] = STATE(514),
    [sym_number_literal] = STATE(514),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(514),
    [sym_hex_string_literal] = STATE(514),
    [sym_unicode_string_literal] = STATE(514),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [62] = {
    [sym__expression] = STATE(449),
    [sym__primary_expression] = STATE(449),
    [sym_type_cast_expression] = STATE(449),
    [sym_ternary_expression] = STATE(449),
    [sym_new_expression] = STATE(449),
    [sym_tuple_expression] = STATE(449),
    [sym_inline_array_expression] = STATE(449),
    [sym_binary_expression] = STATE(449),
    [sym_unary_expression] = STATE(449),
    [sym_update_expression] = STATE(449),
    [sym_member_expression] = STATE(449),
    [sym_array_access] = STATE(449),
    [sym_slice_access] = STATE(449),
    [sym_struct_expression] = STATE(449),
    [sym_parenthesized_expression] = STATE(449),
    [sym_assignment_expression] = STATE(449),
    [sym_augmented_assignment_expression] = STATE(449),
    [sym_call_expression] = STATE(449),
    [sym_payable_conversion_expression] = STATE(449),
    [sym_meta_type_expression] = STATE(449),
    [sym_user_defined_type] = STATE(449),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(449),
    [sym_string_literal] = STATE(449),
    [sym_number_literal] = STATE(449),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(449),
    [sym_hex_string_literal] = STATE(449),
    [sym_unicode_string_literal] = STATE(449),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [63] = {
    [sym__expression] = STATE(518),
    [sym__primary_expression] = STATE(518),
    [sym_type_cast_expression] = STATE(518),
    [sym_ternary_expression] = STATE(518),
    [sym_new_expression] = STATE(518),
    [sym_tuple_expression] = STATE(518),
    [sym_inline_array_expression] = STATE(518),
    [sym_binary_expression] = STATE(518),
    [sym_unary_expression] = STATE(518),
    [sym_update_expression] = STATE(518),
    [sym_member_expression] = STATE(518),
    [sym_array_access] = STATE(518),
    [sym_slice_access] = STATE(518),
    [sym_struct_expression] = STATE(518),
    [sym_parenthesized_expression] = STATE(518),
    [sym_assignment_expression] = STATE(518),
    [sym_augmented_assignment_expression] = STATE(518),
    [sym_call_expression] = STATE(518),
    [sym_payable_conversion_expression] = STATE(518),
    [sym_meta_type_expression] = STATE(518),
    [sym_user_defined_type] = STATE(518),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(518),
    [sym_string_literal] = STATE(518),
    [sym_number_literal] = STATE(518),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(518),
    [sym_hex_string_literal] = STATE(518),
    [sym_unicode_string_literal] = STATE(518),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [64] = {
    [sym__expression] = STATE(437),
    [sym__primary_expression] = STATE(437),
    [sym_type_cast_expression] = STATE(437),
    [sym_ternary_expression] = STATE(437),
    [sym_new_expression] = STATE(437),
    [sym_tuple_expression] = STATE(437),
    [sym_inline_array_expression] = STATE(437),
    [sym_binary_expression] = STATE(437),
    [sym_unary_expression] = STATE(437),
    [sym_update_expression] = STATE(437),
    [sym_member_expression] = STATE(437),
    [sym_array_access] = STATE(437),
    [sym_slice_access] = STATE(437),
    [sym_struct_expression] = STATE(437),
    [sym_parenthesized_expression] = STATE(437),
    [sym_assignment_expression] = STATE(437),
    [sym_augmented_assignment_expression] = STATE(437),
    [sym_call_expression] = STATE(437),
    [sym_payable_conversion_expression] = STATE(437),
    [sym_meta_type_expression] = STATE(437),
    [sym_user_defined_type] = STATE(437),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(437),
    [sym_string_literal] = STATE(437),
    [sym_number_literal] = STATE(437),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(437),
    [sym_hex_string_literal] = STATE(437),
    [sym_unicode_string_literal] = STATE(437),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [65] = {
    [sym__expression] = STATE(508),
    [sym__primary_expression] = STATE(508),
    [sym_type_cast_expression] = STATE(508),
    [sym_ternary_expression] = STATE(508),
    [sym_new_expression] = STATE(508),
    [sym_tuple_expression] = STATE(508),
    [sym_inline_array_expression] = STATE(508),
    [sym_binary_expression] = STATE(508),
    [sym_unary_expression] = STATE(508),
    [sym_update_expression] = STATE(508),
    [sym_member_expression] = STATE(508),
    [sym_array_access] = STATE(508),
    [sym_slice_access] = STATE(508),
    [sym_struct_expression] = STATE(508),
    [sym_parenthesized_expression] = STATE(508),
    [sym_assignment_expression] = STATE(508),
    [sym_augmented_assignment_expression] = STATE(508),
    [sym_call_expression] = STATE(508),
    [sym_payable_conversion_expression] = STATE(508),
    [sym_meta_type_expression] = STATE(508),
    [sym_user_defined_type] = STATE(508),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(508),
    [sym_string_literal] = STATE(508),
    [sym_number_literal] = STATE(508),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(508),
    [sym_hex_string_literal] = STATE(508),
    [sym_unicode_string_literal] = STATE(508),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [66] = {
    [sym__expression] = STATE(441),
    [sym__primary_expression] = STATE(441),
    [sym_type_cast_expression] = STATE(441),
    [sym_ternary_expression] = STATE(441),
    [sym_new_expression] = STATE(441),
    [sym_tuple_expression] = STATE(441),
    [sym_inline_array_expression] = STATE(441),
    [sym_binary_expression] = STATE(441),
    [sym_unary_expression] = STATE(441),
    [sym_update_expression] = STATE(441),
    [sym_member_expression] = STATE(441),
    [sym_array_access] = STATE(441),
    [sym_slice_access] = STATE(441),
    [sym_struct_expression] = STATE(441),
    [sym_parenthesized_expression] = STATE(441),
    [sym_assignment_expression] = STATE(441),
    [sym_augmented_assignment_expression] = STATE(441),
    [sym_call_expression] = STATE(441),
    [sym_payable_conversion_expression] = STATE(441),
    [sym_meta_type_expression] = STATE(441),
    [sym_user_defined_type] = STATE(441),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(441),
    [sym_string_literal] = STATE(441),
    [sym_number_literal] = STATE(441),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(441),
    [sym_hex_string_literal] = STATE(441),
    [sym_unicode_string_literal] = STATE(441),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [67] = {
    [sym__expression] = STATE(452),
    [sym__primary_expression] = STATE(452),
    [sym_type_cast_expression] = STATE(452),
    [sym_ternary_expression] = STATE(452),
    [sym_new_expression] = STATE(452),
    [sym_tuple_expression] = STATE(452),
    [sym_inline_array_expression] = STATE(452),
    [sym_binary_expression] = STATE(452),
    [sym_unary_expression] = STATE(452),
    [sym_update_expression] = STATE(452),
    [sym_member_expression] = STATE(452),
    [sym_array_access] = STATE(452),
    [sym_slice_access] = STATE(452),
    [sym_struct_expression] = STATE(452),
    [sym_parenthesized_expression] = STATE(452),
    [sym_assignment_expression] = STATE(452),
    [sym_augmented_assignment_expression] = STATE(452),
    [sym_call_expression] = STATE(452),
    [sym_payable_conversion_expression] = STATE(452),
    [sym_meta_type_expression] = STATE(452),
    [sym_user_defined_type] = STATE(452),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(452),
    [sym_string_literal] = STATE(452),
    [sym_number_literal] = STATE(452),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(452),
    [sym_hex_string_literal] = STATE(452),
    [sym_unicode_string_literal] = STATE(452),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [68] = {
    [sym__expression] = STATE(509),
    [sym__primary_expression] = STATE(509),
    [sym_type_cast_expression] = STATE(509),
    [sym_ternary_expression] = STATE(509),
    [sym_new_expression] = STATE(509),
    [sym_tuple_expression] = STATE(509),
    [sym_inline_array_expression] = STATE(509),
    [sym_binary_expression] = STATE(509),
    [sym_unary_expression] = STATE(509),
    [sym_update_expression] = STATE(509),
    [sym_member_expression] = STATE(509),
    [sym_array_access] = STATE(509),
    [sym_slice_access] = STATE(509),
    [sym_struct_expression] = STATE(509),
    [sym_parenthesized_expression] = STATE(509),
    [sym_assignment_expression] = STATE(509),
    [sym_augmented_assignment_expression] = STATE(509),
    [sym_call_expression] = STATE(509),
    [sym_payable_conversion_expression] = STATE(509),
    [sym_meta_type_expression] = STATE(509),
    [sym_user_defined_type] = STATE(509),
    [sym__identifier_path] = STATE(399),
    [sym_primitive_type] = STATE(459),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym__literal] = STATE(509),
    [sym_string_literal] = STATE(509),
    [sym_number_literal] = STATE(509),
    [sym__decimal_number] = STATE(418),
    [sym__hex_number] = STATE(418),
    [sym_true] = STATE(460),
    [sym_false] = STATE(460),
    [sym_boolean_literal] = STATE(509),
    [sym_hex_string_literal] = STATE(509),
    [sym_unicode_string_literal] = STATE(509),
    [sym_string] = STATE(429),
    [aux_sym_string_literal_repeat1] = STATE(429),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [aux_sym_unicode_string_literal_repeat3] = STATE(435),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_DASH] = ACTIONS(41),
    [anon_sym_TILDE] = ACTIONS(43),
    [anon_sym_type] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(41),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(63),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_payable] = ACTIONS(85),
    [anon_sym_new] = ACTIONS(87),
    [anon_sym_LBRACK] = ACTIONS(89),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_delete] = ACTIONS(91),
    [anon_sym_PLUS_PLUS] = ACTIONS(93),
    [anon_sym_DASH_DASH] = ACTIONS(93),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [aux_sym__decimal_number_token1] = ACTIONS(95),
    [aux_sym__decimal_number_token2] = ACTIONS(97),
    [aux_sym__hex_number_token1] = ACTIONS(97),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [anon_sym_unicode] = ACTIONS(105),
    [sym_comment] = ACTIONS(3),
  },
  [69] = {
    [sym__source_unit] = STATE(69),
    [sym__directive] = STATE(69),
    [sym_pragma_directive] = STATE(69),
    [sym_import_directive] = STATE(69),
    [sym__declaration] = STATE(69),
    [sym_user_defined_type_definition] = STATE(69),
    [sym_constant_variable_declaration] = STATE(69),
    [sym_contract_declaration] = STATE(69),
    [sym_error_declaration] = STATE(69),
    [sym_interface_declaration] = STATE(69),
    [sym_library_declaration] = STATE(69),
    [sym_struct_declaration] = STATE(69),
    [sym_enum_declaration] = STATE(69),
    [sym_using_directive] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_type_name] = STATE(790),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_source_file_repeat1] = STATE(69),
    [ts_builtin_sym_end] = ACTIONS(294),
    [sym_identifier] = ACTIONS(296),
    [anon_sym_pragma] = ACTIONS(299),
    [anon_sym_import] = ACTIONS(302),
    [anon_sym_type] = ACTIONS(305),
    [anon_sym_abstract] = ACTIONS(308),
    [anon_sym_contract] = ACTIONS(311),
    [anon_sym_error] = ACTIONS(314),
    [anon_sym_interface] = ACTIONS(317),
    [anon_sym_library] = ACTIONS(320),
    [anon_sym_struct] = ACTIONS(323),
    [anon_sym_enum] = ACTIONS(326),
    [anon_sym_using] = ACTIONS(329),
    [anon_sym_function] = ACTIONS(332),
    [anon_sym_byte] = ACTIONS(335),
    [anon_sym_address] = ACTIONS(338),
    [anon_sym_var] = ACTIONS(335),
    [anon_sym_mapping] = ACTIONS(341),
    [anon_sym_bool] = ACTIONS(335),
    [anon_sym_string] = ACTIONS(335),
    [anon_sym_int] = ACTIONS(335),
    [anon_sym_int8] = ACTIONS(335),
    [anon_sym_int16] = ACTIONS(335),
    [anon_sym_int24] = ACTIONS(335),
    [anon_sym_int32] = ACTIONS(335),
    [anon_sym_int40] = ACTIONS(335),
    [anon_sym_int48] = ACTIONS(335),
    [anon_sym_int56] = ACTIONS(335),
    [anon_sym_int64] = ACTIONS(335),
    [anon_sym_int72] = ACTIONS(335),
    [anon_sym_int80] = ACTIONS(335),
    [anon_sym_int88] = ACTIONS(335),
    [anon_sym_int96] = ACTIONS(335),
    [anon_sym_int104] = ACTIONS(335),
    [anon_sym_int112] = ACTIONS(335),
    [anon_sym_int120] = ACTIONS(335),
    [anon_sym_int128] = ACTIONS(335),
    [anon_sym_int136] = ACTIONS(335),
    [anon_sym_int144] = ACTIONS(335),
    [anon_sym_int152] = ACTIONS(335),
    [anon_sym_int160] = ACTIONS(335),
    [anon_sym_int168] = ACTIONS(335),
    [anon_sym_int176] = ACTIONS(335),
    [anon_sym_int184] = ACTIONS(335),
    [anon_sym_int192] = ACTIONS(335),
    [anon_sym_int200] = ACTIONS(335),
    [anon_sym_int208] = ACTIONS(335),
    [anon_sym_int216] = ACTIONS(335),
    [anon_sym_int224] = ACTIONS(335),
    [anon_sym_int232] = ACTIONS(335),
    [anon_sym_int240] = ACTIONS(335),
    [anon_sym_int248] = ACTIONS(335),
    [anon_sym_int256] = ACTIONS(335),
    [anon_sym_uint] = ACTIONS(335),
    [anon_sym_uint8] = ACTIONS(335),
    [anon_sym_uint16] = ACTIONS(335),
    [anon_sym_uint24] = ACTIONS(335),
    [anon_sym_uint32] = ACTIONS(335),
    [anon_sym_uint40] = ACTIONS(335),
    [anon_sym_uint48] = ACTIONS(335),
    [anon_sym_uint56] = ACTIONS(335),
    [anon_sym_uint64] = ACTIONS(335),
    [anon_sym_uint72] = ACTIONS(335),
    [anon_sym_uint80] = ACTIONS(335),
    [anon_sym_uint88] = ACTIONS(335),
    [anon_sym_uint96] = ACTIONS(335),
    [anon_sym_uint104] = ACTIONS(335),
    [anon_sym_uint112] = ACTIONS(335),
    [anon_sym_uint120] = ACTIONS(335),
    [anon_sym_uint128] = ACTIONS(335),
    [anon_sym_uint136] = ACTIONS(335),
    [anon_sym_uint144] = ACTIONS(335),
    [anon_sym_uint152] = ACTIONS(335),
    [anon_sym_uint160] = ACTIONS(335),
    [anon_sym_uint168] = ACTIONS(335),
    [anon_sym_uint176] = ACTIONS(335),
    [anon_sym_uint184] = ACTIONS(335),
    [anon_sym_uint192] = ACTIONS(335),
    [anon_sym_uint200] = ACTIONS(335),
    [anon_sym_uint208] = ACTIONS(335),
    [anon_sym_uint216] = ACTIONS(335),
    [anon_sym_uint224] = ACTIONS(335),
    [anon_sym_uint232] = ACTIONS(335),
    [anon_sym_uint240] = ACTIONS(335),
    [anon_sym_uint248] = ACTIONS(335),
    [anon_sym_uint256] = ACTIONS(335),
    [anon_sym_bytes] = ACTIONS(335),
    [anon_sym_bytes1] = ACTIONS(335),
    [anon_sym_bytes2] = ACTIONS(335),
    [anon_sym_bytes3] = ACTIONS(335),
    [anon_sym_bytes4] = ACTIONS(335),
    [anon_sym_bytes5] = ACTIONS(335),
    [anon_sym_bytes6] = ACTIONS(335),
    [anon_sym_bytes7] = ACTIONS(335),
    [anon_sym_bytes8] = ACTIONS(335),
    [anon_sym_bytes9] = ACTIONS(335),
    [anon_sym_bytes10] = ACTIONS(335),
    [anon_sym_bytes11] = ACTIONS(335),
    [anon_sym_bytes12] = ACTIONS(335),
    [anon_sym_bytes13] = ACTIONS(335),
    [anon_sym_bytes14] = ACTIONS(335),
    [anon_sym_bytes15] = ACTIONS(335),
    [anon_sym_bytes16] = ACTIONS(335),
    [anon_sym_bytes17] = ACTIONS(335),
    [anon_sym_bytes18] = ACTIONS(335),
    [anon_sym_bytes19] = ACTIONS(335),
    [anon_sym_bytes20] = ACTIONS(335),
    [anon_sym_bytes21] = ACTIONS(335),
    [anon_sym_bytes22] = ACTIONS(335),
    [anon_sym_bytes23] = ACTIONS(335),
    [anon_sym_bytes24] = ACTIONS(335),
    [anon_sym_bytes25] = ACTIONS(335),
    [anon_sym_bytes26] = ACTIONS(335),
    [anon_sym_bytes27] = ACTIONS(335),
    [anon_sym_bytes28] = ACTIONS(335),
    [anon_sym_bytes29] = ACTIONS(335),
    [anon_sym_bytes30] = ACTIONS(335),
    [anon_sym_bytes31] = ACTIONS(335),
    [anon_sym_bytes32] = ACTIONS(335),
    [anon_sym_fixed] = ACTIONS(335),
    [aux_sym__fixed_token1] = ACTIONS(335),
    [anon_sym_ufixed] = ACTIONS(335),
    [aux_sym__ufixed_token1] = ACTIONS(335),
    [sym_comment] = ACTIONS(3),
  },
  [70] = {
    [sym__source_unit] = STATE(69),
    [sym__directive] = STATE(69),
    [sym_pragma_directive] = STATE(69),
    [sym_import_directive] = STATE(69),
    [sym__declaration] = STATE(69),
    [sym_user_defined_type_definition] = STATE(69),
    [sym_constant_variable_declaration] = STATE(69),
    [sym_contract_declaration] = STATE(69),
    [sym_error_declaration] = STATE(69),
    [sym_interface_declaration] = STATE(69),
    [sym_library_declaration] = STATE(69),
    [sym_struct_declaration] = STATE(69),
    [sym_enum_declaration] = STATE(69),
    [sym_using_directive] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_type_name] = STATE(790),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_source_file_repeat1] = STATE(69),
    [ts_builtin_sym_end] = ACTIONS(344),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_pragma] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_type] = ACTIONS(13),
    [anon_sym_abstract] = ACTIONS(15),
    [anon_sym_contract] = ACTIONS(17),
    [anon_sym_error] = ACTIONS(19),
    [anon_sym_interface] = ACTIONS(21),
    [anon_sym_library] = ACTIONS(23),
    [anon_sym_struct] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_using] = ACTIONS(29),
    [anon_sym_function] = ACTIONS(31),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [71] = {
    [sym_catch_clause] = STATE(72),
    [aux_sym_try_statement_repeat1] = STATE(72),
    [sym_identifier] = ACTIONS(346),
    [anon_sym_DASH] = ACTIONS(346),
    [anon_sym_TILDE] = ACTIONS(348),
    [anon_sym_LBRACE] = ACTIONS(348),
    [anon_sym_RBRACE] = ACTIONS(348),
    [anon_sym_type] = ACTIONS(346),
    [anon_sym_LPAREN] = ACTIONS(348),
    [anon_sym_for] = ACTIONS(346),
    [anon_sym_PLUS] = ACTIONS(346),
    [anon_sym_assembly] = ACTIONS(346),
    [anon_sym_break] = ACTIONS(346),
    [anon_sym_continue] = ACTIONS(346),
    [anon_sym_true] = ACTIONS(346),
    [anon_sym_false] = ACTIONS(346),
    [anon_sym_if] = ACTIONS(346),
    [anon_sym_function] = ACTIONS(346),
    [anon_sym_byte] = ACTIONS(346),
    [anon_sym_address] = ACTIONS(346),
    [anon_sym_return] = ACTIONS(346),
    [anon_sym_revert] = ACTIONS(346),
    [sym__unchecked] = ACTIONS(346),
    [anon_sym_var] = ACTIONS(346),
    [anon_sym_else] = ACTIONS(346),
    [anon_sym_while] = ACTIONS(346),
    [anon_sym_do] = ACTIONS(346),
    [anon_sym_try] = ACTIONS(346),
    [anon_sym_catch] = ACTIONS(350),
    [anon_sym_emit] = ACTIONS(346),
    [anon_sym_payable] = ACTIONS(346),
    [anon_sym_new] = ACTIONS(346),
    [anon_sym_LBRACK] = ACTIONS(348),
    [anon_sym_BANG] = ACTIONS(348),
    [anon_sym_delete] = ACTIONS(346),
    [anon_sym_PLUS_PLUS] = ACTIONS(348),
    [anon_sym_DASH_DASH] = ACTIONS(348),
    [anon_sym_mapping] = ACTIONS(346),
    [anon_sym_bool] = ACTIONS(346),
    [anon_sym_string] = ACTIONS(346),
    [anon_sym_int] = ACTIONS(346),
    [anon_sym_int8] = ACTIONS(346),
    [anon_sym_int16] = ACTIONS(346),
    [anon_sym_int24] = ACTIONS(346),
    [anon_sym_int32] = ACTIONS(346),
    [anon_sym_int40] = ACTIONS(346),
    [anon_sym_int48] = ACTIONS(346),
    [anon_sym_int56] = ACTIONS(346),
    [anon_sym_int64] = ACTIONS(346),
    [anon_sym_int72] = ACTIONS(346),
    [anon_sym_int80] = ACTIONS(346),
    [anon_sym_int88] = ACTIONS(346),
    [anon_sym_int96] = ACTIONS(346),
    [anon_sym_int104] = ACTIONS(346),
    [anon_sym_int112] = ACTIONS(346),
    [anon_sym_int120] = ACTIONS(346),
    [anon_sym_int128] = ACTIONS(346),
    [anon_sym_int136] = ACTIONS(346),
    [anon_sym_int144] = ACTIONS(346),
    [anon_sym_int152] = ACTIONS(346),
    [anon_sym_int160] = ACTIONS(346),
    [anon_sym_int168] = ACTIONS(346),
    [anon_sym_int176] = ACTIONS(346),
    [anon_sym_int184] = ACTIONS(346),
    [anon_sym_int192] = ACTIONS(346),
    [anon_sym_int200] = ACTIONS(346),
    [anon_sym_int208] = ACTIONS(346),
    [anon_sym_int216] = ACTIONS(346),
    [anon_sym_int224] = ACTIONS(346),
    [anon_sym_int232] = ACTIONS(346),
    [anon_sym_int240] = ACTIONS(346),
    [anon_sym_int248] = ACTIONS(346),
    [anon_sym_int256] = ACTIONS(346),
    [anon_sym_uint] = ACTIONS(346),
    [anon_sym_uint8] = ACTIONS(346),
    [anon_sym_uint16] = ACTIONS(346),
    [anon_sym_uint24] = ACTIONS(346),
    [anon_sym_uint32] = ACTIONS(346),
    [anon_sym_uint40] = ACTIONS(346),
    [anon_sym_uint48] = ACTIONS(346),
    [anon_sym_uint56] = ACTIONS(346),
    [anon_sym_uint64] = ACTIONS(346),
    [anon_sym_uint72] = ACTIONS(346),
    [anon_sym_uint80] = ACTIONS(346),
    [anon_sym_uint88] = ACTIONS(346),
    [anon_sym_uint96] = ACTIONS(346),
    [anon_sym_uint104] = ACTIONS(346),
    [anon_sym_uint112] = ACTIONS(346),
    [anon_sym_uint120] = ACTIONS(346),
    [anon_sym_uint128] = ACTIONS(346),
    [anon_sym_uint136] = ACTIONS(346),
    [anon_sym_uint144] = ACTIONS(346),
    [anon_sym_uint152] = ACTIONS(346),
    [anon_sym_uint160] = ACTIONS(346),
    [anon_sym_uint168] = ACTIONS(346),
    [anon_sym_uint176] = ACTIONS(346),
    [anon_sym_uint184] = ACTIONS(346),
    [anon_sym_uint192] = ACTIONS(346),
    [anon_sym_uint200] = ACTIONS(346),
    [anon_sym_uint208] = ACTIONS(346),
    [anon_sym_uint216] = ACTIONS(346),
    [anon_sym_uint224] = ACTIONS(346),
    [anon_sym_uint232] = ACTIONS(346),
    [anon_sym_uint240] = ACTIONS(346),
    [anon_sym_uint248] = ACTIONS(346),
    [anon_sym_uint256] = ACTIONS(346),
    [anon_sym_bytes] = ACTIONS(346),
    [anon_sym_bytes1] = ACTIONS(346),
    [anon_sym_bytes2] = ACTIONS(346),
    [anon_sym_bytes3] = ACTIONS(346),
    [anon_sym_bytes4] = ACTIONS(346),
    [anon_sym_bytes5] = ACTIONS(346),
    [anon_sym_bytes6] = ACTIONS(346),
    [anon_sym_bytes7] = ACTIONS(346),
    [anon_sym_bytes8] = ACTIONS(346),
    [anon_sym_bytes9] = ACTIONS(346),
    [anon_sym_bytes10] = ACTIONS(346),
    [anon_sym_bytes11] = ACTIONS(346),
    [anon_sym_bytes12] = ACTIONS(346),
    [anon_sym_bytes13] = ACTIONS(346),
    [anon_sym_bytes14] = ACTIONS(346),
    [anon_sym_bytes15] = ACTIONS(346),
    [anon_sym_bytes16] = ACTIONS(346),
    [anon_sym_bytes17] = ACTIONS(346),
    [anon_sym_bytes18] = ACTIONS(346),
    [anon_sym_bytes19] = ACTIONS(346),
    [anon_sym_bytes20] = ACTIONS(346),
    [anon_sym_bytes21] = ACTIONS(346),
    [anon_sym_bytes22] = ACTIONS(346),
    [anon_sym_bytes23] = ACTIONS(346),
    [anon_sym_bytes24] = ACTIONS(346),
    [anon_sym_bytes25] = ACTIONS(346),
    [anon_sym_bytes26] = ACTIONS(346),
    [anon_sym_bytes27] = ACTIONS(346),
    [anon_sym_bytes28] = ACTIONS(346),
    [anon_sym_bytes29] = ACTIONS(346),
    [anon_sym_bytes30] = ACTIONS(346),
    [anon_sym_bytes31] = ACTIONS(346),
    [anon_sym_bytes32] = ACTIONS(346),
    [anon_sym_fixed] = ACTIONS(346),
    [aux_sym__fixed_token1] = ACTIONS(346),
    [anon_sym_ufixed] = ACTIONS(346),
    [aux_sym__ufixed_token1] = ACTIONS(346),
    [aux_sym__decimal_number_token1] = ACTIONS(346),
    [aux_sym__decimal_number_token2] = ACTIONS(348),
    [aux_sym__hex_number_token1] = ACTIONS(348),
    [anon_sym_hex] = ACTIONS(346),
    [anon_sym_DQUOTE] = ACTIONS(348),
    [anon_sym_SQUOTE] = ACTIONS(348),
    [anon_sym_unicode] = ACTIONS(346),
    [sym_comment] = ACTIONS(3),
  },
  [72] = {
    [sym_catch_clause] = STATE(72),
    [aux_sym_try_statement_repeat1] = STATE(72),
    [sym_identifier] = ACTIONS(352),
    [anon_sym_DASH] = ACTIONS(352),
    [anon_sym_TILDE] = ACTIONS(354),
    [anon_sym_LBRACE] = ACTIONS(354),
    [anon_sym_RBRACE] = ACTIONS(354),
    [anon_sym_type] = ACTIONS(352),
    [anon_sym_LPAREN] = ACTIONS(354),
    [anon_sym_for] = ACTIONS(352),
    [anon_sym_PLUS] = ACTIONS(352),
    [anon_sym_assembly] = ACTIONS(352),
    [anon_sym_break] = ACTIONS(352),
    [anon_sym_continue] = ACTIONS(352),
    [anon_sym_true] = ACTIONS(352),
    [anon_sym_false] = ACTIONS(352),
    [anon_sym_if] = ACTIONS(352),
    [anon_sym_function] = ACTIONS(352),
    [anon_sym_byte] = ACTIONS(352),
    [anon_sym_address] = ACTIONS(352),
    [anon_sym_return] = ACTIONS(352),
    [anon_sym_revert] = ACTIONS(352),
    [sym__unchecked] = ACTIONS(352),
    [anon_sym_var] = ACTIONS(352),
    [anon_sym_else] = ACTIONS(352),
    [anon_sym_while] = ACTIONS(352),
    [anon_sym_do] = ACTIONS(352),
    [anon_sym_try] = ACTIONS(352),
    [anon_sym_catch] = ACTIONS(356),
    [anon_sym_emit] = ACTIONS(352),
    [anon_sym_payable] = ACTIONS(352),
    [anon_sym_new] = ACTIONS(352),
    [anon_sym_LBRACK] = ACTIONS(354),
    [anon_sym_BANG] = ACTIONS(354),
    [anon_sym_delete] = ACTIONS(352),
    [anon_sym_PLUS_PLUS] = ACTIONS(354),
    [anon_sym_DASH_DASH] = ACTIONS(354),
    [anon_sym_mapping] = ACTIONS(352),
    [anon_sym_bool] = ACTIONS(352),
    [anon_sym_string] = ACTIONS(352),
    [anon_sym_int] = ACTIONS(352),
    [anon_sym_int8] = ACTIONS(352),
    [anon_sym_int16] = ACTIONS(352),
    [anon_sym_int24] = ACTIONS(352),
    [anon_sym_int32] = ACTIONS(352),
    [anon_sym_int40] = ACTIONS(352),
    [anon_sym_int48] = ACTIONS(352),
    [anon_sym_int56] = ACTIONS(352),
    [anon_sym_int64] = ACTIONS(352),
    [anon_sym_int72] = ACTIONS(352),
    [anon_sym_int80] = ACTIONS(352),
    [anon_sym_int88] = ACTIONS(352),
    [anon_sym_int96] = ACTIONS(352),
    [anon_sym_int104] = ACTIONS(352),
    [anon_sym_int112] = ACTIONS(352),
    [anon_sym_int120] = ACTIONS(352),
    [anon_sym_int128] = ACTIONS(352),
    [anon_sym_int136] = ACTIONS(352),
    [anon_sym_int144] = ACTIONS(352),
    [anon_sym_int152] = ACTIONS(352),
    [anon_sym_int160] = ACTIONS(352),
    [anon_sym_int168] = ACTIONS(352),
    [anon_sym_int176] = ACTIONS(352),
    [anon_sym_int184] = ACTIONS(352),
    [anon_sym_int192] = ACTIONS(352),
    [anon_sym_int200] = ACTIONS(352),
    [anon_sym_int208] = ACTIONS(352),
    [anon_sym_int216] = ACTIONS(352),
    [anon_sym_int224] = ACTIONS(352),
    [anon_sym_int232] = ACTIONS(352),
    [anon_sym_int240] = ACTIONS(352),
    [anon_sym_int248] = ACTIONS(352),
    [anon_sym_int256] = ACTIONS(352),
    [anon_sym_uint] = ACTIONS(352),
    [anon_sym_uint8] = ACTIONS(352),
    [anon_sym_uint16] = ACTIONS(352),
    [anon_sym_uint24] = ACTIONS(352),
    [anon_sym_uint32] = ACTIONS(352),
    [anon_sym_uint40] = ACTIONS(352),
    [anon_sym_uint48] = ACTIONS(352),
    [anon_sym_uint56] = ACTIONS(352),
    [anon_sym_uint64] = ACTIONS(352),
    [anon_sym_uint72] = ACTIONS(352),
    [anon_sym_uint80] = ACTIONS(352),
    [anon_sym_uint88] = ACTIONS(352),
    [anon_sym_uint96] = ACTIONS(352),
    [anon_sym_uint104] = ACTIONS(352),
    [anon_sym_uint112] = ACTIONS(352),
    [anon_sym_uint120] = ACTIONS(352),
    [anon_sym_uint128] = ACTIONS(352),
    [anon_sym_uint136] = ACTIONS(352),
    [anon_sym_uint144] = ACTIONS(352),
    [anon_sym_uint152] = ACTIONS(352),
    [anon_sym_uint160] = ACTIONS(352),
    [anon_sym_uint168] = ACTIONS(352),
    [anon_sym_uint176] = ACTIONS(352),
    [anon_sym_uint184] = ACTIONS(352),
    [anon_sym_uint192] = ACTIONS(352),
    [anon_sym_uint200] = ACTIONS(352),
    [anon_sym_uint208] = ACTIONS(352),
    [anon_sym_uint216] = ACTIONS(352),
    [anon_sym_uint224] = ACTIONS(352),
    [anon_sym_uint232] = ACTIONS(352),
    [anon_sym_uint240] = ACTIONS(352),
    [anon_sym_uint248] = ACTIONS(352),
    [anon_sym_uint256] = ACTIONS(352),
    [anon_sym_bytes] = ACTIONS(352),
    [anon_sym_bytes1] = ACTIONS(352),
    [anon_sym_bytes2] = ACTIONS(352),
    [anon_sym_bytes3] = ACTIONS(352),
    [anon_sym_bytes4] = ACTIONS(352),
    [anon_sym_bytes5] = ACTIONS(352),
    [anon_sym_bytes6] = ACTIONS(352),
    [anon_sym_bytes7] = ACTIONS(352),
    [anon_sym_bytes8] = ACTIONS(352),
    [anon_sym_bytes9] = ACTIONS(352),
    [anon_sym_bytes10] = ACTIONS(352),
    [anon_sym_bytes11] = ACTIONS(352),
    [anon_sym_bytes12] = ACTIONS(352),
    [anon_sym_bytes13] = ACTIONS(352),
    [anon_sym_bytes14] = ACTIONS(352),
    [anon_sym_bytes15] = ACTIONS(352),
    [anon_sym_bytes16] = ACTIONS(352),
    [anon_sym_bytes17] = ACTIONS(352),
    [anon_sym_bytes18] = ACTIONS(352),
    [anon_sym_bytes19] = ACTIONS(352),
    [anon_sym_bytes20] = ACTIONS(352),
    [anon_sym_bytes21] = ACTIONS(352),
    [anon_sym_bytes22] = ACTIONS(352),
    [anon_sym_bytes23] = ACTIONS(352),
    [anon_sym_bytes24] = ACTIONS(352),
    [anon_sym_bytes25] = ACTIONS(352),
    [anon_sym_bytes26] = ACTIONS(352),
    [anon_sym_bytes27] = ACTIONS(352),
    [anon_sym_bytes28] = ACTIONS(352),
    [anon_sym_bytes29] = ACTIONS(352),
    [anon_sym_bytes30] = ACTIONS(352),
    [anon_sym_bytes31] = ACTIONS(352),
    [anon_sym_bytes32] = ACTIONS(352),
    [anon_sym_fixed] = ACTIONS(352),
    [aux_sym__fixed_token1] = ACTIONS(352),
    [anon_sym_ufixed] = ACTIONS(352),
    [aux_sym__ufixed_token1] = ACTIONS(352),
    [aux_sym__decimal_number_token1] = ACTIONS(352),
    [aux_sym__decimal_number_token2] = ACTIONS(354),
    [aux_sym__hex_number_token1] = ACTIONS(354),
    [anon_sym_hex] = ACTIONS(352),
    [anon_sym_DQUOTE] = ACTIONS(354),
    [anon_sym_SQUOTE] = ACTIONS(354),
    [anon_sym_unicode] = ACTIONS(352),
    [sym_comment] = ACTIONS(3),
  },
  [73] = {
    [sym_catch_clause] = STATE(72),
    [aux_sym_try_statement_repeat1] = STATE(72),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(359),
    [anon_sym_TILDE] = ACTIONS(361),
    [anon_sym_LBRACE] = ACTIONS(361),
    [anon_sym_RBRACE] = ACTIONS(361),
    [anon_sym_type] = ACTIONS(359),
    [anon_sym_LPAREN] = ACTIONS(361),
    [anon_sym_for] = ACTIONS(359),
    [anon_sym_PLUS] = ACTIONS(359),
    [anon_sym_assembly] = ACTIONS(359),
    [anon_sym_break] = ACTIONS(359),
    [anon_sym_continue] = ACTIONS(359),
    [anon_sym_true] = ACTIONS(359),
    [anon_sym_false] = ACTIONS(359),
    [anon_sym_if] = ACTIONS(359),
    [anon_sym_function] = ACTIONS(359),
    [anon_sym_byte] = ACTIONS(359),
    [anon_sym_address] = ACTIONS(359),
    [anon_sym_return] = ACTIONS(359),
    [anon_sym_revert] = ACTIONS(359),
    [sym__unchecked] = ACTIONS(359),
    [anon_sym_var] = ACTIONS(359),
    [anon_sym_else] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(359),
    [anon_sym_do] = ACTIONS(359),
    [anon_sym_try] = ACTIONS(359),
    [anon_sym_catch] = ACTIONS(350),
    [anon_sym_emit] = ACTIONS(359),
    [anon_sym_payable] = ACTIONS(359),
    [anon_sym_new] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_BANG] = ACTIONS(361),
    [anon_sym_delete] = ACTIONS(359),
    [anon_sym_PLUS_PLUS] = ACTIONS(361),
    [anon_sym_DASH_DASH] = ACTIONS(361),
    [anon_sym_mapping] = ACTIONS(359),
    [anon_sym_bool] = ACTIONS(359),
    [anon_sym_string] = ACTIONS(359),
    [anon_sym_int] = ACTIONS(359),
    [anon_sym_int8] = ACTIONS(359),
    [anon_sym_int16] = ACTIONS(359),
    [anon_sym_int24] = ACTIONS(359),
    [anon_sym_int32] = ACTIONS(359),
    [anon_sym_int40] = ACTIONS(359),
    [anon_sym_int48] = ACTIONS(359),
    [anon_sym_int56] = ACTIONS(359),
    [anon_sym_int64] = ACTIONS(359),
    [anon_sym_int72] = ACTIONS(359),
    [anon_sym_int80] = ACTIONS(359),
    [anon_sym_int88] = ACTIONS(359),
    [anon_sym_int96] = ACTIONS(359),
    [anon_sym_int104] = ACTIONS(359),
    [anon_sym_int112] = ACTIONS(359),
    [anon_sym_int120] = ACTIONS(359),
    [anon_sym_int128] = ACTIONS(359),
    [anon_sym_int136] = ACTIONS(359),
    [anon_sym_int144] = ACTIONS(359),
    [anon_sym_int152] = ACTIONS(359),
    [anon_sym_int160] = ACTIONS(359),
    [anon_sym_int168] = ACTIONS(359),
    [anon_sym_int176] = ACTIONS(359),
    [anon_sym_int184] = ACTIONS(359),
    [anon_sym_int192] = ACTIONS(359),
    [anon_sym_int200] = ACTIONS(359),
    [anon_sym_int208] = ACTIONS(359),
    [anon_sym_int216] = ACTIONS(359),
    [anon_sym_int224] = ACTIONS(359),
    [anon_sym_int232] = ACTIONS(359),
    [anon_sym_int240] = ACTIONS(359),
    [anon_sym_int248] = ACTIONS(359),
    [anon_sym_int256] = ACTIONS(359),
    [anon_sym_uint] = ACTIONS(359),
    [anon_sym_uint8] = ACTIONS(359),
    [anon_sym_uint16] = ACTIONS(359),
    [anon_sym_uint24] = ACTIONS(359),
    [anon_sym_uint32] = ACTIONS(359),
    [anon_sym_uint40] = ACTIONS(359),
    [anon_sym_uint48] = ACTIONS(359),
    [anon_sym_uint56] = ACTIONS(359),
    [anon_sym_uint64] = ACTIONS(359),
    [anon_sym_uint72] = ACTIONS(359),
    [anon_sym_uint80] = ACTIONS(359),
    [anon_sym_uint88] = ACTIONS(359),
    [anon_sym_uint96] = ACTIONS(359),
    [anon_sym_uint104] = ACTIONS(359),
    [anon_sym_uint112] = ACTIONS(359),
    [anon_sym_uint120] = ACTIONS(359),
    [anon_sym_uint128] = ACTIONS(359),
    [anon_sym_uint136] = ACTIONS(359),
    [anon_sym_uint144] = ACTIONS(359),
    [anon_sym_uint152] = ACTIONS(359),
    [anon_sym_uint160] = ACTIONS(359),
    [anon_sym_uint168] = ACTIONS(359),
    [anon_sym_uint176] = ACTIONS(359),
    [anon_sym_uint184] = ACTIONS(359),
    [anon_sym_uint192] = ACTIONS(359),
    [anon_sym_uint200] = ACTIONS(359),
    [anon_sym_uint208] = ACTIONS(359),
    [anon_sym_uint216] = ACTIONS(359),
    [anon_sym_uint224] = ACTIONS(359),
    [anon_sym_uint232] = ACTIONS(359),
    [anon_sym_uint240] = ACTIONS(359),
    [anon_sym_uint248] = ACTIONS(359),
    [anon_sym_uint256] = ACTIONS(359),
    [anon_sym_bytes] = ACTIONS(359),
    [anon_sym_bytes1] = ACTIONS(359),
    [anon_sym_bytes2] = ACTIONS(359),
    [anon_sym_bytes3] = ACTIONS(359),
    [anon_sym_bytes4] = ACTIONS(359),
    [anon_sym_bytes5] = ACTIONS(359),
    [anon_sym_bytes6] = ACTIONS(359),
    [anon_sym_bytes7] = ACTIONS(359),
    [anon_sym_bytes8] = ACTIONS(359),
    [anon_sym_bytes9] = ACTIONS(359),
    [anon_sym_bytes10] = ACTIONS(359),
    [anon_sym_bytes11] = ACTIONS(359),
    [anon_sym_bytes12] = ACTIONS(359),
    [anon_sym_bytes13] = ACTIONS(359),
    [anon_sym_bytes14] = ACTIONS(359),
    [anon_sym_bytes15] = ACTIONS(359),
    [anon_sym_bytes16] = ACTIONS(359),
    [anon_sym_bytes17] = ACTIONS(359),
    [anon_sym_bytes18] = ACTIONS(359),
    [anon_sym_bytes19] = ACTIONS(359),
    [anon_sym_bytes20] = ACTIONS(359),
    [anon_sym_bytes21] = ACTIONS(359),
    [anon_sym_bytes22] = ACTIONS(359),
    [anon_sym_bytes23] = ACTIONS(359),
    [anon_sym_bytes24] = ACTIONS(359),
    [anon_sym_bytes25] = ACTIONS(359),
    [anon_sym_bytes26] = ACTIONS(359),
    [anon_sym_bytes27] = ACTIONS(359),
    [anon_sym_bytes28] = ACTIONS(359),
    [anon_sym_bytes29] = ACTIONS(359),
    [anon_sym_bytes30] = ACTIONS(359),
    [anon_sym_bytes31] = ACTIONS(359),
    [anon_sym_bytes32] = ACTIONS(359),
    [anon_sym_fixed] = ACTIONS(359),
    [aux_sym__fixed_token1] = ACTIONS(359),
    [anon_sym_ufixed] = ACTIONS(359),
    [aux_sym__ufixed_token1] = ACTIONS(359),
    [aux_sym__decimal_number_token1] = ACTIONS(359),
    [aux_sym__decimal_number_token2] = ACTIONS(361),
    [aux_sym__hex_number_token1] = ACTIONS(361),
    [anon_sym_hex] = ACTIONS(359),
    [anon_sym_DQUOTE] = ACTIONS(361),
    [anon_sym_SQUOTE] = ACTIONS(361),
    [anon_sym_unicode] = ACTIONS(359),
    [sym_comment] = ACTIONS(3),
  },
  [74] = {
    [sym_identifier] = ACTIONS(363),
    [anon_sym_DASH] = ACTIONS(363),
    [anon_sym_TILDE] = ACTIONS(365),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_RBRACE] = ACTIONS(365),
    [anon_sym_type] = ACTIONS(363),
    [anon_sym_LPAREN] = ACTIONS(365),
    [anon_sym_RPAREN] = ACTIONS(365),
    [anon_sym_for] = ACTIONS(363),
    [anon_sym_PLUS] = ACTIONS(363),
    [anon_sym_assembly] = ACTIONS(363),
    [anon_sym_break] = ACTIONS(363),
    [anon_sym_continue] = ACTIONS(363),
    [anon_sym_true] = ACTIONS(363),
    [anon_sym_false] = ACTIONS(363),
    [anon_sym_if] = ACTIONS(363),
    [anon_sym_function] = ACTIONS(363),
    [anon_sym_byte] = ACTIONS(363),
    [anon_sym_address] = ACTIONS(363),
    [anon_sym_return] = ACTIONS(363),
    [anon_sym_revert] = ACTIONS(363),
    [sym__unchecked] = ACTIONS(363),
    [anon_sym_var] = ACTIONS(363),
    [anon_sym_else] = ACTIONS(363),
    [anon_sym_while] = ACTIONS(363),
    [anon_sym_do] = ACTIONS(363),
    [anon_sym_try] = ACTIONS(363),
    [anon_sym_emit] = ACTIONS(363),
    [anon_sym_payable] = ACTIONS(363),
    [anon_sym_new] = ACTIONS(363),
    [anon_sym_LBRACK] = ACTIONS(365),
    [anon_sym_BANG] = ACTIONS(365),
    [anon_sym_delete] = ACTIONS(363),
    [anon_sym_PLUS_PLUS] = ACTIONS(365),
    [anon_sym_DASH_DASH] = ACTIONS(365),
    [anon_sym_mapping] = ACTIONS(363),
    [anon_sym_bool] = ACTIONS(363),
    [anon_sym_string] = ACTIONS(363),
    [anon_sym_int] = ACTIONS(363),
    [anon_sym_int8] = ACTIONS(363),
    [anon_sym_int16] = ACTIONS(363),
    [anon_sym_int24] = ACTIONS(363),
    [anon_sym_int32] = ACTIONS(363),
    [anon_sym_int40] = ACTIONS(363),
    [anon_sym_int48] = ACTIONS(363),
    [anon_sym_int56] = ACTIONS(363),
    [anon_sym_int64] = ACTIONS(363),
    [anon_sym_int72] = ACTIONS(363),
    [anon_sym_int80] = ACTIONS(363),
    [anon_sym_int88] = ACTIONS(363),
    [anon_sym_int96] = ACTIONS(363),
    [anon_sym_int104] = ACTIONS(363),
    [anon_sym_int112] = ACTIONS(363),
    [anon_sym_int120] = ACTIONS(363),
    [anon_sym_int128] = ACTIONS(363),
    [anon_sym_int136] = ACTIONS(363),
    [anon_sym_int144] = ACTIONS(363),
    [anon_sym_int152] = ACTIONS(363),
    [anon_sym_int160] = ACTIONS(363),
    [anon_sym_int168] = ACTIONS(363),
    [anon_sym_int176] = ACTIONS(363),
    [anon_sym_int184] = ACTIONS(363),
    [anon_sym_int192] = ACTIONS(363),
    [anon_sym_int200] = ACTIONS(363),
    [anon_sym_int208] = ACTIONS(363),
    [anon_sym_int216] = ACTIONS(363),
    [anon_sym_int224] = ACTIONS(363),
    [anon_sym_int232] = ACTIONS(363),
    [anon_sym_int240] = ACTIONS(363),
    [anon_sym_int248] = ACTIONS(363),
    [anon_sym_int256] = ACTIONS(363),
    [anon_sym_uint] = ACTIONS(363),
    [anon_sym_uint8] = ACTIONS(363),
    [anon_sym_uint16] = ACTIONS(363),
    [anon_sym_uint24] = ACTIONS(363),
    [anon_sym_uint32] = ACTIONS(363),
    [anon_sym_uint40] = ACTIONS(363),
    [anon_sym_uint48] = ACTIONS(363),
    [anon_sym_uint56] = ACTIONS(363),
    [anon_sym_uint64] = ACTIONS(363),
    [anon_sym_uint72] = ACTIONS(363),
    [anon_sym_uint80] = ACTIONS(363),
    [anon_sym_uint88] = ACTIONS(363),
    [anon_sym_uint96] = ACTIONS(363),
    [anon_sym_uint104] = ACTIONS(363),
    [anon_sym_uint112] = ACTIONS(363),
    [anon_sym_uint120] = ACTIONS(363),
    [anon_sym_uint128] = ACTIONS(363),
    [anon_sym_uint136] = ACTIONS(363),
    [anon_sym_uint144] = ACTIONS(363),
    [anon_sym_uint152] = ACTIONS(363),
    [anon_sym_uint160] = ACTIONS(363),
    [anon_sym_uint168] = ACTIONS(363),
    [anon_sym_uint176] = ACTIONS(363),
    [anon_sym_uint184] = ACTIONS(363),
    [anon_sym_uint192] = ACTIONS(363),
    [anon_sym_uint200] = ACTIONS(363),
    [anon_sym_uint208] = ACTIONS(363),
    [anon_sym_uint216] = ACTIONS(363),
    [anon_sym_uint224] = ACTIONS(363),
    [anon_sym_uint232] = ACTIONS(363),
    [anon_sym_uint240] = ACTIONS(363),
    [anon_sym_uint248] = ACTIONS(363),
    [anon_sym_uint256] = ACTIONS(363),
    [anon_sym_bytes] = ACTIONS(363),
    [anon_sym_bytes1] = ACTIONS(363),
    [anon_sym_bytes2] = ACTIONS(363),
    [anon_sym_bytes3] = ACTIONS(363),
    [anon_sym_bytes4] = ACTIONS(363),
    [anon_sym_bytes5] = ACTIONS(363),
    [anon_sym_bytes6] = ACTIONS(363),
    [anon_sym_bytes7] = ACTIONS(363),
    [anon_sym_bytes8] = ACTIONS(363),
    [anon_sym_bytes9] = ACTIONS(363),
    [anon_sym_bytes10] = ACTIONS(363),
    [anon_sym_bytes11] = ACTIONS(363),
    [anon_sym_bytes12] = ACTIONS(363),
    [anon_sym_bytes13] = ACTIONS(363),
    [anon_sym_bytes14] = ACTIONS(363),
    [anon_sym_bytes15] = ACTIONS(363),
    [anon_sym_bytes16] = ACTIONS(363),
    [anon_sym_bytes17] = ACTIONS(363),
    [anon_sym_bytes18] = ACTIONS(363),
    [anon_sym_bytes19] = ACTIONS(363),
    [anon_sym_bytes20] = ACTIONS(363),
    [anon_sym_bytes21] = ACTIONS(363),
    [anon_sym_bytes22] = ACTIONS(363),
    [anon_sym_bytes23] = ACTIONS(363),
    [anon_sym_bytes24] = ACTIONS(363),
    [anon_sym_bytes25] = ACTIONS(363),
    [anon_sym_bytes26] = ACTIONS(363),
    [anon_sym_bytes27] = ACTIONS(363),
    [anon_sym_bytes28] = ACTIONS(363),
    [anon_sym_bytes29] = ACTIONS(363),
    [anon_sym_bytes30] = ACTIONS(363),
    [anon_sym_bytes31] = ACTIONS(363),
    [anon_sym_bytes32] = ACTIONS(363),
    [anon_sym_fixed] = ACTIONS(363),
    [aux_sym__fixed_token1] = ACTIONS(363),
    [anon_sym_ufixed] = ACTIONS(363),
    [aux_sym__ufixed_token1] = ACTIONS(363),
    [sym__semicolon] = ACTIONS(365),
    [aux_sym__decimal_number_token1] = ACTIONS(363),
    [aux_sym__decimal_number_token2] = ACTIONS(365),
    [aux_sym__hex_number_token1] = ACTIONS(365),
    [anon_sym_hex] = ACTIONS(363),
    [anon_sym_DQUOTE] = ACTIONS(365),
    [anon_sym_SQUOTE] = ACTIONS(365),
    [anon_sym_unicode] = ACTIONS(363),
    [sym_comment] = ACTIONS(3),
  },
  [75] = {
    [sym_identifier] = ACTIONS(367),
    [anon_sym_DASH] = ACTIONS(367),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_LBRACE] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_type] = ACTIONS(367),
    [anon_sym_LPAREN] = ACTIONS(369),
    [anon_sym_for] = ACTIONS(367),
    [anon_sym_PLUS] = ACTIONS(367),
    [anon_sym_assembly] = ACTIONS(367),
    [anon_sym_break] = ACTIONS(367),
    [anon_sym_continue] = ACTIONS(367),
    [anon_sym_true] = ACTIONS(367),
    [anon_sym_false] = ACTIONS(367),
    [anon_sym_if] = ACTIONS(367),
    [anon_sym_function] = ACTIONS(367),
    [anon_sym_byte] = ACTIONS(367),
    [anon_sym_address] = ACTIONS(367),
    [anon_sym_return] = ACTIONS(367),
    [anon_sym_revert] = ACTIONS(367),
    [sym__unchecked] = ACTIONS(367),
    [anon_sym_var] = ACTIONS(367),
    [anon_sym_else] = ACTIONS(367),
    [anon_sym_while] = ACTIONS(367),
    [anon_sym_do] = ACTIONS(367),
    [anon_sym_try] = ACTIONS(367),
    [anon_sym_catch] = ACTIONS(367),
    [anon_sym_emit] = ACTIONS(367),
    [anon_sym_payable] = ACTIONS(367),
    [anon_sym_new] = ACTIONS(367),
    [anon_sym_LBRACK] = ACTIONS(369),
    [anon_sym_BANG] = ACTIONS(369),
    [anon_sym_delete] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_mapping] = ACTIONS(367),
    [anon_sym_bool] = ACTIONS(367),
    [anon_sym_string] = ACTIONS(367),
    [anon_sym_int] = ACTIONS(367),
    [anon_sym_int8] = ACTIONS(367),
    [anon_sym_int16] = ACTIONS(367),
    [anon_sym_int24] = ACTIONS(367),
    [anon_sym_int32] = ACTIONS(367),
    [anon_sym_int40] = ACTIONS(367),
    [anon_sym_int48] = ACTIONS(367),
    [anon_sym_int56] = ACTIONS(367),
    [anon_sym_int64] = ACTIONS(367),
    [anon_sym_int72] = ACTIONS(367),
    [anon_sym_int80] = ACTIONS(367),
    [anon_sym_int88] = ACTIONS(367),
    [anon_sym_int96] = ACTIONS(367),
    [anon_sym_int104] = ACTIONS(367),
    [anon_sym_int112] = ACTIONS(367),
    [anon_sym_int120] = ACTIONS(367),
    [anon_sym_int128] = ACTIONS(367),
    [anon_sym_int136] = ACTIONS(367),
    [anon_sym_int144] = ACTIONS(367),
    [anon_sym_int152] = ACTIONS(367),
    [anon_sym_int160] = ACTIONS(367),
    [anon_sym_int168] = ACTIONS(367),
    [anon_sym_int176] = ACTIONS(367),
    [anon_sym_int184] = ACTIONS(367),
    [anon_sym_int192] = ACTIONS(367),
    [anon_sym_int200] = ACTIONS(367),
    [anon_sym_int208] = ACTIONS(367),
    [anon_sym_int216] = ACTIONS(367),
    [anon_sym_int224] = ACTIONS(367),
    [anon_sym_int232] = ACTIONS(367),
    [anon_sym_int240] = ACTIONS(367),
    [anon_sym_int248] = ACTIONS(367),
    [anon_sym_int256] = ACTIONS(367),
    [anon_sym_uint] = ACTIONS(367),
    [anon_sym_uint8] = ACTIONS(367),
    [anon_sym_uint16] = ACTIONS(367),
    [anon_sym_uint24] = ACTIONS(367),
    [anon_sym_uint32] = ACTIONS(367),
    [anon_sym_uint40] = ACTIONS(367),
    [anon_sym_uint48] = ACTIONS(367),
    [anon_sym_uint56] = ACTIONS(367),
    [anon_sym_uint64] = ACTIONS(367),
    [anon_sym_uint72] = ACTIONS(367),
    [anon_sym_uint80] = ACTIONS(367),
    [anon_sym_uint88] = ACTIONS(367),
    [anon_sym_uint96] = ACTIONS(367),
    [anon_sym_uint104] = ACTIONS(367),
    [anon_sym_uint112] = ACTIONS(367),
    [anon_sym_uint120] = ACTIONS(367),
    [anon_sym_uint128] = ACTIONS(367),
    [anon_sym_uint136] = ACTIONS(367),
    [anon_sym_uint144] = ACTIONS(367),
    [anon_sym_uint152] = ACTIONS(367),
    [anon_sym_uint160] = ACTIONS(367),
    [anon_sym_uint168] = ACTIONS(367),
    [anon_sym_uint176] = ACTIONS(367),
    [anon_sym_uint184] = ACTIONS(367),
    [anon_sym_uint192] = ACTIONS(367),
    [anon_sym_uint200] = ACTIONS(367),
    [anon_sym_uint208] = ACTIONS(367),
    [anon_sym_uint216] = ACTIONS(367),
    [anon_sym_uint224] = ACTIONS(367),
    [anon_sym_uint232] = ACTIONS(367),
    [anon_sym_uint240] = ACTIONS(367),
    [anon_sym_uint248] = ACTIONS(367),
    [anon_sym_uint256] = ACTIONS(367),
    [anon_sym_bytes] = ACTIONS(367),
    [anon_sym_bytes1] = ACTIONS(367),
    [anon_sym_bytes2] = ACTIONS(367),
    [anon_sym_bytes3] = ACTIONS(367),
    [anon_sym_bytes4] = ACTIONS(367),
    [anon_sym_bytes5] = ACTIONS(367),
    [anon_sym_bytes6] = ACTIONS(367),
    [anon_sym_bytes7] = ACTIONS(367),
    [anon_sym_bytes8] = ACTIONS(367),
    [anon_sym_bytes9] = ACTIONS(367),
    [anon_sym_bytes10] = ACTIONS(367),
    [anon_sym_bytes11] = ACTIONS(367),
    [anon_sym_bytes12] = ACTIONS(367),
    [anon_sym_bytes13] = ACTIONS(367),
    [anon_sym_bytes14] = ACTIONS(367),
    [anon_sym_bytes15] = ACTIONS(367),
    [anon_sym_bytes16] = ACTIONS(367),
    [anon_sym_bytes17] = ACTIONS(367),
    [anon_sym_bytes18] = ACTIONS(367),
    [anon_sym_bytes19] = ACTIONS(367),
    [anon_sym_bytes20] = ACTIONS(367),
    [anon_sym_bytes21] = ACTIONS(367),
    [anon_sym_bytes22] = ACTIONS(367),
    [anon_sym_bytes23] = ACTIONS(367),
    [anon_sym_bytes24] = ACTIONS(367),
    [anon_sym_bytes25] = ACTIONS(367),
    [anon_sym_bytes26] = ACTIONS(367),
    [anon_sym_bytes27] = ACTIONS(367),
    [anon_sym_bytes28] = ACTIONS(367),
    [anon_sym_bytes29] = ACTIONS(367),
    [anon_sym_bytes30] = ACTIONS(367),
    [anon_sym_bytes31] = ACTIONS(367),
    [anon_sym_bytes32] = ACTIONS(367),
    [anon_sym_fixed] = ACTIONS(367),
    [aux_sym__fixed_token1] = ACTIONS(367),
    [anon_sym_ufixed] = ACTIONS(367),
    [aux_sym__ufixed_token1] = ACTIONS(367),
    [aux_sym__decimal_number_token1] = ACTIONS(367),
    [aux_sym__decimal_number_token2] = ACTIONS(369),
    [aux_sym__hex_number_token1] = ACTIONS(369),
    [anon_sym_hex] = ACTIONS(367),
    [anon_sym_DQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(369),
    [anon_sym_unicode] = ACTIONS(367),
    [sym_comment] = ACTIONS(3),
  },
  [76] = {
    [sym_user_defined_type_definition] = STATE(79),
    [sym_error_declaration] = STATE(79),
    [sym__contract_member] = STATE(79),
    [sym_struct_declaration] = STATE(79),
    [sym_enum_declaration] = STATE(79),
    [sym_event_definition] = STATE(79),
    [sym_using_directive] = STATE(79),
    [sym_state_variable_declaration] = STATE(79),
    [sym_modifier_definition] = STATE(79),
    [sym_constructor_definition] = STATE(79),
    [sym_fallback_definition] = STATE(79),
    [sym_receive_definition] = STATE(79),
    [sym_function_definition] = STATE(79),
    [sym_type_name] = STATE(544),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_contract_body_repeat1] = STATE(79),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(371),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_error] = ACTIONS(375),
    [anon_sym_struct] = ACTIONS(377),
    [anon_sym_enum] = ACTIONS(379),
    [anon_sym_event] = ACTIONS(381),
    [anon_sym_using] = ACTIONS(383),
    [anon_sym_function] = ACTIONS(385),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_modifier] = ACTIONS(387),
    [anon_sym_constructor] = ACTIONS(389),
    [anon_sym_fallback] = ACTIONS(391),
    [anon_sym_receive] = ACTIONS(393),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [77] = {
    [sym_identifier] = ACTIONS(395),
    [anon_sym_DASH] = ACTIONS(395),
    [anon_sym_TILDE] = ACTIONS(397),
    [anon_sym_LBRACE] = ACTIONS(397),
    [anon_sym_RBRACE] = ACTIONS(397),
    [anon_sym_type] = ACTIONS(395),
    [anon_sym_LPAREN] = ACTIONS(397),
    [anon_sym_for] = ACTIONS(395),
    [anon_sym_PLUS] = ACTIONS(395),
    [anon_sym_assembly] = ACTIONS(395),
    [anon_sym_break] = ACTIONS(395),
    [anon_sym_continue] = ACTIONS(395),
    [anon_sym_true] = ACTIONS(395),
    [anon_sym_false] = ACTIONS(395),
    [anon_sym_if] = ACTIONS(395),
    [anon_sym_function] = ACTIONS(395),
    [anon_sym_byte] = ACTIONS(395),
    [anon_sym_address] = ACTIONS(395),
    [anon_sym_return] = ACTIONS(395),
    [anon_sym_revert] = ACTIONS(395),
    [sym__unchecked] = ACTIONS(395),
    [anon_sym_var] = ACTIONS(395),
    [anon_sym_else] = ACTIONS(395),
    [anon_sym_while] = ACTIONS(395),
    [anon_sym_do] = ACTIONS(395),
    [anon_sym_try] = ACTIONS(395),
    [anon_sym_catch] = ACTIONS(395),
    [anon_sym_emit] = ACTIONS(395),
    [anon_sym_payable] = ACTIONS(395),
    [anon_sym_new] = ACTIONS(395),
    [anon_sym_LBRACK] = ACTIONS(397),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_delete] = ACTIONS(395),
    [anon_sym_PLUS_PLUS] = ACTIONS(397),
    [anon_sym_DASH_DASH] = ACTIONS(397),
    [anon_sym_mapping] = ACTIONS(395),
    [anon_sym_bool] = ACTIONS(395),
    [anon_sym_string] = ACTIONS(395),
    [anon_sym_int] = ACTIONS(395),
    [anon_sym_int8] = ACTIONS(395),
    [anon_sym_int16] = ACTIONS(395),
    [anon_sym_int24] = ACTIONS(395),
    [anon_sym_int32] = ACTIONS(395),
    [anon_sym_int40] = ACTIONS(395),
    [anon_sym_int48] = ACTIONS(395),
    [anon_sym_int56] = ACTIONS(395),
    [anon_sym_int64] = ACTIONS(395),
    [anon_sym_int72] = ACTIONS(395),
    [anon_sym_int80] = ACTIONS(395),
    [anon_sym_int88] = ACTIONS(395),
    [anon_sym_int96] = ACTIONS(395),
    [anon_sym_int104] = ACTIONS(395),
    [anon_sym_int112] = ACTIONS(395),
    [anon_sym_int120] = ACTIONS(395),
    [anon_sym_int128] = ACTIONS(395),
    [anon_sym_int136] = ACTIONS(395),
    [anon_sym_int144] = ACTIONS(395),
    [anon_sym_int152] = ACTIONS(395),
    [anon_sym_int160] = ACTIONS(395),
    [anon_sym_int168] = ACTIONS(395),
    [anon_sym_int176] = ACTIONS(395),
    [anon_sym_int184] = ACTIONS(395),
    [anon_sym_int192] = ACTIONS(395),
    [anon_sym_int200] = ACTIONS(395),
    [anon_sym_int208] = ACTIONS(395),
    [anon_sym_int216] = ACTIONS(395),
    [anon_sym_int224] = ACTIONS(395),
    [anon_sym_int232] = ACTIONS(395),
    [anon_sym_int240] = ACTIONS(395),
    [anon_sym_int248] = ACTIONS(395),
    [anon_sym_int256] = ACTIONS(395),
    [anon_sym_uint] = ACTIONS(395),
    [anon_sym_uint8] = ACTIONS(395),
    [anon_sym_uint16] = ACTIONS(395),
    [anon_sym_uint24] = ACTIONS(395),
    [anon_sym_uint32] = ACTIONS(395),
    [anon_sym_uint40] = ACTIONS(395),
    [anon_sym_uint48] = ACTIONS(395),
    [anon_sym_uint56] = ACTIONS(395),
    [anon_sym_uint64] = ACTIONS(395),
    [anon_sym_uint72] = ACTIONS(395),
    [anon_sym_uint80] = ACTIONS(395),
    [anon_sym_uint88] = ACTIONS(395),
    [anon_sym_uint96] = ACTIONS(395),
    [anon_sym_uint104] = ACTIONS(395),
    [anon_sym_uint112] = ACTIONS(395),
    [anon_sym_uint120] = ACTIONS(395),
    [anon_sym_uint128] = ACTIONS(395),
    [anon_sym_uint136] = ACTIONS(395),
    [anon_sym_uint144] = ACTIONS(395),
    [anon_sym_uint152] = ACTIONS(395),
    [anon_sym_uint160] = ACTIONS(395),
    [anon_sym_uint168] = ACTIONS(395),
    [anon_sym_uint176] = ACTIONS(395),
    [anon_sym_uint184] = ACTIONS(395),
    [anon_sym_uint192] = ACTIONS(395),
    [anon_sym_uint200] = ACTIONS(395),
    [anon_sym_uint208] = ACTIONS(395),
    [anon_sym_uint216] = ACTIONS(395),
    [anon_sym_uint224] = ACTIONS(395),
    [anon_sym_uint232] = ACTIONS(395),
    [anon_sym_uint240] = ACTIONS(395),
    [anon_sym_uint248] = ACTIONS(395),
    [anon_sym_uint256] = ACTIONS(395),
    [anon_sym_bytes] = ACTIONS(395),
    [anon_sym_bytes1] = ACTIONS(395),
    [anon_sym_bytes2] = ACTIONS(395),
    [anon_sym_bytes3] = ACTIONS(395),
    [anon_sym_bytes4] = ACTIONS(395),
    [anon_sym_bytes5] = ACTIONS(395),
    [anon_sym_bytes6] = ACTIONS(395),
    [anon_sym_bytes7] = ACTIONS(395),
    [anon_sym_bytes8] = ACTIONS(395),
    [anon_sym_bytes9] = ACTIONS(395),
    [anon_sym_bytes10] = ACTIONS(395),
    [anon_sym_bytes11] = ACTIONS(395),
    [anon_sym_bytes12] = ACTIONS(395),
    [anon_sym_bytes13] = ACTIONS(395),
    [anon_sym_bytes14] = ACTIONS(395),
    [anon_sym_bytes15] = ACTIONS(395),
    [anon_sym_bytes16] = ACTIONS(395),
    [anon_sym_bytes17] = ACTIONS(395),
    [anon_sym_bytes18] = ACTIONS(395),
    [anon_sym_bytes19] = ACTIONS(395),
    [anon_sym_bytes20] = ACTIONS(395),
    [anon_sym_bytes21] = ACTIONS(395),
    [anon_sym_bytes22] = ACTIONS(395),
    [anon_sym_bytes23] = ACTIONS(395),
    [anon_sym_bytes24] = ACTIONS(395),
    [anon_sym_bytes25] = ACTIONS(395),
    [anon_sym_bytes26] = ACTIONS(395),
    [anon_sym_bytes27] = ACTIONS(395),
    [anon_sym_bytes28] = ACTIONS(395),
    [anon_sym_bytes29] = ACTIONS(395),
    [anon_sym_bytes30] = ACTIONS(395),
    [anon_sym_bytes31] = ACTIONS(395),
    [anon_sym_bytes32] = ACTIONS(395),
    [anon_sym_fixed] = ACTIONS(395),
    [aux_sym__fixed_token1] = ACTIONS(395),
    [anon_sym_ufixed] = ACTIONS(395),
    [aux_sym__ufixed_token1] = ACTIONS(395),
    [aux_sym__decimal_number_token1] = ACTIONS(395),
    [aux_sym__decimal_number_token2] = ACTIONS(397),
    [aux_sym__hex_number_token1] = ACTIONS(397),
    [anon_sym_hex] = ACTIONS(395),
    [anon_sym_DQUOTE] = ACTIONS(397),
    [anon_sym_SQUOTE] = ACTIONS(397),
    [anon_sym_unicode] = ACTIONS(395),
    [sym_comment] = ACTIONS(3),
  },
  [78] = {
    [sym_identifier] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [anon_sym_TILDE] = ACTIONS(401),
    [anon_sym_LBRACE] = ACTIONS(401),
    [anon_sym_RBRACE] = ACTIONS(401),
    [anon_sym_type] = ACTIONS(399),
    [anon_sym_LPAREN] = ACTIONS(401),
    [anon_sym_for] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_assembly] = ACTIONS(399),
    [anon_sym_break] = ACTIONS(399),
    [anon_sym_continue] = ACTIONS(399),
    [anon_sym_true] = ACTIONS(399),
    [anon_sym_false] = ACTIONS(399),
    [anon_sym_if] = ACTIONS(399),
    [anon_sym_function] = ACTIONS(399),
    [anon_sym_byte] = ACTIONS(399),
    [anon_sym_address] = ACTIONS(399),
    [anon_sym_return] = ACTIONS(399),
    [anon_sym_revert] = ACTIONS(399),
    [sym__unchecked] = ACTIONS(399),
    [anon_sym_var] = ACTIONS(399),
    [anon_sym_else] = ACTIONS(399),
    [anon_sym_while] = ACTIONS(399),
    [anon_sym_do] = ACTIONS(399),
    [anon_sym_try] = ACTIONS(399),
    [anon_sym_emit] = ACTIONS(399),
    [anon_sym_payable] = ACTIONS(399),
    [anon_sym_new] = ACTIONS(399),
    [anon_sym_LBRACK] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(401),
    [anon_sym_delete] = ACTIONS(399),
    [anon_sym_PLUS_PLUS] = ACTIONS(401),
    [anon_sym_DASH_DASH] = ACTIONS(401),
    [anon_sym_mapping] = ACTIONS(399),
    [anon_sym_bool] = ACTIONS(399),
    [anon_sym_string] = ACTIONS(399),
    [anon_sym_int] = ACTIONS(399),
    [anon_sym_int8] = ACTIONS(399),
    [anon_sym_int16] = ACTIONS(399),
    [anon_sym_int24] = ACTIONS(399),
    [anon_sym_int32] = ACTIONS(399),
    [anon_sym_int40] = ACTIONS(399),
    [anon_sym_int48] = ACTIONS(399),
    [anon_sym_int56] = ACTIONS(399),
    [anon_sym_int64] = ACTIONS(399),
    [anon_sym_int72] = ACTIONS(399),
    [anon_sym_int80] = ACTIONS(399),
    [anon_sym_int88] = ACTIONS(399),
    [anon_sym_int96] = ACTIONS(399),
    [anon_sym_int104] = ACTIONS(399),
    [anon_sym_int112] = ACTIONS(399),
    [anon_sym_int120] = ACTIONS(399),
    [anon_sym_int128] = ACTIONS(399),
    [anon_sym_int136] = ACTIONS(399),
    [anon_sym_int144] = ACTIONS(399),
    [anon_sym_int152] = ACTIONS(399),
    [anon_sym_int160] = ACTIONS(399),
    [anon_sym_int168] = ACTIONS(399),
    [anon_sym_int176] = ACTIONS(399),
    [anon_sym_int184] = ACTIONS(399),
    [anon_sym_int192] = ACTIONS(399),
    [anon_sym_int200] = ACTIONS(399),
    [anon_sym_int208] = ACTIONS(399),
    [anon_sym_int216] = ACTIONS(399),
    [anon_sym_int224] = ACTIONS(399),
    [anon_sym_int232] = ACTIONS(399),
    [anon_sym_int240] = ACTIONS(399),
    [anon_sym_int248] = ACTIONS(399),
    [anon_sym_int256] = ACTIONS(399),
    [anon_sym_uint] = ACTIONS(399),
    [anon_sym_uint8] = ACTIONS(399),
    [anon_sym_uint16] = ACTIONS(399),
    [anon_sym_uint24] = ACTIONS(399),
    [anon_sym_uint32] = ACTIONS(399),
    [anon_sym_uint40] = ACTIONS(399),
    [anon_sym_uint48] = ACTIONS(399),
    [anon_sym_uint56] = ACTIONS(399),
    [anon_sym_uint64] = ACTIONS(399),
    [anon_sym_uint72] = ACTIONS(399),
    [anon_sym_uint80] = ACTIONS(399),
    [anon_sym_uint88] = ACTIONS(399),
    [anon_sym_uint96] = ACTIONS(399),
    [anon_sym_uint104] = ACTIONS(399),
    [anon_sym_uint112] = ACTIONS(399),
    [anon_sym_uint120] = ACTIONS(399),
    [anon_sym_uint128] = ACTIONS(399),
    [anon_sym_uint136] = ACTIONS(399),
    [anon_sym_uint144] = ACTIONS(399),
    [anon_sym_uint152] = ACTIONS(399),
    [anon_sym_uint160] = ACTIONS(399),
    [anon_sym_uint168] = ACTIONS(399),
    [anon_sym_uint176] = ACTIONS(399),
    [anon_sym_uint184] = ACTIONS(399),
    [anon_sym_uint192] = ACTIONS(399),
    [anon_sym_uint200] = ACTIONS(399),
    [anon_sym_uint208] = ACTIONS(399),
    [anon_sym_uint216] = ACTIONS(399),
    [anon_sym_uint224] = ACTIONS(399),
    [anon_sym_uint232] = ACTIONS(399),
    [anon_sym_uint240] = ACTIONS(399),
    [anon_sym_uint248] = ACTIONS(399),
    [anon_sym_uint256] = ACTIONS(399),
    [anon_sym_bytes] = ACTIONS(399),
    [anon_sym_bytes1] = ACTIONS(399),
    [anon_sym_bytes2] = ACTIONS(399),
    [anon_sym_bytes3] = ACTIONS(399),
    [anon_sym_bytes4] = ACTIONS(399),
    [anon_sym_bytes5] = ACTIONS(399),
    [anon_sym_bytes6] = ACTIONS(399),
    [anon_sym_bytes7] = ACTIONS(399),
    [anon_sym_bytes8] = ACTIONS(399),
    [anon_sym_bytes9] = ACTIONS(399),
    [anon_sym_bytes10] = ACTIONS(399),
    [anon_sym_bytes11] = ACTIONS(399),
    [anon_sym_bytes12] = ACTIONS(399),
    [anon_sym_bytes13] = ACTIONS(399),
    [anon_sym_bytes14] = ACTIONS(399),
    [anon_sym_bytes15] = ACTIONS(399),
    [anon_sym_bytes16] = ACTIONS(399),
    [anon_sym_bytes17] = ACTIONS(399),
    [anon_sym_bytes18] = ACTIONS(399),
    [anon_sym_bytes19] = ACTIONS(399),
    [anon_sym_bytes20] = ACTIONS(399),
    [anon_sym_bytes21] = ACTIONS(399),
    [anon_sym_bytes22] = ACTIONS(399),
    [anon_sym_bytes23] = ACTIONS(399),
    [anon_sym_bytes24] = ACTIONS(399),
    [anon_sym_bytes25] = ACTIONS(399),
    [anon_sym_bytes26] = ACTIONS(399),
    [anon_sym_bytes27] = ACTIONS(399),
    [anon_sym_bytes28] = ACTIONS(399),
    [anon_sym_bytes29] = ACTIONS(399),
    [anon_sym_bytes30] = ACTIONS(399),
    [anon_sym_bytes31] = ACTIONS(399),
    [anon_sym_bytes32] = ACTIONS(399),
    [anon_sym_fixed] = ACTIONS(399),
    [aux_sym__fixed_token1] = ACTIONS(399),
    [anon_sym_ufixed] = ACTIONS(399),
    [aux_sym__ufixed_token1] = ACTIONS(399),
    [sym__semicolon] = ACTIONS(401),
    [aux_sym__decimal_number_token1] = ACTIONS(399),
    [aux_sym__decimal_number_token2] = ACTIONS(401),
    [aux_sym__hex_number_token1] = ACTIONS(401),
    [anon_sym_hex] = ACTIONS(399),
    [anon_sym_DQUOTE] = ACTIONS(401),
    [anon_sym_SQUOTE] = ACTIONS(401),
    [anon_sym_unicode] = ACTIONS(399),
    [sym_comment] = ACTIONS(3),
  },
  [79] = {
    [sym_user_defined_type_definition] = STATE(79),
    [sym_error_declaration] = STATE(79),
    [sym__contract_member] = STATE(79),
    [sym_struct_declaration] = STATE(79),
    [sym_enum_declaration] = STATE(79),
    [sym_event_definition] = STATE(79),
    [sym_using_directive] = STATE(79),
    [sym_state_variable_declaration] = STATE(79),
    [sym_modifier_definition] = STATE(79),
    [sym_constructor_definition] = STATE(79),
    [sym_fallback_definition] = STATE(79),
    [sym_receive_definition] = STATE(79),
    [sym_function_definition] = STATE(79),
    [sym_type_name] = STATE(544),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_contract_body_repeat1] = STATE(79),
    [sym_identifier] = ACTIONS(403),
    [anon_sym_RBRACE] = ACTIONS(406),
    [anon_sym_type] = ACTIONS(408),
    [anon_sym_error] = ACTIONS(411),
    [anon_sym_struct] = ACTIONS(414),
    [anon_sym_enum] = ACTIONS(417),
    [anon_sym_event] = ACTIONS(420),
    [anon_sym_using] = ACTIONS(423),
    [anon_sym_function] = ACTIONS(426),
    [anon_sym_byte] = ACTIONS(429),
    [anon_sym_address] = ACTIONS(432),
    [anon_sym_var] = ACTIONS(429),
    [anon_sym_modifier] = ACTIONS(435),
    [anon_sym_constructor] = ACTIONS(438),
    [anon_sym_fallback] = ACTIONS(441),
    [anon_sym_receive] = ACTIONS(444),
    [anon_sym_mapping] = ACTIONS(447),
    [anon_sym_bool] = ACTIONS(429),
    [anon_sym_string] = ACTIONS(429),
    [anon_sym_int] = ACTIONS(429),
    [anon_sym_int8] = ACTIONS(429),
    [anon_sym_int16] = ACTIONS(429),
    [anon_sym_int24] = ACTIONS(429),
    [anon_sym_int32] = ACTIONS(429),
    [anon_sym_int40] = ACTIONS(429),
    [anon_sym_int48] = ACTIONS(429),
    [anon_sym_int56] = ACTIONS(429),
    [anon_sym_int64] = ACTIONS(429),
    [anon_sym_int72] = ACTIONS(429),
    [anon_sym_int80] = ACTIONS(429),
    [anon_sym_int88] = ACTIONS(429),
    [anon_sym_int96] = ACTIONS(429),
    [anon_sym_int104] = ACTIONS(429),
    [anon_sym_int112] = ACTIONS(429),
    [anon_sym_int120] = ACTIONS(429),
    [anon_sym_int128] = ACTIONS(429),
    [anon_sym_int136] = ACTIONS(429),
    [anon_sym_int144] = ACTIONS(429),
    [anon_sym_int152] = ACTIONS(429),
    [anon_sym_int160] = ACTIONS(429),
    [anon_sym_int168] = ACTIONS(429),
    [anon_sym_int176] = ACTIONS(429),
    [anon_sym_int184] = ACTIONS(429),
    [anon_sym_int192] = ACTIONS(429),
    [anon_sym_int200] = ACTIONS(429),
    [anon_sym_int208] = ACTIONS(429),
    [anon_sym_int216] = ACTIONS(429),
    [anon_sym_int224] = ACTIONS(429),
    [anon_sym_int232] = ACTIONS(429),
    [anon_sym_int240] = ACTIONS(429),
    [anon_sym_int248] = ACTIONS(429),
    [anon_sym_int256] = ACTIONS(429),
    [anon_sym_uint] = ACTIONS(429),
    [anon_sym_uint8] = ACTIONS(429),
    [anon_sym_uint16] = ACTIONS(429),
    [anon_sym_uint24] = ACTIONS(429),
    [anon_sym_uint32] = ACTIONS(429),
    [anon_sym_uint40] = ACTIONS(429),
    [anon_sym_uint48] = ACTIONS(429),
    [anon_sym_uint56] = ACTIONS(429),
    [anon_sym_uint64] = ACTIONS(429),
    [anon_sym_uint72] = ACTIONS(429),
    [anon_sym_uint80] = ACTIONS(429),
    [anon_sym_uint88] = ACTIONS(429),
    [anon_sym_uint96] = ACTIONS(429),
    [anon_sym_uint104] = ACTIONS(429),
    [anon_sym_uint112] = ACTIONS(429),
    [anon_sym_uint120] = ACTIONS(429),
    [anon_sym_uint128] = ACTIONS(429),
    [anon_sym_uint136] = ACTIONS(429),
    [anon_sym_uint144] = ACTIONS(429),
    [anon_sym_uint152] = ACTIONS(429),
    [anon_sym_uint160] = ACTIONS(429),
    [anon_sym_uint168] = ACTIONS(429),
    [anon_sym_uint176] = ACTIONS(429),
    [anon_sym_uint184] = ACTIONS(429),
    [anon_sym_uint192] = ACTIONS(429),
    [anon_sym_uint200] = ACTIONS(429),
    [anon_sym_uint208] = ACTIONS(429),
    [anon_sym_uint216] = ACTIONS(429),
    [anon_sym_uint224] = ACTIONS(429),
    [anon_sym_uint232] = ACTIONS(429),
    [anon_sym_uint240] = ACTIONS(429),
    [anon_sym_uint248] = ACTIONS(429),
    [anon_sym_uint256] = ACTIONS(429),
    [anon_sym_bytes] = ACTIONS(429),
    [anon_sym_bytes1] = ACTIONS(429),
    [anon_sym_bytes2] = ACTIONS(429),
    [anon_sym_bytes3] = ACTIONS(429),
    [anon_sym_bytes4] = ACTIONS(429),
    [anon_sym_bytes5] = ACTIONS(429),
    [anon_sym_bytes6] = ACTIONS(429),
    [anon_sym_bytes7] = ACTIONS(429),
    [anon_sym_bytes8] = ACTIONS(429),
    [anon_sym_bytes9] = ACTIONS(429),
    [anon_sym_bytes10] = ACTIONS(429),
    [anon_sym_bytes11] = ACTIONS(429),
    [anon_sym_bytes12] = ACTIONS(429),
    [anon_sym_bytes13] = ACTIONS(429),
    [anon_sym_bytes14] = ACTIONS(429),
    [anon_sym_bytes15] = ACTIONS(429),
    [anon_sym_bytes16] = ACTIONS(429),
    [anon_sym_bytes17] = ACTIONS(429),
    [anon_sym_bytes18] = ACTIONS(429),
    [anon_sym_bytes19] = ACTIONS(429),
    [anon_sym_bytes20] = ACTIONS(429),
    [anon_sym_bytes21] = ACTIONS(429),
    [anon_sym_bytes22] = ACTIONS(429),
    [anon_sym_bytes23] = ACTIONS(429),
    [anon_sym_bytes24] = ACTIONS(429),
    [anon_sym_bytes25] = ACTIONS(429),
    [anon_sym_bytes26] = ACTIONS(429),
    [anon_sym_bytes27] = ACTIONS(429),
    [anon_sym_bytes28] = ACTIONS(429),
    [anon_sym_bytes29] = ACTIONS(429),
    [anon_sym_bytes30] = ACTIONS(429),
    [anon_sym_bytes31] = ACTIONS(429),
    [anon_sym_bytes32] = ACTIONS(429),
    [anon_sym_fixed] = ACTIONS(429),
    [aux_sym__fixed_token1] = ACTIONS(429),
    [anon_sym_ufixed] = ACTIONS(429),
    [aux_sym__ufixed_token1] = ACTIONS(429),
    [sym_comment] = ACTIONS(3),
  },
  [80] = {
    [sym_identifier] = ACTIONS(450),
    [anon_sym_DASH] = ACTIONS(450),
    [anon_sym_TILDE] = ACTIONS(452),
    [anon_sym_LBRACE] = ACTIONS(452),
    [anon_sym_RBRACE] = ACTIONS(452),
    [anon_sym_type] = ACTIONS(450),
    [anon_sym_LPAREN] = ACTIONS(452),
    [anon_sym_for] = ACTIONS(450),
    [anon_sym_PLUS] = ACTIONS(450),
    [anon_sym_assembly] = ACTIONS(450),
    [anon_sym_break] = ACTIONS(450),
    [anon_sym_continue] = ACTIONS(450),
    [anon_sym_true] = ACTIONS(450),
    [anon_sym_false] = ACTIONS(450),
    [anon_sym_if] = ACTIONS(450),
    [anon_sym_function] = ACTIONS(450),
    [anon_sym_byte] = ACTIONS(450),
    [anon_sym_address] = ACTIONS(450),
    [anon_sym_return] = ACTIONS(450),
    [anon_sym_revert] = ACTIONS(450),
    [sym__unchecked] = ACTIONS(450),
    [anon_sym_var] = ACTIONS(450),
    [anon_sym_else] = ACTIONS(450),
    [anon_sym_while] = ACTIONS(450),
    [anon_sym_do] = ACTIONS(450),
    [anon_sym_try] = ACTIONS(450),
    [anon_sym_emit] = ACTIONS(450),
    [anon_sym_payable] = ACTIONS(450),
    [anon_sym_new] = ACTIONS(450),
    [anon_sym_LBRACK] = ACTIONS(452),
    [anon_sym_BANG] = ACTIONS(452),
    [anon_sym_delete] = ACTIONS(450),
    [anon_sym_PLUS_PLUS] = ACTIONS(452),
    [anon_sym_DASH_DASH] = ACTIONS(452),
    [anon_sym_mapping] = ACTIONS(450),
    [anon_sym_bool] = ACTIONS(450),
    [anon_sym_string] = ACTIONS(450),
    [anon_sym_int] = ACTIONS(450),
    [anon_sym_int8] = ACTIONS(450),
    [anon_sym_int16] = ACTIONS(450),
    [anon_sym_int24] = ACTIONS(450),
    [anon_sym_int32] = ACTIONS(450),
    [anon_sym_int40] = ACTIONS(450),
    [anon_sym_int48] = ACTIONS(450),
    [anon_sym_int56] = ACTIONS(450),
    [anon_sym_int64] = ACTIONS(450),
    [anon_sym_int72] = ACTIONS(450),
    [anon_sym_int80] = ACTIONS(450),
    [anon_sym_int88] = ACTIONS(450),
    [anon_sym_int96] = ACTIONS(450),
    [anon_sym_int104] = ACTIONS(450),
    [anon_sym_int112] = ACTIONS(450),
    [anon_sym_int120] = ACTIONS(450),
    [anon_sym_int128] = ACTIONS(450),
    [anon_sym_int136] = ACTIONS(450),
    [anon_sym_int144] = ACTIONS(450),
    [anon_sym_int152] = ACTIONS(450),
    [anon_sym_int160] = ACTIONS(450),
    [anon_sym_int168] = ACTIONS(450),
    [anon_sym_int176] = ACTIONS(450),
    [anon_sym_int184] = ACTIONS(450),
    [anon_sym_int192] = ACTIONS(450),
    [anon_sym_int200] = ACTIONS(450),
    [anon_sym_int208] = ACTIONS(450),
    [anon_sym_int216] = ACTIONS(450),
    [anon_sym_int224] = ACTIONS(450),
    [anon_sym_int232] = ACTIONS(450),
    [anon_sym_int240] = ACTIONS(450),
    [anon_sym_int248] = ACTIONS(450),
    [anon_sym_int256] = ACTIONS(450),
    [anon_sym_uint] = ACTIONS(450),
    [anon_sym_uint8] = ACTIONS(450),
    [anon_sym_uint16] = ACTIONS(450),
    [anon_sym_uint24] = ACTIONS(450),
    [anon_sym_uint32] = ACTIONS(450),
    [anon_sym_uint40] = ACTIONS(450),
    [anon_sym_uint48] = ACTIONS(450),
    [anon_sym_uint56] = ACTIONS(450),
    [anon_sym_uint64] = ACTIONS(450),
    [anon_sym_uint72] = ACTIONS(450),
    [anon_sym_uint80] = ACTIONS(450),
    [anon_sym_uint88] = ACTIONS(450),
    [anon_sym_uint96] = ACTIONS(450),
    [anon_sym_uint104] = ACTIONS(450),
    [anon_sym_uint112] = ACTIONS(450),
    [anon_sym_uint120] = ACTIONS(450),
    [anon_sym_uint128] = ACTIONS(450),
    [anon_sym_uint136] = ACTIONS(450),
    [anon_sym_uint144] = ACTIONS(450),
    [anon_sym_uint152] = ACTIONS(450),
    [anon_sym_uint160] = ACTIONS(450),
    [anon_sym_uint168] = ACTIONS(450),
    [anon_sym_uint176] = ACTIONS(450),
    [anon_sym_uint184] = ACTIONS(450),
    [anon_sym_uint192] = ACTIONS(450),
    [anon_sym_uint200] = ACTIONS(450),
    [anon_sym_uint208] = ACTIONS(450),
    [anon_sym_uint216] = ACTIONS(450),
    [anon_sym_uint224] = ACTIONS(450),
    [anon_sym_uint232] = ACTIONS(450),
    [anon_sym_uint240] = ACTIONS(450),
    [anon_sym_uint248] = ACTIONS(450),
    [anon_sym_uint256] = ACTIONS(450),
    [anon_sym_bytes] = ACTIONS(450),
    [anon_sym_bytes1] = ACTIONS(450),
    [anon_sym_bytes2] = ACTIONS(450),
    [anon_sym_bytes3] = ACTIONS(450),
    [anon_sym_bytes4] = ACTIONS(450),
    [anon_sym_bytes5] = ACTIONS(450),
    [anon_sym_bytes6] = ACTIONS(450),
    [anon_sym_bytes7] = ACTIONS(450),
    [anon_sym_bytes8] = ACTIONS(450),
    [anon_sym_bytes9] = ACTIONS(450),
    [anon_sym_bytes10] = ACTIONS(450),
    [anon_sym_bytes11] = ACTIONS(450),
    [anon_sym_bytes12] = ACTIONS(450),
    [anon_sym_bytes13] = ACTIONS(450),
    [anon_sym_bytes14] = ACTIONS(450),
    [anon_sym_bytes15] = ACTIONS(450),
    [anon_sym_bytes16] = ACTIONS(450),
    [anon_sym_bytes17] = ACTIONS(450),
    [anon_sym_bytes18] = ACTIONS(450),
    [anon_sym_bytes19] = ACTIONS(450),
    [anon_sym_bytes20] = ACTIONS(450),
    [anon_sym_bytes21] = ACTIONS(450),
    [anon_sym_bytes22] = ACTIONS(450),
    [anon_sym_bytes23] = ACTIONS(450),
    [anon_sym_bytes24] = ACTIONS(450),
    [anon_sym_bytes25] = ACTIONS(450),
    [anon_sym_bytes26] = ACTIONS(450),
    [anon_sym_bytes27] = ACTIONS(450),
    [anon_sym_bytes28] = ACTIONS(450),
    [anon_sym_bytes29] = ACTIONS(450),
    [anon_sym_bytes30] = ACTIONS(450),
    [anon_sym_bytes31] = ACTIONS(450),
    [anon_sym_bytes32] = ACTIONS(450),
    [anon_sym_fixed] = ACTIONS(450),
    [aux_sym__fixed_token1] = ACTIONS(450),
    [anon_sym_ufixed] = ACTIONS(450),
    [aux_sym__ufixed_token1] = ACTIONS(450),
    [sym__semicolon] = ACTIONS(452),
    [aux_sym__decimal_number_token1] = ACTIONS(450),
    [aux_sym__decimal_number_token2] = ACTIONS(452),
    [aux_sym__hex_number_token1] = ACTIONS(452),
    [anon_sym_hex] = ACTIONS(450),
    [anon_sym_DQUOTE] = ACTIONS(452),
    [anon_sym_SQUOTE] = ACTIONS(452),
    [anon_sym_unicode] = ACTIONS(450),
    [sym_comment] = ACTIONS(3),
  },
  [81] = {
    [sym_identifier] = ACTIONS(454),
    [anon_sym_DASH] = ACTIONS(454),
    [anon_sym_TILDE] = ACTIONS(456),
    [anon_sym_LBRACE] = ACTIONS(456),
    [anon_sym_RBRACE] = ACTIONS(456),
    [anon_sym_type] = ACTIONS(454),
    [anon_sym_LPAREN] = ACTIONS(456),
    [anon_sym_for] = ACTIONS(454),
    [anon_sym_PLUS] = ACTIONS(454),
    [anon_sym_assembly] = ACTIONS(454),
    [anon_sym_break] = ACTIONS(454),
    [anon_sym_continue] = ACTIONS(454),
    [anon_sym_true] = ACTIONS(454),
    [anon_sym_false] = ACTIONS(454),
    [anon_sym_if] = ACTIONS(454),
    [anon_sym_function] = ACTIONS(454),
    [anon_sym_byte] = ACTIONS(454),
    [anon_sym_address] = ACTIONS(454),
    [anon_sym_return] = ACTIONS(454),
    [anon_sym_revert] = ACTIONS(454),
    [sym__unchecked] = ACTIONS(454),
    [anon_sym_var] = ACTIONS(454),
    [anon_sym_else] = ACTIONS(454),
    [anon_sym_while] = ACTIONS(454),
    [anon_sym_do] = ACTIONS(454),
    [anon_sym_try] = ACTIONS(454),
    [anon_sym_catch] = ACTIONS(454),
    [anon_sym_emit] = ACTIONS(454),
    [anon_sym_payable] = ACTIONS(454),
    [anon_sym_new] = ACTIONS(454),
    [anon_sym_LBRACK] = ACTIONS(456),
    [anon_sym_BANG] = ACTIONS(456),
    [anon_sym_delete] = ACTIONS(454),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_mapping] = ACTIONS(454),
    [anon_sym_bool] = ACTIONS(454),
    [anon_sym_string] = ACTIONS(454),
    [anon_sym_int] = ACTIONS(454),
    [anon_sym_int8] = ACTIONS(454),
    [anon_sym_int16] = ACTIONS(454),
    [anon_sym_int24] = ACTIONS(454),
    [anon_sym_int32] = ACTIONS(454),
    [anon_sym_int40] = ACTIONS(454),
    [anon_sym_int48] = ACTIONS(454),
    [anon_sym_int56] = ACTIONS(454),
    [anon_sym_int64] = ACTIONS(454),
    [anon_sym_int72] = ACTIONS(454),
    [anon_sym_int80] = ACTIONS(454),
    [anon_sym_int88] = ACTIONS(454),
    [anon_sym_int96] = ACTIONS(454),
    [anon_sym_int104] = ACTIONS(454),
    [anon_sym_int112] = ACTIONS(454),
    [anon_sym_int120] = ACTIONS(454),
    [anon_sym_int128] = ACTIONS(454),
    [anon_sym_int136] = ACTIONS(454),
    [anon_sym_int144] = ACTIONS(454),
    [anon_sym_int152] = ACTIONS(454),
    [anon_sym_int160] = ACTIONS(454),
    [anon_sym_int168] = ACTIONS(454),
    [anon_sym_int176] = ACTIONS(454),
    [anon_sym_int184] = ACTIONS(454),
    [anon_sym_int192] = ACTIONS(454),
    [anon_sym_int200] = ACTIONS(454),
    [anon_sym_int208] = ACTIONS(454),
    [anon_sym_int216] = ACTIONS(454),
    [anon_sym_int224] = ACTIONS(454),
    [anon_sym_int232] = ACTIONS(454),
    [anon_sym_int240] = ACTIONS(454),
    [anon_sym_int248] = ACTIONS(454),
    [anon_sym_int256] = ACTIONS(454),
    [anon_sym_uint] = ACTIONS(454),
    [anon_sym_uint8] = ACTIONS(454),
    [anon_sym_uint16] = ACTIONS(454),
    [anon_sym_uint24] = ACTIONS(454),
    [anon_sym_uint32] = ACTIONS(454),
    [anon_sym_uint40] = ACTIONS(454),
    [anon_sym_uint48] = ACTIONS(454),
    [anon_sym_uint56] = ACTIONS(454),
    [anon_sym_uint64] = ACTIONS(454),
    [anon_sym_uint72] = ACTIONS(454),
    [anon_sym_uint80] = ACTIONS(454),
    [anon_sym_uint88] = ACTIONS(454),
    [anon_sym_uint96] = ACTIONS(454),
    [anon_sym_uint104] = ACTIONS(454),
    [anon_sym_uint112] = ACTIONS(454),
    [anon_sym_uint120] = ACTIONS(454),
    [anon_sym_uint128] = ACTIONS(454),
    [anon_sym_uint136] = ACTIONS(454),
    [anon_sym_uint144] = ACTIONS(454),
    [anon_sym_uint152] = ACTIONS(454),
    [anon_sym_uint160] = ACTIONS(454),
    [anon_sym_uint168] = ACTIONS(454),
    [anon_sym_uint176] = ACTIONS(454),
    [anon_sym_uint184] = ACTIONS(454),
    [anon_sym_uint192] = ACTIONS(454),
    [anon_sym_uint200] = ACTIONS(454),
    [anon_sym_uint208] = ACTIONS(454),
    [anon_sym_uint216] = ACTIONS(454),
    [anon_sym_uint224] = ACTIONS(454),
    [anon_sym_uint232] = ACTIONS(454),
    [anon_sym_uint240] = ACTIONS(454),
    [anon_sym_uint248] = ACTIONS(454),
    [anon_sym_uint256] = ACTIONS(454),
    [anon_sym_bytes] = ACTIONS(454),
    [anon_sym_bytes1] = ACTIONS(454),
    [anon_sym_bytes2] = ACTIONS(454),
    [anon_sym_bytes3] = ACTIONS(454),
    [anon_sym_bytes4] = ACTIONS(454),
    [anon_sym_bytes5] = ACTIONS(454),
    [anon_sym_bytes6] = ACTIONS(454),
    [anon_sym_bytes7] = ACTIONS(454),
    [anon_sym_bytes8] = ACTIONS(454),
    [anon_sym_bytes9] = ACTIONS(454),
    [anon_sym_bytes10] = ACTIONS(454),
    [anon_sym_bytes11] = ACTIONS(454),
    [anon_sym_bytes12] = ACTIONS(454),
    [anon_sym_bytes13] = ACTIONS(454),
    [anon_sym_bytes14] = ACTIONS(454),
    [anon_sym_bytes15] = ACTIONS(454),
    [anon_sym_bytes16] = ACTIONS(454),
    [anon_sym_bytes17] = ACTIONS(454),
    [anon_sym_bytes18] = ACTIONS(454),
    [anon_sym_bytes19] = ACTIONS(454),
    [anon_sym_bytes20] = ACTIONS(454),
    [anon_sym_bytes21] = ACTIONS(454),
    [anon_sym_bytes22] = ACTIONS(454),
    [anon_sym_bytes23] = ACTIONS(454),
    [anon_sym_bytes24] = ACTIONS(454),
    [anon_sym_bytes25] = ACTIONS(454),
    [anon_sym_bytes26] = ACTIONS(454),
    [anon_sym_bytes27] = ACTIONS(454),
    [anon_sym_bytes28] = ACTIONS(454),
    [anon_sym_bytes29] = ACTIONS(454),
    [anon_sym_bytes30] = ACTIONS(454),
    [anon_sym_bytes31] = ACTIONS(454),
    [anon_sym_bytes32] = ACTIONS(454),
    [anon_sym_fixed] = ACTIONS(454),
    [aux_sym__fixed_token1] = ACTIONS(454),
    [anon_sym_ufixed] = ACTIONS(454),
    [aux_sym__ufixed_token1] = ACTIONS(454),
    [aux_sym__decimal_number_token1] = ACTIONS(454),
    [aux_sym__decimal_number_token2] = ACTIONS(456),
    [aux_sym__hex_number_token1] = ACTIONS(456),
    [anon_sym_hex] = ACTIONS(454),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_SQUOTE] = ACTIONS(456),
    [anon_sym_unicode] = ACTIONS(454),
    [sym_comment] = ACTIONS(3),
  },
  [82] = {
    [sym_user_defined_type_definition] = STATE(76),
    [sym_error_declaration] = STATE(76),
    [sym__contract_member] = STATE(76),
    [sym_struct_declaration] = STATE(76),
    [sym_enum_declaration] = STATE(76),
    [sym_event_definition] = STATE(76),
    [sym_using_directive] = STATE(76),
    [sym_state_variable_declaration] = STATE(76),
    [sym_modifier_definition] = STATE(76),
    [sym_constructor_definition] = STATE(76),
    [sym_fallback_definition] = STATE(76),
    [sym_receive_definition] = STATE(76),
    [sym_function_definition] = STATE(76),
    [sym_type_name] = STATE(544),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_contract_body_repeat1] = STATE(76),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(458),
    [anon_sym_type] = ACTIONS(373),
    [anon_sym_error] = ACTIONS(375),
    [anon_sym_struct] = ACTIONS(377),
    [anon_sym_enum] = ACTIONS(379),
    [anon_sym_event] = ACTIONS(381),
    [anon_sym_using] = ACTIONS(383),
    [anon_sym_function] = ACTIONS(385),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_modifier] = ACTIONS(387),
    [anon_sym_constructor] = ACTIONS(389),
    [anon_sym_fallback] = ACTIONS(391),
    [anon_sym_receive] = ACTIONS(393),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [83] = {
    [sym_identifier] = ACTIONS(460),
    [anon_sym_DASH] = ACTIONS(460),
    [anon_sym_TILDE] = ACTIONS(462),
    [anon_sym_LBRACE] = ACTIONS(462),
    [anon_sym_RBRACE] = ACTIONS(462),
    [anon_sym_type] = ACTIONS(460),
    [anon_sym_LPAREN] = ACTIONS(462),
    [anon_sym_for] = ACTIONS(460),
    [anon_sym_PLUS] = ACTIONS(460),
    [anon_sym_assembly] = ACTIONS(460),
    [anon_sym_break] = ACTIONS(460),
    [anon_sym_continue] = ACTIONS(460),
    [anon_sym_true] = ACTIONS(460),
    [anon_sym_false] = ACTIONS(460),
    [anon_sym_if] = ACTIONS(460),
    [anon_sym_function] = ACTIONS(460),
    [anon_sym_byte] = ACTIONS(460),
    [anon_sym_address] = ACTIONS(460),
    [anon_sym_return] = ACTIONS(460),
    [anon_sym_revert] = ACTIONS(460),
    [sym__unchecked] = ACTIONS(460),
    [anon_sym_var] = ACTIONS(460),
    [anon_sym_else] = ACTIONS(460),
    [anon_sym_while] = ACTIONS(460),
    [anon_sym_do] = ACTIONS(460),
    [anon_sym_try] = ACTIONS(460),
    [anon_sym_catch] = ACTIONS(460),
    [anon_sym_emit] = ACTIONS(460),
    [anon_sym_payable] = ACTIONS(460),
    [anon_sym_new] = ACTIONS(460),
    [anon_sym_LBRACK] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(462),
    [anon_sym_delete] = ACTIONS(460),
    [anon_sym_PLUS_PLUS] = ACTIONS(462),
    [anon_sym_DASH_DASH] = ACTIONS(462),
    [anon_sym_mapping] = ACTIONS(460),
    [anon_sym_bool] = ACTIONS(460),
    [anon_sym_string] = ACTIONS(460),
    [anon_sym_int] = ACTIONS(460),
    [anon_sym_int8] = ACTIONS(460),
    [anon_sym_int16] = ACTIONS(460),
    [anon_sym_int24] = ACTIONS(460),
    [anon_sym_int32] = ACTIONS(460),
    [anon_sym_int40] = ACTIONS(460),
    [anon_sym_int48] = ACTIONS(460),
    [anon_sym_int56] = ACTIONS(460),
    [anon_sym_int64] = ACTIONS(460),
    [anon_sym_int72] = ACTIONS(460),
    [anon_sym_int80] = ACTIONS(460),
    [anon_sym_int88] = ACTIONS(460),
    [anon_sym_int96] = ACTIONS(460),
    [anon_sym_int104] = ACTIONS(460),
    [anon_sym_int112] = ACTIONS(460),
    [anon_sym_int120] = ACTIONS(460),
    [anon_sym_int128] = ACTIONS(460),
    [anon_sym_int136] = ACTIONS(460),
    [anon_sym_int144] = ACTIONS(460),
    [anon_sym_int152] = ACTIONS(460),
    [anon_sym_int160] = ACTIONS(460),
    [anon_sym_int168] = ACTIONS(460),
    [anon_sym_int176] = ACTIONS(460),
    [anon_sym_int184] = ACTIONS(460),
    [anon_sym_int192] = ACTIONS(460),
    [anon_sym_int200] = ACTIONS(460),
    [anon_sym_int208] = ACTIONS(460),
    [anon_sym_int216] = ACTIONS(460),
    [anon_sym_int224] = ACTIONS(460),
    [anon_sym_int232] = ACTIONS(460),
    [anon_sym_int240] = ACTIONS(460),
    [anon_sym_int248] = ACTIONS(460),
    [anon_sym_int256] = ACTIONS(460),
    [anon_sym_uint] = ACTIONS(460),
    [anon_sym_uint8] = ACTIONS(460),
    [anon_sym_uint16] = ACTIONS(460),
    [anon_sym_uint24] = ACTIONS(460),
    [anon_sym_uint32] = ACTIONS(460),
    [anon_sym_uint40] = ACTIONS(460),
    [anon_sym_uint48] = ACTIONS(460),
    [anon_sym_uint56] = ACTIONS(460),
    [anon_sym_uint64] = ACTIONS(460),
    [anon_sym_uint72] = ACTIONS(460),
    [anon_sym_uint80] = ACTIONS(460),
    [anon_sym_uint88] = ACTIONS(460),
    [anon_sym_uint96] = ACTIONS(460),
    [anon_sym_uint104] = ACTIONS(460),
    [anon_sym_uint112] = ACTIONS(460),
    [anon_sym_uint120] = ACTIONS(460),
    [anon_sym_uint128] = ACTIONS(460),
    [anon_sym_uint136] = ACTIONS(460),
    [anon_sym_uint144] = ACTIONS(460),
    [anon_sym_uint152] = ACTIONS(460),
    [anon_sym_uint160] = ACTIONS(460),
    [anon_sym_uint168] = ACTIONS(460),
    [anon_sym_uint176] = ACTIONS(460),
    [anon_sym_uint184] = ACTIONS(460),
    [anon_sym_uint192] = ACTIONS(460),
    [anon_sym_uint200] = ACTIONS(460),
    [anon_sym_uint208] = ACTIONS(460),
    [anon_sym_uint216] = ACTIONS(460),
    [anon_sym_uint224] = ACTIONS(460),
    [anon_sym_uint232] = ACTIONS(460),
    [anon_sym_uint240] = ACTIONS(460),
    [anon_sym_uint248] = ACTIONS(460),
    [anon_sym_uint256] = ACTIONS(460),
    [anon_sym_bytes] = ACTIONS(460),
    [anon_sym_bytes1] = ACTIONS(460),
    [anon_sym_bytes2] = ACTIONS(460),
    [anon_sym_bytes3] = ACTIONS(460),
    [anon_sym_bytes4] = ACTIONS(460),
    [anon_sym_bytes5] = ACTIONS(460),
    [anon_sym_bytes6] = ACTIONS(460),
    [anon_sym_bytes7] = ACTIONS(460),
    [anon_sym_bytes8] = ACTIONS(460),
    [anon_sym_bytes9] = ACTIONS(460),
    [anon_sym_bytes10] = ACTIONS(460),
    [anon_sym_bytes11] = ACTIONS(460),
    [anon_sym_bytes12] = ACTIONS(460),
    [anon_sym_bytes13] = ACTIONS(460),
    [anon_sym_bytes14] = ACTIONS(460),
    [anon_sym_bytes15] = ACTIONS(460),
    [anon_sym_bytes16] = ACTIONS(460),
    [anon_sym_bytes17] = ACTIONS(460),
    [anon_sym_bytes18] = ACTIONS(460),
    [anon_sym_bytes19] = ACTIONS(460),
    [anon_sym_bytes20] = ACTIONS(460),
    [anon_sym_bytes21] = ACTIONS(460),
    [anon_sym_bytes22] = ACTIONS(460),
    [anon_sym_bytes23] = ACTIONS(460),
    [anon_sym_bytes24] = ACTIONS(460),
    [anon_sym_bytes25] = ACTIONS(460),
    [anon_sym_bytes26] = ACTIONS(460),
    [anon_sym_bytes27] = ACTIONS(460),
    [anon_sym_bytes28] = ACTIONS(460),
    [anon_sym_bytes29] = ACTIONS(460),
    [anon_sym_bytes30] = ACTIONS(460),
    [anon_sym_bytes31] = ACTIONS(460),
    [anon_sym_bytes32] = ACTIONS(460),
    [anon_sym_fixed] = ACTIONS(460),
    [aux_sym__fixed_token1] = ACTIONS(460),
    [anon_sym_ufixed] = ACTIONS(460),
    [aux_sym__ufixed_token1] = ACTIONS(460),
    [aux_sym__decimal_number_token1] = ACTIONS(460),
    [aux_sym__decimal_number_token2] = ACTIONS(462),
    [aux_sym__hex_number_token1] = ACTIONS(462),
    [anon_sym_hex] = ACTIONS(460),
    [anon_sym_DQUOTE] = ACTIONS(462),
    [anon_sym_SQUOTE] = ACTIONS(462),
    [anon_sym_unicode] = ACTIONS(460),
    [sym_comment] = ACTIONS(3),
  },
  [84] = {
    [sym_identifier] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_TILDE] = ACTIONS(466),
    [anon_sym_LBRACE] = ACTIONS(466),
    [anon_sym_RBRACE] = ACTIONS(466),
    [anon_sym_type] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_assembly] = ACTIONS(464),
    [anon_sym_break] = ACTIONS(464),
    [anon_sym_continue] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_byte] = ACTIONS(464),
    [anon_sym_address] = ACTIONS(464),
    [anon_sym_return] = ACTIONS(464),
    [anon_sym_revert] = ACTIONS(464),
    [sym__unchecked] = ACTIONS(464),
    [anon_sym_var] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_do] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_catch] = ACTIONS(464),
    [anon_sym_emit] = ACTIONS(464),
    [anon_sym_payable] = ACTIONS(464),
    [anon_sym_new] = ACTIONS(464),
    [anon_sym_LBRACK] = ACTIONS(466),
    [anon_sym_BANG] = ACTIONS(466),
    [anon_sym_delete] = ACTIONS(464),
    [anon_sym_PLUS_PLUS] = ACTIONS(466),
    [anon_sym_DASH_DASH] = ACTIONS(466),
    [anon_sym_mapping] = ACTIONS(464),
    [anon_sym_bool] = ACTIONS(464),
    [anon_sym_string] = ACTIONS(464),
    [anon_sym_int] = ACTIONS(464),
    [anon_sym_int8] = ACTIONS(464),
    [anon_sym_int16] = ACTIONS(464),
    [anon_sym_int24] = ACTIONS(464),
    [anon_sym_int32] = ACTIONS(464),
    [anon_sym_int40] = ACTIONS(464),
    [anon_sym_int48] = ACTIONS(464),
    [anon_sym_int56] = ACTIONS(464),
    [anon_sym_int64] = ACTIONS(464),
    [anon_sym_int72] = ACTIONS(464),
    [anon_sym_int80] = ACTIONS(464),
    [anon_sym_int88] = ACTIONS(464),
    [anon_sym_int96] = ACTIONS(464),
    [anon_sym_int104] = ACTIONS(464),
    [anon_sym_int112] = ACTIONS(464),
    [anon_sym_int120] = ACTIONS(464),
    [anon_sym_int128] = ACTIONS(464),
    [anon_sym_int136] = ACTIONS(464),
    [anon_sym_int144] = ACTIONS(464),
    [anon_sym_int152] = ACTIONS(464),
    [anon_sym_int160] = ACTIONS(464),
    [anon_sym_int168] = ACTIONS(464),
    [anon_sym_int176] = ACTIONS(464),
    [anon_sym_int184] = ACTIONS(464),
    [anon_sym_int192] = ACTIONS(464),
    [anon_sym_int200] = ACTIONS(464),
    [anon_sym_int208] = ACTIONS(464),
    [anon_sym_int216] = ACTIONS(464),
    [anon_sym_int224] = ACTIONS(464),
    [anon_sym_int232] = ACTIONS(464),
    [anon_sym_int240] = ACTIONS(464),
    [anon_sym_int248] = ACTIONS(464),
    [anon_sym_int256] = ACTIONS(464),
    [anon_sym_uint] = ACTIONS(464),
    [anon_sym_uint8] = ACTIONS(464),
    [anon_sym_uint16] = ACTIONS(464),
    [anon_sym_uint24] = ACTIONS(464),
    [anon_sym_uint32] = ACTIONS(464),
    [anon_sym_uint40] = ACTIONS(464),
    [anon_sym_uint48] = ACTIONS(464),
    [anon_sym_uint56] = ACTIONS(464),
    [anon_sym_uint64] = ACTIONS(464),
    [anon_sym_uint72] = ACTIONS(464),
    [anon_sym_uint80] = ACTIONS(464),
    [anon_sym_uint88] = ACTIONS(464),
    [anon_sym_uint96] = ACTIONS(464),
    [anon_sym_uint104] = ACTIONS(464),
    [anon_sym_uint112] = ACTIONS(464),
    [anon_sym_uint120] = ACTIONS(464),
    [anon_sym_uint128] = ACTIONS(464),
    [anon_sym_uint136] = ACTIONS(464),
    [anon_sym_uint144] = ACTIONS(464),
    [anon_sym_uint152] = ACTIONS(464),
    [anon_sym_uint160] = ACTIONS(464),
    [anon_sym_uint168] = ACTIONS(464),
    [anon_sym_uint176] = ACTIONS(464),
    [anon_sym_uint184] = ACTIONS(464),
    [anon_sym_uint192] = ACTIONS(464),
    [anon_sym_uint200] = ACTIONS(464),
    [anon_sym_uint208] = ACTIONS(464),
    [anon_sym_uint216] = ACTIONS(464),
    [anon_sym_uint224] = ACTIONS(464),
    [anon_sym_uint232] = ACTIONS(464),
    [anon_sym_uint240] = ACTIONS(464),
    [anon_sym_uint248] = ACTIONS(464),
    [anon_sym_uint256] = ACTIONS(464),
    [anon_sym_bytes] = ACTIONS(464),
    [anon_sym_bytes1] = ACTIONS(464),
    [anon_sym_bytes2] = ACTIONS(464),
    [anon_sym_bytes3] = ACTIONS(464),
    [anon_sym_bytes4] = ACTIONS(464),
    [anon_sym_bytes5] = ACTIONS(464),
    [anon_sym_bytes6] = ACTIONS(464),
    [anon_sym_bytes7] = ACTIONS(464),
    [anon_sym_bytes8] = ACTIONS(464),
    [anon_sym_bytes9] = ACTIONS(464),
    [anon_sym_bytes10] = ACTIONS(464),
    [anon_sym_bytes11] = ACTIONS(464),
    [anon_sym_bytes12] = ACTIONS(464),
    [anon_sym_bytes13] = ACTIONS(464),
    [anon_sym_bytes14] = ACTIONS(464),
    [anon_sym_bytes15] = ACTIONS(464),
    [anon_sym_bytes16] = ACTIONS(464),
    [anon_sym_bytes17] = ACTIONS(464),
    [anon_sym_bytes18] = ACTIONS(464),
    [anon_sym_bytes19] = ACTIONS(464),
    [anon_sym_bytes20] = ACTIONS(464),
    [anon_sym_bytes21] = ACTIONS(464),
    [anon_sym_bytes22] = ACTIONS(464),
    [anon_sym_bytes23] = ACTIONS(464),
    [anon_sym_bytes24] = ACTIONS(464),
    [anon_sym_bytes25] = ACTIONS(464),
    [anon_sym_bytes26] = ACTIONS(464),
    [anon_sym_bytes27] = ACTIONS(464),
    [anon_sym_bytes28] = ACTIONS(464),
    [anon_sym_bytes29] = ACTIONS(464),
    [anon_sym_bytes30] = ACTIONS(464),
    [anon_sym_bytes31] = ACTIONS(464),
    [anon_sym_bytes32] = ACTIONS(464),
    [anon_sym_fixed] = ACTIONS(464),
    [aux_sym__fixed_token1] = ACTIONS(464),
    [anon_sym_ufixed] = ACTIONS(464),
    [aux_sym__ufixed_token1] = ACTIONS(464),
    [aux_sym__decimal_number_token1] = ACTIONS(464),
    [aux_sym__decimal_number_token2] = ACTIONS(466),
    [aux_sym__hex_number_token1] = ACTIONS(466),
    [anon_sym_hex] = ACTIONS(464),
    [anon_sym_DQUOTE] = ACTIONS(466),
    [anon_sym_SQUOTE] = ACTIONS(466),
    [anon_sym_unicode] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
  },
  [85] = {
    [sym_identifier] = ACTIONS(468),
    [anon_sym_DASH] = ACTIONS(468),
    [anon_sym_TILDE] = ACTIONS(470),
    [anon_sym_LBRACE] = ACTIONS(470),
    [anon_sym_RBRACE] = ACTIONS(470),
    [anon_sym_type] = ACTIONS(468),
    [anon_sym_LPAREN] = ACTIONS(470),
    [anon_sym_for] = ACTIONS(468),
    [anon_sym_PLUS] = ACTIONS(468),
    [anon_sym_assembly] = ACTIONS(468),
    [anon_sym_break] = ACTIONS(468),
    [anon_sym_continue] = ACTIONS(468),
    [anon_sym_true] = ACTIONS(468),
    [anon_sym_false] = ACTIONS(468),
    [anon_sym_if] = ACTIONS(468),
    [anon_sym_function] = ACTIONS(468),
    [anon_sym_byte] = ACTIONS(468),
    [anon_sym_address] = ACTIONS(468),
    [anon_sym_return] = ACTIONS(468),
    [anon_sym_revert] = ACTIONS(468),
    [sym__unchecked] = ACTIONS(468),
    [anon_sym_var] = ACTIONS(468),
    [anon_sym_else] = ACTIONS(468),
    [anon_sym_while] = ACTIONS(468),
    [anon_sym_do] = ACTIONS(468),
    [anon_sym_try] = ACTIONS(468),
    [anon_sym_catch] = ACTIONS(468),
    [anon_sym_emit] = ACTIONS(468),
    [anon_sym_payable] = ACTIONS(468),
    [anon_sym_new] = ACTIONS(468),
    [anon_sym_LBRACK] = ACTIONS(470),
    [anon_sym_BANG] = ACTIONS(470),
    [anon_sym_delete] = ACTIONS(468),
    [anon_sym_PLUS_PLUS] = ACTIONS(470),
    [anon_sym_DASH_DASH] = ACTIONS(470),
    [anon_sym_mapping] = ACTIONS(468),
    [anon_sym_bool] = ACTIONS(468),
    [anon_sym_string] = ACTIONS(468),
    [anon_sym_int] = ACTIONS(468),
    [anon_sym_int8] = ACTIONS(468),
    [anon_sym_int16] = ACTIONS(468),
    [anon_sym_int24] = ACTIONS(468),
    [anon_sym_int32] = ACTIONS(468),
    [anon_sym_int40] = ACTIONS(468),
    [anon_sym_int48] = ACTIONS(468),
    [anon_sym_int56] = ACTIONS(468),
    [anon_sym_int64] = ACTIONS(468),
    [anon_sym_int72] = ACTIONS(468),
    [anon_sym_int80] = ACTIONS(468),
    [anon_sym_int88] = ACTIONS(468),
    [anon_sym_int96] = ACTIONS(468),
    [anon_sym_int104] = ACTIONS(468),
    [anon_sym_int112] = ACTIONS(468),
    [anon_sym_int120] = ACTIONS(468),
    [anon_sym_int128] = ACTIONS(468),
    [anon_sym_int136] = ACTIONS(468),
    [anon_sym_int144] = ACTIONS(468),
    [anon_sym_int152] = ACTIONS(468),
    [anon_sym_int160] = ACTIONS(468),
    [anon_sym_int168] = ACTIONS(468),
    [anon_sym_int176] = ACTIONS(468),
    [anon_sym_int184] = ACTIONS(468),
    [anon_sym_int192] = ACTIONS(468),
    [anon_sym_int200] = ACTIONS(468),
    [anon_sym_int208] = ACTIONS(468),
    [anon_sym_int216] = ACTIONS(468),
    [anon_sym_int224] = ACTIONS(468),
    [anon_sym_int232] = ACTIONS(468),
    [anon_sym_int240] = ACTIONS(468),
    [anon_sym_int248] = ACTIONS(468),
    [anon_sym_int256] = ACTIONS(468),
    [anon_sym_uint] = ACTIONS(468),
    [anon_sym_uint8] = ACTIONS(468),
    [anon_sym_uint16] = ACTIONS(468),
    [anon_sym_uint24] = ACTIONS(468),
    [anon_sym_uint32] = ACTIONS(468),
    [anon_sym_uint40] = ACTIONS(468),
    [anon_sym_uint48] = ACTIONS(468),
    [anon_sym_uint56] = ACTIONS(468),
    [anon_sym_uint64] = ACTIONS(468),
    [anon_sym_uint72] = ACTIONS(468),
    [anon_sym_uint80] = ACTIONS(468),
    [anon_sym_uint88] = ACTIONS(468),
    [anon_sym_uint96] = ACTIONS(468),
    [anon_sym_uint104] = ACTIONS(468),
    [anon_sym_uint112] = ACTIONS(468),
    [anon_sym_uint120] = ACTIONS(468),
    [anon_sym_uint128] = ACTIONS(468),
    [anon_sym_uint136] = ACTIONS(468),
    [anon_sym_uint144] = ACTIONS(468),
    [anon_sym_uint152] = ACTIONS(468),
    [anon_sym_uint160] = ACTIONS(468),
    [anon_sym_uint168] = ACTIONS(468),
    [anon_sym_uint176] = ACTIONS(468),
    [anon_sym_uint184] = ACTIONS(468),
    [anon_sym_uint192] = ACTIONS(468),
    [anon_sym_uint200] = ACTIONS(468),
    [anon_sym_uint208] = ACTIONS(468),
    [anon_sym_uint216] = ACTIONS(468),
    [anon_sym_uint224] = ACTIONS(468),
    [anon_sym_uint232] = ACTIONS(468),
    [anon_sym_uint240] = ACTIONS(468),
    [anon_sym_uint248] = ACTIONS(468),
    [anon_sym_uint256] = ACTIONS(468),
    [anon_sym_bytes] = ACTIONS(468),
    [anon_sym_bytes1] = ACTIONS(468),
    [anon_sym_bytes2] = ACTIONS(468),
    [anon_sym_bytes3] = ACTIONS(468),
    [anon_sym_bytes4] = ACTIONS(468),
    [anon_sym_bytes5] = ACTIONS(468),
    [anon_sym_bytes6] = ACTIONS(468),
    [anon_sym_bytes7] = ACTIONS(468),
    [anon_sym_bytes8] = ACTIONS(468),
    [anon_sym_bytes9] = ACTIONS(468),
    [anon_sym_bytes10] = ACTIONS(468),
    [anon_sym_bytes11] = ACTIONS(468),
    [anon_sym_bytes12] = ACTIONS(468),
    [anon_sym_bytes13] = ACTIONS(468),
    [anon_sym_bytes14] = ACTIONS(468),
    [anon_sym_bytes15] = ACTIONS(468),
    [anon_sym_bytes16] = ACTIONS(468),
    [anon_sym_bytes17] = ACTIONS(468),
    [anon_sym_bytes18] = ACTIONS(468),
    [anon_sym_bytes19] = ACTIONS(468),
    [anon_sym_bytes20] = ACTIONS(468),
    [anon_sym_bytes21] = ACTIONS(468),
    [anon_sym_bytes22] = ACTIONS(468),
    [anon_sym_bytes23] = ACTIONS(468),
    [anon_sym_bytes24] = ACTIONS(468),
    [anon_sym_bytes25] = ACTIONS(468),
    [anon_sym_bytes26] = ACTIONS(468),
    [anon_sym_bytes27] = ACTIONS(468),
    [anon_sym_bytes28] = ACTIONS(468),
    [anon_sym_bytes29] = ACTIONS(468),
    [anon_sym_bytes30] = ACTIONS(468),
    [anon_sym_bytes31] = ACTIONS(468),
    [anon_sym_bytes32] = ACTIONS(468),
    [anon_sym_fixed] = ACTIONS(468),
    [aux_sym__fixed_token1] = ACTIONS(468),
    [anon_sym_ufixed] = ACTIONS(468),
    [aux_sym__ufixed_token1] = ACTIONS(468),
    [aux_sym__decimal_number_token1] = ACTIONS(468),
    [aux_sym__decimal_number_token2] = ACTIONS(470),
    [aux_sym__hex_number_token1] = ACTIONS(470),
    [anon_sym_hex] = ACTIONS(468),
    [anon_sym_DQUOTE] = ACTIONS(470),
    [anon_sym_SQUOTE] = ACTIONS(470),
    [anon_sym_unicode] = ACTIONS(468),
    [sym_comment] = ACTIONS(3),
  },
  [86] = {
    [sym_identifier] = ACTIONS(472),
    [anon_sym_DASH] = ACTIONS(472),
    [anon_sym_TILDE] = ACTIONS(474),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_RBRACE] = ACTIONS(474),
    [anon_sym_type] = ACTIONS(472),
    [anon_sym_LPAREN] = ACTIONS(474),
    [anon_sym_for] = ACTIONS(472),
    [anon_sym_PLUS] = ACTIONS(472),
    [anon_sym_assembly] = ACTIONS(472),
    [anon_sym_break] = ACTIONS(472),
    [anon_sym_continue] = ACTIONS(472),
    [anon_sym_true] = ACTIONS(472),
    [anon_sym_false] = ACTIONS(472),
    [anon_sym_if] = ACTIONS(472),
    [anon_sym_function] = ACTIONS(472),
    [anon_sym_byte] = ACTIONS(472),
    [anon_sym_address] = ACTIONS(472),
    [anon_sym_return] = ACTIONS(472),
    [anon_sym_revert] = ACTIONS(472),
    [sym__unchecked] = ACTIONS(472),
    [anon_sym_var] = ACTIONS(472),
    [anon_sym_else] = ACTIONS(472),
    [anon_sym_while] = ACTIONS(472),
    [anon_sym_do] = ACTIONS(472),
    [anon_sym_try] = ACTIONS(472),
    [anon_sym_emit] = ACTIONS(472),
    [anon_sym_payable] = ACTIONS(472),
    [anon_sym_new] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(474),
    [anon_sym_BANG] = ACTIONS(474),
    [anon_sym_delete] = ACTIONS(472),
    [anon_sym_PLUS_PLUS] = ACTIONS(474),
    [anon_sym_DASH_DASH] = ACTIONS(474),
    [anon_sym_mapping] = ACTIONS(472),
    [anon_sym_bool] = ACTIONS(472),
    [anon_sym_string] = ACTIONS(472),
    [anon_sym_int] = ACTIONS(472),
    [anon_sym_int8] = ACTIONS(472),
    [anon_sym_int16] = ACTIONS(472),
    [anon_sym_int24] = ACTIONS(472),
    [anon_sym_int32] = ACTIONS(472),
    [anon_sym_int40] = ACTIONS(472),
    [anon_sym_int48] = ACTIONS(472),
    [anon_sym_int56] = ACTIONS(472),
    [anon_sym_int64] = ACTIONS(472),
    [anon_sym_int72] = ACTIONS(472),
    [anon_sym_int80] = ACTIONS(472),
    [anon_sym_int88] = ACTIONS(472),
    [anon_sym_int96] = ACTIONS(472),
    [anon_sym_int104] = ACTIONS(472),
    [anon_sym_int112] = ACTIONS(472),
    [anon_sym_int120] = ACTIONS(472),
    [anon_sym_int128] = ACTIONS(472),
    [anon_sym_int136] = ACTIONS(472),
    [anon_sym_int144] = ACTIONS(472),
    [anon_sym_int152] = ACTIONS(472),
    [anon_sym_int160] = ACTIONS(472),
    [anon_sym_int168] = ACTIONS(472),
    [anon_sym_int176] = ACTIONS(472),
    [anon_sym_int184] = ACTIONS(472),
    [anon_sym_int192] = ACTIONS(472),
    [anon_sym_int200] = ACTIONS(472),
    [anon_sym_int208] = ACTIONS(472),
    [anon_sym_int216] = ACTIONS(472),
    [anon_sym_int224] = ACTIONS(472),
    [anon_sym_int232] = ACTIONS(472),
    [anon_sym_int240] = ACTIONS(472),
    [anon_sym_int248] = ACTIONS(472),
    [anon_sym_int256] = ACTIONS(472),
    [anon_sym_uint] = ACTIONS(472),
    [anon_sym_uint8] = ACTIONS(472),
    [anon_sym_uint16] = ACTIONS(472),
    [anon_sym_uint24] = ACTIONS(472),
    [anon_sym_uint32] = ACTIONS(472),
    [anon_sym_uint40] = ACTIONS(472),
    [anon_sym_uint48] = ACTIONS(472),
    [anon_sym_uint56] = ACTIONS(472),
    [anon_sym_uint64] = ACTIONS(472),
    [anon_sym_uint72] = ACTIONS(472),
    [anon_sym_uint80] = ACTIONS(472),
    [anon_sym_uint88] = ACTIONS(472),
    [anon_sym_uint96] = ACTIONS(472),
    [anon_sym_uint104] = ACTIONS(472),
    [anon_sym_uint112] = ACTIONS(472),
    [anon_sym_uint120] = ACTIONS(472),
    [anon_sym_uint128] = ACTIONS(472),
    [anon_sym_uint136] = ACTIONS(472),
    [anon_sym_uint144] = ACTIONS(472),
    [anon_sym_uint152] = ACTIONS(472),
    [anon_sym_uint160] = ACTIONS(472),
    [anon_sym_uint168] = ACTIONS(472),
    [anon_sym_uint176] = ACTIONS(472),
    [anon_sym_uint184] = ACTIONS(472),
    [anon_sym_uint192] = ACTIONS(472),
    [anon_sym_uint200] = ACTIONS(472),
    [anon_sym_uint208] = ACTIONS(472),
    [anon_sym_uint216] = ACTIONS(472),
    [anon_sym_uint224] = ACTIONS(472),
    [anon_sym_uint232] = ACTIONS(472),
    [anon_sym_uint240] = ACTIONS(472),
    [anon_sym_uint248] = ACTIONS(472),
    [anon_sym_uint256] = ACTIONS(472),
    [anon_sym_bytes] = ACTIONS(472),
    [anon_sym_bytes1] = ACTIONS(472),
    [anon_sym_bytes2] = ACTIONS(472),
    [anon_sym_bytes3] = ACTIONS(472),
    [anon_sym_bytes4] = ACTIONS(472),
    [anon_sym_bytes5] = ACTIONS(472),
    [anon_sym_bytes6] = ACTIONS(472),
    [anon_sym_bytes7] = ACTIONS(472),
    [anon_sym_bytes8] = ACTIONS(472),
    [anon_sym_bytes9] = ACTIONS(472),
    [anon_sym_bytes10] = ACTIONS(472),
    [anon_sym_bytes11] = ACTIONS(472),
    [anon_sym_bytes12] = ACTIONS(472),
    [anon_sym_bytes13] = ACTIONS(472),
    [anon_sym_bytes14] = ACTIONS(472),
    [anon_sym_bytes15] = ACTIONS(472),
    [anon_sym_bytes16] = ACTIONS(472),
    [anon_sym_bytes17] = ACTIONS(472),
    [anon_sym_bytes18] = ACTIONS(472),
    [anon_sym_bytes19] = ACTIONS(472),
    [anon_sym_bytes20] = ACTIONS(472),
    [anon_sym_bytes21] = ACTIONS(472),
    [anon_sym_bytes22] = ACTIONS(472),
    [anon_sym_bytes23] = ACTIONS(472),
    [anon_sym_bytes24] = ACTIONS(472),
    [anon_sym_bytes25] = ACTIONS(472),
    [anon_sym_bytes26] = ACTIONS(472),
    [anon_sym_bytes27] = ACTIONS(472),
    [anon_sym_bytes28] = ACTIONS(472),
    [anon_sym_bytes29] = ACTIONS(472),
    [anon_sym_bytes30] = ACTIONS(472),
    [anon_sym_bytes31] = ACTIONS(472),
    [anon_sym_bytes32] = ACTIONS(472),
    [anon_sym_fixed] = ACTIONS(472),
    [aux_sym__fixed_token1] = ACTIONS(472),
    [anon_sym_ufixed] = ACTIONS(472),
    [aux_sym__ufixed_token1] = ACTIONS(472),
    [aux_sym__decimal_number_token1] = ACTIONS(472),
    [aux_sym__decimal_number_token2] = ACTIONS(474),
    [aux_sym__hex_number_token1] = ACTIONS(474),
    [anon_sym_hex] = ACTIONS(472),
    [anon_sym_DQUOTE] = ACTIONS(474),
    [anon_sym_SQUOTE] = ACTIONS(474),
    [anon_sym_unicode] = ACTIONS(472),
    [sym_comment] = ACTIONS(3),
  },
  [87] = {
    [sym_identifier] = ACTIONS(476),
    [anon_sym_DASH] = ACTIONS(476),
    [anon_sym_TILDE] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(478),
    [anon_sym_RBRACE] = ACTIONS(478),
    [anon_sym_type] = ACTIONS(476),
    [anon_sym_LPAREN] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(476),
    [anon_sym_PLUS] = ACTIONS(476),
    [anon_sym_assembly] = ACTIONS(476),
    [anon_sym_break] = ACTIONS(476),
    [anon_sym_continue] = ACTIONS(476),
    [anon_sym_true] = ACTIONS(476),
    [anon_sym_false] = ACTIONS(476),
    [anon_sym_if] = ACTIONS(476),
    [anon_sym_function] = ACTIONS(476),
    [anon_sym_byte] = ACTIONS(476),
    [anon_sym_address] = ACTIONS(476),
    [anon_sym_return] = ACTIONS(476),
    [anon_sym_revert] = ACTIONS(476),
    [sym__unchecked] = ACTIONS(476),
    [anon_sym_var] = ACTIONS(476),
    [anon_sym_else] = ACTIONS(476),
    [anon_sym_while] = ACTIONS(476),
    [anon_sym_do] = ACTIONS(476),
    [anon_sym_try] = ACTIONS(476),
    [anon_sym_emit] = ACTIONS(476),
    [anon_sym_payable] = ACTIONS(476),
    [anon_sym_new] = ACTIONS(476),
    [anon_sym_LBRACK] = ACTIONS(478),
    [anon_sym_BANG] = ACTIONS(478),
    [anon_sym_delete] = ACTIONS(476),
    [anon_sym_PLUS_PLUS] = ACTIONS(478),
    [anon_sym_DASH_DASH] = ACTIONS(478),
    [anon_sym_mapping] = ACTIONS(476),
    [anon_sym_bool] = ACTIONS(476),
    [anon_sym_string] = ACTIONS(476),
    [anon_sym_int] = ACTIONS(476),
    [anon_sym_int8] = ACTIONS(476),
    [anon_sym_int16] = ACTIONS(476),
    [anon_sym_int24] = ACTIONS(476),
    [anon_sym_int32] = ACTIONS(476),
    [anon_sym_int40] = ACTIONS(476),
    [anon_sym_int48] = ACTIONS(476),
    [anon_sym_int56] = ACTIONS(476),
    [anon_sym_int64] = ACTIONS(476),
    [anon_sym_int72] = ACTIONS(476),
    [anon_sym_int80] = ACTIONS(476),
    [anon_sym_int88] = ACTIONS(476),
    [anon_sym_int96] = ACTIONS(476),
    [anon_sym_int104] = ACTIONS(476),
    [anon_sym_int112] = ACTIONS(476),
    [anon_sym_int120] = ACTIONS(476),
    [anon_sym_int128] = ACTIONS(476),
    [anon_sym_int136] = ACTIONS(476),
    [anon_sym_int144] = ACTIONS(476),
    [anon_sym_int152] = ACTIONS(476),
    [anon_sym_int160] = ACTIONS(476),
    [anon_sym_int168] = ACTIONS(476),
    [anon_sym_int176] = ACTIONS(476),
    [anon_sym_int184] = ACTIONS(476),
    [anon_sym_int192] = ACTIONS(476),
    [anon_sym_int200] = ACTIONS(476),
    [anon_sym_int208] = ACTIONS(476),
    [anon_sym_int216] = ACTIONS(476),
    [anon_sym_int224] = ACTIONS(476),
    [anon_sym_int232] = ACTIONS(476),
    [anon_sym_int240] = ACTIONS(476),
    [anon_sym_int248] = ACTIONS(476),
    [anon_sym_int256] = ACTIONS(476),
    [anon_sym_uint] = ACTIONS(476),
    [anon_sym_uint8] = ACTIONS(476),
    [anon_sym_uint16] = ACTIONS(476),
    [anon_sym_uint24] = ACTIONS(476),
    [anon_sym_uint32] = ACTIONS(476),
    [anon_sym_uint40] = ACTIONS(476),
    [anon_sym_uint48] = ACTIONS(476),
    [anon_sym_uint56] = ACTIONS(476),
    [anon_sym_uint64] = ACTIONS(476),
    [anon_sym_uint72] = ACTIONS(476),
    [anon_sym_uint80] = ACTIONS(476),
    [anon_sym_uint88] = ACTIONS(476),
    [anon_sym_uint96] = ACTIONS(476),
    [anon_sym_uint104] = ACTIONS(476),
    [anon_sym_uint112] = ACTIONS(476),
    [anon_sym_uint120] = ACTIONS(476),
    [anon_sym_uint128] = ACTIONS(476),
    [anon_sym_uint136] = ACTIONS(476),
    [anon_sym_uint144] = ACTIONS(476),
    [anon_sym_uint152] = ACTIONS(476),
    [anon_sym_uint160] = ACTIONS(476),
    [anon_sym_uint168] = ACTIONS(476),
    [anon_sym_uint176] = ACTIONS(476),
    [anon_sym_uint184] = ACTIONS(476),
    [anon_sym_uint192] = ACTIONS(476),
    [anon_sym_uint200] = ACTIONS(476),
    [anon_sym_uint208] = ACTIONS(476),
    [anon_sym_uint216] = ACTIONS(476),
    [anon_sym_uint224] = ACTIONS(476),
    [anon_sym_uint232] = ACTIONS(476),
    [anon_sym_uint240] = ACTIONS(476),
    [anon_sym_uint248] = ACTIONS(476),
    [anon_sym_uint256] = ACTIONS(476),
    [anon_sym_bytes] = ACTIONS(476),
    [anon_sym_bytes1] = ACTIONS(476),
    [anon_sym_bytes2] = ACTIONS(476),
    [anon_sym_bytes3] = ACTIONS(476),
    [anon_sym_bytes4] = ACTIONS(476),
    [anon_sym_bytes5] = ACTIONS(476),
    [anon_sym_bytes6] = ACTIONS(476),
    [anon_sym_bytes7] = ACTIONS(476),
    [anon_sym_bytes8] = ACTIONS(476),
    [anon_sym_bytes9] = ACTIONS(476),
    [anon_sym_bytes10] = ACTIONS(476),
    [anon_sym_bytes11] = ACTIONS(476),
    [anon_sym_bytes12] = ACTIONS(476),
    [anon_sym_bytes13] = ACTIONS(476),
    [anon_sym_bytes14] = ACTIONS(476),
    [anon_sym_bytes15] = ACTIONS(476),
    [anon_sym_bytes16] = ACTIONS(476),
    [anon_sym_bytes17] = ACTIONS(476),
    [anon_sym_bytes18] = ACTIONS(476),
    [anon_sym_bytes19] = ACTIONS(476),
    [anon_sym_bytes20] = ACTIONS(476),
    [anon_sym_bytes21] = ACTIONS(476),
    [anon_sym_bytes22] = ACTIONS(476),
    [anon_sym_bytes23] = ACTIONS(476),
    [anon_sym_bytes24] = ACTIONS(476),
    [anon_sym_bytes25] = ACTIONS(476),
    [anon_sym_bytes26] = ACTIONS(476),
    [anon_sym_bytes27] = ACTIONS(476),
    [anon_sym_bytes28] = ACTIONS(476),
    [anon_sym_bytes29] = ACTIONS(476),
    [anon_sym_bytes30] = ACTIONS(476),
    [anon_sym_bytes31] = ACTIONS(476),
    [anon_sym_bytes32] = ACTIONS(476),
    [anon_sym_fixed] = ACTIONS(476),
    [aux_sym__fixed_token1] = ACTIONS(476),
    [anon_sym_ufixed] = ACTIONS(476),
    [aux_sym__ufixed_token1] = ACTIONS(476),
    [aux_sym__decimal_number_token1] = ACTIONS(476),
    [aux_sym__decimal_number_token2] = ACTIONS(478),
    [aux_sym__hex_number_token1] = ACTIONS(478),
    [anon_sym_hex] = ACTIONS(476),
    [anon_sym_DQUOTE] = ACTIONS(478),
    [anon_sym_SQUOTE] = ACTIONS(478),
    [anon_sym_unicode] = ACTIONS(476),
    [sym_comment] = ACTIONS(3),
  },
  [88] = {
    [sym_identifier] = ACTIONS(480),
    [anon_sym_DASH] = ACTIONS(480),
    [anon_sym_TILDE] = ACTIONS(482),
    [anon_sym_LBRACE] = ACTIONS(482),
    [anon_sym_RBRACE] = ACTIONS(482),
    [anon_sym_type] = ACTIONS(480),
    [anon_sym_LPAREN] = ACTIONS(482),
    [anon_sym_for] = ACTIONS(480),
    [anon_sym_PLUS] = ACTIONS(480),
    [anon_sym_assembly] = ACTIONS(480),
    [anon_sym_break] = ACTIONS(480),
    [anon_sym_continue] = ACTIONS(480),
    [anon_sym_true] = ACTIONS(480),
    [anon_sym_false] = ACTIONS(480),
    [anon_sym_if] = ACTIONS(480),
    [anon_sym_function] = ACTIONS(480),
    [anon_sym_byte] = ACTIONS(480),
    [anon_sym_address] = ACTIONS(480),
    [anon_sym_return] = ACTIONS(480),
    [anon_sym_revert] = ACTIONS(480),
    [sym__unchecked] = ACTIONS(480),
    [anon_sym_var] = ACTIONS(480),
    [anon_sym_else] = ACTIONS(484),
    [anon_sym_while] = ACTIONS(480),
    [anon_sym_do] = ACTIONS(480),
    [anon_sym_try] = ACTIONS(480),
    [anon_sym_emit] = ACTIONS(480),
    [anon_sym_payable] = ACTIONS(480),
    [anon_sym_new] = ACTIONS(480),
    [anon_sym_LBRACK] = ACTIONS(482),
    [anon_sym_BANG] = ACTIONS(482),
    [anon_sym_delete] = ACTIONS(480),
    [anon_sym_PLUS_PLUS] = ACTIONS(482),
    [anon_sym_DASH_DASH] = ACTIONS(482),
    [anon_sym_mapping] = ACTIONS(480),
    [anon_sym_bool] = ACTIONS(480),
    [anon_sym_string] = ACTIONS(480),
    [anon_sym_int] = ACTIONS(480),
    [anon_sym_int8] = ACTIONS(480),
    [anon_sym_int16] = ACTIONS(480),
    [anon_sym_int24] = ACTIONS(480),
    [anon_sym_int32] = ACTIONS(480),
    [anon_sym_int40] = ACTIONS(480),
    [anon_sym_int48] = ACTIONS(480),
    [anon_sym_int56] = ACTIONS(480),
    [anon_sym_int64] = ACTIONS(480),
    [anon_sym_int72] = ACTIONS(480),
    [anon_sym_int80] = ACTIONS(480),
    [anon_sym_int88] = ACTIONS(480),
    [anon_sym_int96] = ACTIONS(480),
    [anon_sym_int104] = ACTIONS(480),
    [anon_sym_int112] = ACTIONS(480),
    [anon_sym_int120] = ACTIONS(480),
    [anon_sym_int128] = ACTIONS(480),
    [anon_sym_int136] = ACTIONS(480),
    [anon_sym_int144] = ACTIONS(480),
    [anon_sym_int152] = ACTIONS(480),
    [anon_sym_int160] = ACTIONS(480),
    [anon_sym_int168] = ACTIONS(480),
    [anon_sym_int176] = ACTIONS(480),
    [anon_sym_int184] = ACTIONS(480),
    [anon_sym_int192] = ACTIONS(480),
    [anon_sym_int200] = ACTIONS(480),
    [anon_sym_int208] = ACTIONS(480),
    [anon_sym_int216] = ACTIONS(480),
    [anon_sym_int224] = ACTIONS(480),
    [anon_sym_int232] = ACTIONS(480),
    [anon_sym_int240] = ACTIONS(480),
    [anon_sym_int248] = ACTIONS(480),
    [anon_sym_int256] = ACTIONS(480),
    [anon_sym_uint] = ACTIONS(480),
    [anon_sym_uint8] = ACTIONS(480),
    [anon_sym_uint16] = ACTIONS(480),
    [anon_sym_uint24] = ACTIONS(480),
    [anon_sym_uint32] = ACTIONS(480),
    [anon_sym_uint40] = ACTIONS(480),
    [anon_sym_uint48] = ACTIONS(480),
    [anon_sym_uint56] = ACTIONS(480),
    [anon_sym_uint64] = ACTIONS(480),
    [anon_sym_uint72] = ACTIONS(480),
    [anon_sym_uint80] = ACTIONS(480),
    [anon_sym_uint88] = ACTIONS(480),
    [anon_sym_uint96] = ACTIONS(480),
    [anon_sym_uint104] = ACTIONS(480),
    [anon_sym_uint112] = ACTIONS(480),
    [anon_sym_uint120] = ACTIONS(480),
    [anon_sym_uint128] = ACTIONS(480),
    [anon_sym_uint136] = ACTIONS(480),
    [anon_sym_uint144] = ACTIONS(480),
    [anon_sym_uint152] = ACTIONS(480),
    [anon_sym_uint160] = ACTIONS(480),
    [anon_sym_uint168] = ACTIONS(480),
    [anon_sym_uint176] = ACTIONS(480),
    [anon_sym_uint184] = ACTIONS(480),
    [anon_sym_uint192] = ACTIONS(480),
    [anon_sym_uint200] = ACTIONS(480),
    [anon_sym_uint208] = ACTIONS(480),
    [anon_sym_uint216] = ACTIONS(480),
    [anon_sym_uint224] = ACTIONS(480),
    [anon_sym_uint232] = ACTIONS(480),
    [anon_sym_uint240] = ACTIONS(480),
    [anon_sym_uint248] = ACTIONS(480),
    [anon_sym_uint256] = ACTIONS(480),
    [anon_sym_bytes] = ACTIONS(480),
    [anon_sym_bytes1] = ACTIONS(480),
    [anon_sym_bytes2] = ACTIONS(480),
    [anon_sym_bytes3] = ACTIONS(480),
    [anon_sym_bytes4] = ACTIONS(480),
    [anon_sym_bytes5] = ACTIONS(480),
    [anon_sym_bytes6] = ACTIONS(480),
    [anon_sym_bytes7] = ACTIONS(480),
    [anon_sym_bytes8] = ACTIONS(480),
    [anon_sym_bytes9] = ACTIONS(480),
    [anon_sym_bytes10] = ACTIONS(480),
    [anon_sym_bytes11] = ACTIONS(480),
    [anon_sym_bytes12] = ACTIONS(480),
    [anon_sym_bytes13] = ACTIONS(480),
    [anon_sym_bytes14] = ACTIONS(480),
    [anon_sym_bytes15] = ACTIONS(480),
    [anon_sym_bytes16] = ACTIONS(480),
    [anon_sym_bytes17] = ACTIONS(480),
    [anon_sym_bytes18] = ACTIONS(480),
    [anon_sym_bytes19] = ACTIONS(480),
    [anon_sym_bytes20] = ACTIONS(480),
    [anon_sym_bytes21] = ACTIONS(480),
    [anon_sym_bytes22] = ACTIONS(480),
    [anon_sym_bytes23] = ACTIONS(480),
    [anon_sym_bytes24] = ACTIONS(480),
    [anon_sym_bytes25] = ACTIONS(480),
    [anon_sym_bytes26] = ACTIONS(480),
    [anon_sym_bytes27] = ACTIONS(480),
    [anon_sym_bytes28] = ACTIONS(480),
    [anon_sym_bytes29] = ACTIONS(480),
    [anon_sym_bytes30] = ACTIONS(480),
    [anon_sym_bytes31] = ACTIONS(480),
    [anon_sym_bytes32] = ACTIONS(480),
    [anon_sym_fixed] = ACTIONS(480),
    [aux_sym__fixed_token1] = ACTIONS(480),
    [anon_sym_ufixed] = ACTIONS(480),
    [aux_sym__ufixed_token1] = ACTIONS(480),
    [aux_sym__decimal_number_token1] = ACTIONS(480),
    [aux_sym__decimal_number_token2] = ACTIONS(482),
    [aux_sym__hex_number_token1] = ACTIONS(482),
    [anon_sym_hex] = ACTIONS(480),
    [anon_sym_DQUOTE] = ACTIONS(482),
    [anon_sym_SQUOTE] = ACTIONS(482),
    [anon_sym_unicode] = ACTIONS(480),
    [sym_comment] = ACTIONS(3),
  },
  [89] = {
    [sym_identifier] = ACTIONS(486),
    [anon_sym_DASH] = ACTIONS(486),
    [anon_sym_TILDE] = ACTIONS(488),
    [anon_sym_LBRACE] = ACTIONS(488),
    [anon_sym_RBRACE] = ACTIONS(488),
    [anon_sym_type] = ACTIONS(486),
    [anon_sym_LPAREN] = ACTIONS(488),
    [anon_sym_for] = ACTIONS(486),
    [anon_sym_PLUS] = ACTIONS(486),
    [anon_sym_assembly] = ACTIONS(486),
    [anon_sym_break] = ACTIONS(486),
    [anon_sym_continue] = ACTIONS(486),
    [anon_sym_true] = ACTIONS(486),
    [anon_sym_false] = ACTIONS(486),
    [anon_sym_if] = ACTIONS(486),
    [anon_sym_function] = ACTIONS(486),
    [anon_sym_byte] = ACTIONS(486),
    [anon_sym_address] = ACTIONS(486),
    [anon_sym_return] = ACTIONS(486),
    [anon_sym_revert] = ACTIONS(486),
    [sym__unchecked] = ACTIONS(486),
    [anon_sym_var] = ACTIONS(486),
    [anon_sym_else] = ACTIONS(486),
    [anon_sym_while] = ACTIONS(486),
    [anon_sym_do] = ACTIONS(486),
    [anon_sym_try] = ACTIONS(486),
    [anon_sym_emit] = ACTIONS(486),
    [anon_sym_payable] = ACTIONS(486),
    [anon_sym_new] = ACTIONS(486),
    [anon_sym_LBRACK] = ACTIONS(488),
    [anon_sym_BANG] = ACTIONS(488),
    [anon_sym_delete] = ACTIONS(486),
    [anon_sym_PLUS_PLUS] = ACTIONS(488),
    [anon_sym_DASH_DASH] = ACTIONS(488),
    [anon_sym_mapping] = ACTIONS(486),
    [anon_sym_bool] = ACTIONS(486),
    [anon_sym_string] = ACTIONS(486),
    [anon_sym_int] = ACTIONS(486),
    [anon_sym_int8] = ACTIONS(486),
    [anon_sym_int16] = ACTIONS(486),
    [anon_sym_int24] = ACTIONS(486),
    [anon_sym_int32] = ACTIONS(486),
    [anon_sym_int40] = ACTIONS(486),
    [anon_sym_int48] = ACTIONS(486),
    [anon_sym_int56] = ACTIONS(486),
    [anon_sym_int64] = ACTIONS(486),
    [anon_sym_int72] = ACTIONS(486),
    [anon_sym_int80] = ACTIONS(486),
    [anon_sym_int88] = ACTIONS(486),
    [anon_sym_int96] = ACTIONS(486),
    [anon_sym_int104] = ACTIONS(486),
    [anon_sym_int112] = ACTIONS(486),
    [anon_sym_int120] = ACTIONS(486),
    [anon_sym_int128] = ACTIONS(486),
    [anon_sym_int136] = ACTIONS(486),
    [anon_sym_int144] = ACTIONS(486),
    [anon_sym_int152] = ACTIONS(486),
    [anon_sym_int160] = ACTIONS(486),
    [anon_sym_int168] = ACTIONS(486),
    [anon_sym_int176] = ACTIONS(486),
    [anon_sym_int184] = ACTIONS(486),
    [anon_sym_int192] = ACTIONS(486),
    [anon_sym_int200] = ACTIONS(486),
    [anon_sym_int208] = ACTIONS(486),
    [anon_sym_int216] = ACTIONS(486),
    [anon_sym_int224] = ACTIONS(486),
    [anon_sym_int232] = ACTIONS(486),
    [anon_sym_int240] = ACTIONS(486),
    [anon_sym_int248] = ACTIONS(486),
    [anon_sym_int256] = ACTIONS(486),
    [anon_sym_uint] = ACTIONS(486),
    [anon_sym_uint8] = ACTIONS(486),
    [anon_sym_uint16] = ACTIONS(486),
    [anon_sym_uint24] = ACTIONS(486),
    [anon_sym_uint32] = ACTIONS(486),
    [anon_sym_uint40] = ACTIONS(486),
    [anon_sym_uint48] = ACTIONS(486),
    [anon_sym_uint56] = ACTIONS(486),
    [anon_sym_uint64] = ACTIONS(486),
    [anon_sym_uint72] = ACTIONS(486),
    [anon_sym_uint80] = ACTIONS(486),
    [anon_sym_uint88] = ACTIONS(486),
    [anon_sym_uint96] = ACTIONS(486),
    [anon_sym_uint104] = ACTIONS(486),
    [anon_sym_uint112] = ACTIONS(486),
    [anon_sym_uint120] = ACTIONS(486),
    [anon_sym_uint128] = ACTIONS(486),
    [anon_sym_uint136] = ACTIONS(486),
    [anon_sym_uint144] = ACTIONS(486),
    [anon_sym_uint152] = ACTIONS(486),
    [anon_sym_uint160] = ACTIONS(486),
    [anon_sym_uint168] = ACTIONS(486),
    [anon_sym_uint176] = ACTIONS(486),
    [anon_sym_uint184] = ACTIONS(486),
    [anon_sym_uint192] = ACTIONS(486),
    [anon_sym_uint200] = ACTIONS(486),
    [anon_sym_uint208] = ACTIONS(486),
    [anon_sym_uint216] = ACTIONS(486),
    [anon_sym_uint224] = ACTIONS(486),
    [anon_sym_uint232] = ACTIONS(486),
    [anon_sym_uint240] = ACTIONS(486),
    [anon_sym_uint248] = ACTIONS(486),
    [anon_sym_uint256] = ACTIONS(486),
    [anon_sym_bytes] = ACTIONS(486),
    [anon_sym_bytes1] = ACTIONS(486),
    [anon_sym_bytes2] = ACTIONS(486),
    [anon_sym_bytes3] = ACTIONS(486),
    [anon_sym_bytes4] = ACTIONS(486),
    [anon_sym_bytes5] = ACTIONS(486),
    [anon_sym_bytes6] = ACTIONS(486),
    [anon_sym_bytes7] = ACTIONS(486),
    [anon_sym_bytes8] = ACTIONS(486),
    [anon_sym_bytes9] = ACTIONS(486),
    [anon_sym_bytes10] = ACTIONS(486),
    [anon_sym_bytes11] = ACTIONS(486),
    [anon_sym_bytes12] = ACTIONS(486),
    [anon_sym_bytes13] = ACTIONS(486),
    [anon_sym_bytes14] = ACTIONS(486),
    [anon_sym_bytes15] = ACTIONS(486),
    [anon_sym_bytes16] = ACTIONS(486),
    [anon_sym_bytes17] = ACTIONS(486),
    [anon_sym_bytes18] = ACTIONS(486),
    [anon_sym_bytes19] = ACTIONS(486),
    [anon_sym_bytes20] = ACTIONS(486),
    [anon_sym_bytes21] = ACTIONS(486),
    [anon_sym_bytes22] = ACTIONS(486),
    [anon_sym_bytes23] = ACTIONS(486),
    [anon_sym_bytes24] = ACTIONS(486),
    [anon_sym_bytes25] = ACTIONS(486),
    [anon_sym_bytes26] = ACTIONS(486),
    [anon_sym_bytes27] = ACTIONS(486),
    [anon_sym_bytes28] = ACTIONS(486),
    [anon_sym_bytes29] = ACTIONS(486),
    [anon_sym_bytes30] = ACTIONS(486),
    [anon_sym_bytes31] = ACTIONS(486),
    [anon_sym_bytes32] = ACTIONS(486),
    [anon_sym_fixed] = ACTIONS(486),
    [aux_sym__fixed_token1] = ACTIONS(486),
    [anon_sym_ufixed] = ACTIONS(486),
    [aux_sym__ufixed_token1] = ACTIONS(486),
    [aux_sym__decimal_number_token1] = ACTIONS(486),
    [aux_sym__decimal_number_token2] = ACTIONS(488),
    [aux_sym__hex_number_token1] = ACTIONS(488),
    [anon_sym_hex] = ACTIONS(486),
    [anon_sym_DQUOTE] = ACTIONS(488),
    [anon_sym_SQUOTE] = ACTIONS(488),
    [anon_sym_unicode] = ACTIONS(486),
    [sym_comment] = ACTIONS(3),
  },
  [90] = {
    [sym_identifier] = ACTIONS(490),
    [anon_sym_DASH] = ACTIONS(490),
    [anon_sym_TILDE] = ACTIONS(492),
    [anon_sym_LBRACE] = ACTIONS(492),
    [anon_sym_RBRACE] = ACTIONS(492),
    [anon_sym_type] = ACTIONS(490),
    [anon_sym_LPAREN] = ACTIONS(492),
    [anon_sym_for] = ACTIONS(490),
    [anon_sym_PLUS] = ACTIONS(490),
    [anon_sym_assembly] = ACTIONS(490),
    [anon_sym_break] = ACTIONS(490),
    [anon_sym_continue] = ACTIONS(490),
    [anon_sym_true] = ACTIONS(490),
    [anon_sym_false] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(490),
    [anon_sym_function] = ACTIONS(490),
    [anon_sym_byte] = ACTIONS(490),
    [anon_sym_address] = ACTIONS(490),
    [anon_sym_return] = ACTIONS(490),
    [anon_sym_revert] = ACTIONS(490),
    [sym__unchecked] = ACTIONS(490),
    [anon_sym_var] = ACTIONS(490),
    [anon_sym_else] = ACTIONS(490),
    [anon_sym_while] = ACTIONS(490),
    [anon_sym_do] = ACTIONS(490),
    [anon_sym_try] = ACTIONS(490),
    [anon_sym_emit] = ACTIONS(490),
    [anon_sym_payable] = ACTIONS(490),
    [anon_sym_new] = ACTIONS(490),
    [anon_sym_LBRACK] = ACTIONS(492),
    [anon_sym_BANG] = ACTIONS(492),
    [anon_sym_delete] = ACTIONS(490),
    [anon_sym_PLUS_PLUS] = ACTIONS(492),
    [anon_sym_DASH_DASH] = ACTIONS(492),
    [anon_sym_mapping] = ACTIONS(490),
    [anon_sym_bool] = ACTIONS(490),
    [anon_sym_string] = ACTIONS(490),
    [anon_sym_int] = ACTIONS(490),
    [anon_sym_int8] = ACTIONS(490),
    [anon_sym_int16] = ACTIONS(490),
    [anon_sym_int24] = ACTIONS(490),
    [anon_sym_int32] = ACTIONS(490),
    [anon_sym_int40] = ACTIONS(490),
    [anon_sym_int48] = ACTIONS(490),
    [anon_sym_int56] = ACTIONS(490),
    [anon_sym_int64] = ACTIONS(490),
    [anon_sym_int72] = ACTIONS(490),
    [anon_sym_int80] = ACTIONS(490),
    [anon_sym_int88] = ACTIONS(490),
    [anon_sym_int96] = ACTIONS(490),
    [anon_sym_int104] = ACTIONS(490),
    [anon_sym_int112] = ACTIONS(490),
    [anon_sym_int120] = ACTIONS(490),
    [anon_sym_int128] = ACTIONS(490),
    [anon_sym_int136] = ACTIONS(490),
    [anon_sym_int144] = ACTIONS(490),
    [anon_sym_int152] = ACTIONS(490),
    [anon_sym_int160] = ACTIONS(490),
    [anon_sym_int168] = ACTIONS(490),
    [anon_sym_int176] = ACTIONS(490),
    [anon_sym_int184] = ACTIONS(490),
    [anon_sym_int192] = ACTIONS(490),
    [anon_sym_int200] = ACTIONS(490),
    [anon_sym_int208] = ACTIONS(490),
    [anon_sym_int216] = ACTIONS(490),
    [anon_sym_int224] = ACTIONS(490),
    [anon_sym_int232] = ACTIONS(490),
    [anon_sym_int240] = ACTIONS(490),
    [anon_sym_int248] = ACTIONS(490),
    [anon_sym_int256] = ACTIONS(490),
    [anon_sym_uint] = ACTIONS(490),
    [anon_sym_uint8] = ACTIONS(490),
    [anon_sym_uint16] = ACTIONS(490),
    [anon_sym_uint24] = ACTIONS(490),
    [anon_sym_uint32] = ACTIONS(490),
    [anon_sym_uint40] = ACTIONS(490),
    [anon_sym_uint48] = ACTIONS(490),
    [anon_sym_uint56] = ACTIONS(490),
    [anon_sym_uint64] = ACTIONS(490),
    [anon_sym_uint72] = ACTIONS(490),
    [anon_sym_uint80] = ACTIONS(490),
    [anon_sym_uint88] = ACTIONS(490),
    [anon_sym_uint96] = ACTIONS(490),
    [anon_sym_uint104] = ACTIONS(490),
    [anon_sym_uint112] = ACTIONS(490),
    [anon_sym_uint120] = ACTIONS(490),
    [anon_sym_uint128] = ACTIONS(490),
    [anon_sym_uint136] = ACTIONS(490),
    [anon_sym_uint144] = ACTIONS(490),
    [anon_sym_uint152] = ACTIONS(490),
    [anon_sym_uint160] = ACTIONS(490),
    [anon_sym_uint168] = ACTIONS(490),
    [anon_sym_uint176] = ACTIONS(490),
    [anon_sym_uint184] = ACTIONS(490),
    [anon_sym_uint192] = ACTIONS(490),
    [anon_sym_uint200] = ACTIONS(490),
    [anon_sym_uint208] = ACTIONS(490),
    [anon_sym_uint216] = ACTIONS(490),
    [anon_sym_uint224] = ACTIONS(490),
    [anon_sym_uint232] = ACTIONS(490),
    [anon_sym_uint240] = ACTIONS(490),
    [anon_sym_uint248] = ACTIONS(490),
    [anon_sym_uint256] = ACTIONS(490),
    [anon_sym_bytes] = ACTIONS(490),
    [anon_sym_bytes1] = ACTIONS(490),
    [anon_sym_bytes2] = ACTIONS(490),
    [anon_sym_bytes3] = ACTIONS(490),
    [anon_sym_bytes4] = ACTIONS(490),
    [anon_sym_bytes5] = ACTIONS(490),
    [anon_sym_bytes6] = ACTIONS(490),
    [anon_sym_bytes7] = ACTIONS(490),
    [anon_sym_bytes8] = ACTIONS(490),
    [anon_sym_bytes9] = ACTIONS(490),
    [anon_sym_bytes10] = ACTIONS(490),
    [anon_sym_bytes11] = ACTIONS(490),
    [anon_sym_bytes12] = ACTIONS(490),
    [anon_sym_bytes13] = ACTIONS(490),
    [anon_sym_bytes14] = ACTIONS(490),
    [anon_sym_bytes15] = ACTIONS(490),
    [anon_sym_bytes16] = ACTIONS(490),
    [anon_sym_bytes17] = ACTIONS(490),
    [anon_sym_bytes18] = ACTIONS(490),
    [anon_sym_bytes19] = ACTIONS(490),
    [anon_sym_bytes20] = ACTIONS(490),
    [anon_sym_bytes21] = ACTIONS(490),
    [anon_sym_bytes22] = ACTIONS(490),
    [anon_sym_bytes23] = ACTIONS(490),
    [anon_sym_bytes24] = ACTIONS(490),
    [anon_sym_bytes25] = ACTIONS(490),
    [anon_sym_bytes26] = ACTIONS(490),
    [anon_sym_bytes27] = ACTIONS(490),
    [anon_sym_bytes28] = ACTIONS(490),
    [anon_sym_bytes29] = ACTIONS(490),
    [anon_sym_bytes30] = ACTIONS(490),
    [anon_sym_bytes31] = ACTIONS(490),
    [anon_sym_bytes32] = ACTIONS(490),
    [anon_sym_fixed] = ACTIONS(490),
    [aux_sym__fixed_token1] = ACTIONS(490),
    [anon_sym_ufixed] = ACTIONS(490),
    [aux_sym__ufixed_token1] = ACTIONS(490),
    [aux_sym__decimal_number_token1] = ACTIONS(490),
    [aux_sym__decimal_number_token2] = ACTIONS(492),
    [aux_sym__hex_number_token1] = ACTIONS(492),
    [anon_sym_hex] = ACTIONS(490),
    [anon_sym_DQUOTE] = ACTIONS(492),
    [anon_sym_SQUOTE] = ACTIONS(492),
    [anon_sym_unicode] = ACTIONS(490),
    [sym_comment] = ACTIONS(3),
  },
  [91] = {
    [sym_identifier] = ACTIONS(494),
    [anon_sym_DASH] = ACTIONS(494),
    [anon_sym_TILDE] = ACTIONS(496),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_RBRACE] = ACTIONS(496),
    [anon_sym_type] = ACTIONS(494),
    [anon_sym_LPAREN] = ACTIONS(496),
    [anon_sym_for] = ACTIONS(494),
    [anon_sym_PLUS] = ACTIONS(494),
    [anon_sym_assembly] = ACTIONS(494),
    [anon_sym_break] = ACTIONS(494),
    [anon_sym_continue] = ACTIONS(494),
    [anon_sym_true] = ACTIONS(494),
    [anon_sym_false] = ACTIONS(494),
    [anon_sym_if] = ACTIONS(494),
    [anon_sym_function] = ACTIONS(494),
    [anon_sym_byte] = ACTIONS(494),
    [anon_sym_address] = ACTIONS(494),
    [anon_sym_return] = ACTIONS(494),
    [anon_sym_revert] = ACTIONS(494),
    [sym__unchecked] = ACTIONS(494),
    [anon_sym_var] = ACTIONS(494),
    [anon_sym_else] = ACTIONS(494),
    [anon_sym_while] = ACTIONS(494),
    [anon_sym_do] = ACTIONS(494),
    [anon_sym_try] = ACTIONS(494),
    [anon_sym_emit] = ACTIONS(494),
    [anon_sym_payable] = ACTIONS(494),
    [anon_sym_new] = ACTIONS(494),
    [anon_sym_LBRACK] = ACTIONS(496),
    [anon_sym_BANG] = ACTIONS(496),
    [anon_sym_delete] = ACTIONS(494),
    [anon_sym_PLUS_PLUS] = ACTIONS(496),
    [anon_sym_DASH_DASH] = ACTIONS(496),
    [anon_sym_mapping] = ACTIONS(494),
    [anon_sym_bool] = ACTIONS(494),
    [anon_sym_string] = ACTIONS(494),
    [anon_sym_int] = ACTIONS(494),
    [anon_sym_int8] = ACTIONS(494),
    [anon_sym_int16] = ACTIONS(494),
    [anon_sym_int24] = ACTIONS(494),
    [anon_sym_int32] = ACTIONS(494),
    [anon_sym_int40] = ACTIONS(494),
    [anon_sym_int48] = ACTIONS(494),
    [anon_sym_int56] = ACTIONS(494),
    [anon_sym_int64] = ACTIONS(494),
    [anon_sym_int72] = ACTIONS(494),
    [anon_sym_int80] = ACTIONS(494),
    [anon_sym_int88] = ACTIONS(494),
    [anon_sym_int96] = ACTIONS(494),
    [anon_sym_int104] = ACTIONS(494),
    [anon_sym_int112] = ACTIONS(494),
    [anon_sym_int120] = ACTIONS(494),
    [anon_sym_int128] = ACTIONS(494),
    [anon_sym_int136] = ACTIONS(494),
    [anon_sym_int144] = ACTIONS(494),
    [anon_sym_int152] = ACTIONS(494),
    [anon_sym_int160] = ACTIONS(494),
    [anon_sym_int168] = ACTIONS(494),
    [anon_sym_int176] = ACTIONS(494),
    [anon_sym_int184] = ACTIONS(494),
    [anon_sym_int192] = ACTIONS(494),
    [anon_sym_int200] = ACTIONS(494),
    [anon_sym_int208] = ACTIONS(494),
    [anon_sym_int216] = ACTIONS(494),
    [anon_sym_int224] = ACTIONS(494),
    [anon_sym_int232] = ACTIONS(494),
    [anon_sym_int240] = ACTIONS(494),
    [anon_sym_int248] = ACTIONS(494),
    [anon_sym_int256] = ACTIONS(494),
    [anon_sym_uint] = ACTIONS(494),
    [anon_sym_uint8] = ACTIONS(494),
    [anon_sym_uint16] = ACTIONS(494),
    [anon_sym_uint24] = ACTIONS(494),
    [anon_sym_uint32] = ACTIONS(494),
    [anon_sym_uint40] = ACTIONS(494),
    [anon_sym_uint48] = ACTIONS(494),
    [anon_sym_uint56] = ACTIONS(494),
    [anon_sym_uint64] = ACTIONS(494),
    [anon_sym_uint72] = ACTIONS(494),
    [anon_sym_uint80] = ACTIONS(494),
    [anon_sym_uint88] = ACTIONS(494),
    [anon_sym_uint96] = ACTIONS(494),
    [anon_sym_uint104] = ACTIONS(494),
    [anon_sym_uint112] = ACTIONS(494),
    [anon_sym_uint120] = ACTIONS(494),
    [anon_sym_uint128] = ACTIONS(494),
    [anon_sym_uint136] = ACTIONS(494),
    [anon_sym_uint144] = ACTIONS(494),
    [anon_sym_uint152] = ACTIONS(494),
    [anon_sym_uint160] = ACTIONS(494),
    [anon_sym_uint168] = ACTIONS(494),
    [anon_sym_uint176] = ACTIONS(494),
    [anon_sym_uint184] = ACTIONS(494),
    [anon_sym_uint192] = ACTIONS(494),
    [anon_sym_uint200] = ACTIONS(494),
    [anon_sym_uint208] = ACTIONS(494),
    [anon_sym_uint216] = ACTIONS(494),
    [anon_sym_uint224] = ACTIONS(494),
    [anon_sym_uint232] = ACTIONS(494),
    [anon_sym_uint240] = ACTIONS(494),
    [anon_sym_uint248] = ACTIONS(494),
    [anon_sym_uint256] = ACTIONS(494),
    [anon_sym_bytes] = ACTIONS(494),
    [anon_sym_bytes1] = ACTIONS(494),
    [anon_sym_bytes2] = ACTIONS(494),
    [anon_sym_bytes3] = ACTIONS(494),
    [anon_sym_bytes4] = ACTIONS(494),
    [anon_sym_bytes5] = ACTIONS(494),
    [anon_sym_bytes6] = ACTIONS(494),
    [anon_sym_bytes7] = ACTIONS(494),
    [anon_sym_bytes8] = ACTIONS(494),
    [anon_sym_bytes9] = ACTIONS(494),
    [anon_sym_bytes10] = ACTIONS(494),
    [anon_sym_bytes11] = ACTIONS(494),
    [anon_sym_bytes12] = ACTIONS(494),
    [anon_sym_bytes13] = ACTIONS(494),
    [anon_sym_bytes14] = ACTIONS(494),
    [anon_sym_bytes15] = ACTIONS(494),
    [anon_sym_bytes16] = ACTIONS(494),
    [anon_sym_bytes17] = ACTIONS(494),
    [anon_sym_bytes18] = ACTIONS(494),
    [anon_sym_bytes19] = ACTIONS(494),
    [anon_sym_bytes20] = ACTIONS(494),
    [anon_sym_bytes21] = ACTIONS(494),
    [anon_sym_bytes22] = ACTIONS(494),
    [anon_sym_bytes23] = ACTIONS(494),
    [anon_sym_bytes24] = ACTIONS(494),
    [anon_sym_bytes25] = ACTIONS(494),
    [anon_sym_bytes26] = ACTIONS(494),
    [anon_sym_bytes27] = ACTIONS(494),
    [anon_sym_bytes28] = ACTIONS(494),
    [anon_sym_bytes29] = ACTIONS(494),
    [anon_sym_bytes30] = ACTIONS(494),
    [anon_sym_bytes31] = ACTIONS(494),
    [anon_sym_bytes32] = ACTIONS(494),
    [anon_sym_fixed] = ACTIONS(494),
    [aux_sym__fixed_token1] = ACTIONS(494),
    [anon_sym_ufixed] = ACTIONS(494),
    [aux_sym__ufixed_token1] = ACTIONS(494),
    [aux_sym__decimal_number_token1] = ACTIONS(494),
    [aux_sym__decimal_number_token2] = ACTIONS(496),
    [aux_sym__hex_number_token1] = ACTIONS(496),
    [anon_sym_hex] = ACTIONS(494),
    [anon_sym_DQUOTE] = ACTIONS(496),
    [anon_sym_SQUOTE] = ACTIONS(496),
    [anon_sym_unicode] = ACTIONS(494),
    [sym_comment] = ACTIONS(3),
  },
  [92] = {
    [sym_identifier] = ACTIONS(498),
    [anon_sym_DASH] = ACTIONS(498),
    [anon_sym_TILDE] = ACTIONS(500),
    [anon_sym_LBRACE] = ACTIONS(500),
    [anon_sym_RBRACE] = ACTIONS(500),
    [anon_sym_type] = ACTIONS(498),
    [anon_sym_LPAREN] = ACTIONS(500),
    [anon_sym_for] = ACTIONS(498),
    [anon_sym_PLUS] = ACTIONS(498),
    [anon_sym_assembly] = ACTIONS(498),
    [anon_sym_break] = ACTIONS(498),
    [anon_sym_continue] = ACTIONS(498),
    [anon_sym_true] = ACTIONS(498),
    [anon_sym_false] = ACTIONS(498),
    [anon_sym_if] = ACTIONS(498),
    [anon_sym_function] = ACTIONS(498),
    [anon_sym_byte] = ACTIONS(498),
    [anon_sym_address] = ACTIONS(498),
    [anon_sym_return] = ACTIONS(498),
    [anon_sym_revert] = ACTIONS(498),
    [sym__unchecked] = ACTIONS(498),
    [anon_sym_var] = ACTIONS(498),
    [anon_sym_else] = ACTIONS(498),
    [anon_sym_while] = ACTIONS(498),
    [anon_sym_do] = ACTIONS(498),
    [anon_sym_try] = ACTIONS(498),
    [anon_sym_emit] = ACTIONS(498),
    [anon_sym_payable] = ACTIONS(498),
    [anon_sym_new] = ACTIONS(498),
    [anon_sym_LBRACK] = ACTIONS(500),
    [anon_sym_BANG] = ACTIONS(500),
    [anon_sym_delete] = ACTIONS(498),
    [anon_sym_PLUS_PLUS] = ACTIONS(500),
    [anon_sym_DASH_DASH] = ACTIONS(500),
    [anon_sym_mapping] = ACTIONS(498),
    [anon_sym_bool] = ACTIONS(498),
    [anon_sym_string] = ACTIONS(498),
    [anon_sym_int] = ACTIONS(498),
    [anon_sym_int8] = ACTIONS(498),
    [anon_sym_int16] = ACTIONS(498),
    [anon_sym_int24] = ACTIONS(498),
    [anon_sym_int32] = ACTIONS(498),
    [anon_sym_int40] = ACTIONS(498),
    [anon_sym_int48] = ACTIONS(498),
    [anon_sym_int56] = ACTIONS(498),
    [anon_sym_int64] = ACTIONS(498),
    [anon_sym_int72] = ACTIONS(498),
    [anon_sym_int80] = ACTIONS(498),
    [anon_sym_int88] = ACTIONS(498),
    [anon_sym_int96] = ACTIONS(498),
    [anon_sym_int104] = ACTIONS(498),
    [anon_sym_int112] = ACTIONS(498),
    [anon_sym_int120] = ACTIONS(498),
    [anon_sym_int128] = ACTIONS(498),
    [anon_sym_int136] = ACTIONS(498),
    [anon_sym_int144] = ACTIONS(498),
    [anon_sym_int152] = ACTIONS(498),
    [anon_sym_int160] = ACTIONS(498),
    [anon_sym_int168] = ACTIONS(498),
    [anon_sym_int176] = ACTIONS(498),
    [anon_sym_int184] = ACTIONS(498),
    [anon_sym_int192] = ACTIONS(498),
    [anon_sym_int200] = ACTIONS(498),
    [anon_sym_int208] = ACTIONS(498),
    [anon_sym_int216] = ACTIONS(498),
    [anon_sym_int224] = ACTIONS(498),
    [anon_sym_int232] = ACTIONS(498),
    [anon_sym_int240] = ACTIONS(498),
    [anon_sym_int248] = ACTIONS(498),
    [anon_sym_int256] = ACTIONS(498),
    [anon_sym_uint] = ACTIONS(498),
    [anon_sym_uint8] = ACTIONS(498),
    [anon_sym_uint16] = ACTIONS(498),
    [anon_sym_uint24] = ACTIONS(498),
    [anon_sym_uint32] = ACTIONS(498),
    [anon_sym_uint40] = ACTIONS(498),
    [anon_sym_uint48] = ACTIONS(498),
    [anon_sym_uint56] = ACTIONS(498),
    [anon_sym_uint64] = ACTIONS(498),
    [anon_sym_uint72] = ACTIONS(498),
    [anon_sym_uint80] = ACTIONS(498),
    [anon_sym_uint88] = ACTIONS(498),
    [anon_sym_uint96] = ACTIONS(498),
    [anon_sym_uint104] = ACTIONS(498),
    [anon_sym_uint112] = ACTIONS(498),
    [anon_sym_uint120] = ACTIONS(498),
    [anon_sym_uint128] = ACTIONS(498),
    [anon_sym_uint136] = ACTIONS(498),
    [anon_sym_uint144] = ACTIONS(498),
    [anon_sym_uint152] = ACTIONS(498),
    [anon_sym_uint160] = ACTIONS(498),
    [anon_sym_uint168] = ACTIONS(498),
    [anon_sym_uint176] = ACTIONS(498),
    [anon_sym_uint184] = ACTIONS(498),
    [anon_sym_uint192] = ACTIONS(498),
    [anon_sym_uint200] = ACTIONS(498),
    [anon_sym_uint208] = ACTIONS(498),
    [anon_sym_uint216] = ACTIONS(498),
    [anon_sym_uint224] = ACTIONS(498),
    [anon_sym_uint232] = ACTIONS(498),
    [anon_sym_uint240] = ACTIONS(498),
    [anon_sym_uint248] = ACTIONS(498),
    [anon_sym_uint256] = ACTIONS(498),
    [anon_sym_bytes] = ACTIONS(498),
    [anon_sym_bytes1] = ACTIONS(498),
    [anon_sym_bytes2] = ACTIONS(498),
    [anon_sym_bytes3] = ACTIONS(498),
    [anon_sym_bytes4] = ACTIONS(498),
    [anon_sym_bytes5] = ACTIONS(498),
    [anon_sym_bytes6] = ACTIONS(498),
    [anon_sym_bytes7] = ACTIONS(498),
    [anon_sym_bytes8] = ACTIONS(498),
    [anon_sym_bytes9] = ACTIONS(498),
    [anon_sym_bytes10] = ACTIONS(498),
    [anon_sym_bytes11] = ACTIONS(498),
    [anon_sym_bytes12] = ACTIONS(498),
    [anon_sym_bytes13] = ACTIONS(498),
    [anon_sym_bytes14] = ACTIONS(498),
    [anon_sym_bytes15] = ACTIONS(498),
    [anon_sym_bytes16] = ACTIONS(498),
    [anon_sym_bytes17] = ACTIONS(498),
    [anon_sym_bytes18] = ACTIONS(498),
    [anon_sym_bytes19] = ACTIONS(498),
    [anon_sym_bytes20] = ACTIONS(498),
    [anon_sym_bytes21] = ACTIONS(498),
    [anon_sym_bytes22] = ACTIONS(498),
    [anon_sym_bytes23] = ACTIONS(498),
    [anon_sym_bytes24] = ACTIONS(498),
    [anon_sym_bytes25] = ACTIONS(498),
    [anon_sym_bytes26] = ACTIONS(498),
    [anon_sym_bytes27] = ACTIONS(498),
    [anon_sym_bytes28] = ACTIONS(498),
    [anon_sym_bytes29] = ACTIONS(498),
    [anon_sym_bytes30] = ACTIONS(498),
    [anon_sym_bytes31] = ACTIONS(498),
    [anon_sym_bytes32] = ACTIONS(498),
    [anon_sym_fixed] = ACTIONS(498),
    [aux_sym__fixed_token1] = ACTIONS(498),
    [anon_sym_ufixed] = ACTIONS(498),
    [aux_sym__ufixed_token1] = ACTIONS(498),
    [aux_sym__decimal_number_token1] = ACTIONS(498),
    [aux_sym__decimal_number_token2] = ACTIONS(500),
    [aux_sym__hex_number_token1] = ACTIONS(500),
    [anon_sym_hex] = ACTIONS(498),
    [anon_sym_DQUOTE] = ACTIONS(500),
    [anon_sym_SQUOTE] = ACTIONS(500),
    [anon_sym_unicode] = ACTIONS(498),
    [sym_comment] = ACTIONS(3),
  },
  [93] = {
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_type] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_PLUS] = ACTIONS(502),
    [anon_sym_assembly] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_true] = ACTIONS(502),
    [anon_sym_false] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_function] = ACTIONS(502),
    [anon_sym_byte] = ACTIONS(502),
    [anon_sym_address] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_revert] = ACTIONS(502),
    [sym__unchecked] = ACTIONS(502),
    [anon_sym_var] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_try] = ACTIONS(502),
    [anon_sym_emit] = ACTIONS(502),
    [anon_sym_payable] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_LBRACK] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(504),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_PLUS_PLUS] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(504),
    [anon_sym_mapping] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_string] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_int8] = ACTIONS(502),
    [anon_sym_int16] = ACTIONS(502),
    [anon_sym_int24] = ACTIONS(502),
    [anon_sym_int32] = ACTIONS(502),
    [anon_sym_int40] = ACTIONS(502),
    [anon_sym_int48] = ACTIONS(502),
    [anon_sym_int56] = ACTIONS(502),
    [anon_sym_int64] = ACTIONS(502),
    [anon_sym_int72] = ACTIONS(502),
    [anon_sym_int80] = ACTIONS(502),
    [anon_sym_int88] = ACTIONS(502),
    [anon_sym_int96] = ACTIONS(502),
    [anon_sym_int104] = ACTIONS(502),
    [anon_sym_int112] = ACTIONS(502),
    [anon_sym_int120] = ACTIONS(502),
    [anon_sym_int128] = ACTIONS(502),
    [anon_sym_int136] = ACTIONS(502),
    [anon_sym_int144] = ACTIONS(502),
    [anon_sym_int152] = ACTIONS(502),
    [anon_sym_int160] = ACTIONS(502),
    [anon_sym_int168] = ACTIONS(502),
    [anon_sym_int176] = ACTIONS(502),
    [anon_sym_int184] = ACTIONS(502),
    [anon_sym_int192] = ACTIONS(502),
    [anon_sym_int200] = ACTIONS(502),
    [anon_sym_int208] = ACTIONS(502),
    [anon_sym_int216] = ACTIONS(502),
    [anon_sym_int224] = ACTIONS(502),
    [anon_sym_int232] = ACTIONS(502),
    [anon_sym_int240] = ACTIONS(502),
    [anon_sym_int248] = ACTIONS(502),
    [anon_sym_int256] = ACTIONS(502),
    [anon_sym_uint] = ACTIONS(502),
    [anon_sym_uint8] = ACTIONS(502),
    [anon_sym_uint16] = ACTIONS(502),
    [anon_sym_uint24] = ACTIONS(502),
    [anon_sym_uint32] = ACTIONS(502),
    [anon_sym_uint40] = ACTIONS(502),
    [anon_sym_uint48] = ACTIONS(502),
    [anon_sym_uint56] = ACTIONS(502),
    [anon_sym_uint64] = ACTIONS(502),
    [anon_sym_uint72] = ACTIONS(502),
    [anon_sym_uint80] = ACTIONS(502),
    [anon_sym_uint88] = ACTIONS(502),
    [anon_sym_uint96] = ACTIONS(502),
    [anon_sym_uint104] = ACTIONS(502),
    [anon_sym_uint112] = ACTIONS(502),
    [anon_sym_uint120] = ACTIONS(502),
    [anon_sym_uint128] = ACTIONS(502),
    [anon_sym_uint136] = ACTIONS(502),
    [anon_sym_uint144] = ACTIONS(502),
    [anon_sym_uint152] = ACTIONS(502),
    [anon_sym_uint160] = ACTIONS(502),
    [anon_sym_uint168] = ACTIONS(502),
    [anon_sym_uint176] = ACTIONS(502),
    [anon_sym_uint184] = ACTIONS(502),
    [anon_sym_uint192] = ACTIONS(502),
    [anon_sym_uint200] = ACTIONS(502),
    [anon_sym_uint208] = ACTIONS(502),
    [anon_sym_uint216] = ACTIONS(502),
    [anon_sym_uint224] = ACTIONS(502),
    [anon_sym_uint232] = ACTIONS(502),
    [anon_sym_uint240] = ACTIONS(502),
    [anon_sym_uint248] = ACTIONS(502),
    [anon_sym_uint256] = ACTIONS(502),
    [anon_sym_bytes] = ACTIONS(502),
    [anon_sym_bytes1] = ACTIONS(502),
    [anon_sym_bytes2] = ACTIONS(502),
    [anon_sym_bytes3] = ACTIONS(502),
    [anon_sym_bytes4] = ACTIONS(502),
    [anon_sym_bytes5] = ACTIONS(502),
    [anon_sym_bytes6] = ACTIONS(502),
    [anon_sym_bytes7] = ACTIONS(502),
    [anon_sym_bytes8] = ACTIONS(502),
    [anon_sym_bytes9] = ACTIONS(502),
    [anon_sym_bytes10] = ACTIONS(502),
    [anon_sym_bytes11] = ACTIONS(502),
    [anon_sym_bytes12] = ACTIONS(502),
    [anon_sym_bytes13] = ACTIONS(502),
    [anon_sym_bytes14] = ACTIONS(502),
    [anon_sym_bytes15] = ACTIONS(502),
    [anon_sym_bytes16] = ACTIONS(502),
    [anon_sym_bytes17] = ACTIONS(502),
    [anon_sym_bytes18] = ACTIONS(502),
    [anon_sym_bytes19] = ACTIONS(502),
    [anon_sym_bytes20] = ACTIONS(502),
    [anon_sym_bytes21] = ACTIONS(502),
    [anon_sym_bytes22] = ACTIONS(502),
    [anon_sym_bytes23] = ACTIONS(502),
    [anon_sym_bytes24] = ACTIONS(502),
    [anon_sym_bytes25] = ACTIONS(502),
    [anon_sym_bytes26] = ACTIONS(502),
    [anon_sym_bytes27] = ACTIONS(502),
    [anon_sym_bytes28] = ACTIONS(502),
    [anon_sym_bytes29] = ACTIONS(502),
    [anon_sym_bytes30] = ACTIONS(502),
    [anon_sym_bytes31] = ACTIONS(502),
    [anon_sym_bytes32] = ACTIONS(502),
    [anon_sym_fixed] = ACTIONS(502),
    [aux_sym__fixed_token1] = ACTIONS(502),
    [anon_sym_ufixed] = ACTIONS(502),
    [aux_sym__ufixed_token1] = ACTIONS(502),
    [aux_sym__decimal_number_token1] = ACTIONS(502),
    [aux_sym__decimal_number_token2] = ACTIONS(504),
    [aux_sym__hex_number_token1] = ACTIONS(504),
    [anon_sym_hex] = ACTIONS(502),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_unicode] = ACTIONS(502),
    [sym_comment] = ACTIONS(3),
  },
  [94] = {
    [sym_identifier] = ACTIONS(506),
    [anon_sym_DASH] = ACTIONS(506),
    [anon_sym_TILDE] = ACTIONS(508),
    [anon_sym_LBRACE] = ACTIONS(508),
    [anon_sym_RBRACE] = ACTIONS(508),
    [anon_sym_type] = ACTIONS(506),
    [anon_sym_LPAREN] = ACTIONS(508),
    [anon_sym_for] = ACTIONS(506),
    [anon_sym_PLUS] = ACTIONS(506),
    [anon_sym_assembly] = ACTIONS(506),
    [anon_sym_break] = ACTIONS(506),
    [anon_sym_continue] = ACTIONS(506),
    [anon_sym_true] = ACTIONS(506),
    [anon_sym_false] = ACTIONS(506),
    [anon_sym_if] = ACTIONS(506),
    [anon_sym_function] = ACTIONS(506),
    [anon_sym_byte] = ACTIONS(506),
    [anon_sym_address] = ACTIONS(506),
    [anon_sym_return] = ACTIONS(506),
    [anon_sym_revert] = ACTIONS(506),
    [sym__unchecked] = ACTIONS(506),
    [anon_sym_var] = ACTIONS(506),
    [anon_sym_else] = ACTIONS(506),
    [anon_sym_while] = ACTIONS(506),
    [anon_sym_do] = ACTIONS(506),
    [anon_sym_try] = ACTIONS(506),
    [anon_sym_emit] = ACTIONS(506),
    [anon_sym_payable] = ACTIONS(506),
    [anon_sym_new] = ACTIONS(506),
    [anon_sym_LBRACK] = ACTIONS(508),
    [anon_sym_BANG] = ACTIONS(508),
    [anon_sym_delete] = ACTIONS(506),
    [anon_sym_PLUS_PLUS] = ACTIONS(508),
    [anon_sym_DASH_DASH] = ACTIONS(508),
    [anon_sym_mapping] = ACTIONS(506),
    [anon_sym_bool] = ACTIONS(506),
    [anon_sym_string] = ACTIONS(506),
    [anon_sym_int] = ACTIONS(506),
    [anon_sym_int8] = ACTIONS(506),
    [anon_sym_int16] = ACTIONS(506),
    [anon_sym_int24] = ACTIONS(506),
    [anon_sym_int32] = ACTIONS(506),
    [anon_sym_int40] = ACTIONS(506),
    [anon_sym_int48] = ACTIONS(506),
    [anon_sym_int56] = ACTIONS(506),
    [anon_sym_int64] = ACTIONS(506),
    [anon_sym_int72] = ACTIONS(506),
    [anon_sym_int80] = ACTIONS(506),
    [anon_sym_int88] = ACTIONS(506),
    [anon_sym_int96] = ACTIONS(506),
    [anon_sym_int104] = ACTIONS(506),
    [anon_sym_int112] = ACTIONS(506),
    [anon_sym_int120] = ACTIONS(506),
    [anon_sym_int128] = ACTIONS(506),
    [anon_sym_int136] = ACTIONS(506),
    [anon_sym_int144] = ACTIONS(506),
    [anon_sym_int152] = ACTIONS(506),
    [anon_sym_int160] = ACTIONS(506),
    [anon_sym_int168] = ACTIONS(506),
    [anon_sym_int176] = ACTIONS(506),
    [anon_sym_int184] = ACTIONS(506),
    [anon_sym_int192] = ACTIONS(506),
    [anon_sym_int200] = ACTIONS(506),
    [anon_sym_int208] = ACTIONS(506),
    [anon_sym_int216] = ACTIONS(506),
    [anon_sym_int224] = ACTIONS(506),
    [anon_sym_int232] = ACTIONS(506),
    [anon_sym_int240] = ACTIONS(506),
    [anon_sym_int248] = ACTIONS(506),
    [anon_sym_int256] = ACTIONS(506),
    [anon_sym_uint] = ACTIONS(506),
    [anon_sym_uint8] = ACTIONS(506),
    [anon_sym_uint16] = ACTIONS(506),
    [anon_sym_uint24] = ACTIONS(506),
    [anon_sym_uint32] = ACTIONS(506),
    [anon_sym_uint40] = ACTIONS(506),
    [anon_sym_uint48] = ACTIONS(506),
    [anon_sym_uint56] = ACTIONS(506),
    [anon_sym_uint64] = ACTIONS(506),
    [anon_sym_uint72] = ACTIONS(506),
    [anon_sym_uint80] = ACTIONS(506),
    [anon_sym_uint88] = ACTIONS(506),
    [anon_sym_uint96] = ACTIONS(506),
    [anon_sym_uint104] = ACTIONS(506),
    [anon_sym_uint112] = ACTIONS(506),
    [anon_sym_uint120] = ACTIONS(506),
    [anon_sym_uint128] = ACTIONS(506),
    [anon_sym_uint136] = ACTIONS(506),
    [anon_sym_uint144] = ACTIONS(506),
    [anon_sym_uint152] = ACTIONS(506),
    [anon_sym_uint160] = ACTIONS(506),
    [anon_sym_uint168] = ACTIONS(506),
    [anon_sym_uint176] = ACTIONS(506),
    [anon_sym_uint184] = ACTIONS(506),
    [anon_sym_uint192] = ACTIONS(506),
    [anon_sym_uint200] = ACTIONS(506),
    [anon_sym_uint208] = ACTIONS(506),
    [anon_sym_uint216] = ACTIONS(506),
    [anon_sym_uint224] = ACTIONS(506),
    [anon_sym_uint232] = ACTIONS(506),
    [anon_sym_uint240] = ACTIONS(506),
    [anon_sym_uint248] = ACTIONS(506),
    [anon_sym_uint256] = ACTIONS(506),
    [anon_sym_bytes] = ACTIONS(506),
    [anon_sym_bytes1] = ACTIONS(506),
    [anon_sym_bytes2] = ACTIONS(506),
    [anon_sym_bytes3] = ACTIONS(506),
    [anon_sym_bytes4] = ACTIONS(506),
    [anon_sym_bytes5] = ACTIONS(506),
    [anon_sym_bytes6] = ACTIONS(506),
    [anon_sym_bytes7] = ACTIONS(506),
    [anon_sym_bytes8] = ACTIONS(506),
    [anon_sym_bytes9] = ACTIONS(506),
    [anon_sym_bytes10] = ACTIONS(506),
    [anon_sym_bytes11] = ACTIONS(506),
    [anon_sym_bytes12] = ACTIONS(506),
    [anon_sym_bytes13] = ACTIONS(506),
    [anon_sym_bytes14] = ACTIONS(506),
    [anon_sym_bytes15] = ACTIONS(506),
    [anon_sym_bytes16] = ACTIONS(506),
    [anon_sym_bytes17] = ACTIONS(506),
    [anon_sym_bytes18] = ACTIONS(506),
    [anon_sym_bytes19] = ACTIONS(506),
    [anon_sym_bytes20] = ACTIONS(506),
    [anon_sym_bytes21] = ACTIONS(506),
    [anon_sym_bytes22] = ACTIONS(506),
    [anon_sym_bytes23] = ACTIONS(506),
    [anon_sym_bytes24] = ACTIONS(506),
    [anon_sym_bytes25] = ACTIONS(506),
    [anon_sym_bytes26] = ACTIONS(506),
    [anon_sym_bytes27] = ACTIONS(506),
    [anon_sym_bytes28] = ACTIONS(506),
    [anon_sym_bytes29] = ACTIONS(506),
    [anon_sym_bytes30] = ACTIONS(506),
    [anon_sym_bytes31] = ACTIONS(506),
    [anon_sym_bytes32] = ACTIONS(506),
    [anon_sym_fixed] = ACTIONS(506),
    [aux_sym__fixed_token1] = ACTIONS(506),
    [anon_sym_ufixed] = ACTIONS(506),
    [aux_sym__ufixed_token1] = ACTIONS(506),
    [aux_sym__decimal_number_token1] = ACTIONS(506),
    [aux_sym__decimal_number_token2] = ACTIONS(508),
    [aux_sym__hex_number_token1] = ACTIONS(508),
    [anon_sym_hex] = ACTIONS(506),
    [anon_sym_DQUOTE] = ACTIONS(508),
    [anon_sym_SQUOTE] = ACTIONS(508),
    [anon_sym_unicode] = ACTIONS(506),
    [sym_comment] = ACTIONS(3),
  },
  [95] = {
    [sym_identifier] = ACTIONS(510),
    [anon_sym_DASH] = ACTIONS(510),
    [anon_sym_TILDE] = ACTIONS(512),
    [anon_sym_LBRACE] = ACTIONS(512),
    [anon_sym_RBRACE] = ACTIONS(512),
    [anon_sym_type] = ACTIONS(510),
    [anon_sym_LPAREN] = ACTIONS(512),
    [anon_sym_for] = ACTIONS(510),
    [anon_sym_PLUS] = ACTIONS(510),
    [anon_sym_assembly] = ACTIONS(510),
    [anon_sym_break] = ACTIONS(510),
    [anon_sym_continue] = ACTIONS(510),
    [anon_sym_true] = ACTIONS(510),
    [anon_sym_false] = ACTIONS(510),
    [anon_sym_if] = ACTIONS(510),
    [anon_sym_function] = ACTIONS(510),
    [anon_sym_byte] = ACTIONS(510),
    [anon_sym_address] = ACTIONS(510),
    [anon_sym_return] = ACTIONS(510),
    [anon_sym_revert] = ACTIONS(510),
    [sym__unchecked] = ACTIONS(510),
    [anon_sym_var] = ACTIONS(510),
    [anon_sym_else] = ACTIONS(510),
    [anon_sym_while] = ACTIONS(510),
    [anon_sym_do] = ACTIONS(510),
    [anon_sym_try] = ACTIONS(510),
    [anon_sym_emit] = ACTIONS(510),
    [anon_sym_payable] = ACTIONS(510),
    [anon_sym_new] = ACTIONS(510),
    [anon_sym_LBRACK] = ACTIONS(512),
    [anon_sym_BANG] = ACTIONS(512),
    [anon_sym_delete] = ACTIONS(510),
    [anon_sym_PLUS_PLUS] = ACTIONS(512),
    [anon_sym_DASH_DASH] = ACTIONS(512),
    [anon_sym_mapping] = ACTIONS(510),
    [anon_sym_bool] = ACTIONS(510),
    [anon_sym_string] = ACTIONS(510),
    [anon_sym_int] = ACTIONS(510),
    [anon_sym_int8] = ACTIONS(510),
    [anon_sym_int16] = ACTIONS(510),
    [anon_sym_int24] = ACTIONS(510),
    [anon_sym_int32] = ACTIONS(510),
    [anon_sym_int40] = ACTIONS(510),
    [anon_sym_int48] = ACTIONS(510),
    [anon_sym_int56] = ACTIONS(510),
    [anon_sym_int64] = ACTIONS(510),
    [anon_sym_int72] = ACTIONS(510),
    [anon_sym_int80] = ACTIONS(510),
    [anon_sym_int88] = ACTIONS(510),
    [anon_sym_int96] = ACTIONS(510),
    [anon_sym_int104] = ACTIONS(510),
    [anon_sym_int112] = ACTIONS(510),
    [anon_sym_int120] = ACTIONS(510),
    [anon_sym_int128] = ACTIONS(510),
    [anon_sym_int136] = ACTIONS(510),
    [anon_sym_int144] = ACTIONS(510),
    [anon_sym_int152] = ACTIONS(510),
    [anon_sym_int160] = ACTIONS(510),
    [anon_sym_int168] = ACTIONS(510),
    [anon_sym_int176] = ACTIONS(510),
    [anon_sym_int184] = ACTIONS(510),
    [anon_sym_int192] = ACTIONS(510),
    [anon_sym_int200] = ACTIONS(510),
    [anon_sym_int208] = ACTIONS(510),
    [anon_sym_int216] = ACTIONS(510),
    [anon_sym_int224] = ACTIONS(510),
    [anon_sym_int232] = ACTIONS(510),
    [anon_sym_int240] = ACTIONS(510),
    [anon_sym_int248] = ACTIONS(510),
    [anon_sym_int256] = ACTIONS(510),
    [anon_sym_uint] = ACTIONS(510),
    [anon_sym_uint8] = ACTIONS(510),
    [anon_sym_uint16] = ACTIONS(510),
    [anon_sym_uint24] = ACTIONS(510),
    [anon_sym_uint32] = ACTIONS(510),
    [anon_sym_uint40] = ACTIONS(510),
    [anon_sym_uint48] = ACTIONS(510),
    [anon_sym_uint56] = ACTIONS(510),
    [anon_sym_uint64] = ACTIONS(510),
    [anon_sym_uint72] = ACTIONS(510),
    [anon_sym_uint80] = ACTIONS(510),
    [anon_sym_uint88] = ACTIONS(510),
    [anon_sym_uint96] = ACTIONS(510),
    [anon_sym_uint104] = ACTIONS(510),
    [anon_sym_uint112] = ACTIONS(510),
    [anon_sym_uint120] = ACTIONS(510),
    [anon_sym_uint128] = ACTIONS(510),
    [anon_sym_uint136] = ACTIONS(510),
    [anon_sym_uint144] = ACTIONS(510),
    [anon_sym_uint152] = ACTIONS(510),
    [anon_sym_uint160] = ACTIONS(510),
    [anon_sym_uint168] = ACTIONS(510),
    [anon_sym_uint176] = ACTIONS(510),
    [anon_sym_uint184] = ACTIONS(510),
    [anon_sym_uint192] = ACTIONS(510),
    [anon_sym_uint200] = ACTIONS(510),
    [anon_sym_uint208] = ACTIONS(510),
    [anon_sym_uint216] = ACTIONS(510),
    [anon_sym_uint224] = ACTIONS(510),
    [anon_sym_uint232] = ACTIONS(510),
    [anon_sym_uint240] = ACTIONS(510),
    [anon_sym_uint248] = ACTIONS(510),
    [anon_sym_uint256] = ACTIONS(510),
    [anon_sym_bytes] = ACTIONS(510),
    [anon_sym_bytes1] = ACTIONS(510),
    [anon_sym_bytes2] = ACTIONS(510),
    [anon_sym_bytes3] = ACTIONS(510),
    [anon_sym_bytes4] = ACTIONS(510),
    [anon_sym_bytes5] = ACTIONS(510),
    [anon_sym_bytes6] = ACTIONS(510),
    [anon_sym_bytes7] = ACTIONS(510),
    [anon_sym_bytes8] = ACTIONS(510),
    [anon_sym_bytes9] = ACTIONS(510),
    [anon_sym_bytes10] = ACTIONS(510),
    [anon_sym_bytes11] = ACTIONS(510),
    [anon_sym_bytes12] = ACTIONS(510),
    [anon_sym_bytes13] = ACTIONS(510),
    [anon_sym_bytes14] = ACTIONS(510),
    [anon_sym_bytes15] = ACTIONS(510),
    [anon_sym_bytes16] = ACTIONS(510),
    [anon_sym_bytes17] = ACTIONS(510),
    [anon_sym_bytes18] = ACTIONS(510),
    [anon_sym_bytes19] = ACTIONS(510),
    [anon_sym_bytes20] = ACTIONS(510),
    [anon_sym_bytes21] = ACTIONS(510),
    [anon_sym_bytes22] = ACTIONS(510),
    [anon_sym_bytes23] = ACTIONS(510),
    [anon_sym_bytes24] = ACTIONS(510),
    [anon_sym_bytes25] = ACTIONS(510),
    [anon_sym_bytes26] = ACTIONS(510),
    [anon_sym_bytes27] = ACTIONS(510),
    [anon_sym_bytes28] = ACTIONS(510),
    [anon_sym_bytes29] = ACTIONS(510),
    [anon_sym_bytes30] = ACTIONS(510),
    [anon_sym_bytes31] = ACTIONS(510),
    [anon_sym_bytes32] = ACTIONS(510),
    [anon_sym_fixed] = ACTIONS(510),
    [aux_sym__fixed_token1] = ACTIONS(510),
    [anon_sym_ufixed] = ACTIONS(510),
    [aux_sym__ufixed_token1] = ACTIONS(510),
    [aux_sym__decimal_number_token1] = ACTIONS(510),
    [aux_sym__decimal_number_token2] = ACTIONS(512),
    [aux_sym__hex_number_token1] = ACTIONS(512),
    [anon_sym_hex] = ACTIONS(510),
    [anon_sym_DQUOTE] = ACTIONS(512),
    [anon_sym_SQUOTE] = ACTIONS(512),
    [anon_sym_unicode] = ACTIONS(510),
    [sym_comment] = ACTIONS(3),
  },
  [96] = {
    [sym_identifier] = ACTIONS(514),
    [anon_sym_DASH] = ACTIONS(514),
    [anon_sym_TILDE] = ACTIONS(516),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_RBRACE] = ACTIONS(516),
    [anon_sym_type] = ACTIONS(514),
    [anon_sym_LPAREN] = ACTIONS(516),
    [anon_sym_for] = ACTIONS(514),
    [anon_sym_PLUS] = ACTIONS(514),
    [anon_sym_assembly] = ACTIONS(514),
    [anon_sym_break] = ACTIONS(514),
    [anon_sym_continue] = ACTIONS(514),
    [anon_sym_true] = ACTIONS(514),
    [anon_sym_false] = ACTIONS(514),
    [anon_sym_if] = ACTIONS(514),
    [anon_sym_function] = ACTIONS(514),
    [anon_sym_byte] = ACTIONS(514),
    [anon_sym_address] = ACTIONS(514),
    [anon_sym_return] = ACTIONS(514),
    [anon_sym_revert] = ACTIONS(514),
    [sym__unchecked] = ACTIONS(514),
    [anon_sym_var] = ACTIONS(514),
    [anon_sym_else] = ACTIONS(514),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_do] = ACTIONS(514),
    [anon_sym_try] = ACTIONS(514),
    [anon_sym_emit] = ACTIONS(514),
    [anon_sym_payable] = ACTIONS(514),
    [anon_sym_new] = ACTIONS(514),
    [anon_sym_LBRACK] = ACTIONS(516),
    [anon_sym_BANG] = ACTIONS(516),
    [anon_sym_delete] = ACTIONS(514),
    [anon_sym_PLUS_PLUS] = ACTIONS(516),
    [anon_sym_DASH_DASH] = ACTIONS(516),
    [anon_sym_mapping] = ACTIONS(514),
    [anon_sym_bool] = ACTIONS(514),
    [anon_sym_string] = ACTIONS(514),
    [anon_sym_int] = ACTIONS(514),
    [anon_sym_int8] = ACTIONS(514),
    [anon_sym_int16] = ACTIONS(514),
    [anon_sym_int24] = ACTIONS(514),
    [anon_sym_int32] = ACTIONS(514),
    [anon_sym_int40] = ACTIONS(514),
    [anon_sym_int48] = ACTIONS(514),
    [anon_sym_int56] = ACTIONS(514),
    [anon_sym_int64] = ACTIONS(514),
    [anon_sym_int72] = ACTIONS(514),
    [anon_sym_int80] = ACTIONS(514),
    [anon_sym_int88] = ACTIONS(514),
    [anon_sym_int96] = ACTIONS(514),
    [anon_sym_int104] = ACTIONS(514),
    [anon_sym_int112] = ACTIONS(514),
    [anon_sym_int120] = ACTIONS(514),
    [anon_sym_int128] = ACTIONS(514),
    [anon_sym_int136] = ACTIONS(514),
    [anon_sym_int144] = ACTIONS(514),
    [anon_sym_int152] = ACTIONS(514),
    [anon_sym_int160] = ACTIONS(514),
    [anon_sym_int168] = ACTIONS(514),
    [anon_sym_int176] = ACTIONS(514),
    [anon_sym_int184] = ACTIONS(514),
    [anon_sym_int192] = ACTIONS(514),
    [anon_sym_int200] = ACTIONS(514),
    [anon_sym_int208] = ACTIONS(514),
    [anon_sym_int216] = ACTIONS(514),
    [anon_sym_int224] = ACTIONS(514),
    [anon_sym_int232] = ACTIONS(514),
    [anon_sym_int240] = ACTIONS(514),
    [anon_sym_int248] = ACTIONS(514),
    [anon_sym_int256] = ACTIONS(514),
    [anon_sym_uint] = ACTIONS(514),
    [anon_sym_uint8] = ACTIONS(514),
    [anon_sym_uint16] = ACTIONS(514),
    [anon_sym_uint24] = ACTIONS(514),
    [anon_sym_uint32] = ACTIONS(514),
    [anon_sym_uint40] = ACTIONS(514),
    [anon_sym_uint48] = ACTIONS(514),
    [anon_sym_uint56] = ACTIONS(514),
    [anon_sym_uint64] = ACTIONS(514),
    [anon_sym_uint72] = ACTIONS(514),
    [anon_sym_uint80] = ACTIONS(514),
    [anon_sym_uint88] = ACTIONS(514),
    [anon_sym_uint96] = ACTIONS(514),
    [anon_sym_uint104] = ACTIONS(514),
    [anon_sym_uint112] = ACTIONS(514),
    [anon_sym_uint120] = ACTIONS(514),
    [anon_sym_uint128] = ACTIONS(514),
    [anon_sym_uint136] = ACTIONS(514),
    [anon_sym_uint144] = ACTIONS(514),
    [anon_sym_uint152] = ACTIONS(514),
    [anon_sym_uint160] = ACTIONS(514),
    [anon_sym_uint168] = ACTIONS(514),
    [anon_sym_uint176] = ACTIONS(514),
    [anon_sym_uint184] = ACTIONS(514),
    [anon_sym_uint192] = ACTIONS(514),
    [anon_sym_uint200] = ACTIONS(514),
    [anon_sym_uint208] = ACTIONS(514),
    [anon_sym_uint216] = ACTIONS(514),
    [anon_sym_uint224] = ACTIONS(514),
    [anon_sym_uint232] = ACTIONS(514),
    [anon_sym_uint240] = ACTIONS(514),
    [anon_sym_uint248] = ACTIONS(514),
    [anon_sym_uint256] = ACTIONS(514),
    [anon_sym_bytes] = ACTIONS(514),
    [anon_sym_bytes1] = ACTIONS(514),
    [anon_sym_bytes2] = ACTIONS(514),
    [anon_sym_bytes3] = ACTIONS(514),
    [anon_sym_bytes4] = ACTIONS(514),
    [anon_sym_bytes5] = ACTIONS(514),
    [anon_sym_bytes6] = ACTIONS(514),
    [anon_sym_bytes7] = ACTIONS(514),
    [anon_sym_bytes8] = ACTIONS(514),
    [anon_sym_bytes9] = ACTIONS(514),
    [anon_sym_bytes10] = ACTIONS(514),
    [anon_sym_bytes11] = ACTIONS(514),
    [anon_sym_bytes12] = ACTIONS(514),
    [anon_sym_bytes13] = ACTIONS(514),
    [anon_sym_bytes14] = ACTIONS(514),
    [anon_sym_bytes15] = ACTIONS(514),
    [anon_sym_bytes16] = ACTIONS(514),
    [anon_sym_bytes17] = ACTIONS(514),
    [anon_sym_bytes18] = ACTIONS(514),
    [anon_sym_bytes19] = ACTIONS(514),
    [anon_sym_bytes20] = ACTIONS(514),
    [anon_sym_bytes21] = ACTIONS(514),
    [anon_sym_bytes22] = ACTIONS(514),
    [anon_sym_bytes23] = ACTIONS(514),
    [anon_sym_bytes24] = ACTIONS(514),
    [anon_sym_bytes25] = ACTIONS(514),
    [anon_sym_bytes26] = ACTIONS(514),
    [anon_sym_bytes27] = ACTIONS(514),
    [anon_sym_bytes28] = ACTIONS(514),
    [anon_sym_bytes29] = ACTIONS(514),
    [anon_sym_bytes30] = ACTIONS(514),
    [anon_sym_bytes31] = ACTIONS(514),
    [anon_sym_bytes32] = ACTIONS(514),
    [anon_sym_fixed] = ACTIONS(514),
    [aux_sym__fixed_token1] = ACTIONS(514),
    [anon_sym_ufixed] = ACTIONS(514),
    [aux_sym__ufixed_token1] = ACTIONS(514),
    [aux_sym__decimal_number_token1] = ACTIONS(514),
    [aux_sym__decimal_number_token2] = ACTIONS(516),
    [aux_sym__hex_number_token1] = ACTIONS(516),
    [anon_sym_hex] = ACTIONS(514),
    [anon_sym_DQUOTE] = ACTIONS(516),
    [anon_sym_SQUOTE] = ACTIONS(516),
    [anon_sym_unicode] = ACTIONS(514),
    [sym_comment] = ACTIONS(3),
  },
  [97] = {
    [sym_identifier] = ACTIONS(518),
    [anon_sym_DASH] = ACTIONS(518),
    [anon_sym_TILDE] = ACTIONS(520),
    [anon_sym_LBRACE] = ACTIONS(520),
    [anon_sym_RBRACE] = ACTIONS(520),
    [anon_sym_type] = ACTIONS(518),
    [anon_sym_LPAREN] = ACTIONS(520),
    [anon_sym_for] = ACTIONS(518),
    [anon_sym_PLUS] = ACTIONS(518),
    [anon_sym_assembly] = ACTIONS(518),
    [anon_sym_break] = ACTIONS(518),
    [anon_sym_continue] = ACTIONS(518),
    [anon_sym_true] = ACTIONS(518),
    [anon_sym_false] = ACTIONS(518),
    [anon_sym_if] = ACTIONS(518),
    [anon_sym_function] = ACTIONS(518),
    [anon_sym_byte] = ACTIONS(518),
    [anon_sym_address] = ACTIONS(518),
    [anon_sym_return] = ACTIONS(518),
    [anon_sym_revert] = ACTIONS(518),
    [sym__unchecked] = ACTIONS(518),
    [anon_sym_var] = ACTIONS(518),
    [anon_sym_else] = ACTIONS(518),
    [anon_sym_while] = ACTIONS(518),
    [anon_sym_do] = ACTIONS(518),
    [anon_sym_try] = ACTIONS(518),
    [anon_sym_emit] = ACTIONS(518),
    [anon_sym_payable] = ACTIONS(518),
    [anon_sym_new] = ACTIONS(518),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_BANG] = ACTIONS(520),
    [anon_sym_delete] = ACTIONS(518),
    [anon_sym_PLUS_PLUS] = ACTIONS(520),
    [anon_sym_DASH_DASH] = ACTIONS(520),
    [anon_sym_mapping] = ACTIONS(518),
    [anon_sym_bool] = ACTIONS(518),
    [anon_sym_string] = ACTIONS(518),
    [anon_sym_int] = ACTIONS(518),
    [anon_sym_int8] = ACTIONS(518),
    [anon_sym_int16] = ACTIONS(518),
    [anon_sym_int24] = ACTIONS(518),
    [anon_sym_int32] = ACTIONS(518),
    [anon_sym_int40] = ACTIONS(518),
    [anon_sym_int48] = ACTIONS(518),
    [anon_sym_int56] = ACTIONS(518),
    [anon_sym_int64] = ACTIONS(518),
    [anon_sym_int72] = ACTIONS(518),
    [anon_sym_int80] = ACTIONS(518),
    [anon_sym_int88] = ACTIONS(518),
    [anon_sym_int96] = ACTIONS(518),
    [anon_sym_int104] = ACTIONS(518),
    [anon_sym_int112] = ACTIONS(518),
    [anon_sym_int120] = ACTIONS(518),
    [anon_sym_int128] = ACTIONS(518),
    [anon_sym_int136] = ACTIONS(518),
    [anon_sym_int144] = ACTIONS(518),
    [anon_sym_int152] = ACTIONS(518),
    [anon_sym_int160] = ACTIONS(518),
    [anon_sym_int168] = ACTIONS(518),
    [anon_sym_int176] = ACTIONS(518),
    [anon_sym_int184] = ACTIONS(518),
    [anon_sym_int192] = ACTIONS(518),
    [anon_sym_int200] = ACTIONS(518),
    [anon_sym_int208] = ACTIONS(518),
    [anon_sym_int216] = ACTIONS(518),
    [anon_sym_int224] = ACTIONS(518),
    [anon_sym_int232] = ACTIONS(518),
    [anon_sym_int240] = ACTIONS(518),
    [anon_sym_int248] = ACTIONS(518),
    [anon_sym_int256] = ACTIONS(518),
    [anon_sym_uint] = ACTIONS(518),
    [anon_sym_uint8] = ACTIONS(518),
    [anon_sym_uint16] = ACTIONS(518),
    [anon_sym_uint24] = ACTIONS(518),
    [anon_sym_uint32] = ACTIONS(518),
    [anon_sym_uint40] = ACTIONS(518),
    [anon_sym_uint48] = ACTIONS(518),
    [anon_sym_uint56] = ACTIONS(518),
    [anon_sym_uint64] = ACTIONS(518),
    [anon_sym_uint72] = ACTIONS(518),
    [anon_sym_uint80] = ACTIONS(518),
    [anon_sym_uint88] = ACTIONS(518),
    [anon_sym_uint96] = ACTIONS(518),
    [anon_sym_uint104] = ACTIONS(518),
    [anon_sym_uint112] = ACTIONS(518),
    [anon_sym_uint120] = ACTIONS(518),
    [anon_sym_uint128] = ACTIONS(518),
    [anon_sym_uint136] = ACTIONS(518),
    [anon_sym_uint144] = ACTIONS(518),
    [anon_sym_uint152] = ACTIONS(518),
    [anon_sym_uint160] = ACTIONS(518),
    [anon_sym_uint168] = ACTIONS(518),
    [anon_sym_uint176] = ACTIONS(518),
    [anon_sym_uint184] = ACTIONS(518),
    [anon_sym_uint192] = ACTIONS(518),
    [anon_sym_uint200] = ACTIONS(518),
    [anon_sym_uint208] = ACTIONS(518),
    [anon_sym_uint216] = ACTIONS(518),
    [anon_sym_uint224] = ACTIONS(518),
    [anon_sym_uint232] = ACTIONS(518),
    [anon_sym_uint240] = ACTIONS(518),
    [anon_sym_uint248] = ACTIONS(518),
    [anon_sym_uint256] = ACTIONS(518),
    [anon_sym_bytes] = ACTIONS(518),
    [anon_sym_bytes1] = ACTIONS(518),
    [anon_sym_bytes2] = ACTIONS(518),
    [anon_sym_bytes3] = ACTIONS(518),
    [anon_sym_bytes4] = ACTIONS(518),
    [anon_sym_bytes5] = ACTIONS(518),
    [anon_sym_bytes6] = ACTIONS(518),
    [anon_sym_bytes7] = ACTIONS(518),
    [anon_sym_bytes8] = ACTIONS(518),
    [anon_sym_bytes9] = ACTIONS(518),
    [anon_sym_bytes10] = ACTIONS(518),
    [anon_sym_bytes11] = ACTIONS(518),
    [anon_sym_bytes12] = ACTIONS(518),
    [anon_sym_bytes13] = ACTIONS(518),
    [anon_sym_bytes14] = ACTIONS(518),
    [anon_sym_bytes15] = ACTIONS(518),
    [anon_sym_bytes16] = ACTIONS(518),
    [anon_sym_bytes17] = ACTIONS(518),
    [anon_sym_bytes18] = ACTIONS(518),
    [anon_sym_bytes19] = ACTIONS(518),
    [anon_sym_bytes20] = ACTIONS(518),
    [anon_sym_bytes21] = ACTIONS(518),
    [anon_sym_bytes22] = ACTIONS(518),
    [anon_sym_bytes23] = ACTIONS(518),
    [anon_sym_bytes24] = ACTIONS(518),
    [anon_sym_bytes25] = ACTIONS(518),
    [anon_sym_bytes26] = ACTIONS(518),
    [anon_sym_bytes27] = ACTIONS(518),
    [anon_sym_bytes28] = ACTIONS(518),
    [anon_sym_bytes29] = ACTIONS(518),
    [anon_sym_bytes30] = ACTIONS(518),
    [anon_sym_bytes31] = ACTIONS(518),
    [anon_sym_bytes32] = ACTIONS(518),
    [anon_sym_fixed] = ACTIONS(518),
    [aux_sym__fixed_token1] = ACTIONS(518),
    [anon_sym_ufixed] = ACTIONS(518),
    [aux_sym__ufixed_token1] = ACTIONS(518),
    [aux_sym__decimal_number_token1] = ACTIONS(518),
    [aux_sym__decimal_number_token2] = ACTIONS(520),
    [aux_sym__hex_number_token1] = ACTIONS(520),
    [anon_sym_hex] = ACTIONS(518),
    [anon_sym_DQUOTE] = ACTIONS(520),
    [anon_sym_SQUOTE] = ACTIONS(520),
    [anon_sym_unicode] = ACTIONS(518),
    [sym_comment] = ACTIONS(3),
  },
  [98] = {
    [sym_identifier] = ACTIONS(522),
    [anon_sym_DASH] = ACTIONS(522),
    [anon_sym_TILDE] = ACTIONS(524),
    [anon_sym_LBRACE] = ACTIONS(524),
    [anon_sym_RBRACE] = ACTIONS(524),
    [anon_sym_type] = ACTIONS(522),
    [anon_sym_LPAREN] = ACTIONS(524),
    [anon_sym_for] = ACTIONS(522),
    [anon_sym_PLUS] = ACTIONS(522),
    [anon_sym_assembly] = ACTIONS(522),
    [anon_sym_break] = ACTIONS(522),
    [anon_sym_continue] = ACTIONS(522),
    [anon_sym_true] = ACTIONS(522),
    [anon_sym_false] = ACTIONS(522),
    [anon_sym_if] = ACTIONS(522),
    [anon_sym_function] = ACTIONS(522),
    [anon_sym_byte] = ACTIONS(522),
    [anon_sym_address] = ACTIONS(522),
    [anon_sym_return] = ACTIONS(522),
    [anon_sym_revert] = ACTIONS(522),
    [sym__unchecked] = ACTIONS(522),
    [anon_sym_var] = ACTIONS(522),
    [anon_sym_else] = ACTIONS(522),
    [anon_sym_while] = ACTIONS(522),
    [anon_sym_do] = ACTIONS(522),
    [anon_sym_try] = ACTIONS(522),
    [anon_sym_emit] = ACTIONS(522),
    [anon_sym_payable] = ACTIONS(522),
    [anon_sym_new] = ACTIONS(522),
    [anon_sym_LBRACK] = ACTIONS(524),
    [anon_sym_BANG] = ACTIONS(524),
    [anon_sym_delete] = ACTIONS(522),
    [anon_sym_PLUS_PLUS] = ACTIONS(524),
    [anon_sym_DASH_DASH] = ACTIONS(524),
    [anon_sym_mapping] = ACTIONS(522),
    [anon_sym_bool] = ACTIONS(522),
    [anon_sym_string] = ACTIONS(522),
    [anon_sym_int] = ACTIONS(522),
    [anon_sym_int8] = ACTIONS(522),
    [anon_sym_int16] = ACTIONS(522),
    [anon_sym_int24] = ACTIONS(522),
    [anon_sym_int32] = ACTIONS(522),
    [anon_sym_int40] = ACTIONS(522),
    [anon_sym_int48] = ACTIONS(522),
    [anon_sym_int56] = ACTIONS(522),
    [anon_sym_int64] = ACTIONS(522),
    [anon_sym_int72] = ACTIONS(522),
    [anon_sym_int80] = ACTIONS(522),
    [anon_sym_int88] = ACTIONS(522),
    [anon_sym_int96] = ACTIONS(522),
    [anon_sym_int104] = ACTIONS(522),
    [anon_sym_int112] = ACTIONS(522),
    [anon_sym_int120] = ACTIONS(522),
    [anon_sym_int128] = ACTIONS(522),
    [anon_sym_int136] = ACTIONS(522),
    [anon_sym_int144] = ACTIONS(522),
    [anon_sym_int152] = ACTIONS(522),
    [anon_sym_int160] = ACTIONS(522),
    [anon_sym_int168] = ACTIONS(522),
    [anon_sym_int176] = ACTIONS(522),
    [anon_sym_int184] = ACTIONS(522),
    [anon_sym_int192] = ACTIONS(522),
    [anon_sym_int200] = ACTIONS(522),
    [anon_sym_int208] = ACTIONS(522),
    [anon_sym_int216] = ACTIONS(522),
    [anon_sym_int224] = ACTIONS(522),
    [anon_sym_int232] = ACTIONS(522),
    [anon_sym_int240] = ACTIONS(522),
    [anon_sym_int248] = ACTIONS(522),
    [anon_sym_int256] = ACTIONS(522),
    [anon_sym_uint] = ACTIONS(522),
    [anon_sym_uint8] = ACTIONS(522),
    [anon_sym_uint16] = ACTIONS(522),
    [anon_sym_uint24] = ACTIONS(522),
    [anon_sym_uint32] = ACTIONS(522),
    [anon_sym_uint40] = ACTIONS(522),
    [anon_sym_uint48] = ACTIONS(522),
    [anon_sym_uint56] = ACTIONS(522),
    [anon_sym_uint64] = ACTIONS(522),
    [anon_sym_uint72] = ACTIONS(522),
    [anon_sym_uint80] = ACTIONS(522),
    [anon_sym_uint88] = ACTIONS(522),
    [anon_sym_uint96] = ACTIONS(522),
    [anon_sym_uint104] = ACTIONS(522),
    [anon_sym_uint112] = ACTIONS(522),
    [anon_sym_uint120] = ACTIONS(522),
    [anon_sym_uint128] = ACTIONS(522),
    [anon_sym_uint136] = ACTIONS(522),
    [anon_sym_uint144] = ACTIONS(522),
    [anon_sym_uint152] = ACTIONS(522),
    [anon_sym_uint160] = ACTIONS(522),
    [anon_sym_uint168] = ACTIONS(522),
    [anon_sym_uint176] = ACTIONS(522),
    [anon_sym_uint184] = ACTIONS(522),
    [anon_sym_uint192] = ACTIONS(522),
    [anon_sym_uint200] = ACTIONS(522),
    [anon_sym_uint208] = ACTIONS(522),
    [anon_sym_uint216] = ACTIONS(522),
    [anon_sym_uint224] = ACTIONS(522),
    [anon_sym_uint232] = ACTIONS(522),
    [anon_sym_uint240] = ACTIONS(522),
    [anon_sym_uint248] = ACTIONS(522),
    [anon_sym_uint256] = ACTIONS(522),
    [anon_sym_bytes] = ACTIONS(522),
    [anon_sym_bytes1] = ACTIONS(522),
    [anon_sym_bytes2] = ACTIONS(522),
    [anon_sym_bytes3] = ACTIONS(522),
    [anon_sym_bytes4] = ACTIONS(522),
    [anon_sym_bytes5] = ACTIONS(522),
    [anon_sym_bytes6] = ACTIONS(522),
    [anon_sym_bytes7] = ACTIONS(522),
    [anon_sym_bytes8] = ACTIONS(522),
    [anon_sym_bytes9] = ACTIONS(522),
    [anon_sym_bytes10] = ACTIONS(522),
    [anon_sym_bytes11] = ACTIONS(522),
    [anon_sym_bytes12] = ACTIONS(522),
    [anon_sym_bytes13] = ACTIONS(522),
    [anon_sym_bytes14] = ACTIONS(522),
    [anon_sym_bytes15] = ACTIONS(522),
    [anon_sym_bytes16] = ACTIONS(522),
    [anon_sym_bytes17] = ACTIONS(522),
    [anon_sym_bytes18] = ACTIONS(522),
    [anon_sym_bytes19] = ACTIONS(522),
    [anon_sym_bytes20] = ACTIONS(522),
    [anon_sym_bytes21] = ACTIONS(522),
    [anon_sym_bytes22] = ACTIONS(522),
    [anon_sym_bytes23] = ACTIONS(522),
    [anon_sym_bytes24] = ACTIONS(522),
    [anon_sym_bytes25] = ACTIONS(522),
    [anon_sym_bytes26] = ACTIONS(522),
    [anon_sym_bytes27] = ACTIONS(522),
    [anon_sym_bytes28] = ACTIONS(522),
    [anon_sym_bytes29] = ACTIONS(522),
    [anon_sym_bytes30] = ACTIONS(522),
    [anon_sym_bytes31] = ACTIONS(522),
    [anon_sym_bytes32] = ACTIONS(522),
    [anon_sym_fixed] = ACTIONS(522),
    [aux_sym__fixed_token1] = ACTIONS(522),
    [anon_sym_ufixed] = ACTIONS(522),
    [aux_sym__ufixed_token1] = ACTIONS(522),
    [aux_sym__decimal_number_token1] = ACTIONS(522),
    [aux_sym__decimal_number_token2] = ACTIONS(524),
    [aux_sym__hex_number_token1] = ACTIONS(524),
    [anon_sym_hex] = ACTIONS(522),
    [anon_sym_DQUOTE] = ACTIONS(524),
    [anon_sym_SQUOTE] = ACTIONS(524),
    [anon_sym_unicode] = ACTIONS(522),
    [sym_comment] = ACTIONS(3),
  },
  [99] = {
    [sym_identifier] = ACTIONS(526),
    [anon_sym_DASH] = ACTIONS(526),
    [anon_sym_TILDE] = ACTIONS(528),
    [anon_sym_LBRACE] = ACTIONS(528),
    [anon_sym_RBRACE] = ACTIONS(528),
    [anon_sym_type] = ACTIONS(526),
    [anon_sym_LPAREN] = ACTIONS(528),
    [anon_sym_for] = ACTIONS(526),
    [anon_sym_PLUS] = ACTIONS(526),
    [anon_sym_assembly] = ACTIONS(526),
    [anon_sym_break] = ACTIONS(526),
    [anon_sym_continue] = ACTIONS(526),
    [anon_sym_true] = ACTIONS(526),
    [anon_sym_false] = ACTIONS(526),
    [anon_sym_if] = ACTIONS(526),
    [anon_sym_function] = ACTIONS(526),
    [anon_sym_byte] = ACTIONS(526),
    [anon_sym_address] = ACTIONS(526),
    [anon_sym_return] = ACTIONS(526),
    [anon_sym_revert] = ACTIONS(526),
    [sym__unchecked] = ACTIONS(526),
    [anon_sym_var] = ACTIONS(526),
    [anon_sym_else] = ACTIONS(526),
    [anon_sym_while] = ACTIONS(526),
    [anon_sym_do] = ACTIONS(526),
    [anon_sym_try] = ACTIONS(526),
    [anon_sym_emit] = ACTIONS(526),
    [anon_sym_payable] = ACTIONS(526),
    [anon_sym_new] = ACTIONS(526),
    [anon_sym_LBRACK] = ACTIONS(528),
    [anon_sym_BANG] = ACTIONS(528),
    [anon_sym_delete] = ACTIONS(526),
    [anon_sym_PLUS_PLUS] = ACTIONS(528),
    [anon_sym_DASH_DASH] = ACTIONS(528),
    [anon_sym_mapping] = ACTIONS(526),
    [anon_sym_bool] = ACTIONS(526),
    [anon_sym_string] = ACTIONS(526),
    [anon_sym_int] = ACTIONS(526),
    [anon_sym_int8] = ACTIONS(526),
    [anon_sym_int16] = ACTIONS(526),
    [anon_sym_int24] = ACTIONS(526),
    [anon_sym_int32] = ACTIONS(526),
    [anon_sym_int40] = ACTIONS(526),
    [anon_sym_int48] = ACTIONS(526),
    [anon_sym_int56] = ACTIONS(526),
    [anon_sym_int64] = ACTIONS(526),
    [anon_sym_int72] = ACTIONS(526),
    [anon_sym_int80] = ACTIONS(526),
    [anon_sym_int88] = ACTIONS(526),
    [anon_sym_int96] = ACTIONS(526),
    [anon_sym_int104] = ACTIONS(526),
    [anon_sym_int112] = ACTIONS(526),
    [anon_sym_int120] = ACTIONS(526),
    [anon_sym_int128] = ACTIONS(526),
    [anon_sym_int136] = ACTIONS(526),
    [anon_sym_int144] = ACTIONS(526),
    [anon_sym_int152] = ACTIONS(526),
    [anon_sym_int160] = ACTIONS(526),
    [anon_sym_int168] = ACTIONS(526),
    [anon_sym_int176] = ACTIONS(526),
    [anon_sym_int184] = ACTIONS(526),
    [anon_sym_int192] = ACTIONS(526),
    [anon_sym_int200] = ACTIONS(526),
    [anon_sym_int208] = ACTIONS(526),
    [anon_sym_int216] = ACTIONS(526),
    [anon_sym_int224] = ACTIONS(526),
    [anon_sym_int232] = ACTIONS(526),
    [anon_sym_int240] = ACTIONS(526),
    [anon_sym_int248] = ACTIONS(526),
    [anon_sym_int256] = ACTIONS(526),
    [anon_sym_uint] = ACTIONS(526),
    [anon_sym_uint8] = ACTIONS(526),
    [anon_sym_uint16] = ACTIONS(526),
    [anon_sym_uint24] = ACTIONS(526),
    [anon_sym_uint32] = ACTIONS(526),
    [anon_sym_uint40] = ACTIONS(526),
    [anon_sym_uint48] = ACTIONS(526),
    [anon_sym_uint56] = ACTIONS(526),
    [anon_sym_uint64] = ACTIONS(526),
    [anon_sym_uint72] = ACTIONS(526),
    [anon_sym_uint80] = ACTIONS(526),
    [anon_sym_uint88] = ACTIONS(526),
    [anon_sym_uint96] = ACTIONS(526),
    [anon_sym_uint104] = ACTIONS(526),
    [anon_sym_uint112] = ACTIONS(526),
    [anon_sym_uint120] = ACTIONS(526),
    [anon_sym_uint128] = ACTIONS(526),
    [anon_sym_uint136] = ACTIONS(526),
    [anon_sym_uint144] = ACTIONS(526),
    [anon_sym_uint152] = ACTIONS(526),
    [anon_sym_uint160] = ACTIONS(526),
    [anon_sym_uint168] = ACTIONS(526),
    [anon_sym_uint176] = ACTIONS(526),
    [anon_sym_uint184] = ACTIONS(526),
    [anon_sym_uint192] = ACTIONS(526),
    [anon_sym_uint200] = ACTIONS(526),
    [anon_sym_uint208] = ACTIONS(526),
    [anon_sym_uint216] = ACTIONS(526),
    [anon_sym_uint224] = ACTIONS(526),
    [anon_sym_uint232] = ACTIONS(526),
    [anon_sym_uint240] = ACTIONS(526),
    [anon_sym_uint248] = ACTIONS(526),
    [anon_sym_uint256] = ACTIONS(526),
    [anon_sym_bytes] = ACTIONS(526),
    [anon_sym_bytes1] = ACTIONS(526),
    [anon_sym_bytes2] = ACTIONS(526),
    [anon_sym_bytes3] = ACTIONS(526),
    [anon_sym_bytes4] = ACTIONS(526),
    [anon_sym_bytes5] = ACTIONS(526),
    [anon_sym_bytes6] = ACTIONS(526),
    [anon_sym_bytes7] = ACTIONS(526),
    [anon_sym_bytes8] = ACTIONS(526),
    [anon_sym_bytes9] = ACTIONS(526),
    [anon_sym_bytes10] = ACTIONS(526),
    [anon_sym_bytes11] = ACTIONS(526),
    [anon_sym_bytes12] = ACTIONS(526),
    [anon_sym_bytes13] = ACTIONS(526),
    [anon_sym_bytes14] = ACTIONS(526),
    [anon_sym_bytes15] = ACTIONS(526),
    [anon_sym_bytes16] = ACTIONS(526),
    [anon_sym_bytes17] = ACTIONS(526),
    [anon_sym_bytes18] = ACTIONS(526),
    [anon_sym_bytes19] = ACTIONS(526),
    [anon_sym_bytes20] = ACTIONS(526),
    [anon_sym_bytes21] = ACTIONS(526),
    [anon_sym_bytes22] = ACTIONS(526),
    [anon_sym_bytes23] = ACTIONS(526),
    [anon_sym_bytes24] = ACTIONS(526),
    [anon_sym_bytes25] = ACTIONS(526),
    [anon_sym_bytes26] = ACTIONS(526),
    [anon_sym_bytes27] = ACTIONS(526),
    [anon_sym_bytes28] = ACTIONS(526),
    [anon_sym_bytes29] = ACTIONS(526),
    [anon_sym_bytes30] = ACTIONS(526),
    [anon_sym_bytes31] = ACTIONS(526),
    [anon_sym_bytes32] = ACTIONS(526),
    [anon_sym_fixed] = ACTIONS(526),
    [aux_sym__fixed_token1] = ACTIONS(526),
    [anon_sym_ufixed] = ACTIONS(526),
    [aux_sym__ufixed_token1] = ACTIONS(526),
    [aux_sym__decimal_number_token1] = ACTIONS(526),
    [aux_sym__decimal_number_token2] = ACTIONS(528),
    [aux_sym__hex_number_token1] = ACTIONS(528),
    [anon_sym_hex] = ACTIONS(526),
    [anon_sym_DQUOTE] = ACTIONS(528),
    [anon_sym_SQUOTE] = ACTIONS(528),
    [anon_sym_unicode] = ACTIONS(526),
    [sym_comment] = ACTIONS(3),
  },
  [100] = {
    [sym_identifier] = ACTIONS(530),
    [anon_sym_DASH] = ACTIONS(530),
    [anon_sym_TILDE] = ACTIONS(532),
    [anon_sym_LBRACE] = ACTIONS(532),
    [anon_sym_RBRACE] = ACTIONS(532),
    [anon_sym_type] = ACTIONS(530),
    [anon_sym_LPAREN] = ACTIONS(532),
    [anon_sym_for] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(530),
    [anon_sym_assembly] = ACTIONS(530),
    [anon_sym_break] = ACTIONS(530),
    [anon_sym_continue] = ACTIONS(530),
    [anon_sym_true] = ACTIONS(530),
    [anon_sym_false] = ACTIONS(530),
    [anon_sym_if] = ACTIONS(530),
    [anon_sym_function] = ACTIONS(530),
    [anon_sym_byte] = ACTIONS(530),
    [anon_sym_address] = ACTIONS(530),
    [anon_sym_return] = ACTIONS(530),
    [anon_sym_revert] = ACTIONS(530),
    [sym__unchecked] = ACTIONS(530),
    [anon_sym_var] = ACTIONS(530),
    [anon_sym_else] = ACTIONS(530),
    [anon_sym_while] = ACTIONS(530),
    [anon_sym_do] = ACTIONS(530),
    [anon_sym_try] = ACTIONS(530),
    [anon_sym_emit] = ACTIONS(530),
    [anon_sym_payable] = ACTIONS(530),
    [anon_sym_new] = ACTIONS(530),
    [anon_sym_LBRACK] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(532),
    [anon_sym_delete] = ACTIONS(530),
    [anon_sym_PLUS_PLUS] = ACTIONS(532),
    [anon_sym_DASH_DASH] = ACTIONS(532),
    [anon_sym_mapping] = ACTIONS(530),
    [anon_sym_bool] = ACTIONS(530),
    [anon_sym_string] = ACTIONS(530),
    [anon_sym_int] = ACTIONS(530),
    [anon_sym_int8] = ACTIONS(530),
    [anon_sym_int16] = ACTIONS(530),
    [anon_sym_int24] = ACTIONS(530),
    [anon_sym_int32] = ACTIONS(530),
    [anon_sym_int40] = ACTIONS(530),
    [anon_sym_int48] = ACTIONS(530),
    [anon_sym_int56] = ACTIONS(530),
    [anon_sym_int64] = ACTIONS(530),
    [anon_sym_int72] = ACTIONS(530),
    [anon_sym_int80] = ACTIONS(530),
    [anon_sym_int88] = ACTIONS(530),
    [anon_sym_int96] = ACTIONS(530),
    [anon_sym_int104] = ACTIONS(530),
    [anon_sym_int112] = ACTIONS(530),
    [anon_sym_int120] = ACTIONS(530),
    [anon_sym_int128] = ACTIONS(530),
    [anon_sym_int136] = ACTIONS(530),
    [anon_sym_int144] = ACTIONS(530),
    [anon_sym_int152] = ACTIONS(530),
    [anon_sym_int160] = ACTIONS(530),
    [anon_sym_int168] = ACTIONS(530),
    [anon_sym_int176] = ACTIONS(530),
    [anon_sym_int184] = ACTIONS(530),
    [anon_sym_int192] = ACTIONS(530),
    [anon_sym_int200] = ACTIONS(530),
    [anon_sym_int208] = ACTIONS(530),
    [anon_sym_int216] = ACTIONS(530),
    [anon_sym_int224] = ACTIONS(530),
    [anon_sym_int232] = ACTIONS(530),
    [anon_sym_int240] = ACTIONS(530),
    [anon_sym_int248] = ACTIONS(530),
    [anon_sym_int256] = ACTIONS(530),
    [anon_sym_uint] = ACTIONS(530),
    [anon_sym_uint8] = ACTIONS(530),
    [anon_sym_uint16] = ACTIONS(530),
    [anon_sym_uint24] = ACTIONS(530),
    [anon_sym_uint32] = ACTIONS(530),
    [anon_sym_uint40] = ACTIONS(530),
    [anon_sym_uint48] = ACTIONS(530),
    [anon_sym_uint56] = ACTIONS(530),
    [anon_sym_uint64] = ACTIONS(530),
    [anon_sym_uint72] = ACTIONS(530),
    [anon_sym_uint80] = ACTIONS(530),
    [anon_sym_uint88] = ACTIONS(530),
    [anon_sym_uint96] = ACTIONS(530),
    [anon_sym_uint104] = ACTIONS(530),
    [anon_sym_uint112] = ACTIONS(530),
    [anon_sym_uint120] = ACTIONS(530),
    [anon_sym_uint128] = ACTIONS(530),
    [anon_sym_uint136] = ACTIONS(530),
    [anon_sym_uint144] = ACTIONS(530),
    [anon_sym_uint152] = ACTIONS(530),
    [anon_sym_uint160] = ACTIONS(530),
    [anon_sym_uint168] = ACTIONS(530),
    [anon_sym_uint176] = ACTIONS(530),
    [anon_sym_uint184] = ACTIONS(530),
    [anon_sym_uint192] = ACTIONS(530),
    [anon_sym_uint200] = ACTIONS(530),
    [anon_sym_uint208] = ACTIONS(530),
    [anon_sym_uint216] = ACTIONS(530),
    [anon_sym_uint224] = ACTIONS(530),
    [anon_sym_uint232] = ACTIONS(530),
    [anon_sym_uint240] = ACTIONS(530),
    [anon_sym_uint248] = ACTIONS(530),
    [anon_sym_uint256] = ACTIONS(530),
    [anon_sym_bytes] = ACTIONS(530),
    [anon_sym_bytes1] = ACTIONS(530),
    [anon_sym_bytes2] = ACTIONS(530),
    [anon_sym_bytes3] = ACTIONS(530),
    [anon_sym_bytes4] = ACTIONS(530),
    [anon_sym_bytes5] = ACTIONS(530),
    [anon_sym_bytes6] = ACTIONS(530),
    [anon_sym_bytes7] = ACTIONS(530),
    [anon_sym_bytes8] = ACTIONS(530),
    [anon_sym_bytes9] = ACTIONS(530),
    [anon_sym_bytes10] = ACTIONS(530),
    [anon_sym_bytes11] = ACTIONS(530),
    [anon_sym_bytes12] = ACTIONS(530),
    [anon_sym_bytes13] = ACTIONS(530),
    [anon_sym_bytes14] = ACTIONS(530),
    [anon_sym_bytes15] = ACTIONS(530),
    [anon_sym_bytes16] = ACTIONS(530),
    [anon_sym_bytes17] = ACTIONS(530),
    [anon_sym_bytes18] = ACTIONS(530),
    [anon_sym_bytes19] = ACTIONS(530),
    [anon_sym_bytes20] = ACTIONS(530),
    [anon_sym_bytes21] = ACTIONS(530),
    [anon_sym_bytes22] = ACTIONS(530),
    [anon_sym_bytes23] = ACTIONS(530),
    [anon_sym_bytes24] = ACTIONS(530),
    [anon_sym_bytes25] = ACTIONS(530),
    [anon_sym_bytes26] = ACTIONS(530),
    [anon_sym_bytes27] = ACTIONS(530),
    [anon_sym_bytes28] = ACTIONS(530),
    [anon_sym_bytes29] = ACTIONS(530),
    [anon_sym_bytes30] = ACTIONS(530),
    [anon_sym_bytes31] = ACTIONS(530),
    [anon_sym_bytes32] = ACTIONS(530),
    [anon_sym_fixed] = ACTIONS(530),
    [aux_sym__fixed_token1] = ACTIONS(530),
    [anon_sym_ufixed] = ACTIONS(530),
    [aux_sym__ufixed_token1] = ACTIONS(530),
    [aux_sym__decimal_number_token1] = ACTIONS(530),
    [aux_sym__decimal_number_token2] = ACTIONS(532),
    [aux_sym__hex_number_token1] = ACTIONS(532),
    [anon_sym_hex] = ACTIONS(530),
    [anon_sym_DQUOTE] = ACTIONS(532),
    [anon_sym_SQUOTE] = ACTIONS(532),
    [anon_sym_unicode] = ACTIONS(530),
    [sym_comment] = ACTIONS(3),
  },
  [101] = {
    [sym_identifier] = ACTIONS(534),
    [anon_sym_DASH] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(536),
    [anon_sym_LBRACE] = ACTIONS(536),
    [anon_sym_RBRACE] = ACTIONS(536),
    [anon_sym_type] = ACTIONS(534),
    [anon_sym_LPAREN] = ACTIONS(536),
    [anon_sym_for] = ACTIONS(534),
    [anon_sym_PLUS] = ACTIONS(534),
    [anon_sym_assembly] = ACTIONS(534),
    [anon_sym_break] = ACTIONS(534),
    [anon_sym_continue] = ACTIONS(534),
    [anon_sym_true] = ACTIONS(534),
    [anon_sym_false] = ACTIONS(534),
    [anon_sym_if] = ACTIONS(534),
    [anon_sym_function] = ACTIONS(534),
    [anon_sym_byte] = ACTIONS(534),
    [anon_sym_address] = ACTIONS(534),
    [anon_sym_return] = ACTIONS(534),
    [anon_sym_revert] = ACTIONS(534),
    [sym__unchecked] = ACTIONS(534),
    [anon_sym_var] = ACTIONS(534),
    [anon_sym_else] = ACTIONS(534),
    [anon_sym_while] = ACTIONS(534),
    [anon_sym_do] = ACTIONS(534),
    [anon_sym_try] = ACTIONS(534),
    [anon_sym_emit] = ACTIONS(534),
    [anon_sym_payable] = ACTIONS(534),
    [anon_sym_new] = ACTIONS(534),
    [anon_sym_LBRACK] = ACTIONS(536),
    [anon_sym_BANG] = ACTIONS(536),
    [anon_sym_delete] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_mapping] = ACTIONS(534),
    [anon_sym_bool] = ACTIONS(534),
    [anon_sym_string] = ACTIONS(534),
    [anon_sym_int] = ACTIONS(534),
    [anon_sym_int8] = ACTIONS(534),
    [anon_sym_int16] = ACTIONS(534),
    [anon_sym_int24] = ACTIONS(534),
    [anon_sym_int32] = ACTIONS(534),
    [anon_sym_int40] = ACTIONS(534),
    [anon_sym_int48] = ACTIONS(534),
    [anon_sym_int56] = ACTIONS(534),
    [anon_sym_int64] = ACTIONS(534),
    [anon_sym_int72] = ACTIONS(534),
    [anon_sym_int80] = ACTIONS(534),
    [anon_sym_int88] = ACTIONS(534),
    [anon_sym_int96] = ACTIONS(534),
    [anon_sym_int104] = ACTIONS(534),
    [anon_sym_int112] = ACTIONS(534),
    [anon_sym_int120] = ACTIONS(534),
    [anon_sym_int128] = ACTIONS(534),
    [anon_sym_int136] = ACTIONS(534),
    [anon_sym_int144] = ACTIONS(534),
    [anon_sym_int152] = ACTIONS(534),
    [anon_sym_int160] = ACTIONS(534),
    [anon_sym_int168] = ACTIONS(534),
    [anon_sym_int176] = ACTIONS(534),
    [anon_sym_int184] = ACTIONS(534),
    [anon_sym_int192] = ACTIONS(534),
    [anon_sym_int200] = ACTIONS(534),
    [anon_sym_int208] = ACTIONS(534),
    [anon_sym_int216] = ACTIONS(534),
    [anon_sym_int224] = ACTIONS(534),
    [anon_sym_int232] = ACTIONS(534),
    [anon_sym_int240] = ACTIONS(534),
    [anon_sym_int248] = ACTIONS(534),
    [anon_sym_int256] = ACTIONS(534),
    [anon_sym_uint] = ACTIONS(534),
    [anon_sym_uint8] = ACTIONS(534),
    [anon_sym_uint16] = ACTIONS(534),
    [anon_sym_uint24] = ACTIONS(534),
    [anon_sym_uint32] = ACTIONS(534),
    [anon_sym_uint40] = ACTIONS(534),
    [anon_sym_uint48] = ACTIONS(534),
    [anon_sym_uint56] = ACTIONS(534),
    [anon_sym_uint64] = ACTIONS(534),
    [anon_sym_uint72] = ACTIONS(534),
    [anon_sym_uint80] = ACTIONS(534),
    [anon_sym_uint88] = ACTIONS(534),
    [anon_sym_uint96] = ACTIONS(534),
    [anon_sym_uint104] = ACTIONS(534),
    [anon_sym_uint112] = ACTIONS(534),
    [anon_sym_uint120] = ACTIONS(534),
    [anon_sym_uint128] = ACTIONS(534),
    [anon_sym_uint136] = ACTIONS(534),
    [anon_sym_uint144] = ACTIONS(534),
    [anon_sym_uint152] = ACTIONS(534),
    [anon_sym_uint160] = ACTIONS(534),
    [anon_sym_uint168] = ACTIONS(534),
    [anon_sym_uint176] = ACTIONS(534),
    [anon_sym_uint184] = ACTIONS(534),
    [anon_sym_uint192] = ACTIONS(534),
    [anon_sym_uint200] = ACTIONS(534),
    [anon_sym_uint208] = ACTIONS(534),
    [anon_sym_uint216] = ACTIONS(534),
    [anon_sym_uint224] = ACTIONS(534),
    [anon_sym_uint232] = ACTIONS(534),
    [anon_sym_uint240] = ACTIONS(534),
    [anon_sym_uint248] = ACTIONS(534),
    [anon_sym_uint256] = ACTIONS(534),
    [anon_sym_bytes] = ACTIONS(534),
    [anon_sym_bytes1] = ACTIONS(534),
    [anon_sym_bytes2] = ACTIONS(534),
    [anon_sym_bytes3] = ACTIONS(534),
    [anon_sym_bytes4] = ACTIONS(534),
    [anon_sym_bytes5] = ACTIONS(534),
    [anon_sym_bytes6] = ACTIONS(534),
    [anon_sym_bytes7] = ACTIONS(534),
    [anon_sym_bytes8] = ACTIONS(534),
    [anon_sym_bytes9] = ACTIONS(534),
    [anon_sym_bytes10] = ACTIONS(534),
    [anon_sym_bytes11] = ACTIONS(534),
    [anon_sym_bytes12] = ACTIONS(534),
    [anon_sym_bytes13] = ACTIONS(534),
    [anon_sym_bytes14] = ACTIONS(534),
    [anon_sym_bytes15] = ACTIONS(534),
    [anon_sym_bytes16] = ACTIONS(534),
    [anon_sym_bytes17] = ACTIONS(534),
    [anon_sym_bytes18] = ACTIONS(534),
    [anon_sym_bytes19] = ACTIONS(534),
    [anon_sym_bytes20] = ACTIONS(534),
    [anon_sym_bytes21] = ACTIONS(534),
    [anon_sym_bytes22] = ACTIONS(534),
    [anon_sym_bytes23] = ACTIONS(534),
    [anon_sym_bytes24] = ACTIONS(534),
    [anon_sym_bytes25] = ACTIONS(534),
    [anon_sym_bytes26] = ACTIONS(534),
    [anon_sym_bytes27] = ACTIONS(534),
    [anon_sym_bytes28] = ACTIONS(534),
    [anon_sym_bytes29] = ACTIONS(534),
    [anon_sym_bytes30] = ACTIONS(534),
    [anon_sym_bytes31] = ACTIONS(534),
    [anon_sym_bytes32] = ACTIONS(534),
    [anon_sym_fixed] = ACTIONS(534),
    [aux_sym__fixed_token1] = ACTIONS(534),
    [anon_sym_ufixed] = ACTIONS(534),
    [aux_sym__ufixed_token1] = ACTIONS(534),
    [aux_sym__decimal_number_token1] = ACTIONS(534),
    [aux_sym__decimal_number_token2] = ACTIONS(536),
    [aux_sym__hex_number_token1] = ACTIONS(536),
    [anon_sym_hex] = ACTIONS(534),
    [anon_sym_DQUOTE] = ACTIONS(536),
    [anon_sym_SQUOTE] = ACTIONS(536),
    [anon_sym_unicode] = ACTIONS(534),
    [sym_comment] = ACTIONS(3),
  },
  [102] = {
    [sym_identifier] = ACTIONS(538),
    [anon_sym_DASH] = ACTIONS(538),
    [anon_sym_TILDE] = ACTIONS(540),
    [anon_sym_LBRACE] = ACTIONS(540),
    [anon_sym_RBRACE] = ACTIONS(540),
    [anon_sym_type] = ACTIONS(538),
    [anon_sym_LPAREN] = ACTIONS(540),
    [anon_sym_for] = ACTIONS(538),
    [anon_sym_PLUS] = ACTIONS(538),
    [anon_sym_assembly] = ACTIONS(538),
    [anon_sym_break] = ACTIONS(538),
    [anon_sym_continue] = ACTIONS(538),
    [anon_sym_true] = ACTIONS(538),
    [anon_sym_false] = ACTIONS(538),
    [anon_sym_if] = ACTIONS(538),
    [anon_sym_function] = ACTIONS(538),
    [anon_sym_byte] = ACTIONS(538),
    [anon_sym_address] = ACTIONS(538),
    [anon_sym_return] = ACTIONS(538),
    [anon_sym_revert] = ACTIONS(538),
    [sym__unchecked] = ACTIONS(538),
    [anon_sym_var] = ACTIONS(538),
    [anon_sym_else] = ACTIONS(538),
    [anon_sym_while] = ACTIONS(538),
    [anon_sym_do] = ACTIONS(538),
    [anon_sym_try] = ACTIONS(538),
    [anon_sym_emit] = ACTIONS(538),
    [anon_sym_payable] = ACTIONS(538),
    [anon_sym_new] = ACTIONS(538),
    [anon_sym_LBRACK] = ACTIONS(540),
    [anon_sym_BANG] = ACTIONS(540),
    [anon_sym_delete] = ACTIONS(538),
    [anon_sym_PLUS_PLUS] = ACTIONS(540),
    [anon_sym_DASH_DASH] = ACTIONS(540),
    [anon_sym_mapping] = ACTIONS(538),
    [anon_sym_bool] = ACTIONS(538),
    [anon_sym_string] = ACTIONS(538),
    [anon_sym_int] = ACTIONS(538),
    [anon_sym_int8] = ACTIONS(538),
    [anon_sym_int16] = ACTIONS(538),
    [anon_sym_int24] = ACTIONS(538),
    [anon_sym_int32] = ACTIONS(538),
    [anon_sym_int40] = ACTIONS(538),
    [anon_sym_int48] = ACTIONS(538),
    [anon_sym_int56] = ACTIONS(538),
    [anon_sym_int64] = ACTIONS(538),
    [anon_sym_int72] = ACTIONS(538),
    [anon_sym_int80] = ACTIONS(538),
    [anon_sym_int88] = ACTIONS(538),
    [anon_sym_int96] = ACTIONS(538),
    [anon_sym_int104] = ACTIONS(538),
    [anon_sym_int112] = ACTIONS(538),
    [anon_sym_int120] = ACTIONS(538),
    [anon_sym_int128] = ACTIONS(538),
    [anon_sym_int136] = ACTIONS(538),
    [anon_sym_int144] = ACTIONS(538),
    [anon_sym_int152] = ACTIONS(538),
    [anon_sym_int160] = ACTIONS(538),
    [anon_sym_int168] = ACTIONS(538),
    [anon_sym_int176] = ACTIONS(538),
    [anon_sym_int184] = ACTIONS(538),
    [anon_sym_int192] = ACTIONS(538),
    [anon_sym_int200] = ACTIONS(538),
    [anon_sym_int208] = ACTIONS(538),
    [anon_sym_int216] = ACTIONS(538),
    [anon_sym_int224] = ACTIONS(538),
    [anon_sym_int232] = ACTIONS(538),
    [anon_sym_int240] = ACTIONS(538),
    [anon_sym_int248] = ACTIONS(538),
    [anon_sym_int256] = ACTIONS(538),
    [anon_sym_uint] = ACTIONS(538),
    [anon_sym_uint8] = ACTIONS(538),
    [anon_sym_uint16] = ACTIONS(538),
    [anon_sym_uint24] = ACTIONS(538),
    [anon_sym_uint32] = ACTIONS(538),
    [anon_sym_uint40] = ACTIONS(538),
    [anon_sym_uint48] = ACTIONS(538),
    [anon_sym_uint56] = ACTIONS(538),
    [anon_sym_uint64] = ACTIONS(538),
    [anon_sym_uint72] = ACTIONS(538),
    [anon_sym_uint80] = ACTIONS(538),
    [anon_sym_uint88] = ACTIONS(538),
    [anon_sym_uint96] = ACTIONS(538),
    [anon_sym_uint104] = ACTIONS(538),
    [anon_sym_uint112] = ACTIONS(538),
    [anon_sym_uint120] = ACTIONS(538),
    [anon_sym_uint128] = ACTIONS(538),
    [anon_sym_uint136] = ACTIONS(538),
    [anon_sym_uint144] = ACTIONS(538),
    [anon_sym_uint152] = ACTIONS(538),
    [anon_sym_uint160] = ACTIONS(538),
    [anon_sym_uint168] = ACTIONS(538),
    [anon_sym_uint176] = ACTIONS(538),
    [anon_sym_uint184] = ACTIONS(538),
    [anon_sym_uint192] = ACTIONS(538),
    [anon_sym_uint200] = ACTIONS(538),
    [anon_sym_uint208] = ACTIONS(538),
    [anon_sym_uint216] = ACTIONS(538),
    [anon_sym_uint224] = ACTIONS(538),
    [anon_sym_uint232] = ACTIONS(538),
    [anon_sym_uint240] = ACTIONS(538),
    [anon_sym_uint248] = ACTIONS(538),
    [anon_sym_uint256] = ACTIONS(538),
    [anon_sym_bytes] = ACTIONS(538),
    [anon_sym_bytes1] = ACTIONS(538),
    [anon_sym_bytes2] = ACTIONS(538),
    [anon_sym_bytes3] = ACTIONS(538),
    [anon_sym_bytes4] = ACTIONS(538),
    [anon_sym_bytes5] = ACTIONS(538),
    [anon_sym_bytes6] = ACTIONS(538),
    [anon_sym_bytes7] = ACTIONS(538),
    [anon_sym_bytes8] = ACTIONS(538),
    [anon_sym_bytes9] = ACTIONS(538),
    [anon_sym_bytes10] = ACTIONS(538),
    [anon_sym_bytes11] = ACTIONS(538),
    [anon_sym_bytes12] = ACTIONS(538),
    [anon_sym_bytes13] = ACTIONS(538),
    [anon_sym_bytes14] = ACTIONS(538),
    [anon_sym_bytes15] = ACTIONS(538),
    [anon_sym_bytes16] = ACTIONS(538),
    [anon_sym_bytes17] = ACTIONS(538),
    [anon_sym_bytes18] = ACTIONS(538),
    [anon_sym_bytes19] = ACTIONS(538),
    [anon_sym_bytes20] = ACTIONS(538),
    [anon_sym_bytes21] = ACTIONS(538),
    [anon_sym_bytes22] = ACTIONS(538),
    [anon_sym_bytes23] = ACTIONS(538),
    [anon_sym_bytes24] = ACTIONS(538),
    [anon_sym_bytes25] = ACTIONS(538),
    [anon_sym_bytes26] = ACTIONS(538),
    [anon_sym_bytes27] = ACTIONS(538),
    [anon_sym_bytes28] = ACTIONS(538),
    [anon_sym_bytes29] = ACTIONS(538),
    [anon_sym_bytes30] = ACTIONS(538),
    [anon_sym_bytes31] = ACTIONS(538),
    [anon_sym_bytes32] = ACTIONS(538),
    [anon_sym_fixed] = ACTIONS(538),
    [aux_sym__fixed_token1] = ACTIONS(538),
    [anon_sym_ufixed] = ACTIONS(538),
    [aux_sym__ufixed_token1] = ACTIONS(538),
    [aux_sym__decimal_number_token1] = ACTIONS(538),
    [aux_sym__decimal_number_token2] = ACTIONS(540),
    [aux_sym__hex_number_token1] = ACTIONS(540),
    [anon_sym_hex] = ACTIONS(538),
    [anon_sym_DQUOTE] = ACTIONS(540),
    [anon_sym_SQUOTE] = ACTIONS(540),
    [anon_sym_unicode] = ACTIONS(538),
    [sym_comment] = ACTIONS(3),
  },
  [103] = {
    [sym_identifier] = ACTIONS(542),
    [anon_sym_DASH] = ACTIONS(542),
    [anon_sym_TILDE] = ACTIONS(544),
    [anon_sym_LBRACE] = ACTIONS(544),
    [anon_sym_RBRACE] = ACTIONS(544),
    [anon_sym_type] = ACTIONS(542),
    [anon_sym_LPAREN] = ACTIONS(544),
    [anon_sym_for] = ACTIONS(542),
    [anon_sym_PLUS] = ACTIONS(542),
    [anon_sym_assembly] = ACTIONS(542),
    [anon_sym_break] = ACTIONS(542),
    [anon_sym_continue] = ACTIONS(542),
    [anon_sym_true] = ACTIONS(542),
    [anon_sym_false] = ACTIONS(542),
    [anon_sym_if] = ACTIONS(542),
    [anon_sym_function] = ACTIONS(542),
    [anon_sym_byte] = ACTIONS(542),
    [anon_sym_address] = ACTIONS(542),
    [anon_sym_return] = ACTIONS(542),
    [anon_sym_revert] = ACTIONS(542),
    [sym__unchecked] = ACTIONS(542),
    [anon_sym_var] = ACTIONS(542),
    [anon_sym_else] = ACTIONS(542),
    [anon_sym_while] = ACTIONS(542),
    [anon_sym_do] = ACTIONS(542),
    [anon_sym_try] = ACTIONS(542),
    [anon_sym_emit] = ACTIONS(542),
    [anon_sym_payable] = ACTIONS(542),
    [anon_sym_new] = ACTIONS(542),
    [anon_sym_LBRACK] = ACTIONS(544),
    [anon_sym_BANG] = ACTIONS(544),
    [anon_sym_delete] = ACTIONS(542),
    [anon_sym_PLUS_PLUS] = ACTIONS(544),
    [anon_sym_DASH_DASH] = ACTIONS(544),
    [anon_sym_mapping] = ACTIONS(542),
    [anon_sym_bool] = ACTIONS(542),
    [anon_sym_string] = ACTIONS(542),
    [anon_sym_int] = ACTIONS(542),
    [anon_sym_int8] = ACTIONS(542),
    [anon_sym_int16] = ACTIONS(542),
    [anon_sym_int24] = ACTIONS(542),
    [anon_sym_int32] = ACTIONS(542),
    [anon_sym_int40] = ACTIONS(542),
    [anon_sym_int48] = ACTIONS(542),
    [anon_sym_int56] = ACTIONS(542),
    [anon_sym_int64] = ACTIONS(542),
    [anon_sym_int72] = ACTIONS(542),
    [anon_sym_int80] = ACTIONS(542),
    [anon_sym_int88] = ACTIONS(542),
    [anon_sym_int96] = ACTIONS(542),
    [anon_sym_int104] = ACTIONS(542),
    [anon_sym_int112] = ACTIONS(542),
    [anon_sym_int120] = ACTIONS(542),
    [anon_sym_int128] = ACTIONS(542),
    [anon_sym_int136] = ACTIONS(542),
    [anon_sym_int144] = ACTIONS(542),
    [anon_sym_int152] = ACTIONS(542),
    [anon_sym_int160] = ACTIONS(542),
    [anon_sym_int168] = ACTIONS(542),
    [anon_sym_int176] = ACTIONS(542),
    [anon_sym_int184] = ACTIONS(542),
    [anon_sym_int192] = ACTIONS(542),
    [anon_sym_int200] = ACTIONS(542),
    [anon_sym_int208] = ACTIONS(542),
    [anon_sym_int216] = ACTIONS(542),
    [anon_sym_int224] = ACTIONS(542),
    [anon_sym_int232] = ACTIONS(542),
    [anon_sym_int240] = ACTIONS(542),
    [anon_sym_int248] = ACTIONS(542),
    [anon_sym_int256] = ACTIONS(542),
    [anon_sym_uint] = ACTIONS(542),
    [anon_sym_uint8] = ACTIONS(542),
    [anon_sym_uint16] = ACTIONS(542),
    [anon_sym_uint24] = ACTIONS(542),
    [anon_sym_uint32] = ACTIONS(542),
    [anon_sym_uint40] = ACTIONS(542),
    [anon_sym_uint48] = ACTIONS(542),
    [anon_sym_uint56] = ACTIONS(542),
    [anon_sym_uint64] = ACTIONS(542),
    [anon_sym_uint72] = ACTIONS(542),
    [anon_sym_uint80] = ACTIONS(542),
    [anon_sym_uint88] = ACTIONS(542),
    [anon_sym_uint96] = ACTIONS(542),
    [anon_sym_uint104] = ACTIONS(542),
    [anon_sym_uint112] = ACTIONS(542),
    [anon_sym_uint120] = ACTIONS(542),
    [anon_sym_uint128] = ACTIONS(542),
    [anon_sym_uint136] = ACTIONS(542),
    [anon_sym_uint144] = ACTIONS(542),
    [anon_sym_uint152] = ACTIONS(542),
    [anon_sym_uint160] = ACTIONS(542),
    [anon_sym_uint168] = ACTIONS(542),
    [anon_sym_uint176] = ACTIONS(542),
    [anon_sym_uint184] = ACTIONS(542),
    [anon_sym_uint192] = ACTIONS(542),
    [anon_sym_uint200] = ACTIONS(542),
    [anon_sym_uint208] = ACTIONS(542),
    [anon_sym_uint216] = ACTIONS(542),
    [anon_sym_uint224] = ACTIONS(542),
    [anon_sym_uint232] = ACTIONS(542),
    [anon_sym_uint240] = ACTIONS(542),
    [anon_sym_uint248] = ACTIONS(542),
    [anon_sym_uint256] = ACTIONS(542),
    [anon_sym_bytes] = ACTIONS(542),
    [anon_sym_bytes1] = ACTIONS(542),
    [anon_sym_bytes2] = ACTIONS(542),
    [anon_sym_bytes3] = ACTIONS(542),
    [anon_sym_bytes4] = ACTIONS(542),
    [anon_sym_bytes5] = ACTIONS(542),
    [anon_sym_bytes6] = ACTIONS(542),
    [anon_sym_bytes7] = ACTIONS(542),
    [anon_sym_bytes8] = ACTIONS(542),
    [anon_sym_bytes9] = ACTIONS(542),
    [anon_sym_bytes10] = ACTIONS(542),
    [anon_sym_bytes11] = ACTIONS(542),
    [anon_sym_bytes12] = ACTIONS(542),
    [anon_sym_bytes13] = ACTIONS(542),
    [anon_sym_bytes14] = ACTIONS(542),
    [anon_sym_bytes15] = ACTIONS(542),
    [anon_sym_bytes16] = ACTIONS(542),
    [anon_sym_bytes17] = ACTIONS(542),
    [anon_sym_bytes18] = ACTIONS(542),
    [anon_sym_bytes19] = ACTIONS(542),
    [anon_sym_bytes20] = ACTIONS(542),
    [anon_sym_bytes21] = ACTIONS(542),
    [anon_sym_bytes22] = ACTIONS(542),
    [anon_sym_bytes23] = ACTIONS(542),
    [anon_sym_bytes24] = ACTIONS(542),
    [anon_sym_bytes25] = ACTIONS(542),
    [anon_sym_bytes26] = ACTIONS(542),
    [anon_sym_bytes27] = ACTIONS(542),
    [anon_sym_bytes28] = ACTIONS(542),
    [anon_sym_bytes29] = ACTIONS(542),
    [anon_sym_bytes30] = ACTIONS(542),
    [anon_sym_bytes31] = ACTIONS(542),
    [anon_sym_bytes32] = ACTIONS(542),
    [anon_sym_fixed] = ACTIONS(542),
    [aux_sym__fixed_token1] = ACTIONS(542),
    [anon_sym_ufixed] = ACTIONS(542),
    [aux_sym__ufixed_token1] = ACTIONS(542),
    [aux_sym__decimal_number_token1] = ACTIONS(542),
    [aux_sym__decimal_number_token2] = ACTIONS(544),
    [aux_sym__hex_number_token1] = ACTIONS(544),
    [anon_sym_hex] = ACTIONS(542),
    [anon_sym_DQUOTE] = ACTIONS(544),
    [anon_sym_SQUOTE] = ACTIONS(544),
    [anon_sym_unicode] = ACTIONS(542),
    [sym_comment] = ACTIONS(3),
  },
  [104] = {
    [sym_identifier] = ACTIONS(546),
    [anon_sym_DASH] = ACTIONS(546),
    [anon_sym_TILDE] = ACTIONS(548),
    [anon_sym_LBRACE] = ACTIONS(548),
    [anon_sym_RBRACE] = ACTIONS(548),
    [anon_sym_type] = ACTIONS(546),
    [anon_sym_LPAREN] = ACTIONS(548),
    [anon_sym_for] = ACTIONS(546),
    [anon_sym_PLUS] = ACTIONS(546),
    [anon_sym_assembly] = ACTIONS(546),
    [anon_sym_break] = ACTIONS(546),
    [anon_sym_continue] = ACTIONS(546),
    [anon_sym_true] = ACTIONS(546),
    [anon_sym_false] = ACTIONS(546),
    [anon_sym_if] = ACTIONS(546),
    [anon_sym_function] = ACTIONS(546),
    [anon_sym_byte] = ACTIONS(546),
    [anon_sym_address] = ACTIONS(546),
    [anon_sym_return] = ACTIONS(546),
    [anon_sym_revert] = ACTIONS(546),
    [sym__unchecked] = ACTIONS(546),
    [anon_sym_var] = ACTIONS(546),
    [anon_sym_else] = ACTIONS(546),
    [anon_sym_while] = ACTIONS(546),
    [anon_sym_do] = ACTIONS(546),
    [anon_sym_try] = ACTIONS(546),
    [anon_sym_emit] = ACTIONS(546),
    [anon_sym_payable] = ACTIONS(546),
    [anon_sym_new] = ACTIONS(546),
    [anon_sym_LBRACK] = ACTIONS(548),
    [anon_sym_BANG] = ACTIONS(548),
    [anon_sym_delete] = ACTIONS(546),
    [anon_sym_PLUS_PLUS] = ACTIONS(548),
    [anon_sym_DASH_DASH] = ACTIONS(548),
    [anon_sym_mapping] = ACTIONS(546),
    [anon_sym_bool] = ACTIONS(546),
    [anon_sym_string] = ACTIONS(546),
    [anon_sym_int] = ACTIONS(546),
    [anon_sym_int8] = ACTIONS(546),
    [anon_sym_int16] = ACTIONS(546),
    [anon_sym_int24] = ACTIONS(546),
    [anon_sym_int32] = ACTIONS(546),
    [anon_sym_int40] = ACTIONS(546),
    [anon_sym_int48] = ACTIONS(546),
    [anon_sym_int56] = ACTIONS(546),
    [anon_sym_int64] = ACTIONS(546),
    [anon_sym_int72] = ACTIONS(546),
    [anon_sym_int80] = ACTIONS(546),
    [anon_sym_int88] = ACTIONS(546),
    [anon_sym_int96] = ACTIONS(546),
    [anon_sym_int104] = ACTIONS(546),
    [anon_sym_int112] = ACTIONS(546),
    [anon_sym_int120] = ACTIONS(546),
    [anon_sym_int128] = ACTIONS(546),
    [anon_sym_int136] = ACTIONS(546),
    [anon_sym_int144] = ACTIONS(546),
    [anon_sym_int152] = ACTIONS(546),
    [anon_sym_int160] = ACTIONS(546),
    [anon_sym_int168] = ACTIONS(546),
    [anon_sym_int176] = ACTIONS(546),
    [anon_sym_int184] = ACTIONS(546),
    [anon_sym_int192] = ACTIONS(546),
    [anon_sym_int200] = ACTIONS(546),
    [anon_sym_int208] = ACTIONS(546),
    [anon_sym_int216] = ACTIONS(546),
    [anon_sym_int224] = ACTIONS(546),
    [anon_sym_int232] = ACTIONS(546),
    [anon_sym_int240] = ACTIONS(546),
    [anon_sym_int248] = ACTIONS(546),
    [anon_sym_int256] = ACTIONS(546),
    [anon_sym_uint] = ACTIONS(546),
    [anon_sym_uint8] = ACTIONS(546),
    [anon_sym_uint16] = ACTIONS(546),
    [anon_sym_uint24] = ACTIONS(546),
    [anon_sym_uint32] = ACTIONS(546),
    [anon_sym_uint40] = ACTIONS(546),
    [anon_sym_uint48] = ACTIONS(546),
    [anon_sym_uint56] = ACTIONS(546),
    [anon_sym_uint64] = ACTIONS(546),
    [anon_sym_uint72] = ACTIONS(546),
    [anon_sym_uint80] = ACTIONS(546),
    [anon_sym_uint88] = ACTIONS(546),
    [anon_sym_uint96] = ACTIONS(546),
    [anon_sym_uint104] = ACTIONS(546),
    [anon_sym_uint112] = ACTIONS(546),
    [anon_sym_uint120] = ACTIONS(546),
    [anon_sym_uint128] = ACTIONS(546),
    [anon_sym_uint136] = ACTIONS(546),
    [anon_sym_uint144] = ACTIONS(546),
    [anon_sym_uint152] = ACTIONS(546),
    [anon_sym_uint160] = ACTIONS(546),
    [anon_sym_uint168] = ACTIONS(546),
    [anon_sym_uint176] = ACTIONS(546),
    [anon_sym_uint184] = ACTIONS(546),
    [anon_sym_uint192] = ACTIONS(546),
    [anon_sym_uint200] = ACTIONS(546),
    [anon_sym_uint208] = ACTIONS(546),
    [anon_sym_uint216] = ACTIONS(546),
    [anon_sym_uint224] = ACTIONS(546),
    [anon_sym_uint232] = ACTIONS(546),
    [anon_sym_uint240] = ACTIONS(546),
    [anon_sym_uint248] = ACTIONS(546),
    [anon_sym_uint256] = ACTIONS(546),
    [anon_sym_bytes] = ACTIONS(546),
    [anon_sym_bytes1] = ACTIONS(546),
    [anon_sym_bytes2] = ACTIONS(546),
    [anon_sym_bytes3] = ACTIONS(546),
    [anon_sym_bytes4] = ACTIONS(546),
    [anon_sym_bytes5] = ACTIONS(546),
    [anon_sym_bytes6] = ACTIONS(546),
    [anon_sym_bytes7] = ACTIONS(546),
    [anon_sym_bytes8] = ACTIONS(546),
    [anon_sym_bytes9] = ACTIONS(546),
    [anon_sym_bytes10] = ACTIONS(546),
    [anon_sym_bytes11] = ACTIONS(546),
    [anon_sym_bytes12] = ACTIONS(546),
    [anon_sym_bytes13] = ACTIONS(546),
    [anon_sym_bytes14] = ACTIONS(546),
    [anon_sym_bytes15] = ACTIONS(546),
    [anon_sym_bytes16] = ACTIONS(546),
    [anon_sym_bytes17] = ACTIONS(546),
    [anon_sym_bytes18] = ACTIONS(546),
    [anon_sym_bytes19] = ACTIONS(546),
    [anon_sym_bytes20] = ACTIONS(546),
    [anon_sym_bytes21] = ACTIONS(546),
    [anon_sym_bytes22] = ACTIONS(546),
    [anon_sym_bytes23] = ACTIONS(546),
    [anon_sym_bytes24] = ACTIONS(546),
    [anon_sym_bytes25] = ACTIONS(546),
    [anon_sym_bytes26] = ACTIONS(546),
    [anon_sym_bytes27] = ACTIONS(546),
    [anon_sym_bytes28] = ACTIONS(546),
    [anon_sym_bytes29] = ACTIONS(546),
    [anon_sym_bytes30] = ACTIONS(546),
    [anon_sym_bytes31] = ACTIONS(546),
    [anon_sym_bytes32] = ACTIONS(546),
    [anon_sym_fixed] = ACTIONS(546),
    [aux_sym__fixed_token1] = ACTIONS(546),
    [anon_sym_ufixed] = ACTIONS(546),
    [aux_sym__ufixed_token1] = ACTIONS(546),
    [aux_sym__decimal_number_token1] = ACTIONS(546),
    [aux_sym__decimal_number_token2] = ACTIONS(548),
    [aux_sym__hex_number_token1] = ACTIONS(548),
    [anon_sym_hex] = ACTIONS(546),
    [anon_sym_DQUOTE] = ACTIONS(548),
    [anon_sym_SQUOTE] = ACTIONS(548),
    [anon_sym_unicode] = ACTIONS(546),
    [sym_comment] = ACTIONS(3),
  },
  [105] = {
    [sym_identifier] = ACTIONS(550),
    [anon_sym_DASH] = ACTIONS(550),
    [anon_sym_TILDE] = ACTIONS(552),
    [anon_sym_LBRACE] = ACTIONS(552),
    [anon_sym_RBRACE] = ACTIONS(552),
    [anon_sym_type] = ACTIONS(550),
    [anon_sym_LPAREN] = ACTIONS(552),
    [anon_sym_for] = ACTIONS(550),
    [anon_sym_PLUS] = ACTIONS(550),
    [anon_sym_assembly] = ACTIONS(550),
    [anon_sym_break] = ACTIONS(550),
    [anon_sym_continue] = ACTIONS(550),
    [anon_sym_true] = ACTIONS(550),
    [anon_sym_false] = ACTIONS(550),
    [anon_sym_if] = ACTIONS(550),
    [anon_sym_function] = ACTIONS(550),
    [anon_sym_byte] = ACTIONS(550),
    [anon_sym_address] = ACTIONS(550),
    [anon_sym_return] = ACTIONS(550),
    [anon_sym_revert] = ACTIONS(550),
    [sym__unchecked] = ACTIONS(550),
    [anon_sym_var] = ACTIONS(550),
    [anon_sym_else] = ACTIONS(550),
    [anon_sym_while] = ACTIONS(550),
    [anon_sym_do] = ACTIONS(550),
    [anon_sym_try] = ACTIONS(550),
    [anon_sym_emit] = ACTIONS(550),
    [anon_sym_payable] = ACTIONS(550),
    [anon_sym_new] = ACTIONS(550),
    [anon_sym_LBRACK] = ACTIONS(552),
    [anon_sym_BANG] = ACTIONS(552),
    [anon_sym_delete] = ACTIONS(550),
    [anon_sym_PLUS_PLUS] = ACTIONS(552),
    [anon_sym_DASH_DASH] = ACTIONS(552),
    [anon_sym_mapping] = ACTIONS(550),
    [anon_sym_bool] = ACTIONS(550),
    [anon_sym_string] = ACTIONS(550),
    [anon_sym_int] = ACTIONS(550),
    [anon_sym_int8] = ACTIONS(550),
    [anon_sym_int16] = ACTIONS(550),
    [anon_sym_int24] = ACTIONS(550),
    [anon_sym_int32] = ACTIONS(550),
    [anon_sym_int40] = ACTIONS(550),
    [anon_sym_int48] = ACTIONS(550),
    [anon_sym_int56] = ACTIONS(550),
    [anon_sym_int64] = ACTIONS(550),
    [anon_sym_int72] = ACTIONS(550),
    [anon_sym_int80] = ACTIONS(550),
    [anon_sym_int88] = ACTIONS(550),
    [anon_sym_int96] = ACTIONS(550),
    [anon_sym_int104] = ACTIONS(550),
    [anon_sym_int112] = ACTIONS(550),
    [anon_sym_int120] = ACTIONS(550),
    [anon_sym_int128] = ACTIONS(550),
    [anon_sym_int136] = ACTIONS(550),
    [anon_sym_int144] = ACTIONS(550),
    [anon_sym_int152] = ACTIONS(550),
    [anon_sym_int160] = ACTIONS(550),
    [anon_sym_int168] = ACTIONS(550),
    [anon_sym_int176] = ACTIONS(550),
    [anon_sym_int184] = ACTIONS(550),
    [anon_sym_int192] = ACTIONS(550),
    [anon_sym_int200] = ACTIONS(550),
    [anon_sym_int208] = ACTIONS(550),
    [anon_sym_int216] = ACTIONS(550),
    [anon_sym_int224] = ACTIONS(550),
    [anon_sym_int232] = ACTIONS(550),
    [anon_sym_int240] = ACTIONS(550),
    [anon_sym_int248] = ACTIONS(550),
    [anon_sym_int256] = ACTIONS(550),
    [anon_sym_uint] = ACTIONS(550),
    [anon_sym_uint8] = ACTIONS(550),
    [anon_sym_uint16] = ACTIONS(550),
    [anon_sym_uint24] = ACTIONS(550),
    [anon_sym_uint32] = ACTIONS(550),
    [anon_sym_uint40] = ACTIONS(550),
    [anon_sym_uint48] = ACTIONS(550),
    [anon_sym_uint56] = ACTIONS(550),
    [anon_sym_uint64] = ACTIONS(550),
    [anon_sym_uint72] = ACTIONS(550),
    [anon_sym_uint80] = ACTIONS(550),
    [anon_sym_uint88] = ACTIONS(550),
    [anon_sym_uint96] = ACTIONS(550),
    [anon_sym_uint104] = ACTIONS(550),
    [anon_sym_uint112] = ACTIONS(550),
    [anon_sym_uint120] = ACTIONS(550),
    [anon_sym_uint128] = ACTIONS(550),
    [anon_sym_uint136] = ACTIONS(550),
    [anon_sym_uint144] = ACTIONS(550),
    [anon_sym_uint152] = ACTIONS(550),
    [anon_sym_uint160] = ACTIONS(550),
    [anon_sym_uint168] = ACTIONS(550),
    [anon_sym_uint176] = ACTIONS(550),
    [anon_sym_uint184] = ACTIONS(550),
    [anon_sym_uint192] = ACTIONS(550),
    [anon_sym_uint200] = ACTIONS(550),
    [anon_sym_uint208] = ACTIONS(550),
    [anon_sym_uint216] = ACTIONS(550),
    [anon_sym_uint224] = ACTIONS(550),
    [anon_sym_uint232] = ACTIONS(550),
    [anon_sym_uint240] = ACTIONS(550),
    [anon_sym_uint248] = ACTIONS(550),
    [anon_sym_uint256] = ACTIONS(550),
    [anon_sym_bytes] = ACTIONS(550),
    [anon_sym_bytes1] = ACTIONS(550),
    [anon_sym_bytes2] = ACTIONS(550),
    [anon_sym_bytes3] = ACTIONS(550),
    [anon_sym_bytes4] = ACTIONS(550),
    [anon_sym_bytes5] = ACTIONS(550),
    [anon_sym_bytes6] = ACTIONS(550),
    [anon_sym_bytes7] = ACTIONS(550),
    [anon_sym_bytes8] = ACTIONS(550),
    [anon_sym_bytes9] = ACTIONS(550),
    [anon_sym_bytes10] = ACTIONS(550),
    [anon_sym_bytes11] = ACTIONS(550),
    [anon_sym_bytes12] = ACTIONS(550),
    [anon_sym_bytes13] = ACTIONS(550),
    [anon_sym_bytes14] = ACTIONS(550),
    [anon_sym_bytes15] = ACTIONS(550),
    [anon_sym_bytes16] = ACTIONS(550),
    [anon_sym_bytes17] = ACTIONS(550),
    [anon_sym_bytes18] = ACTIONS(550),
    [anon_sym_bytes19] = ACTIONS(550),
    [anon_sym_bytes20] = ACTIONS(550),
    [anon_sym_bytes21] = ACTIONS(550),
    [anon_sym_bytes22] = ACTIONS(550),
    [anon_sym_bytes23] = ACTIONS(550),
    [anon_sym_bytes24] = ACTIONS(550),
    [anon_sym_bytes25] = ACTIONS(550),
    [anon_sym_bytes26] = ACTIONS(550),
    [anon_sym_bytes27] = ACTIONS(550),
    [anon_sym_bytes28] = ACTIONS(550),
    [anon_sym_bytes29] = ACTIONS(550),
    [anon_sym_bytes30] = ACTIONS(550),
    [anon_sym_bytes31] = ACTIONS(550),
    [anon_sym_bytes32] = ACTIONS(550),
    [anon_sym_fixed] = ACTIONS(550),
    [aux_sym__fixed_token1] = ACTIONS(550),
    [anon_sym_ufixed] = ACTIONS(550),
    [aux_sym__ufixed_token1] = ACTIONS(550),
    [aux_sym__decimal_number_token1] = ACTIONS(550),
    [aux_sym__decimal_number_token2] = ACTIONS(552),
    [aux_sym__hex_number_token1] = ACTIONS(552),
    [anon_sym_hex] = ACTIONS(550),
    [anon_sym_DQUOTE] = ACTIONS(552),
    [anon_sym_SQUOTE] = ACTIONS(552),
    [anon_sym_unicode] = ACTIONS(550),
    [sym_comment] = ACTIONS(3),
  },
  [106] = {
    [sym_identifier] = ACTIONS(554),
    [anon_sym_DASH] = ACTIONS(554),
    [anon_sym_TILDE] = ACTIONS(556),
    [anon_sym_LBRACE] = ACTIONS(556),
    [anon_sym_RBRACE] = ACTIONS(556),
    [anon_sym_type] = ACTIONS(554),
    [anon_sym_LPAREN] = ACTIONS(556),
    [anon_sym_for] = ACTIONS(554),
    [anon_sym_PLUS] = ACTIONS(554),
    [anon_sym_assembly] = ACTIONS(554),
    [anon_sym_break] = ACTIONS(554),
    [anon_sym_continue] = ACTIONS(554),
    [anon_sym_true] = ACTIONS(554),
    [anon_sym_false] = ACTIONS(554),
    [anon_sym_if] = ACTIONS(554),
    [anon_sym_function] = ACTIONS(554),
    [anon_sym_byte] = ACTIONS(554),
    [anon_sym_address] = ACTIONS(554),
    [anon_sym_return] = ACTIONS(554),
    [anon_sym_revert] = ACTIONS(554),
    [sym__unchecked] = ACTIONS(554),
    [anon_sym_var] = ACTIONS(554),
    [anon_sym_else] = ACTIONS(554),
    [anon_sym_while] = ACTIONS(554),
    [anon_sym_do] = ACTIONS(554),
    [anon_sym_try] = ACTIONS(554),
    [anon_sym_emit] = ACTIONS(554),
    [anon_sym_payable] = ACTIONS(554),
    [anon_sym_new] = ACTIONS(554),
    [anon_sym_LBRACK] = ACTIONS(556),
    [anon_sym_BANG] = ACTIONS(556),
    [anon_sym_delete] = ACTIONS(554),
    [anon_sym_PLUS_PLUS] = ACTIONS(556),
    [anon_sym_DASH_DASH] = ACTIONS(556),
    [anon_sym_mapping] = ACTIONS(554),
    [anon_sym_bool] = ACTIONS(554),
    [anon_sym_string] = ACTIONS(554),
    [anon_sym_int] = ACTIONS(554),
    [anon_sym_int8] = ACTIONS(554),
    [anon_sym_int16] = ACTIONS(554),
    [anon_sym_int24] = ACTIONS(554),
    [anon_sym_int32] = ACTIONS(554),
    [anon_sym_int40] = ACTIONS(554),
    [anon_sym_int48] = ACTIONS(554),
    [anon_sym_int56] = ACTIONS(554),
    [anon_sym_int64] = ACTIONS(554),
    [anon_sym_int72] = ACTIONS(554),
    [anon_sym_int80] = ACTIONS(554),
    [anon_sym_int88] = ACTIONS(554),
    [anon_sym_int96] = ACTIONS(554),
    [anon_sym_int104] = ACTIONS(554),
    [anon_sym_int112] = ACTIONS(554),
    [anon_sym_int120] = ACTIONS(554),
    [anon_sym_int128] = ACTIONS(554),
    [anon_sym_int136] = ACTIONS(554),
    [anon_sym_int144] = ACTIONS(554),
    [anon_sym_int152] = ACTIONS(554),
    [anon_sym_int160] = ACTIONS(554),
    [anon_sym_int168] = ACTIONS(554),
    [anon_sym_int176] = ACTIONS(554),
    [anon_sym_int184] = ACTIONS(554),
    [anon_sym_int192] = ACTIONS(554),
    [anon_sym_int200] = ACTIONS(554),
    [anon_sym_int208] = ACTIONS(554),
    [anon_sym_int216] = ACTIONS(554),
    [anon_sym_int224] = ACTIONS(554),
    [anon_sym_int232] = ACTIONS(554),
    [anon_sym_int240] = ACTIONS(554),
    [anon_sym_int248] = ACTIONS(554),
    [anon_sym_int256] = ACTIONS(554),
    [anon_sym_uint] = ACTIONS(554),
    [anon_sym_uint8] = ACTIONS(554),
    [anon_sym_uint16] = ACTIONS(554),
    [anon_sym_uint24] = ACTIONS(554),
    [anon_sym_uint32] = ACTIONS(554),
    [anon_sym_uint40] = ACTIONS(554),
    [anon_sym_uint48] = ACTIONS(554),
    [anon_sym_uint56] = ACTIONS(554),
    [anon_sym_uint64] = ACTIONS(554),
    [anon_sym_uint72] = ACTIONS(554),
    [anon_sym_uint80] = ACTIONS(554),
    [anon_sym_uint88] = ACTIONS(554),
    [anon_sym_uint96] = ACTIONS(554),
    [anon_sym_uint104] = ACTIONS(554),
    [anon_sym_uint112] = ACTIONS(554),
    [anon_sym_uint120] = ACTIONS(554),
    [anon_sym_uint128] = ACTIONS(554),
    [anon_sym_uint136] = ACTIONS(554),
    [anon_sym_uint144] = ACTIONS(554),
    [anon_sym_uint152] = ACTIONS(554),
    [anon_sym_uint160] = ACTIONS(554),
    [anon_sym_uint168] = ACTIONS(554),
    [anon_sym_uint176] = ACTIONS(554),
    [anon_sym_uint184] = ACTIONS(554),
    [anon_sym_uint192] = ACTIONS(554),
    [anon_sym_uint200] = ACTIONS(554),
    [anon_sym_uint208] = ACTIONS(554),
    [anon_sym_uint216] = ACTIONS(554),
    [anon_sym_uint224] = ACTIONS(554),
    [anon_sym_uint232] = ACTIONS(554),
    [anon_sym_uint240] = ACTIONS(554),
    [anon_sym_uint248] = ACTIONS(554),
    [anon_sym_uint256] = ACTIONS(554),
    [anon_sym_bytes] = ACTIONS(554),
    [anon_sym_bytes1] = ACTIONS(554),
    [anon_sym_bytes2] = ACTIONS(554),
    [anon_sym_bytes3] = ACTIONS(554),
    [anon_sym_bytes4] = ACTIONS(554),
    [anon_sym_bytes5] = ACTIONS(554),
    [anon_sym_bytes6] = ACTIONS(554),
    [anon_sym_bytes7] = ACTIONS(554),
    [anon_sym_bytes8] = ACTIONS(554),
    [anon_sym_bytes9] = ACTIONS(554),
    [anon_sym_bytes10] = ACTIONS(554),
    [anon_sym_bytes11] = ACTIONS(554),
    [anon_sym_bytes12] = ACTIONS(554),
    [anon_sym_bytes13] = ACTIONS(554),
    [anon_sym_bytes14] = ACTIONS(554),
    [anon_sym_bytes15] = ACTIONS(554),
    [anon_sym_bytes16] = ACTIONS(554),
    [anon_sym_bytes17] = ACTIONS(554),
    [anon_sym_bytes18] = ACTIONS(554),
    [anon_sym_bytes19] = ACTIONS(554),
    [anon_sym_bytes20] = ACTIONS(554),
    [anon_sym_bytes21] = ACTIONS(554),
    [anon_sym_bytes22] = ACTIONS(554),
    [anon_sym_bytes23] = ACTIONS(554),
    [anon_sym_bytes24] = ACTIONS(554),
    [anon_sym_bytes25] = ACTIONS(554),
    [anon_sym_bytes26] = ACTIONS(554),
    [anon_sym_bytes27] = ACTIONS(554),
    [anon_sym_bytes28] = ACTIONS(554),
    [anon_sym_bytes29] = ACTIONS(554),
    [anon_sym_bytes30] = ACTIONS(554),
    [anon_sym_bytes31] = ACTIONS(554),
    [anon_sym_bytes32] = ACTIONS(554),
    [anon_sym_fixed] = ACTIONS(554),
    [aux_sym__fixed_token1] = ACTIONS(554),
    [anon_sym_ufixed] = ACTIONS(554),
    [aux_sym__ufixed_token1] = ACTIONS(554),
    [aux_sym__decimal_number_token1] = ACTIONS(554),
    [aux_sym__decimal_number_token2] = ACTIONS(556),
    [aux_sym__hex_number_token1] = ACTIONS(556),
    [anon_sym_hex] = ACTIONS(554),
    [anon_sym_DQUOTE] = ACTIONS(556),
    [anon_sym_SQUOTE] = ACTIONS(556),
    [anon_sym_unicode] = ACTIONS(554),
    [sym_comment] = ACTIONS(3),
  },
  [107] = {
    [sym_identifier] = ACTIONS(558),
    [anon_sym_DASH] = ACTIONS(558),
    [anon_sym_TILDE] = ACTIONS(560),
    [anon_sym_LBRACE] = ACTIONS(560),
    [anon_sym_RBRACE] = ACTIONS(560),
    [anon_sym_type] = ACTIONS(558),
    [anon_sym_LPAREN] = ACTIONS(560),
    [anon_sym_for] = ACTIONS(558),
    [anon_sym_PLUS] = ACTIONS(558),
    [anon_sym_assembly] = ACTIONS(558),
    [anon_sym_break] = ACTIONS(558),
    [anon_sym_continue] = ACTIONS(558),
    [anon_sym_true] = ACTIONS(558),
    [anon_sym_false] = ACTIONS(558),
    [anon_sym_if] = ACTIONS(558),
    [anon_sym_function] = ACTIONS(558),
    [anon_sym_byte] = ACTIONS(558),
    [anon_sym_address] = ACTIONS(558),
    [anon_sym_return] = ACTIONS(558),
    [anon_sym_revert] = ACTIONS(558),
    [sym__unchecked] = ACTIONS(558),
    [anon_sym_var] = ACTIONS(558),
    [anon_sym_else] = ACTIONS(558),
    [anon_sym_while] = ACTIONS(558),
    [anon_sym_do] = ACTIONS(558),
    [anon_sym_try] = ACTIONS(558),
    [anon_sym_emit] = ACTIONS(558),
    [anon_sym_payable] = ACTIONS(558),
    [anon_sym_new] = ACTIONS(558),
    [anon_sym_LBRACK] = ACTIONS(560),
    [anon_sym_BANG] = ACTIONS(560),
    [anon_sym_delete] = ACTIONS(558),
    [anon_sym_PLUS_PLUS] = ACTIONS(560),
    [anon_sym_DASH_DASH] = ACTIONS(560),
    [anon_sym_mapping] = ACTIONS(558),
    [anon_sym_bool] = ACTIONS(558),
    [anon_sym_string] = ACTIONS(558),
    [anon_sym_int] = ACTIONS(558),
    [anon_sym_int8] = ACTIONS(558),
    [anon_sym_int16] = ACTIONS(558),
    [anon_sym_int24] = ACTIONS(558),
    [anon_sym_int32] = ACTIONS(558),
    [anon_sym_int40] = ACTIONS(558),
    [anon_sym_int48] = ACTIONS(558),
    [anon_sym_int56] = ACTIONS(558),
    [anon_sym_int64] = ACTIONS(558),
    [anon_sym_int72] = ACTIONS(558),
    [anon_sym_int80] = ACTIONS(558),
    [anon_sym_int88] = ACTIONS(558),
    [anon_sym_int96] = ACTIONS(558),
    [anon_sym_int104] = ACTIONS(558),
    [anon_sym_int112] = ACTIONS(558),
    [anon_sym_int120] = ACTIONS(558),
    [anon_sym_int128] = ACTIONS(558),
    [anon_sym_int136] = ACTIONS(558),
    [anon_sym_int144] = ACTIONS(558),
    [anon_sym_int152] = ACTIONS(558),
    [anon_sym_int160] = ACTIONS(558),
    [anon_sym_int168] = ACTIONS(558),
    [anon_sym_int176] = ACTIONS(558),
    [anon_sym_int184] = ACTIONS(558),
    [anon_sym_int192] = ACTIONS(558),
    [anon_sym_int200] = ACTIONS(558),
    [anon_sym_int208] = ACTIONS(558),
    [anon_sym_int216] = ACTIONS(558),
    [anon_sym_int224] = ACTIONS(558),
    [anon_sym_int232] = ACTIONS(558),
    [anon_sym_int240] = ACTIONS(558),
    [anon_sym_int248] = ACTIONS(558),
    [anon_sym_int256] = ACTIONS(558),
    [anon_sym_uint] = ACTIONS(558),
    [anon_sym_uint8] = ACTIONS(558),
    [anon_sym_uint16] = ACTIONS(558),
    [anon_sym_uint24] = ACTIONS(558),
    [anon_sym_uint32] = ACTIONS(558),
    [anon_sym_uint40] = ACTIONS(558),
    [anon_sym_uint48] = ACTIONS(558),
    [anon_sym_uint56] = ACTIONS(558),
    [anon_sym_uint64] = ACTIONS(558),
    [anon_sym_uint72] = ACTIONS(558),
    [anon_sym_uint80] = ACTIONS(558),
    [anon_sym_uint88] = ACTIONS(558),
    [anon_sym_uint96] = ACTIONS(558),
    [anon_sym_uint104] = ACTIONS(558),
    [anon_sym_uint112] = ACTIONS(558),
    [anon_sym_uint120] = ACTIONS(558),
    [anon_sym_uint128] = ACTIONS(558),
    [anon_sym_uint136] = ACTIONS(558),
    [anon_sym_uint144] = ACTIONS(558),
    [anon_sym_uint152] = ACTIONS(558),
    [anon_sym_uint160] = ACTIONS(558),
    [anon_sym_uint168] = ACTIONS(558),
    [anon_sym_uint176] = ACTIONS(558),
    [anon_sym_uint184] = ACTIONS(558),
    [anon_sym_uint192] = ACTIONS(558),
    [anon_sym_uint200] = ACTIONS(558),
    [anon_sym_uint208] = ACTIONS(558),
    [anon_sym_uint216] = ACTIONS(558),
    [anon_sym_uint224] = ACTIONS(558),
    [anon_sym_uint232] = ACTIONS(558),
    [anon_sym_uint240] = ACTIONS(558),
    [anon_sym_uint248] = ACTIONS(558),
    [anon_sym_uint256] = ACTIONS(558),
    [anon_sym_bytes] = ACTIONS(558),
    [anon_sym_bytes1] = ACTIONS(558),
    [anon_sym_bytes2] = ACTIONS(558),
    [anon_sym_bytes3] = ACTIONS(558),
    [anon_sym_bytes4] = ACTIONS(558),
    [anon_sym_bytes5] = ACTIONS(558),
    [anon_sym_bytes6] = ACTIONS(558),
    [anon_sym_bytes7] = ACTIONS(558),
    [anon_sym_bytes8] = ACTIONS(558),
    [anon_sym_bytes9] = ACTIONS(558),
    [anon_sym_bytes10] = ACTIONS(558),
    [anon_sym_bytes11] = ACTIONS(558),
    [anon_sym_bytes12] = ACTIONS(558),
    [anon_sym_bytes13] = ACTIONS(558),
    [anon_sym_bytes14] = ACTIONS(558),
    [anon_sym_bytes15] = ACTIONS(558),
    [anon_sym_bytes16] = ACTIONS(558),
    [anon_sym_bytes17] = ACTIONS(558),
    [anon_sym_bytes18] = ACTIONS(558),
    [anon_sym_bytes19] = ACTIONS(558),
    [anon_sym_bytes20] = ACTIONS(558),
    [anon_sym_bytes21] = ACTIONS(558),
    [anon_sym_bytes22] = ACTIONS(558),
    [anon_sym_bytes23] = ACTIONS(558),
    [anon_sym_bytes24] = ACTIONS(558),
    [anon_sym_bytes25] = ACTIONS(558),
    [anon_sym_bytes26] = ACTIONS(558),
    [anon_sym_bytes27] = ACTIONS(558),
    [anon_sym_bytes28] = ACTIONS(558),
    [anon_sym_bytes29] = ACTIONS(558),
    [anon_sym_bytes30] = ACTIONS(558),
    [anon_sym_bytes31] = ACTIONS(558),
    [anon_sym_bytes32] = ACTIONS(558),
    [anon_sym_fixed] = ACTIONS(558),
    [aux_sym__fixed_token1] = ACTIONS(558),
    [anon_sym_ufixed] = ACTIONS(558),
    [aux_sym__ufixed_token1] = ACTIONS(558),
    [aux_sym__decimal_number_token1] = ACTIONS(558),
    [aux_sym__decimal_number_token2] = ACTIONS(560),
    [aux_sym__hex_number_token1] = ACTIONS(560),
    [anon_sym_hex] = ACTIONS(558),
    [anon_sym_DQUOTE] = ACTIONS(560),
    [anon_sym_SQUOTE] = ACTIONS(560),
    [anon_sym_unicode] = ACTIONS(558),
    [sym_comment] = ACTIONS(3),
  },
  [108] = {
    [sym_variable_declaration] = STATE(852),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(562),
    [anon_sym_RPAREN] = ACTIONS(564),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [109] = {
    [sym_variable_declaration] = STATE(852),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(562),
    [anon_sym_RPAREN] = ACTIONS(562),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [110] = {
    [sym_struct_member] = STATE(110),
    [sym_type_name] = STATE(866),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_struct_declaration_repeat1] = STATE(110),
    [sym_identifier] = ACTIONS(566),
    [anon_sym_RBRACE] = ACTIONS(569),
    [anon_sym_function] = ACTIONS(571),
    [anon_sym_byte] = ACTIONS(574),
    [anon_sym_address] = ACTIONS(577),
    [anon_sym_var] = ACTIONS(574),
    [anon_sym_mapping] = ACTIONS(580),
    [anon_sym_bool] = ACTIONS(574),
    [anon_sym_string] = ACTIONS(574),
    [anon_sym_int] = ACTIONS(574),
    [anon_sym_int8] = ACTIONS(574),
    [anon_sym_int16] = ACTIONS(574),
    [anon_sym_int24] = ACTIONS(574),
    [anon_sym_int32] = ACTIONS(574),
    [anon_sym_int40] = ACTIONS(574),
    [anon_sym_int48] = ACTIONS(574),
    [anon_sym_int56] = ACTIONS(574),
    [anon_sym_int64] = ACTIONS(574),
    [anon_sym_int72] = ACTIONS(574),
    [anon_sym_int80] = ACTIONS(574),
    [anon_sym_int88] = ACTIONS(574),
    [anon_sym_int96] = ACTIONS(574),
    [anon_sym_int104] = ACTIONS(574),
    [anon_sym_int112] = ACTIONS(574),
    [anon_sym_int120] = ACTIONS(574),
    [anon_sym_int128] = ACTIONS(574),
    [anon_sym_int136] = ACTIONS(574),
    [anon_sym_int144] = ACTIONS(574),
    [anon_sym_int152] = ACTIONS(574),
    [anon_sym_int160] = ACTIONS(574),
    [anon_sym_int168] = ACTIONS(574),
    [anon_sym_int176] = ACTIONS(574),
    [anon_sym_int184] = ACTIONS(574),
    [anon_sym_int192] = ACTIONS(574),
    [anon_sym_int200] = ACTIONS(574),
    [anon_sym_int208] = ACTIONS(574),
    [anon_sym_int216] = ACTIONS(574),
    [anon_sym_int224] = ACTIONS(574),
    [anon_sym_int232] = ACTIONS(574),
    [anon_sym_int240] = ACTIONS(574),
    [anon_sym_int248] = ACTIONS(574),
    [anon_sym_int256] = ACTIONS(574),
    [anon_sym_uint] = ACTIONS(574),
    [anon_sym_uint8] = ACTIONS(574),
    [anon_sym_uint16] = ACTIONS(574),
    [anon_sym_uint24] = ACTIONS(574),
    [anon_sym_uint32] = ACTIONS(574),
    [anon_sym_uint40] = ACTIONS(574),
    [anon_sym_uint48] = ACTIONS(574),
    [anon_sym_uint56] = ACTIONS(574),
    [anon_sym_uint64] = ACTIONS(574),
    [anon_sym_uint72] = ACTIONS(574),
    [anon_sym_uint80] = ACTIONS(574),
    [anon_sym_uint88] = ACTIONS(574),
    [anon_sym_uint96] = ACTIONS(574),
    [anon_sym_uint104] = ACTIONS(574),
    [anon_sym_uint112] = ACTIONS(574),
    [anon_sym_uint120] = ACTIONS(574),
    [anon_sym_uint128] = ACTIONS(574),
    [anon_sym_uint136] = ACTIONS(574),
    [anon_sym_uint144] = ACTIONS(574),
    [anon_sym_uint152] = ACTIONS(574),
    [anon_sym_uint160] = ACTIONS(574),
    [anon_sym_uint168] = ACTIONS(574),
    [anon_sym_uint176] = ACTIONS(574),
    [anon_sym_uint184] = ACTIONS(574),
    [anon_sym_uint192] = ACTIONS(574),
    [anon_sym_uint200] = ACTIONS(574),
    [anon_sym_uint208] = ACTIONS(574),
    [anon_sym_uint216] = ACTIONS(574),
    [anon_sym_uint224] = ACTIONS(574),
    [anon_sym_uint232] = ACTIONS(574),
    [anon_sym_uint240] = ACTIONS(574),
    [anon_sym_uint248] = ACTIONS(574),
    [anon_sym_uint256] = ACTIONS(574),
    [anon_sym_bytes] = ACTIONS(574),
    [anon_sym_bytes1] = ACTIONS(574),
    [anon_sym_bytes2] = ACTIONS(574),
    [anon_sym_bytes3] = ACTIONS(574),
    [anon_sym_bytes4] = ACTIONS(574),
    [anon_sym_bytes5] = ACTIONS(574),
    [anon_sym_bytes6] = ACTIONS(574),
    [anon_sym_bytes7] = ACTIONS(574),
    [anon_sym_bytes8] = ACTIONS(574),
    [anon_sym_bytes9] = ACTIONS(574),
    [anon_sym_bytes10] = ACTIONS(574),
    [anon_sym_bytes11] = ACTIONS(574),
    [anon_sym_bytes12] = ACTIONS(574),
    [anon_sym_bytes13] = ACTIONS(574),
    [anon_sym_bytes14] = ACTIONS(574),
    [anon_sym_bytes15] = ACTIONS(574),
    [anon_sym_bytes16] = ACTIONS(574),
    [anon_sym_bytes17] = ACTIONS(574),
    [anon_sym_bytes18] = ACTIONS(574),
    [anon_sym_bytes19] = ACTIONS(574),
    [anon_sym_bytes20] = ACTIONS(574),
    [anon_sym_bytes21] = ACTIONS(574),
    [anon_sym_bytes22] = ACTIONS(574),
    [anon_sym_bytes23] = ACTIONS(574),
    [anon_sym_bytes24] = ACTIONS(574),
    [anon_sym_bytes25] = ACTIONS(574),
    [anon_sym_bytes26] = ACTIONS(574),
    [anon_sym_bytes27] = ACTIONS(574),
    [anon_sym_bytes28] = ACTIONS(574),
    [anon_sym_bytes29] = ACTIONS(574),
    [anon_sym_bytes30] = ACTIONS(574),
    [anon_sym_bytes31] = ACTIONS(574),
    [anon_sym_bytes32] = ACTIONS(574),
    [anon_sym_fixed] = ACTIONS(574),
    [aux_sym__fixed_token1] = ACTIONS(574),
    [anon_sym_ufixed] = ACTIONS(574),
    [aux_sym__ufixed_token1] = ACTIONS(574),
    [sym_comment] = ACTIONS(3),
  },
  [111] = {
    [sym_struct_member] = STATE(110),
    [sym_type_name] = STATE(866),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_struct_declaration_repeat1] = STATE(110),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(583),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [112] = {
    [sym_variable_declaration] = STATE(852),
    [sym_type_name] = STATE(583),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(562),
    [anon_sym_RPAREN] = ACTIONS(585),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [113] = {
    [sym_struct_member] = STATE(110),
    [sym_type_name] = STATE(866),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_struct_declaration_repeat1] = STATE(110),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(587),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [114] = {
    [sym_error_parameter] = STATE(879),
    [sym_type_name] = STATE(631),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(589),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [115] = {
    [sym_error_parameter] = STATE(879),
    [sym_type_name] = STATE(631),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(591),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [116] = {
    [sym_any_source_type] = STATE(809),
    [sym_type_name] = STATE(707),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [117] = {
    [sym_any_source_type] = STATE(808),
    [sym_type_name] = STATE(734),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [118] = {
    [sym_event_paramater] = STATE(668),
    [sym_type_name] = STATE(573),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(595),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [119] = {
    [sym_any_source_type] = STATE(807),
    [sym_type_name] = STATE(736),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [120] = {
    [sym_any_source_type] = STATE(834),
    [sym_type_name] = STATE(670),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [121] = {
    [sym_any_source_type] = STATE(859),
    [sym_type_name] = STATE(771),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [122] = {
    [sym_event_paramater] = STATE(815),
    [sym_type_name] = STATE(573),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(597),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [123] = {
    [sym_error_parameter] = STATE(744),
    [sym_type_name] = STATE(631),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [124] = {
    [sym_any_source_type] = STATE(806),
    [sym_type_name] = STATE(738),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [125] = {
    [sym_any_source_type] = STATE(836),
    [sym_type_name] = STATE(674),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [126] = {
    [sym_any_source_type] = STATE(813),
    [sym_type_name] = STATE(702),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [127] = {
    [sym_struct_member] = STATE(111),
    [sym_type_name] = STATE(866),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_struct_declaration_repeat1] = STATE(111),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [128] = {
    [sym_any_source_type] = STATE(826),
    [sym_type_name] = STATE(763),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [129] = {
    [sym_error_parameter] = STATE(661),
    [sym_type_name] = STATE(631),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(601),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [130] = {
    [sym_any_source_type] = STATE(857),
    [sym_type_name] = STATE(699),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [131] = {
    [sym_type_name] = STATE(564),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_parameter] = STATE(709),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(603),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [132] = {
    [sym_any_source_type] = STATE(811),
    [sym_type_name] = STATE(732),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [133] = {
    [sym_type_name] = STATE(565),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym__nameless_parameter] = STATE(844),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(605),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [134] = {
    [sym_any_source_type] = STATE(853),
    [sym_type_name] = STATE(766),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [135] = {
    [sym_type_name] = STATE(565),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym__nameless_parameter] = STATE(844),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [136] = {
    [sym_event_paramater] = STATE(815),
    [sym_type_name] = STATE(573),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(609),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [137] = {
    [sym_type_name] = STATE(564),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_parameter] = STATE(892),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(611),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [138] = {
    [sym_any_source_type] = STATE(810),
    [sym_type_name] = STATE(733),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [139] = {
    [sym_error_parameter] = STATE(879),
    [sym_type_name] = STATE(631),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(613),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [140] = {
    [sym_type_name] = STATE(564),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_parameter] = STATE(892),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(615),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [141] = {
    [sym_any_source_type] = STATE(805),
    [sym_type_name] = STATE(739),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [142] = {
    [sym_any_source_type] = STATE(792),
    [sym_type_name] = STATE(768),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [143] = {
    [sym_any_source_type] = STATE(827),
    [sym_type_name] = STATE(715),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [144] = {
    [sym_error_parameter] = STATE(879),
    [sym_type_name] = STATE(631),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_RPAREN] = ACTIONS(617),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [145] = {
    [sym_any_source_type] = STATE(870),
    [sym_type_name] = STATE(654),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [146] = {
    [sym_struct_member] = STATE(113),
    [sym_type_name] = STATE(866),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [aux_sym_struct_declaration_repeat1] = STATE(113),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [147] = {
    [sym_any_source_type] = STATE(812),
    [sym_type_name] = STATE(728),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_STAR] = ACTIONS(593),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [148] = {
    [sym_type_name] = STATE(565),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym__nameless_parameter] = STATE(701),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [149] = {
    [sym_event_paramater] = STATE(815),
    [sym_type_name] = STATE(573),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [150] = {
    [sym_type_name] = STATE(565),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym__nameless_parameter] = STATE(844),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [151] = {
    [sym_error_parameter] = STATE(879),
    [sym_type_name] = STATE(631),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [152] = {
    [sym_type_name] = STATE(564),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_parameter] = STATE(892),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [153] = {
    [ts_builtin_sym_end] = ACTIONS(619),
    [sym_identifier] = ACTIONS(621),
    [anon_sym_pragma] = ACTIONS(621),
    [anon_sym_import] = ACTIONS(621),
    [anon_sym_type] = ACTIONS(621),
    [anon_sym_abstract] = ACTIONS(621),
    [anon_sym_contract] = ACTIONS(621),
    [anon_sym_error] = ACTIONS(621),
    [anon_sym_interface] = ACTIONS(621),
    [anon_sym_library] = ACTIONS(621),
    [anon_sym_struct] = ACTIONS(621),
    [anon_sym_enum] = ACTIONS(621),
    [anon_sym_using] = ACTIONS(621),
    [anon_sym_function] = ACTIONS(621),
    [anon_sym_byte] = ACTIONS(621),
    [anon_sym_address] = ACTIONS(621),
    [anon_sym_var] = ACTIONS(621),
    [anon_sym_mapping] = ACTIONS(621),
    [anon_sym_bool] = ACTIONS(621),
    [anon_sym_string] = ACTIONS(621),
    [anon_sym_int] = ACTIONS(621),
    [anon_sym_int8] = ACTIONS(621),
    [anon_sym_int16] = ACTIONS(621),
    [anon_sym_int24] = ACTIONS(621),
    [anon_sym_int32] = ACTIONS(621),
    [anon_sym_int40] = ACTIONS(621),
    [anon_sym_int48] = ACTIONS(621),
    [anon_sym_int56] = ACTIONS(621),
    [anon_sym_int64] = ACTIONS(621),
    [anon_sym_int72] = ACTIONS(621),
    [anon_sym_int80] = ACTIONS(621),
    [anon_sym_int88] = ACTIONS(621),
    [anon_sym_int96] = ACTIONS(621),
    [anon_sym_int104] = ACTIONS(621),
    [anon_sym_int112] = ACTIONS(621),
    [anon_sym_int120] = ACTIONS(621),
    [anon_sym_int128] = ACTIONS(621),
    [anon_sym_int136] = ACTIONS(621),
    [anon_sym_int144] = ACTIONS(621),
    [anon_sym_int152] = ACTIONS(621),
    [anon_sym_int160] = ACTIONS(621),
    [anon_sym_int168] = ACTIONS(621),
    [anon_sym_int176] = ACTIONS(621),
    [anon_sym_int184] = ACTIONS(621),
    [anon_sym_int192] = ACTIONS(621),
    [anon_sym_int200] = ACTIONS(621),
    [anon_sym_int208] = ACTIONS(621),
    [anon_sym_int216] = ACTIONS(621),
    [anon_sym_int224] = ACTIONS(621),
    [anon_sym_int232] = ACTIONS(621),
    [anon_sym_int240] = ACTIONS(621),
    [anon_sym_int248] = ACTIONS(621),
    [anon_sym_int256] = ACTIONS(621),
    [anon_sym_uint] = ACTIONS(621),
    [anon_sym_uint8] = ACTIONS(621),
    [anon_sym_uint16] = ACTIONS(621),
    [anon_sym_uint24] = ACTIONS(621),
    [anon_sym_uint32] = ACTIONS(621),
    [anon_sym_uint40] = ACTIONS(621),
    [anon_sym_uint48] = ACTIONS(621),
    [anon_sym_uint56] = ACTIONS(621),
    [anon_sym_uint64] = ACTIONS(621),
    [anon_sym_uint72] = ACTIONS(621),
    [anon_sym_uint80] = ACTIONS(621),
    [anon_sym_uint88] = ACTIONS(621),
    [anon_sym_uint96] = ACTIONS(621),
    [anon_sym_uint104] = ACTIONS(621),
    [anon_sym_uint112] = ACTIONS(621),
    [anon_sym_uint120] = ACTIONS(621),
    [anon_sym_uint128] = ACTIONS(621),
    [anon_sym_uint136] = ACTIONS(621),
    [anon_sym_uint144] = ACTIONS(621),
    [anon_sym_uint152] = ACTIONS(621),
    [anon_sym_uint160] = ACTIONS(621),
    [anon_sym_uint168] = ACTIONS(621),
    [anon_sym_uint176] = ACTIONS(621),
    [anon_sym_uint184] = ACTIONS(621),
    [anon_sym_uint192] = ACTIONS(621),
    [anon_sym_uint200] = ACTIONS(621),
    [anon_sym_uint208] = ACTIONS(621),
    [anon_sym_uint216] = ACTIONS(621),
    [anon_sym_uint224] = ACTIONS(621),
    [anon_sym_uint232] = ACTIONS(621),
    [anon_sym_uint240] = ACTIONS(621),
    [anon_sym_uint248] = ACTIONS(621),
    [anon_sym_uint256] = ACTIONS(621),
    [anon_sym_bytes] = ACTIONS(621),
    [anon_sym_bytes1] = ACTIONS(621),
    [anon_sym_bytes2] = ACTIONS(621),
    [anon_sym_bytes3] = ACTIONS(621),
    [anon_sym_bytes4] = ACTIONS(621),
    [anon_sym_bytes5] = ACTIONS(621),
    [anon_sym_bytes6] = ACTIONS(621),
    [anon_sym_bytes7] = ACTIONS(621),
    [anon_sym_bytes8] = ACTIONS(621),
    [anon_sym_bytes9] = ACTIONS(621),
    [anon_sym_bytes10] = ACTIONS(621),
    [anon_sym_bytes11] = ACTIONS(621),
    [anon_sym_bytes12] = ACTIONS(621),
    [anon_sym_bytes13] = ACTIONS(621),
    [anon_sym_bytes14] = ACTIONS(621),
    [anon_sym_bytes15] = ACTIONS(621),
    [anon_sym_bytes16] = ACTIONS(621),
    [anon_sym_bytes17] = ACTIONS(621),
    [anon_sym_bytes18] = ACTIONS(621),
    [anon_sym_bytes19] = ACTIONS(621),
    [anon_sym_bytes20] = ACTIONS(621),
    [anon_sym_bytes21] = ACTIONS(621),
    [anon_sym_bytes22] = ACTIONS(621),
    [anon_sym_bytes23] = ACTIONS(621),
    [anon_sym_bytes24] = ACTIONS(621),
    [anon_sym_bytes25] = ACTIONS(621),
    [anon_sym_bytes26] = ACTIONS(621),
    [anon_sym_bytes27] = ACTIONS(621),
    [anon_sym_bytes28] = ACTIONS(621),
    [anon_sym_bytes29] = ACTIONS(621),
    [anon_sym_bytes30] = ACTIONS(621),
    [anon_sym_bytes31] = ACTIONS(621),
    [anon_sym_bytes32] = ACTIONS(621),
    [anon_sym_fixed] = ACTIONS(621),
    [aux_sym__fixed_token1] = ACTIONS(621),
    [anon_sym_ufixed] = ACTIONS(621),
    [aux_sym__ufixed_token1] = ACTIONS(621),
    [sym_comment] = ACTIONS(3),
  },
  [154] = {
    [ts_builtin_sym_end] = ACTIONS(623),
    [sym_identifier] = ACTIONS(625),
    [anon_sym_pragma] = ACTIONS(625),
    [anon_sym_import] = ACTIONS(625),
    [anon_sym_type] = ACTIONS(625),
    [anon_sym_abstract] = ACTIONS(625),
    [anon_sym_contract] = ACTIONS(625),
    [anon_sym_error] = ACTIONS(625),
    [anon_sym_interface] = ACTIONS(625),
    [anon_sym_library] = ACTIONS(625),
    [anon_sym_struct] = ACTIONS(625),
    [anon_sym_enum] = ACTIONS(625),
    [anon_sym_using] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(625),
    [anon_sym_byte] = ACTIONS(625),
    [anon_sym_address] = ACTIONS(625),
    [anon_sym_var] = ACTIONS(625),
    [anon_sym_mapping] = ACTIONS(625),
    [anon_sym_bool] = ACTIONS(625),
    [anon_sym_string] = ACTIONS(625),
    [anon_sym_int] = ACTIONS(625),
    [anon_sym_int8] = ACTIONS(625),
    [anon_sym_int16] = ACTIONS(625),
    [anon_sym_int24] = ACTIONS(625),
    [anon_sym_int32] = ACTIONS(625),
    [anon_sym_int40] = ACTIONS(625),
    [anon_sym_int48] = ACTIONS(625),
    [anon_sym_int56] = ACTIONS(625),
    [anon_sym_int64] = ACTIONS(625),
    [anon_sym_int72] = ACTIONS(625),
    [anon_sym_int80] = ACTIONS(625),
    [anon_sym_int88] = ACTIONS(625),
    [anon_sym_int96] = ACTIONS(625),
    [anon_sym_int104] = ACTIONS(625),
    [anon_sym_int112] = ACTIONS(625),
    [anon_sym_int120] = ACTIONS(625),
    [anon_sym_int128] = ACTIONS(625),
    [anon_sym_int136] = ACTIONS(625),
    [anon_sym_int144] = ACTIONS(625),
    [anon_sym_int152] = ACTIONS(625),
    [anon_sym_int160] = ACTIONS(625),
    [anon_sym_int168] = ACTIONS(625),
    [anon_sym_int176] = ACTIONS(625),
    [anon_sym_int184] = ACTIONS(625),
    [anon_sym_int192] = ACTIONS(625),
    [anon_sym_int200] = ACTIONS(625),
    [anon_sym_int208] = ACTIONS(625),
    [anon_sym_int216] = ACTIONS(625),
    [anon_sym_int224] = ACTIONS(625),
    [anon_sym_int232] = ACTIONS(625),
    [anon_sym_int240] = ACTIONS(625),
    [anon_sym_int248] = ACTIONS(625),
    [anon_sym_int256] = ACTIONS(625),
    [anon_sym_uint] = ACTIONS(625),
    [anon_sym_uint8] = ACTIONS(625),
    [anon_sym_uint16] = ACTIONS(625),
    [anon_sym_uint24] = ACTIONS(625),
    [anon_sym_uint32] = ACTIONS(625),
    [anon_sym_uint40] = ACTIONS(625),
    [anon_sym_uint48] = ACTIONS(625),
    [anon_sym_uint56] = ACTIONS(625),
    [anon_sym_uint64] = ACTIONS(625),
    [anon_sym_uint72] = ACTIONS(625),
    [anon_sym_uint80] = ACTIONS(625),
    [anon_sym_uint88] = ACTIONS(625),
    [anon_sym_uint96] = ACTIONS(625),
    [anon_sym_uint104] = ACTIONS(625),
    [anon_sym_uint112] = ACTIONS(625),
    [anon_sym_uint120] = ACTIONS(625),
    [anon_sym_uint128] = ACTIONS(625),
    [anon_sym_uint136] = ACTIONS(625),
    [anon_sym_uint144] = ACTIONS(625),
    [anon_sym_uint152] = ACTIONS(625),
    [anon_sym_uint160] = ACTIONS(625),
    [anon_sym_uint168] = ACTIONS(625),
    [anon_sym_uint176] = ACTIONS(625),
    [anon_sym_uint184] = ACTIONS(625),
    [anon_sym_uint192] = ACTIONS(625),
    [anon_sym_uint200] = ACTIONS(625),
    [anon_sym_uint208] = ACTIONS(625),
    [anon_sym_uint216] = ACTIONS(625),
    [anon_sym_uint224] = ACTIONS(625),
    [anon_sym_uint232] = ACTIONS(625),
    [anon_sym_uint240] = ACTIONS(625),
    [anon_sym_uint248] = ACTIONS(625),
    [anon_sym_uint256] = ACTIONS(625),
    [anon_sym_bytes] = ACTIONS(625),
    [anon_sym_bytes1] = ACTIONS(625),
    [anon_sym_bytes2] = ACTIONS(625),
    [anon_sym_bytes3] = ACTIONS(625),
    [anon_sym_bytes4] = ACTIONS(625),
    [anon_sym_bytes5] = ACTIONS(625),
    [anon_sym_bytes6] = ACTIONS(625),
    [anon_sym_bytes7] = ACTIONS(625),
    [anon_sym_bytes8] = ACTIONS(625),
    [anon_sym_bytes9] = ACTIONS(625),
    [anon_sym_bytes10] = ACTIONS(625),
    [anon_sym_bytes11] = ACTIONS(625),
    [anon_sym_bytes12] = ACTIONS(625),
    [anon_sym_bytes13] = ACTIONS(625),
    [anon_sym_bytes14] = ACTIONS(625),
    [anon_sym_bytes15] = ACTIONS(625),
    [anon_sym_bytes16] = ACTIONS(625),
    [anon_sym_bytes17] = ACTIONS(625),
    [anon_sym_bytes18] = ACTIONS(625),
    [anon_sym_bytes19] = ACTIONS(625),
    [anon_sym_bytes20] = ACTIONS(625),
    [anon_sym_bytes21] = ACTIONS(625),
    [anon_sym_bytes22] = ACTIONS(625),
    [anon_sym_bytes23] = ACTIONS(625),
    [anon_sym_bytes24] = ACTIONS(625),
    [anon_sym_bytes25] = ACTIONS(625),
    [anon_sym_bytes26] = ACTIONS(625),
    [anon_sym_bytes27] = ACTIONS(625),
    [anon_sym_bytes28] = ACTIONS(625),
    [anon_sym_bytes29] = ACTIONS(625),
    [anon_sym_bytes30] = ACTIONS(625),
    [anon_sym_bytes31] = ACTIONS(625),
    [anon_sym_bytes32] = ACTIONS(625),
    [anon_sym_fixed] = ACTIONS(625),
    [aux_sym__fixed_token1] = ACTIONS(625),
    [anon_sym_ufixed] = ACTIONS(625),
    [aux_sym__ufixed_token1] = ACTIONS(625),
    [sym_comment] = ACTIONS(3),
  },
  [155] = {
    [ts_builtin_sym_end] = ACTIONS(627),
    [sym_identifier] = ACTIONS(629),
    [anon_sym_pragma] = ACTIONS(629),
    [anon_sym_import] = ACTIONS(629),
    [anon_sym_type] = ACTIONS(629),
    [anon_sym_abstract] = ACTIONS(629),
    [anon_sym_contract] = ACTIONS(629),
    [anon_sym_error] = ACTIONS(629),
    [anon_sym_interface] = ACTIONS(629),
    [anon_sym_library] = ACTIONS(629),
    [anon_sym_struct] = ACTIONS(629),
    [anon_sym_enum] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(629),
    [anon_sym_function] = ACTIONS(629),
    [anon_sym_byte] = ACTIONS(629),
    [anon_sym_address] = ACTIONS(629),
    [anon_sym_var] = ACTIONS(629),
    [anon_sym_mapping] = ACTIONS(629),
    [anon_sym_bool] = ACTIONS(629),
    [anon_sym_string] = ACTIONS(629),
    [anon_sym_int] = ACTIONS(629),
    [anon_sym_int8] = ACTIONS(629),
    [anon_sym_int16] = ACTIONS(629),
    [anon_sym_int24] = ACTIONS(629),
    [anon_sym_int32] = ACTIONS(629),
    [anon_sym_int40] = ACTIONS(629),
    [anon_sym_int48] = ACTIONS(629),
    [anon_sym_int56] = ACTIONS(629),
    [anon_sym_int64] = ACTIONS(629),
    [anon_sym_int72] = ACTIONS(629),
    [anon_sym_int80] = ACTIONS(629),
    [anon_sym_int88] = ACTIONS(629),
    [anon_sym_int96] = ACTIONS(629),
    [anon_sym_int104] = ACTIONS(629),
    [anon_sym_int112] = ACTIONS(629),
    [anon_sym_int120] = ACTIONS(629),
    [anon_sym_int128] = ACTIONS(629),
    [anon_sym_int136] = ACTIONS(629),
    [anon_sym_int144] = ACTIONS(629),
    [anon_sym_int152] = ACTIONS(629),
    [anon_sym_int160] = ACTIONS(629),
    [anon_sym_int168] = ACTIONS(629),
    [anon_sym_int176] = ACTIONS(629),
    [anon_sym_int184] = ACTIONS(629),
    [anon_sym_int192] = ACTIONS(629),
    [anon_sym_int200] = ACTIONS(629),
    [anon_sym_int208] = ACTIONS(629),
    [anon_sym_int216] = ACTIONS(629),
    [anon_sym_int224] = ACTIONS(629),
    [anon_sym_int232] = ACTIONS(629),
    [anon_sym_int240] = ACTIONS(629),
    [anon_sym_int248] = ACTIONS(629),
    [anon_sym_int256] = ACTIONS(629),
    [anon_sym_uint] = ACTIONS(629),
    [anon_sym_uint8] = ACTIONS(629),
    [anon_sym_uint16] = ACTIONS(629),
    [anon_sym_uint24] = ACTIONS(629),
    [anon_sym_uint32] = ACTIONS(629),
    [anon_sym_uint40] = ACTIONS(629),
    [anon_sym_uint48] = ACTIONS(629),
    [anon_sym_uint56] = ACTIONS(629),
    [anon_sym_uint64] = ACTIONS(629),
    [anon_sym_uint72] = ACTIONS(629),
    [anon_sym_uint80] = ACTIONS(629),
    [anon_sym_uint88] = ACTIONS(629),
    [anon_sym_uint96] = ACTIONS(629),
    [anon_sym_uint104] = ACTIONS(629),
    [anon_sym_uint112] = ACTIONS(629),
    [anon_sym_uint120] = ACTIONS(629),
    [anon_sym_uint128] = ACTIONS(629),
    [anon_sym_uint136] = ACTIONS(629),
    [anon_sym_uint144] = ACTIONS(629),
    [anon_sym_uint152] = ACTIONS(629),
    [anon_sym_uint160] = ACTIONS(629),
    [anon_sym_uint168] = ACTIONS(629),
    [anon_sym_uint176] = ACTIONS(629),
    [anon_sym_uint184] = ACTIONS(629),
    [anon_sym_uint192] = ACTIONS(629),
    [anon_sym_uint200] = ACTIONS(629),
    [anon_sym_uint208] = ACTIONS(629),
    [anon_sym_uint216] = ACTIONS(629),
    [anon_sym_uint224] = ACTIONS(629),
    [anon_sym_uint232] = ACTIONS(629),
    [anon_sym_uint240] = ACTIONS(629),
    [anon_sym_uint248] = ACTIONS(629),
    [anon_sym_uint256] = ACTIONS(629),
    [anon_sym_bytes] = ACTIONS(629),
    [anon_sym_bytes1] = ACTIONS(629),
    [anon_sym_bytes2] = ACTIONS(629),
    [anon_sym_bytes3] = ACTIONS(629),
    [anon_sym_bytes4] = ACTIONS(629),
    [anon_sym_bytes5] = ACTIONS(629),
    [anon_sym_bytes6] = ACTIONS(629),
    [anon_sym_bytes7] = ACTIONS(629),
    [anon_sym_bytes8] = ACTIONS(629),
    [anon_sym_bytes9] = ACTIONS(629),
    [anon_sym_bytes10] = ACTIONS(629),
    [anon_sym_bytes11] = ACTIONS(629),
    [anon_sym_bytes12] = ACTIONS(629),
    [anon_sym_bytes13] = ACTIONS(629),
    [anon_sym_bytes14] = ACTIONS(629),
    [anon_sym_bytes15] = ACTIONS(629),
    [anon_sym_bytes16] = ACTIONS(629),
    [anon_sym_bytes17] = ACTIONS(629),
    [anon_sym_bytes18] = ACTIONS(629),
    [anon_sym_bytes19] = ACTIONS(629),
    [anon_sym_bytes20] = ACTIONS(629),
    [anon_sym_bytes21] = ACTIONS(629),
    [anon_sym_bytes22] = ACTIONS(629),
    [anon_sym_bytes23] = ACTIONS(629),
    [anon_sym_bytes24] = ACTIONS(629),
    [anon_sym_bytes25] = ACTIONS(629),
    [anon_sym_bytes26] = ACTIONS(629),
    [anon_sym_bytes27] = ACTIONS(629),
    [anon_sym_bytes28] = ACTIONS(629),
    [anon_sym_bytes29] = ACTIONS(629),
    [anon_sym_bytes30] = ACTIONS(629),
    [anon_sym_bytes31] = ACTIONS(629),
    [anon_sym_bytes32] = ACTIONS(629),
    [anon_sym_fixed] = ACTIONS(629),
    [aux_sym__fixed_token1] = ACTIONS(629),
    [anon_sym_ufixed] = ACTIONS(629),
    [aux_sym__ufixed_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(3),
  },
  [156] = {
    [ts_builtin_sym_end] = ACTIONS(631),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_pragma] = ACTIONS(633),
    [anon_sym_import] = ACTIONS(633),
    [anon_sym_type] = ACTIONS(633),
    [anon_sym_abstract] = ACTIONS(633),
    [anon_sym_contract] = ACTIONS(633),
    [anon_sym_error] = ACTIONS(633),
    [anon_sym_interface] = ACTIONS(633),
    [anon_sym_library] = ACTIONS(633),
    [anon_sym_struct] = ACTIONS(633),
    [anon_sym_enum] = ACTIONS(633),
    [anon_sym_using] = ACTIONS(633),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_byte] = ACTIONS(633),
    [anon_sym_address] = ACTIONS(633),
    [anon_sym_var] = ACTIONS(633),
    [anon_sym_mapping] = ACTIONS(633),
    [anon_sym_bool] = ACTIONS(633),
    [anon_sym_string] = ACTIONS(633),
    [anon_sym_int] = ACTIONS(633),
    [anon_sym_int8] = ACTIONS(633),
    [anon_sym_int16] = ACTIONS(633),
    [anon_sym_int24] = ACTIONS(633),
    [anon_sym_int32] = ACTIONS(633),
    [anon_sym_int40] = ACTIONS(633),
    [anon_sym_int48] = ACTIONS(633),
    [anon_sym_int56] = ACTIONS(633),
    [anon_sym_int64] = ACTIONS(633),
    [anon_sym_int72] = ACTIONS(633),
    [anon_sym_int80] = ACTIONS(633),
    [anon_sym_int88] = ACTIONS(633),
    [anon_sym_int96] = ACTIONS(633),
    [anon_sym_int104] = ACTIONS(633),
    [anon_sym_int112] = ACTIONS(633),
    [anon_sym_int120] = ACTIONS(633),
    [anon_sym_int128] = ACTIONS(633),
    [anon_sym_int136] = ACTIONS(633),
    [anon_sym_int144] = ACTIONS(633),
    [anon_sym_int152] = ACTIONS(633),
    [anon_sym_int160] = ACTIONS(633),
    [anon_sym_int168] = ACTIONS(633),
    [anon_sym_int176] = ACTIONS(633),
    [anon_sym_int184] = ACTIONS(633),
    [anon_sym_int192] = ACTIONS(633),
    [anon_sym_int200] = ACTIONS(633),
    [anon_sym_int208] = ACTIONS(633),
    [anon_sym_int216] = ACTIONS(633),
    [anon_sym_int224] = ACTIONS(633),
    [anon_sym_int232] = ACTIONS(633),
    [anon_sym_int240] = ACTIONS(633),
    [anon_sym_int248] = ACTIONS(633),
    [anon_sym_int256] = ACTIONS(633),
    [anon_sym_uint] = ACTIONS(633),
    [anon_sym_uint8] = ACTIONS(633),
    [anon_sym_uint16] = ACTIONS(633),
    [anon_sym_uint24] = ACTIONS(633),
    [anon_sym_uint32] = ACTIONS(633),
    [anon_sym_uint40] = ACTIONS(633),
    [anon_sym_uint48] = ACTIONS(633),
    [anon_sym_uint56] = ACTIONS(633),
    [anon_sym_uint64] = ACTIONS(633),
    [anon_sym_uint72] = ACTIONS(633),
    [anon_sym_uint80] = ACTIONS(633),
    [anon_sym_uint88] = ACTIONS(633),
    [anon_sym_uint96] = ACTIONS(633),
    [anon_sym_uint104] = ACTIONS(633),
    [anon_sym_uint112] = ACTIONS(633),
    [anon_sym_uint120] = ACTIONS(633),
    [anon_sym_uint128] = ACTIONS(633),
    [anon_sym_uint136] = ACTIONS(633),
    [anon_sym_uint144] = ACTIONS(633),
    [anon_sym_uint152] = ACTIONS(633),
    [anon_sym_uint160] = ACTIONS(633),
    [anon_sym_uint168] = ACTIONS(633),
    [anon_sym_uint176] = ACTIONS(633),
    [anon_sym_uint184] = ACTIONS(633),
    [anon_sym_uint192] = ACTIONS(633),
    [anon_sym_uint200] = ACTIONS(633),
    [anon_sym_uint208] = ACTIONS(633),
    [anon_sym_uint216] = ACTIONS(633),
    [anon_sym_uint224] = ACTIONS(633),
    [anon_sym_uint232] = ACTIONS(633),
    [anon_sym_uint240] = ACTIONS(633),
    [anon_sym_uint248] = ACTIONS(633),
    [anon_sym_uint256] = ACTIONS(633),
    [anon_sym_bytes] = ACTIONS(633),
    [anon_sym_bytes1] = ACTIONS(633),
    [anon_sym_bytes2] = ACTIONS(633),
    [anon_sym_bytes3] = ACTIONS(633),
    [anon_sym_bytes4] = ACTIONS(633),
    [anon_sym_bytes5] = ACTIONS(633),
    [anon_sym_bytes6] = ACTIONS(633),
    [anon_sym_bytes7] = ACTIONS(633),
    [anon_sym_bytes8] = ACTIONS(633),
    [anon_sym_bytes9] = ACTIONS(633),
    [anon_sym_bytes10] = ACTIONS(633),
    [anon_sym_bytes11] = ACTIONS(633),
    [anon_sym_bytes12] = ACTIONS(633),
    [anon_sym_bytes13] = ACTIONS(633),
    [anon_sym_bytes14] = ACTIONS(633),
    [anon_sym_bytes15] = ACTIONS(633),
    [anon_sym_bytes16] = ACTIONS(633),
    [anon_sym_bytes17] = ACTIONS(633),
    [anon_sym_bytes18] = ACTIONS(633),
    [anon_sym_bytes19] = ACTIONS(633),
    [anon_sym_bytes20] = ACTIONS(633),
    [anon_sym_bytes21] = ACTIONS(633),
    [anon_sym_bytes22] = ACTIONS(633),
    [anon_sym_bytes23] = ACTIONS(633),
    [anon_sym_bytes24] = ACTIONS(633),
    [anon_sym_bytes25] = ACTIONS(633),
    [anon_sym_bytes26] = ACTIONS(633),
    [anon_sym_bytes27] = ACTIONS(633),
    [anon_sym_bytes28] = ACTIONS(633),
    [anon_sym_bytes29] = ACTIONS(633),
    [anon_sym_bytes30] = ACTIONS(633),
    [anon_sym_bytes31] = ACTIONS(633),
    [anon_sym_bytes32] = ACTIONS(633),
    [anon_sym_fixed] = ACTIONS(633),
    [aux_sym__fixed_token1] = ACTIONS(633),
    [anon_sym_ufixed] = ACTIONS(633),
    [aux_sym__ufixed_token1] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
  },
  [157] = {
    [ts_builtin_sym_end] = ACTIONS(635),
    [sym_identifier] = ACTIONS(637),
    [anon_sym_pragma] = ACTIONS(637),
    [anon_sym_import] = ACTIONS(637),
    [anon_sym_type] = ACTIONS(637),
    [anon_sym_abstract] = ACTIONS(637),
    [anon_sym_contract] = ACTIONS(637),
    [anon_sym_error] = ACTIONS(637),
    [anon_sym_interface] = ACTIONS(637),
    [anon_sym_library] = ACTIONS(637),
    [anon_sym_struct] = ACTIONS(637),
    [anon_sym_enum] = ACTIONS(637),
    [anon_sym_using] = ACTIONS(637),
    [anon_sym_function] = ACTIONS(637),
    [anon_sym_byte] = ACTIONS(637),
    [anon_sym_address] = ACTIONS(637),
    [anon_sym_var] = ACTIONS(637),
    [anon_sym_mapping] = ACTIONS(637),
    [anon_sym_bool] = ACTIONS(637),
    [anon_sym_string] = ACTIONS(637),
    [anon_sym_int] = ACTIONS(637),
    [anon_sym_int8] = ACTIONS(637),
    [anon_sym_int16] = ACTIONS(637),
    [anon_sym_int24] = ACTIONS(637),
    [anon_sym_int32] = ACTIONS(637),
    [anon_sym_int40] = ACTIONS(637),
    [anon_sym_int48] = ACTIONS(637),
    [anon_sym_int56] = ACTIONS(637),
    [anon_sym_int64] = ACTIONS(637),
    [anon_sym_int72] = ACTIONS(637),
    [anon_sym_int80] = ACTIONS(637),
    [anon_sym_int88] = ACTIONS(637),
    [anon_sym_int96] = ACTIONS(637),
    [anon_sym_int104] = ACTIONS(637),
    [anon_sym_int112] = ACTIONS(637),
    [anon_sym_int120] = ACTIONS(637),
    [anon_sym_int128] = ACTIONS(637),
    [anon_sym_int136] = ACTIONS(637),
    [anon_sym_int144] = ACTIONS(637),
    [anon_sym_int152] = ACTIONS(637),
    [anon_sym_int160] = ACTIONS(637),
    [anon_sym_int168] = ACTIONS(637),
    [anon_sym_int176] = ACTIONS(637),
    [anon_sym_int184] = ACTIONS(637),
    [anon_sym_int192] = ACTIONS(637),
    [anon_sym_int200] = ACTIONS(637),
    [anon_sym_int208] = ACTIONS(637),
    [anon_sym_int216] = ACTIONS(637),
    [anon_sym_int224] = ACTIONS(637),
    [anon_sym_int232] = ACTIONS(637),
    [anon_sym_int240] = ACTIONS(637),
    [anon_sym_int248] = ACTIONS(637),
    [anon_sym_int256] = ACTIONS(637),
    [anon_sym_uint] = ACTIONS(637),
    [anon_sym_uint8] = ACTIONS(637),
    [anon_sym_uint16] = ACTIONS(637),
    [anon_sym_uint24] = ACTIONS(637),
    [anon_sym_uint32] = ACTIONS(637),
    [anon_sym_uint40] = ACTIONS(637),
    [anon_sym_uint48] = ACTIONS(637),
    [anon_sym_uint56] = ACTIONS(637),
    [anon_sym_uint64] = ACTIONS(637),
    [anon_sym_uint72] = ACTIONS(637),
    [anon_sym_uint80] = ACTIONS(637),
    [anon_sym_uint88] = ACTIONS(637),
    [anon_sym_uint96] = ACTIONS(637),
    [anon_sym_uint104] = ACTIONS(637),
    [anon_sym_uint112] = ACTIONS(637),
    [anon_sym_uint120] = ACTIONS(637),
    [anon_sym_uint128] = ACTIONS(637),
    [anon_sym_uint136] = ACTIONS(637),
    [anon_sym_uint144] = ACTIONS(637),
    [anon_sym_uint152] = ACTIONS(637),
    [anon_sym_uint160] = ACTIONS(637),
    [anon_sym_uint168] = ACTIONS(637),
    [anon_sym_uint176] = ACTIONS(637),
    [anon_sym_uint184] = ACTIONS(637),
    [anon_sym_uint192] = ACTIONS(637),
    [anon_sym_uint200] = ACTIONS(637),
    [anon_sym_uint208] = ACTIONS(637),
    [anon_sym_uint216] = ACTIONS(637),
    [anon_sym_uint224] = ACTIONS(637),
    [anon_sym_uint232] = ACTIONS(637),
    [anon_sym_uint240] = ACTIONS(637),
    [anon_sym_uint248] = ACTIONS(637),
    [anon_sym_uint256] = ACTIONS(637),
    [anon_sym_bytes] = ACTIONS(637),
    [anon_sym_bytes1] = ACTIONS(637),
    [anon_sym_bytes2] = ACTIONS(637),
    [anon_sym_bytes3] = ACTIONS(637),
    [anon_sym_bytes4] = ACTIONS(637),
    [anon_sym_bytes5] = ACTIONS(637),
    [anon_sym_bytes6] = ACTIONS(637),
    [anon_sym_bytes7] = ACTIONS(637),
    [anon_sym_bytes8] = ACTIONS(637),
    [anon_sym_bytes9] = ACTIONS(637),
    [anon_sym_bytes10] = ACTIONS(637),
    [anon_sym_bytes11] = ACTIONS(637),
    [anon_sym_bytes12] = ACTIONS(637),
    [anon_sym_bytes13] = ACTIONS(637),
    [anon_sym_bytes14] = ACTIONS(637),
    [anon_sym_bytes15] = ACTIONS(637),
    [anon_sym_bytes16] = ACTIONS(637),
    [anon_sym_bytes17] = ACTIONS(637),
    [anon_sym_bytes18] = ACTIONS(637),
    [anon_sym_bytes19] = ACTIONS(637),
    [anon_sym_bytes20] = ACTIONS(637),
    [anon_sym_bytes21] = ACTIONS(637),
    [anon_sym_bytes22] = ACTIONS(637),
    [anon_sym_bytes23] = ACTIONS(637),
    [anon_sym_bytes24] = ACTIONS(637),
    [anon_sym_bytes25] = ACTIONS(637),
    [anon_sym_bytes26] = ACTIONS(637),
    [anon_sym_bytes27] = ACTIONS(637),
    [anon_sym_bytes28] = ACTIONS(637),
    [anon_sym_bytes29] = ACTIONS(637),
    [anon_sym_bytes30] = ACTIONS(637),
    [anon_sym_bytes31] = ACTIONS(637),
    [anon_sym_bytes32] = ACTIONS(637),
    [anon_sym_fixed] = ACTIONS(637),
    [aux_sym__fixed_token1] = ACTIONS(637),
    [anon_sym_ufixed] = ACTIONS(637),
    [aux_sym__ufixed_token1] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
  },
  [158] = {
    [ts_builtin_sym_end] = ACTIONS(639),
    [sym_identifier] = ACTIONS(641),
    [anon_sym_pragma] = ACTIONS(641),
    [anon_sym_import] = ACTIONS(641),
    [anon_sym_type] = ACTIONS(641),
    [anon_sym_abstract] = ACTIONS(641),
    [anon_sym_contract] = ACTIONS(641),
    [anon_sym_error] = ACTIONS(641),
    [anon_sym_interface] = ACTIONS(641),
    [anon_sym_library] = ACTIONS(641),
    [anon_sym_struct] = ACTIONS(641),
    [anon_sym_enum] = ACTIONS(641),
    [anon_sym_using] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(641),
    [anon_sym_byte] = ACTIONS(641),
    [anon_sym_address] = ACTIONS(641),
    [anon_sym_var] = ACTIONS(641),
    [anon_sym_mapping] = ACTIONS(641),
    [anon_sym_bool] = ACTIONS(641),
    [anon_sym_string] = ACTIONS(641),
    [anon_sym_int] = ACTIONS(641),
    [anon_sym_int8] = ACTIONS(641),
    [anon_sym_int16] = ACTIONS(641),
    [anon_sym_int24] = ACTIONS(641),
    [anon_sym_int32] = ACTIONS(641),
    [anon_sym_int40] = ACTIONS(641),
    [anon_sym_int48] = ACTIONS(641),
    [anon_sym_int56] = ACTIONS(641),
    [anon_sym_int64] = ACTIONS(641),
    [anon_sym_int72] = ACTIONS(641),
    [anon_sym_int80] = ACTIONS(641),
    [anon_sym_int88] = ACTIONS(641),
    [anon_sym_int96] = ACTIONS(641),
    [anon_sym_int104] = ACTIONS(641),
    [anon_sym_int112] = ACTIONS(641),
    [anon_sym_int120] = ACTIONS(641),
    [anon_sym_int128] = ACTIONS(641),
    [anon_sym_int136] = ACTIONS(641),
    [anon_sym_int144] = ACTIONS(641),
    [anon_sym_int152] = ACTIONS(641),
    [anon_sym_int160] = ACTIONS(641),
    [anon_sym_int168] = ACTIONS(641),
    [anon_sym_int176] = ACTIONS(641),
    [anon_sym_int184] = ACTIONS(641),
    [anon_sym_int192] = ACTIONS(641),
    [anon_sym_int200] = ACTIONS(641),
    [anon_sym_int208] = ACTIONS(641),
    [anon_sym_int216] = ACTIONS(641),
    [anon_sym_int224] = ACTIONS(641),
    [anon_sym_int232] = ACTIONS(641),
    [anon_sym_int240] = ACTIONS(641),
    [anon_sym_int248] = ACTIONS(641),
    [anon_sym_int256] = ACTIONS(641),
    [anon_sym_uint] = ACTIONS(641),
    [anon_sym_uint8] = ACTIONS(641),
    [anon_sym_uint16] = ACTIONS(641),
    [anon_sym_uint24] = ACTIONS(641),
    [anon_sym_uint32] = ACTIONS(641),
    [anon_sym_uint40] = ACTIONS(641),
    [anon_sym_uint48] = ACTIONS(641),
    [anon_sym_uint56] = ACTIONS(641),
    [anon_sym_uint64] = ACTIONS(641),
    [anon_sym_uint72] = ACTIONS(641),
    [anon_sym_uint80] = ACTIONS(641),
    [anon_sym_uint88] = ACTIONS(641),
    [anon_sym_uint96] = ACTIONS(641),
    [anon_sym_uint104] = ACTIONS(641),
    [anon_sym_uint112] = ACTIONS(641),
    [anon_sym_uint120] = ACTIONS(641),
    [anon_sym_uint128] = ACTIONS(641),
    [anon_sym_uint136] = ACTIONS(641),
    [anon_sym_uint144] = ACTIONS(641),
    [anon_sym_uint152] = ACTIONS(641),
    [anon_sym_uint160] = ACTIONS(641),
    [anon_sym_uint168] = ACTIONS(641),
    [anon_sym_uint176] = ACTIONS(641),
    [anon_sym_uint184] = ACTIONS(641),
    [anon_sym_uint192] = ACTIONS(641),
    [anon_sym_uint200] = ACTIONS(641),
    [anon_sym_uint208] = ACTIONS(641),
    [anon_sym_uint216] = ACTIONS(641),
    [anon_sym_uint224] = ACTIONS(641),
    [anon_sym_uint232] = ACTIONS(641),
    [anon_sym_uint240] = ACTIONS(641),
    [anon_sym_uint248] = ACTIONS(641),
    [anon_sym_uint256] = ACTIONS(641),
    [anon_sym_bytes] = ACTIONS(641),
    [anon_sym_bytes1] = ACTIONS(641),
    [anon_sym_bytes2] = ACTIONS(641),
    [anon_sym_bytes3] = ACTIONS(641),
    [anon_sym_bytes4] = ACTIONS(641),
    [anon_sym_bytes5] = ACTIONS(641),
    [anon_sym_bytes6] = ACTIONS(641),
    [anon_sym_bytes7] = ACTIONS(641),
    [anon_sym_bytes8] = ACTIONS(641),
    [anon_sym_bytes9] = ACTIONS(641),
    [anon_sym_bytes10] = ACTIONS(641),
    [anon_sym_bytes11] = ACTIONS(641),
    [anon_sym_bytes12] = ACTIONS(641),
    [anon_sym_bytes13] = ACTIONS(641),
    [anon_sym_bytes14] = ACTIONS(641),
    [anon_sym_bytes15] = ACTIONS(641),
    [anon_sym_bytes16] = ACTIONS(641),
    [anon_sym_bytes17] = ACTIONS(641),
    [anon_sym_bytes18] = ACTIONS(641),
    [anon_sym_bytes19] = ACTIONS(641),
    [anon_sym_bytes20] = ACTIONS(641),
    [anon_sym_bytes21] = ACTIONS(641),
    [anon_sym_bytes22] = ACTIONS(641),
    [anon_sym_bytes23] = ACTIONS(641),
    [anon_sym_bytes24] = ACTIONS(641),
    [anon_sym_bytes25] = ACTIONS(641),
    [anon_sym_bytes26] = ACTIONS(641),
    [anon_sym_bytes27] = ACTIONS(641),
    [anon_sym_bytes28] = ACTIONS(641),
    [anon_sym_bytes29] = ACTIONS(641),
    [anon_sym_bytes30] = ACTIONS(641),
    [anon_sym_bytes31] = ACTIONS(641),
    [anon_sym_bytes32] = ACTIONS(641),
    [anon_sym_fixed] = ACTIONS(641),
    [aux_sym__fixed_token1] = ACTIONS(641),
    [anon_sym_ufixed] = ACTIONS(641),
    [aux_sym__ufixed_token1] = ACTIONS(641),
    [sym_comment] = ACTIONS(3),
  },
  [159] = {
    [ts_builtin_sym_end] = ACTIONS(643),
    [sym_identifier] = ACTIONS(645),
    [anon_sym_pragma] = ACTIONS(645),
    [anon_sym_import] = ACTIONS(645),
    [anon_sym_type] = ACTIONS(645),
    [anon_sym_abstract] = ACTIONS(645),
    [anon_sym_contract] = ACTIONS(645),
    [anon_sym_error] = ACTIONS(645),
    [anon_sym_interface] = ACTIONS(645),
    [anon_sym_library] = ACTIONS(645),
    [anon_sym_struct] = ACTIONS(645),
    [anon_sym_enum] = ACTIONS(645),
    [anon_sym_using] = ACTIONS(645),
    [anon_sym_function] = ACTIONS(645),
    [anon_sym_byte] = ACTIONS(645),
    [anon_sym_address] = ACTIONS(645),
    [anon_sym_var] = ACTIONS(645),
    [anon_sym_mapping] = ACTIONS(645),
    [anon_sym_bool] = ACTIONS(645),
    [anon_sym_string] = ACTIONS(645),
    [anon_sym_int] = ACTIONS(645),
    [anon_sym_int8] = ACTIONS(645),
    [anon_sym_int16] = ACTIONS(645),
    [anon_sym_int24] = ACTIONS(645),
    [anon_sym_int32] = ACTIONS(645),
    [anon_sym_int40] = ACTIONS(645),
    [anon_sym_int48] = ACTIONS(645),
    [anon_sym_int56] = ACTIONS(645),
    [anon_sym_int64] = ACTIONS(645),
    [anon_sym_int72] = ACTIONS(645),
    [anon_sym_int80] = ACTIONS(645),
    [anon_sym_int88] = ACTIONS(645),
    [anon_sym_int96] = ACTIONS(645),
    [anon_sym_int104] = ACTIONS(645),
    [anon_sym_int112] = ACTIONS(645),
    [anon_sym_int120] = ACTIONS(645),
    [anon_sym_int128] = ACTIONS(645),
    [anon_sym_int136] = ACTIONS(645),
    [anon_sym_int144] = ACTIONS(645),
    [anon_sym_int152] = ACTIONS(645),
    [anon_sym_int160] = ACTIONS(645),
    [anon_sym_int168] = ACTIONS(645),
    [anon_sym_int176] = ACTIONS(645),
    [anon_sym_int184] = ACTIONS(645),
    [anon_sym_int192] = ACTIONS(645),
    [anon_sym_int200] = ACTIONS(645),
    [anon_sym_int208] = ACTIONS(645),
    [anon_sym_int216] = ACTIONS(645),
    [anon_sym_int224] = ACTIONS(645),
    [anon_sym_int232] = ACTIONS(645),
    [anon_sym_int240] = ACTIONS(645),
    [anon_sym_int248] = ACTIONS(645),
    [anon_sym_int256] = ACTIONS(645),
    [anon_sym_uint] = ACTIONS(645),
    [anon_sym_uint8] = ACTIONS(645),
    [anon_sym_uint16] = ACTIONS(645),
    [anon_sym_uint24] = ACTIONS(645),
    [anon_sym_uint32] = ACTIONS(645),
    [anon_sym_uint40] = ACTIONS(645),
    [anon_sym_uint48] = ACTIONS(645),
    [anon_sym_uint56] = ACTIONS(645),
    [anon_sym_uint64] = ACTIONS(645),
    [anon_sym_uint72] = ACTIONS(645),
    [anon_sym_uint80] = ACTIONS(645),
    [anon_sym_uint88] = ACTIONS(645),
    [anon_sym_uint96] = ACTIONS(645),
    [anon_sym_uint104] = ACTIONS(645),
    [anon_sym_uint112] = ACTIONS(645),
    [anon_sym_uint120] = ACTIONS(645),
    [anon_sym_uint128] = ACTIONS(645),
    [anon_sym_uint136] = ACTIONS(645),
    [anon_sym_uint144] = ACTIONS(645),
    [anon_sym_uint152] = ACTIONS(645),
    [anon_sym_uint160] = ACTIONS(645),
    [anon_sym_uint168] = ACTIONS(645),
    [anon_sym_uint176] = ACTIONS(645),
    [anon_sym_uint184] = ACTIONS(645),
    [anon_sym_uint192] = ACTIONS(645),
    [anon_sym_uint200] = ACTIONS(645),
    [anon_sym_uint208] = ACTIONS(645),
    [anon_sym_uint216] = ACTIONS(645),
    [anon_sym_uint224] = ACTIONS(645),
    [anon_sym_uint232] = ACTIONS(645),
    [anon_sym_uint240] = ACTIONS(645),
    [anon_sym_uint248] = ACTIONS(645),
    [anon_sym_uint256] = ACTIONS(645),
    [anon_sym_bytes] = ACTIONS(645),
    [anon_sym_bytes1] = ACTIONS(645),
    [anon_sym_bytes2] = ACTIONS(645),
    [anon_sym_bytes3] = ACTIONS(645),
    [anon_sym_bytes4] = ACTIONS(645),
    [anon_sym_bytes5] = ACTIONS(645),
    [anon_sym_bytes6] = ACTIONS(645),
    [anon_sym_bytes7] = ACTIONS(645),
    [anon_sym_bytes8] = ACTIONS(645),
    [anon_sym_bytes9] = ACTIONS(645),
    [anon_sym_bytes10] = ACTIONS(645),
    [anon_sym_bytes11] = ACTIONS(645),
    [anon_sym_bytes12] = ACTIONS(645),
    [anon_sym_bytes13] = ACTIONS(645),
    [anon_sym_bytes14] = ACTIONS(645),
    [anon_sym_bytes15] = ACTIONS(645),
    [anon_sym_bytes16] = ACTIONS(645),
    [anon_sym_bytes17] = ACTIONS(645),
    [anon_sym_bytes18] = ACTIONS(645),
    [anon_sym_bytes19] = ACTIONS(645),
    [anon_sym_bytes20] = ACTIONS(645),
    [anon_sym_bytes21] = ACTIONS(645),
    [anon_sym_bytes22] = ACTIONS(645),
    [anon_sym_bytes23] = ACTIONS(645),
    [anon_sym_bytes24] = ACTIONS(645),
    [anon_sym_bytes25] = ACTIONS(645),
    [anon_sym_bytes26] = ACTIONS(645),
    [anon_sym_bytes27] = ACTIONS(645),
    [anon_sym_bytes28] = ACTIONS(645),
    [anon_sym_bytes29] = ACTIONS(645),
    [anon_sym_bytes30] = ACTIONS(645),
    [anon_sym_bytes31] = ACTIONS(645),
    [anon_sym_bytes32] = ACTIONS(645),
    [anon_sym_fixed] = ACTIONS(645),
    [aux_sym__fixed_token1] = ACTIONS(645),
    [anon_sym_ufixed] = ACTIONS(645),
    [aux_sym__ufixed_token1] = ACTIONS(645),
    [sym_comment] = ACTIONS(3),
  },
  [160] = {
    [ts_builtin_sym_end] = ACTIONS(631),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_pragma] = ACTIONS(633),
    [anon_sym_import] = ACTIONS(633),
    [anon_sym_type] = ACTIONS(633),
    [anon_sym_abstract] = ACTIONS(633),
    [anon_sym_contract] = ACTIONS(633),
    [anon_sym_error] = ACTIONS(633),
    [anon_sym_interface] = ACTIONS(633),
    [anon_sym_library] = ACTIONS(633),
    [anon_sym_struct] = ACTIONS(633),
    [anon_sym_enum] = ACTIONS(633),
    [anon_sym_using] = ACTIONS(633),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_byte] = ACTIONS(633),
    [anon_sym_address] = ACTIONS(633),
    [anon_sym_var] = ACTIONS(633),
    [anon_sym_mapping] = ACTIONS(633),
    [anon_sym_bool] = ACTIONS(633),
    [anon_sym_string] = ACTIONS(633),
    [anon_sym_int] = ACTIONS(633),
    [anon_sym_int8] = ACTIONS(633),
    [anon_sym_int16] = ACTIONS(633),
    [anon_sym_int24] = ACTIONS(633),
    [anon_sym_int32] = ACTIONS(633),
    [anon_sym_int40] = ACTIONS(633),
    [anon_sym_int48] = ACTIONS(633),
    [anon_sym_int56] = ACTIONS(633),
    [anon_sym_int64] = ACTIONS(633),
    [anon_sym_int72] = ACTIONS(633),
    [anon_sym_int80] = ACTIONS(633),
    [anon_sym_int88] = ACTIONS(633),
    [anon_sym_int96] = ACTIONS(633),
    [anon_sym_int104] = ACTIONS(633),
    [anon_sym_int112] = ACTIONS(633),
    [anon_sym_int120] = ACTIONS(633),
    [anon_sym_int128] = ACTIONS(633),
    [anon_sym_int136] = ACTIONS(633),
    [anon_sym_int144] = ACTIONS(633),
    [anon_sym_int152] = ACTIONS(633),
    [anon_sym_int160] = ACTIONS(633),
    [anon_sym_int168] = ACTIONS(633),
    [anon_sym_int176] = ACTIONS(633),
    [anon_sym_int184] = ACTIONS(633),
    [anon_sym_int192] = ACTIONS(633),
    [anon_sym_int200] = ACTIONS(633),
    [anon_sym_int208] = ACTIONS(633),
    [anon_sym_int216] = ACTIONS(633),
    [anon_sym_int224] = ACTIONS(633),
    [anon_sym_int232] = ACTIONS(633),
    [anon_sym_int240] = ACTIONS(633),
    [anon_sym_int248] = ACTIONS(633),
    [anon_sym_int256] = ACTIONS(633),
    [anon_sym_uint] = ACTIONS(633),
    [anon_sym_uint8] = ACTIONS(633),
    [anon_sym_uint16] = ACTIONS(633),
    [anon_sym_uint24] = ACTIONS(633),
    [anon_sym_uint32] = ACTIONS(633),
    [anon_sym_uint40] = ACTIONS(633),
    [anon_sym_uint48] = ACTIONS(633),
    [anon_sym_uint56] = ACTIONS(633),
    [anon_sym_uint64] = ACTIONS(633),
    [anon_sym_uint72] = ACTIONS(633),
    [anon_sym_uint80] = ACTIONS(633),
    [anon_sym_uint88] = ACTIONS(633),
    [anon_sym_uint96] = ACTIONS(633),
    [anon_sym_uint104] = ACTIONS(633),
    [anon_sym_uint112] = ACTIONS(633),
    [anon_sym_uint120] = ACTIONS(633),
    [anon_sym_uint128] = ACTIONS(633),
    [anon_sym_uint136] = ACTIONS(633),
    [anon_sym_uint144] = ACTIONS(633),
    [anon_sym_uint152] = ACTIONS(633),
    [anon_sym_uint160] = ACTIONS(633),
    [anon_sym_uint168] = ACTIONS(633),
    [anon_sym_uint176] = ACTIONS(633),
    [anon_sym_uint184] = ACTIONS(633),
    [anon_sym_uint192] = ACTIONS(633),
    [anon_sym_uint200] = ACTIONS(633),
    [anon_sym_uint208] = ACTIONS(633),
    [anon_sym_uint216] = ACTIONS(633),
    [anon_sym_uint224] = ACTIONS(633),
    [anon_sym_uint232] = ACTIONS(633),
    [anon_sym_uint240] = ACTIONS(633),
    [anon_sym_uint248] = ACTIONS(633),
    [anon_sym_uint256] = ACTIONS(633),
    [anon_sym_bytes] = ACTIONS(633),
    [anon_sym_bytes1] = ACTIONS(633),
    [anon_sym_bytes2] = ACTIONS(633),
    [anon_sym_bytes3] = ACTIONS(633),
    [anon_sym_bytes4] = ACTIONS(633),
    [anon_sym_bytes5] = ACTIONS(633),
    [anon_sym_bytes6] = ACTIONS(633),
    [anon_sym_bytes7] = ACTIONS(633),
    [anon_sym_bytes8] = ACTIONS(633),
    [anon_sym_bytes9] = ACTIONS(633),
    [anon_sym_bytes10] = ACTIONS(633),
    [anon_sym_bytes11] = ACTIONS(633),
    [anon_sym_bytes12] = ACTIONS(633),
    [anon_sym_bytes13] = ACTIONS(633),
    [anon_sym_bytes14] = ACTIONS(633),
    [anon_sym_bytes15] = ACTIONS(633),
    [anon_sym_bytes16] = ACTIONS(633),
    [anon_sym_bytes17] = ACTIONS(633),
    [anon_sym_bytes18] = ACTIONS(633),
    [anon_sym_bytes19] = ACTIONS(633),
    [anon_sym_bytes20] = ACTIONS(633),
    [anon_sym_bytes21] = ACTIONS(633),
    [anon_sym_bytes22] = ACTIONS(633),
    [anon_sym_bytes23] = ACTIONS(633),
    [anon_sym_bytes24] = ACTIONS(633),
    [anon_sym_bytes25] = ACTIONS(633),
    [anon_sym_bytes26] = ACTIONS(633),
    [anon_sym_bytes27] = ACTIONS(633),
    [anon_sym_bytes28] = ACTIONS(633),
    [anon_sym_bytes29] = ACTIONS(633),
    [anon_sym_bytes30] = ACTIONS(633),
    [anon_sym_bytes31] = ACTIONS(633),
    [anon_sym_bytes32] = ACTIONS(633),
    [anon_sym_fixed] = ACTIONS(633),
    [aux_sym__fixed_token1] = ACTIONS(633),
    [anon_sym_ufixed] = ACTIONS(633),
    [aux_sym__ufixed_token1] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
  },
  [161] = {
    [ts_builtin_sym_end] = ACTIONS(647),
    [sym_identifier] = ACTIONS(649),
    [anon_sym_pragma] = ACTIONS(649),
    [anon_sym_import] = ACTIONS(649),
    [anon_sym_type] = ACTIONS(649),
    [anon_sym_abstract] = ACTIONS(649),
    [anon_sym_contract] = ACTIONS(649),
    [anon_sym_error] = ACTIONS(649),
    [anon_sym_interface] = ACTIONS(649),
    [anon_sym_library] = ACTIONS(649),
    [anon_sym_struct] = ACTIONS(649),
    [anon_sym_enum] = ACTIONS(649),
    [anon_sym_using] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(649),
    [anon_sym_byte] = ACTIONS(649),
    [anon_sym_address] = ACTIONS(649),
    [anon_sym_var] = ACTIONS(649),
    [anon_sym_mapping] = ACTIONS(649),
    [anon_sym_bool] = ACTIONS(649),
    [anon_sym_string] = ACTIONS(649),
    [anon_sym_int] = ACTIONS(649),
    [anon_sym_int8] = ACTIONS(649),
    [anon_sym_int16] = ACTIONS(649),
    [anon_sym_int24] = ACTIONS(649),
    [anon_sym_int32] = ACTIONS(649),
    [anon_sym_int40] = ACTIONS(649),
    [anon_sym_int48] = ACTIONS(649),
    [anon_sym_int56] = ACTIONS(649),
    [anon_sym_int64] = ACTIONS(649),
    [anon_sym_int72] = ACTIONS(649),
    [anon_sym_int80] = ACTIONS(649),
    [anon_sym_int88] = ACTIONS(649),
    [anon_sym_int96] = ACTIONS(649),
    [anon_sym_int104] = ACTIONS(649),
    [anon_sym_int112] = ACTIONS(649),
    [anon_sym_int120] = ACTIONS(649),
    [anon_sym_int128] = ACTIONS(649),
    [anon_sym_int136] = ACTIONS(649),
    [anon_sym_int144] = ACTIONS(649),
    [anon_sym_int152] = ACTIONS(649),
    [anon_sym_int160] = ACTIONS(649),
    [anon_sym_int168] = ACTIONS(649),
    [anon_sym_int176] = ACTIONS(649),
    [anon_sym_int184] = ACTIONS(649),
    [anon_sym_int192] = ACTIONS(649),
    [anon_sym_int200] = ACTIONS(649),
    [anon_sym_int208] = ACTIONS(649),
    [anon_sym_int216] = ACTIONS(649),
    [anon_sym_int224] = ACTIONS(649),
    [anon_sym_int232] = ACTIONS(649),
    [anon_sym_int240] = ACTIONS(649),
    [anon_sym_int248] = ACTIONS(649),
    [anon_sym_int256] = ACTIONS(649),
    [anon_sym_uint] = ACTIONS(649),
    [anon_sym_uint8] = ACTIONS(649),
    [anon_sym_uint16] = ACTIONS(649),
    [anon_sym_uint24] = ACTIONS(649),
    [anon_sym_uint32] = ACTIONS(649),
    [anon_sym_uint40] = ACTIONS(649),
    [anon_sym_uint48] = ACTIONS(649),
    [anon_sym_uint56] = ACTIONS(649),
    [anon_sym_uint64] = ACTIONS(649),
    [anon_sym_uint72] = ACTIONS(649),
    [anon_sym_uint80] = ACTIONS(649),
    [anon_sym_uint88] = ACTIONS(649),
    [anon_sym_uint96] = ACTIONS(649),
    [anon_sym_uint104] = ACTIONS(649),
    [anon_sym_uint112] = ACTIONS(649),
    [anon_sym_uint120] = ACTIONS(649),
    [anon_sym_uint128] = ACTIONS(649),
    [anon_sym_uint136] = ACTIONS(649),
    [anon_sym_uint144] = ACTIONS(649),
    [anon_sym_uint152] = ACTIONS(649),
    [anon_sym_uint160] = ACTIONS(649),
    [anon_sym_uint168] = ACTIONS(649),
    [anon_sym_uint176] = ACTIONS(649),
    [anon_sym_uint184] = ACTIONS(649),
    [anon_sym_uint192] = ACTIONS(649),
    [anon_sym_uint200] = ACTIONS(649),
    [anon_sym_uint208] = ACTIONS(649),
    [anon_sym_uint216] = ACTIONS(649),
    [anon_sym_uint224] = ACTIONS(649),
    [anon_sym_uint232] = ACTIONS(649),
    [anon_sym_uint240] = ACTIONS(649),
    [anon_sym_uint248] = ACTIONS(649),
    [anon_sym_uint256] = ACTIONS(649),
    [anon_sym_bytes] = ACTIONS(649),
    [anon_sym_bytes1] = ACTIONS(649),
    [anon_sym_bytes2] = ACTIONS(649),
    [anon_sym_bytes3] = ACTIONS(649),
    [anon_sym_bytes4] = ACTIONS(649),
    [anon_sym_bytes5] = ACTIONS(649),
    [anon_sym_bytes6] = ACTIONS(649),
    [anon_sym_bytes7] = ACTIONS(649),
    [anon_sym_bytes8] = ACTIONS(649),
    [anon_sym_bytes9] = ACTIONS(649),
    [anon_sym_bytes10] = ACTIONS(649),
    [anon_sym_bytes11] = ACTIONS(649),
    [anon_sym_bytes12] = ACTIONS(649),
    [anon_sym_bytes13] = ACTIONS(649),
    [anon_sym_bytes14] = ACTIONS(649),
    [anon_sym_bytes15] = ACTIONS(649),
    [anon_sym_bytes16] = ACTIONS(649),
    [anon_sym_bytes17] = ACTIONS(649),
    [anon_sym_bytes18] = ACTIONS(649),
    [anon_sym_bytes19] = ACTIONS(649),
    [anon_sym_bytes20] = ACTIONS(649),
    [anon_sym_bytes21] = ACTIONS(649),
    [anon_sym_bytes22] = ACTIONS(649),
    [anon_sym_bytes23] = ACTIONS(649),
    [anon_sym_bytes24] = ACTIONS(649),
    [anon_sym_bytes25] = ACTIONS(649),
    [anon_sym_bytes26] = ACTIONS(649),
    [anon_sym_bytes27] = ACTIONS(649),
    [anon_sym_bytes28] = ACTIONS(649),
    [anon_sym_bytes29] = ACTIONS(649),
    [anon_sym_bytes30] = ACTIONS(649),
    [anon_sym_bytes31] = ACTIONS(649),
    [anon_sym_bytes32] = ACTIONS(649),
    [anon_sym_fixed] = ACTIONS(649),
    [aux_sym__fixed_token1] = ACTIONS(649),
    [anon_sym_ufixed] = ACTIONS(649),
    [aux_sym__ufixed_token1] = ACTIONS(649),
    [sym_comment] = ACTIONS(3),
  },
  [162] = {
    [ts_builtin_sym_end] = ACTIONS(651),
    [sym_identifier] = ACTIONS(653),
    [anon_sym_pragma] = ACTIONS(653),
    [anon_sym_import] = ACTIONS(653),
    [anon_sym_type] = ACTIONS(653),
    [anon_sym_abstract] = ACTIONS(653),
    [anon_sym_contract] = ACTIONS(653),
    [anon_sym_error] = ACTIONS(653),
    [anon_sym_interface] = ACTIONS(653),
    [anon_sym_library] = ACTIONS(653),
    [anon_sym_struct] = ACTIONS(653),
    [anon_sym_enum] = ACTIONS(653),
    [anon_sym_using] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(653),
    [anon_sym_byte] = ACTIONS(653),
    [anon_sym_address] = ACTIONS(653),
    [anon_sym_var] = ACTIONS(653),
    [anon_sym_mapping] = ACTIONS(653),
    [anon_sym_bool] = ACTIONS(653),
    [anon_sym_string] = ACTIONS(653),
    [anon_sym_int] = ACTIONS(653),
    [anon_sym_int8] = ACTIONS(653),
    [anon_sym_int16] = ACTIONS(653),
    [anon_sym_int24] = ACTIONS(653),
    [anon_sym_int32] = ACTIONS(653),
    [anon_sym_int40] = ACTIONS(653),
    [anon_sym_int48] = ACTIONS(653),
    [anon_sym_int56] = ACTIONS(653),
    [anon_sym_int64] = ACTIONS(653),
    [anon_sym_int72] = ACTIONS(653),
    [anon_sym_int80] = ACTIONS(653),
    [anon_sym_int88] = ACTIONS(653),
    [anon_sym_int96] = ACTIONS(653),
    [anon_sym_int104] = ACTIONS(653),
    [anon_sym_int112] = ACTIONS(653),
    [anon_sym_int120] = ACTIONS(653),
    [anon_sym_int128] = ACTIONS(653),
    [anon_sym_int136] = ACTIONS(653),
    [anon_sym_int144] = ACTIONS(653),
    [anon_sym_int152] = ACTIONS(653),
    [anon_sym_int160] = ACTIONS(653),
    [anon_sym_int168] = ACTIONS(653),
    [anon_sym_int176] = ACTIONS(653),
    [anon_sym_int184] = ACTIONS(653),
    [anon_sym_int192] = ACTIONS(653),
    [anon_sym_int200] = ACTIONS(653),
    [anon_sym_int208] = ACTIONS(653),
    [anon_sym_int216] = ACTIONS(653),
    [anon_sym_int224] = ACTIONS(653),
    [anon_sym_int232] = ACTIONS(653),
    [anon_sym_int240] = ACTIONS(653),
    [anon_sym_int248] = ACTIONS(653),
    [anon_sym_int256] = ACTIONS(653),
    [anon_sym_uint] = ACTIONS(653),
    [anon_sym_uint8] = ACTIONS(653),
    [anon_sym_uint16] = ACTIONS(653),
    [anon_sym_uint24] = ACTIONS(653),
    [anon_sym_uint32] = ACTIONS(653),
    [anon_sym_uint40] = ACTIONS(653),
    [anon_sym_uint48] = ACTIONS(653),
    [anon_sym_uint56] = ACTIONS(653),
    [anon_sym_uint64] = ACTIONS(653),
    [anon_sym_uint72] = ACTIONS(653),
    [anon_sym_uint80] = ACTIONS(653),
    [anon_sym_uint88] = ACTIONS(653),
    [anon_sym_uint96] = ACTIONS(653),
    [anon_sym_uint104] = ACTIONS(653),
    [anon_sym_uint112] = ACTIONS(653),
    [anon_sym_uint120] = ACTIONS(653),
    [anon_sym_uint128] = ACTIONS(653),
    [anon_sym_uint136] = ACTIONS(653),
    [anon_sym_uint144] = ACTIONS(653),
    [anon_sym_uint152] = ACTIONS(653),
    [anon_sym_uint160] = ACTIONS(653),
    [anon_sym_uint168] = ACTIONS(653),
    [anon_sym_uint176] = ACTIONS(653),
    [anon_sym_uint184] = ACTIONS(653),
    [anon_sym_uint192] = ACTIONS(653),
    [anon_sym_uint200] = ACTIONS(653),
    [anon_sym_uint208] = ACTIONS(653),
    [anon_sym_uint216] = ACTIONS(653),
    [anon_sym_uint224] = ACTIONS(653),
    [anon_sym_uint232] = ACTIONS(653),
    [anon_sym_uint240] = ACTIONS(653),
    [anon_sym_uint248] = ACTIONS(653),
    [anon_sym_uint256] = ACTIONS(653),
    [anon_sym_bytes] = ACTIONS(653),
    [anon_sym_bytes1] = ACTIONS(653),
    [anon_sym_bytes2] = ACTIONS(653),
    [anon_sym_bytes3] = ACTIONS(653),
    [anon_sym_bytes4] = ACTIONS(653),
    [anon_sym_bytes5] = ACTIONS(653),
    [anon_sym_bytes6] = ACTIONS(653),
    [anon_sym_bytes7] = ACTIONS(653),
    [anon_sym_bytes8] = ACTIONS(653),
    [anon_sym_bytes9] = ACTIONS(653),
    [anon_sym_bytes10] = ACTIONS(653),
    [anon_sym_bytes11] = ACTIONS(653),
    [anon_sym_bytes12] = ACTIONS(653),
    [anon_sym_bytes13] = ACTIONS(653),
    [anon_sym_bytes14] = ACTIONS(653),
    [anon_sym_bytes15] = ACTIONS(653),
    [anon_sym_bytes16] = ACTIONS(653),
    [anon_sym_bytes17] = ACTIONS(653),
    [anon_sym_bytes18] = ACTIONS(653),
    [anon_sym_bytes19] = ACTIONS(653),
    [anon_sym_bytes20] = ACTIONS(653),
    [anon_sym_bytes21] = ACTIONS(653),
    [anon_sym_bytes22] = ACTIONS(653),
    [anon_sym_bytes23] = ACTIONS(653),
    [anon_sym_bytes24] = ACTIONS(653),
    [anon_sym_bytes25] = ACTIONS(653),
    [anon_sym_bytes26] = ACTIONS(653),
    [anon_sym_bytes27] = ACTIONS(653),
    [anon_sym_bytes28] = ACTIONS(653),
    [anon_sym_bytes29] = ACTIONS(653),
    [anon_sym_bytes30] = ACTIONS(653),
    [anon_sym_bytes31] = ACTIONS(653),
    [anon_sym_bytes32] = ACTIONS(653),
    [anon_sym_fixed] = ACTIONS(653),
    [aux_sym__fixed_token1] = ACTIONS(653),
    [anon_sym_ufixed] = ACTIONS(653),
    [aux_sym__ufixed_token1] = ACTIONS(653),
    [sym_comment] = ACTIONS(3),
  },
  [163] = {
    [ts_builtin_sym_end] = ACTIONS(655),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_pragma] = ACTIONS(657),
    [anon_sym_import] = ACTIONS(657),
    [anon_sym_type] = ACTIONS(657),
    [anon_sym_abstract] = ACTIONS(657),
    [anon_sym_contract] = ACTIONS(657),
    [anon_sym_error] = ACTIONS(657),
    [anon_sym_interface] = ACTIONS(657),
    [anon_sym_library] = ACTIONS(657),
    [anon_sym_struct] = ACTIONS(657),
    [anon_sym_enum] = ACTIONS(657),
    [anon_sym_using] = ACTIONS(657),
    [anon_sym_function] = ACTIONS(657),
    [anon_sym_byte] = ACTIONS(657),
    [anon_sym_address] = ACTIONS(657),
    [anon_sym_var] = ACTIONS(657),
    [anon_sym_mapping] = ACTIONS(657),
    [anon_sym_bool] = ACTIONS(657),
    [anon_sym_string] = ACTIONS(657),
    [anon_sym_int] = ACTIONS(657),
    [anon_sym_int8] = ACTIONS(657),
    [anon_sym_int16] = ACTIONS(657),
    [anon_sym_int24] = ACTIONS(657),
    [anon_sym_int32] = ACTIONS(657),
    [anon_sym_int40] = ACTIONS(657),
    [anon_sym_int48] = ACTIONS(657),
    [anon_sym_int56] = ACTIONS(657),
    [anon_sym_int64] = ACTIONS(657),
    [anon_sym_int72] = ACTIONS(657),
    [anon_sym_int80] = ACTIONS(657),
    [anon_sym_int88] = ACTIONS(657),
    [anon_sym_int96] = ACTIONS(657),
    [anon_sym_int104] = ACTIONS(657),
    [anon_sym_int112] = ACTIONS(657),
    [anon_sym_int120] = ACTIONS(657),
    [anon_sym_int128] = ACTIONS(657),
    [anon_sym_int136] = ACTIONS(657),
    [anon_sym_int144] = ACTIONS(657),
    [anon_sym_int152] = ACTIONS(657),
    [anon_sym_int160] = ACTIONS(657),
    [anon_sym_int168] = ACTIONS(657),
    [anon_sym_int176] = ACTIONS(657),
    [anon_sym_int184] = ACTIONS(657),
    [anon_sym_int192] = ACTIONS(657),
    [anon_sym_int200] = ACTIONS(657),
    [anon_sym_int208] = ACTIONS(657),
    [anon_sym_int216] = ACTIONS(657),
    [anon_sym_int224] = ACTIONS(657),
    [anon_sym_int232] = ACTIONS(657),
    [anon_sym_int240] = ACTIONS(657),
    [anon_sym_int248] = ACTIONS(657),
    [anon_sym_int256] = ACTIONS(657),
    [anon_sym_uint] = ACTIONS(657),
    [anon_sym_uint8] = ACTIONS(657),
    [anon_sym_uint16] = ACTIONS(657),
    [anon_sym_uint24] = ACTIONS(657),
    [anon_sym_uint32] = ACTIONS(657),
    [anon_sym_uint40] = ACTIONS(657),
    [anon_sym_uint48] = ACTIONS(657),
    [anon_sym_uint56] = ACTIONS(657),
    [anon_sym_uint64] = ACTIONS(657),
    [anon_sym_uint72] = ACTIONS(657),
    [anon_sym_uint80] = ACTIONS(657),
    [anon_sym_uint88] = ACTIONS(657),
    [anon_sym_uint96] = ACTIONS(657),
    [anon_sym_uint104] = ACTIONS(657),
    [anon_sym_uint112] = ACTIONS(657),
    [anon_sym_uint120] = ACTIONS(657),
    [anon_sym_uint128] = ACTIONS(657),
    [anon_sym_uint136] = ACTIONS(657),
    [anon_sym_uint144] = ACTIONS(657),
    [anon_sym_uint152] = ACTIONS(657),
    [anon_sym_uint160] = ACTIONS(657),
    [anon_sym_uint168] = ACTIONS(657),
    [anon_sym_uint176] = ACTIONS(657),
    [anon_sym_uint184] = ACTIONS(657),
    [anon_sym_uint192] = ACTIONS(657),
    [anon_sym_uint200] = ACTIONS(657),
    [anon_sym_uint208] = ACTIONS(657),
    [anon_sym_uint216] = ACTIONS(657),
    [anon_sym_uint224] = ACTIONS(657),
    [anon_sym_uint232] = ACTIONS(657),
    [anon_sym_uint240] = ACTIONS(657),
    [anon_sym_uint248] = ACTIONS(657),
    [anon_sym_uint256] = ACTIONS(657),
    [anon_sym_bytes] = ACTIONS(657),
    [anon_sym_bytes1] = ACTIONS(657),
    [anon_sym_bytes2] = ACTIONS(657),
    [anon_sym_bytes3] = ACTIONS(657),
    [anon_sym_bytes4] = ACTIONS(657),
    [anon_sym_bytes5] = ACTIONS(657),
    [anon_sym_bytes6] = ACTIONS(657),
    [anon_sym_bytes7] = ACTIONS(657),
    [anon_sym_bytes8] = ACTIONS(657),
    [anon_sym_bytes9] = ACTIONS(657),
    [anon_sym_bytes10] = ACTIONS(657),
    [anon_sym_bytes11] = ACTIONS(657),
    [anon_sym_bytes12] = ACTIONS(657),
    [anon_sym_bytes13] = ACTIONS(657),
    [anon_sym_bytes14] = ACTIONS(657),
    [anon_sym_bytes15] = ACTIONS(657),
    [anon_sym_bytes16] = ACTIONS(657),
    [anon_sym_bytes17] = ACTIONS(657),
    [anon_sym_bytes18] = ACTIONS(657),
    [anon_sym_bytes19] = ACTIONS(657),
    [anon_sym_bytes20] = ACTIONS(657),
    [anon_sym_bytes21] = ACTIONS(657),
    [anon_sym_bytes22] = ACTIONS(657),
    [anon_sym_bytes23] = ACTIONS(657),
    [anon_sym_bytes24] = ACTIONS(657),
    [anon_sym_bytes25] = ACTIONS(657),
    [anon_sym_bytes26] = ACTIONS(657),
    [anon_sym_bytes27] = ACTIONS(657),
    [anon_sym_bytes28] = ACTIONS(657),
    [anon_sym_bytes29] = ACTIONS(657),
    [anon_sym_bytes30] = ACTIONS(657),
    [anon_sym_bytes31] = ACTIONS(657),
    [anon_sym_bytes32] = ACTIONS(657),
    [anon_sym_fixed] = ACTIONS(657),
    [aux_sym__fixed_token1] = ACTIONS(657),
    [anon_sym_ufixed] = ACTIONS(657),
    [aux_sym__ufixed_token1] = ACTIONS(657),
    [sym_comment] = ACTIONS(3),
  },
  [164] = {
    [ts_builtin_sym_end] = ACTIONS(659),
    [sym_identifier] = ACTIONS(661),
    [anon_sym_pragma] = ACTIONS(661),
    [anon_sym_import] = ACTIONS(661),
    [anon_sym_type] = ACTIONS(661),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_contract] = ACTIONS(661),
    [anon_sym_error] = ACTIONS(661),
    [anon_sym_interface] = ACTIONS(661),
    [anon_sym_library] = ACTIONS(661),
    [anon_sym_struct] = ACTIONS(661),
    [anon_sym_enum] = ACTIONS(661),
    [anon_sym_using] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(661),
    [anon_sym_byte] = ACTIONS(661),
    [anon_sym_address] = ACTIONS(661),
    [anon_sym_var] = ACTIONS(661),
    [anon_sym_mapping] = ACTIONS(661),
    [anon_sym_bool] = ACTIONS(661),
    [anon_sym_string] = ACTIONS(661),
    [anon_sym_int] = ACTIONS(661),
    [anon_sym_int8] = ACTIONS(661),
    [anon_sym_int16] = ACTIONS(661),
    [anon_sym_int24] = ACTIONS(661),
    [anon_sym_int32] = ACTIONS(661),
    [anon_sym_int40] = ACTIONS(661),
    [anon_sym_int48] = ACTIONS(661),
    [anon_sym_int56] = ACTIONS(661),
    [anon_sym_int64] = ACTIONS(661),
    [anon_sym_int72] = ACTIONS(661),
    [anon_sym_int80] = ACTIONS(661),
    [anon_sym_int88] = ACTIONS(661),
    [anon_sym_int96] = ACTIONS(661),
    [anon_sym_int104] = ACTIONS(661),
    [anon_sym_int112] = ACTIONS(661),
    [anon_sym_int120] = ACTIONS(661),
    [anon_sym_int128] = ACTIONS(661),
    [anon_sym_int136] = ACTIONS(661),
    [anon_sym_int144] = ACTIONS(661),
    [anon_sym_int152] = ACTIONS(661),
    [anon_sym_int160] = ACTIONS(661),
    [anon_sym_int168] = ACTIONS(661),
    [anon_sym_int176] = ACTIONS(661),
    [anon_sym_int184] = ACTIONS(661),
    [anon_sym_int192] = ACTIONS(661),
    [anon_sym_int200] = ACTIONS(661),
    [anon_sym_int208] = ACTIONS(661),
    [anon_sym_int216] = ACTIONS(661),
    [anon_sym_int224] = ACTIONS(661),
    [anon_sym_int232] = ACTIONS(661),
    [anon_sym_int240] = ACTIONS(661),
    [anon_sym_int248] = ACTIONS(661),
    [anon_sym_int256] = ACTIONS(661),
    [anon_sym_uint] = ACTIONS(661),
    [anon_sym_uint8] = ACTIONS(661),
    [anon_sym_uint16] = ACTIONS(661),
    [anon_sym_uint24] = ACTIONS(661),
    [anon_sym_uint32] = ACTIONS(661),
    [anon_sym_uint40] = ACTIONS(661),
    [anon_sym_uint48] = ACTIONS(661),
    [anon_sym_uint56] = ACTIONS(661),
    [anon_sym_uint64] = ACTIONS(661),
    [anon_sym_uint72] = ACTIONS(661),
    [anon_sym_uint80] = ACTIONS(661),
    [anon_sym_uint88] = ACTIONS(661),
    [anon_sym_uint96] = ACTIONS(661),
    [anon_sym_uint104] = ACTIONS(661),
    [anon_sym_uint112] = ACTIONS(661),
    [anon_sym_uint120] = ACTIONS(661),
    [anon_sym_uint128] = ACTIONS(661),
    [anon_sym_uint136] = ACTIONS(661),
    [anon_sym_uint144] = ACTIONS(661),
    [anon_sym_uint152] = ACTIONS(661),
    [anon_sym_uint160] = ACTIONS(661),
    [anon_sym_uint168] = ACTIONS(661),
    [anon_sym_uint176] = ACTIONS(661),
    [anon_sym_uint184] = ACTIONS(661),
    [anon_sym_uint192] = ACTIONS(661),
    [anon_sym_uint200] = ACTIONS(661),
    [anon_sym_uint208] = ACTIONS(661),
    [anon_sym_uint216] = ACTIONS(661),
    [anon_sym_uint224] = ACTIONS(661),
    [anon_sym_uint232] = ACTIONS(661),
    [anon_sym_uint240] = ACTIONS(661),
    [anon_sym_uint248] = ACTIONS(661),
    [anon_sym_uint256] = ACTIONS(661),
    [anon_sym_bytes] = ACTIONS(661),
    [anon_sym_bytes1] = ACTIONS(661),
    [anon_sym_bytes2] = ACTIONS(661),
    [anon_sym_bytes3] = ACTIONS(661),
    [anon_sym_bytes4] = ACTIONS(661),
    [anon_sym_bytes5] = ACTIONS(661),
    [anon_sym_bytes6] = ACTIONS(661),
    [anon_sym_bytes7] = ACTIONS(661),
    [anon_sym_bytes8] = ACTIONS(661),
    [anon_sym_bytes9] = ACTIONS(661),
    [anon_sym_bytes10] = ACTIONS(661),
    [anon_sym_bytes11] = ACTIONS(661),
    [anon_sym_bytes12] = ACTIONS(661),
    [anon_sym_bytes13] = ACTIONS(661),
    [anon_sym_bytes14] = ACTIONS(661),
    [anon_sym_bytes15] = ACTIONS(661),
    [anon_sym_bytes16] = ACTIONS(661),
    [anon_sym_bytes17] = ACTIONS(661),
    [anon_sym_bytes18] = ACTIONS(661),
    [anon_sym_bytes19] = ACTIONS(661),
    [anon_sym_bytes20] = ACTIONS(661),
    [anon_sym_bytes21] = ACTIONS(661),
    [anon_sym_bytes22] = ACTIONS(661),
    [anon_sym_bytes23] = ACTIONS(661),
    [anon_sym_bytes24] = ACTIONS(661),
    [anon_sym_bytes25] = ACTIONS(661),
    [anon_sym_bytes26] = ACTIONS(661),
    [anon_sym_bytes27] = ACTIONS(661),
    [anon_sym_bytes28] = ACTIONS(661),
    [anon_sym_bytes29] = ACTIONS(661),
    [anon_sym_bytes30] = ACTIONS(661),
    [anon_sym_bytes31] = ACTIONS(661),
    [anon_sym_bytes32] = ACTIONS(661),
    [anon_sym_fixed] = ACTIONS(661),
    [aux_sym__fixed_token1] = ACTIONS(661),
    [anon_sym_ufixed] = ACTIONS(661),
    [aux_sym__ufixed_token1] = ACTIONS(661),
    [sym_comment] = ACTIONS(3),
  },
  [165] = {
    [ts_builtin_sym_end] = ACTIONS(663),
    [sym_identifier] = ACTIONS(665),
    [anon_sym_pragma] = ACTIONS(665),
    [anon_sym_import] = ACTIONS(665),
    [anon_sym_type] = ACTIONS(665),
    [anon_sym_abstract] = ACTIONS(665),
    [anon_sym_contract] = ACTIONS(665),
    [anon_sym_error] = ACTIONS(665),
    [anon_sym_interface] = ACTIONS(665),
    [anon_sym_library] = ACTIONS(665),
    [anon_sym_struct] = ACTIONS(665),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_function] = ACTIONS(665),
    [anon_sym_byte] = ACTIONS(665),
    [anon_sym_address] = ACTIONS(665),
    [anon_sym_var] = ACTIONS(665),
    [anon_sym_mapping] = ACTIONS(665),
    [anon_sym_bool] = ACTIONS(665),
    [anon_sym_string] = ACTIONS(665),
    [anon_sym_int] = ACTIONS(665),
    [anon_sym_int8] = ACTIONS(665),
    [anon_sym_int16] = ACTIONS(665),
    [anon_sym_int24] = ACTIONS(665),
    [anon_sym_int32] = ACTIONS(665),
    [anon_sym_int40] = ACTIONS(665),
    [anon_sym_int48] = ACTIONS(665),
    [anon_sym_int56] = ACTIONS(665),
    [anon_sym_int64] = ACTIONS(665),
    [anon_sym_int72] = ACTIONS(665),
    [anon_sym_int80] = ACTIONS(665),
    [anon_sym_int88] = ACTIONS(665),
    [anon_sym_int96] = ACTIONS(665),
    [anon_sym_int104] = ACTIONS(665),
    [anon_sym_int112] = ACTIONS(665),
    [anon_sym_int120] = ACTIONS(665),
    [anon_sym_int128] = ACTIONS(665),
    [anon_sym_int136] = ACTIONS(665),
    [anon_sym_int144] = ACTIONS(665),
    [anon_sym_int152] = ACTIONS(665),
    [anon_sym_int160] = ACTIONS(665),
    [anon_sym_int168] = ACTIONS(665),
    [anon_sym_int176] = ACTIONS(665),
    [anon_sym_int184] = ACTIONS(665),
    [anon_sym_int192] = ACTIONS(665),
    [anon_sym_int200] = ACTIONS(665),
    [anon_sym_int208] = ACTIONS(665),
    [anon_sym_int216] = ACTIONS(665),
    [anon_sym_int224] = ACTIONS(665),
    [anon_sym_int232] = ACTIONS(665),
    [anon_sym_int240] = ACTIONS(665),
    [anon_sym_int248] = ACTIONS(665),
    [anon_sym_int256] = ACTIONS(665),
    [anon_sym_uint] = ACTIONS(665),
    [anon_sym_uint8] = ACTIONS(665),
    [anon_sym_uint16] = ACTIONS(665),
    [anon_sym_uint24] = ACTIONS(665),
    [anon_sym_uint32] = ACTIONS(665),
    [anon_sym_uint40] = ACTIONS(665),
    [anon_sym_uint48] = ACTIONS(665),
    [anon_sym_uint56] = ACTIONS(665),
    [anon_sym_uint64] = ACTIONS(665),
    [anon_sym_uint72] = ACTIONS(665),
    [anon_sym_uint80] = ACTIONS(665),
    [anon_sym_uint88] = ACTIONS(665),
    [anon_sym_uint96] = ACTIONS(665),
    [anon_sym_uint104] = ACTIONS(665),
    [anon_sym_uint112] = ACTIONS(665),
    [anon_sym_uint120] = ACTIONS(665),
    [anon_sym_uint128] = ACTIONS(665),
    [anon_sym_uint136] = ACTIONS(665),
    [anon_sym_uint144] = ACTIONS(665),
    [anon_sym_uint152] = ACTIONS(665),
    [anon_sym_uint160] = ACTIONS(665),
    [anon_sym_uint168] = ACTIONS(665),
    [anon_sym_uint176] = ACTIONS(665),
    [anon_sym_uint184] = ACTIONS(665),
    [anon_sym_uint192] = ACTIONS(665),
    [anon_sym_uint200] = ACTIONS(665),
    [anon_sym_uint208] = ACTIONS(665),
    [anon_sym_uint216] = ACTIONS(665),
    [anon_sym_uint224] = ACTIONS(665),
    [anon_sym_uint232] = ACTIONS(665),
    [anon_sym_uint240] = ACTIONS(665),
    [anon_sym_uint248] = ACTIONS(665),
    [anon_sym_uint256] = ACTIONS(665),
    [anon_sym_bytes] = ACTIONS(665),
    [anon_sym_bytes1] = ACTIONS(665),
    [anon_sym_bytes2] = ACTIONS(665),
    [anon_sym_bytes3] = ACTIONS(665),
    [anon_sym_bytes4] = ACTIONS(665),
    [anon_sym_bytes5] = ACTIONS(665),
    [anon_sym_bytes6] = ACTIONS(665),
    [anon_sym_bytes7] = ACTIONS(665),
    [anon_sym_bytes8] = ACTIONS(665),
    [anon_sym_bytes9] = ACTIONS(665),
    [anon_sym_bytes10] = ACTIONS(665),
    [anon_sym_bytes11] = ACTIONS(665),
    [anon_sym_bytes12] = ACTIONS(665),
    [anon_sym_bytes13] = ACTIONS(665),
    [anon_sym_bytes14] = ACTIONS(665),
    [anon_sym_bytes15] = ACTIONS(665),
    [anon_sym_bytes16] = ACTIONS(665),
    [anon_sym_bytes17] = ACTIONS(665),
    [anon_sym_bytes18] = ACTIONS(665),
    [anon_sym_bytes19] = ACTIONS(665),
    [anon_sym_bytes20] = ACTIONS(665),
    [anon_sym_bytes21] = ACTIONS(665),
    [anon_sym_bytes22] = ACTIONS(665),
    [anon_sym_bytes23] = ACTIONS(665),
    [anon_sym_bytes24] = ACTIONS(665),
    [anon_sym_bytes25] = ACTIONS(665),
    [anon_sym_bytes26] = ACTIONS(665),
    [anon_sym_bytes27] = ACTIONS(665),
    [anon_sym_bytes28] = ACTIONS(665),
    [anon_sym_bytes29] = ACTIONS(665),
    [anon_sym_bytes30] = ACTIONS(665),
    [anon_sym_bytes31] = ACTIONS(665),
    [anon_sym_bytes32] = ACTIONS(665),
    [anon_sym_fixed] = ACTIONS(665),
    [aux_sym__fixed_token1] = ACTIONS(665),
    [anon_sym_ufixed] = ACTIONS(665),
    [aux_sym__ufixed_token1] = ACTIONS(665),
    [sym_comment] = ACTIONS(3),
  },
  [166] = {
    [ts_builtin_sym_end] = ACTIONS(667),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_pragma] = ACTIONS(669),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_type] = ACTIONS(669),
    [anon_sym_abstract] = ACTIONS(669),
    [anon_sym_contract] = ACTIONS(669),
    [anon_sym_error] = ACTIONS(669),
    [anon_sym_interface] = ACTIONS(669),
    [anon_sym_library] = ACTIONS(669),
    [anon_sym_struct] = ACTIONS(669),
    [anon_sym_enum] = ACTIONS(669),
    [anon_sym_using] = ACTIONS(669),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_byte] = ACTIONS(669),
    [anon_sym_address] = ACTIONS(669),
    [anon_sym_var] = ACTIONS(669),
    [anon_sym_mapping] = ACTIONS(669),
    [anon_sym_bool] = ACTIONS(669),
    [anon_sym_string] = ACTIONS(669),
    [anon_sym_int] = ACTIONS(669),
    [anon_sym_int8] = ACTIONS(669),
    [anon_sym_int16] = ACTIONS(669),
    [anon_sym_int24] = ACTIONS(669),
    [anon_sym_int32] = ACTIONS(669),
    [anon_sym_int40] = ACTIONS(669),
    [anon_sym_int48] = ACTIONS(669),
    [anon_sym_int56] = ACTIONS(669),
    [anon_sym_int64] = ACTIONS(669),
    [anon_sym_int72] = ACTIONS(669),
    [anon_sym_int80] = ACTIONS(669),
    [anon_sym_int88] = ACTIONS(669),
    [anon_sym_int96] = ACTIONS(669),
    [anon_sym_int104] = ACTIONS(669),
    [anon_sym_int112] = ACTIONS(669),
    [anon_sym_int120] = ACTIONS(669),
    [anon_sym_int128] = ACTIONS(669),
    [anon_sym_int136] = ACTIONS(669),
    [anon_sym_int144] = ACTIONS(669),
    [anon_sym_int152] = ACTIONS(669),
    [anon_sym_int160] = ACTIONS(669),
    [anon_sym_int168] = ACTIONS(669),
    [anon_sym_int176] = ACTIONS(669),
    [anon_sym_int184] = ACTIONS(669),
    [anon_sym_int192] = ACTIONS(669),
    [anon_sym_int200] = ACTIONS(669),
    [anon_sym_int208] = ACTIONS(669),
    [anon_sym_int216] = ACTIONS(669),
    [anon_sym_int224] = ACTIONS(669),
    [anon_sym_int232] = ACTIONS(669),
    [anon_sym_int240] = ACTIONS(669),
    [anon_sym_int248] = ACTIONS(669),
    [anon_sym_int256] = ACTIONS(669),
    [anon_sym_uint] = ACTIONS(669),
    [anon_sym_uint8] = ACTIONS(669),
    [anon_sym_uint16] = ACTIONS(669),
    [anon_sym_uint24] = ACTIONS(669),
    [anon_sym_uint32] = ACTIONS(669),
    [anon_sym_uint40] = ACTIONS(669),
    [anon_sym_uint48] = ACTIONS(669),
    [anon_sym_uint56] = ACTIONS(669),
    [anon_sym_uint64] = ACTIONS(669),
    [anon_sym_uint72] = ACTIONS(669),
    [anon_sym_uint80] = ACTIONS(669),
    [anon_sym_uint88] = ACTIONS(669),
    [anon_sym_uint96] = ACTIONS(669),
    [anon_sym_uint104] = ACTIONS(669),
    [anon_sym_uint112] = ACTIONS(669),
    [anon_sym_uint120] = ACTIONS(669),
    [anon_sym_uint128] = ACTIONS(669),
    [anon_sym_uint136] = ACTIONS(669),
    [anon_sym_uint144] = ACTIONS(669),
    [anon_sym_uint152] = ACTIONS(669),
    [anon_sym_uint160] = ACTIONS(669),
    [anon_sym_uint168] = ACTIONS(669),
    [anon_sym_uint176] = ACTIONS(669),
    [anon_sym_uint184] = ACTIONS(669),
    [anon_sym_uint192] = ACTIONS(669),
    [anon_sym_uint200] = ACTIONS(669),
    [anon_sym_uint208] = ACTIONS(669),
    [anon_sym_uint216] = ACTIONS(669),
    [anon_sym_uint224] = ACTIONS(669),
    [anon_sym_uint232] = ACTIONS(669),
    [anon_sym_uint240] = ACTIONS(669),
    [anon_sym_uint248] = ACTIONS(669),
    [anon_sym_uint256] = ACTIONS(669),
    [anon_sym_bytes] = ACTIONS(669),
    [anon_sym_bytes1] = ACTIONS(669),
    [anon_sym_bytes2] = ACTIONS(669),
    [anon_sym_bytes3] = ACTIONS(669),
    [anon_sym_bytes4] = ACTIONS(669),
    [anon_sym_bytes5] = ACTIONS(669),
    [anon_sym_bytes6] = ACTIONS(669),
    [anon_sym_bytes7] = ACTIONS(669),
    [anon_sym_bytes8] = ACTIONS(669),
    [anon_sym_bytes9] = ACTIONS(669),
    [anon_sym_bytes10] = ACTIONS(669),
    [anon_sym_bytes11] = ACTIONS(669),
    [anon_sym_bytes12] = ACTIONS(669),
    [anon_sym_bytes13] = ACTIONS(669),
    [anon_sym_bytes14] = ACTIONS(669),
    [anon_sym_bytes15] = ACTIONS(669),
    [anon_sym_bytes16] = ACTIONS(669),
    [anon_sym_bytes17] = ACTIONS(669),
    [anon_sym_bytes18] = ACTIONS(669),
    [anon_sym_bytes19] = ACTIONS(669),
    [anon_sym_bytes20] = ACTIONS(669),
    [anon_sym_bytes21] = ACTIONS(669),
    [anon_sym_bytes22] = ACTIONS(669),
    [anon_sym_bytes23] = ACTIONS(669),
    [anon_sym_bytes24] = ACTIONS(669),
    [anon_sym_bytes25] = ACTIONS(669),
    [anon_sym_bytes26] = ACTIONS(669),
    [anon_sym_bytes27] = ACTIONS(669),
    [anon_sym_bytes28] = ACTIONS(669),
    [anon_sym_bytes29] = ACTIONS(669),
    [anon_sym_bytes30] = ACTIONS(669),
    [anon_sym_bytes31] = ACTIONS(669),
    [anon_sym_bytes32] = ACTIONS(669),
    [anon_sym_fixed] = ACTIONS(669),
    [aux_sym__fixed_token1] = ACTIONS(669),
    [anon_sym_ufixed] = ACTIONS(669),
    [aux_sym__ufixed_token1] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
  },
  [167] = {
    [ts_builtin_sym_end] = ACTIONS(671),
    [sym_identifier] = ACTIONS(673),
    [anon_sym_pragma] = ACTIONS(673),
    [anon_sym_import] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(673),
    [anon_sym_abstract] = ACTIONS(673),
    [anon_sym_contract] = ACTIONS(673),
    [anon_sym_error] = ACTIONS(673),
    [anon_sym_interface] = ACTIONS(673),
    [anon_sym_library] = ACTIONS(673),
    [anon_sym_struct] = ACTIONS(673),
    [anon_sym_enum] = ACTIONS(673),
    [anon_sym_using] = ACTIONS(673),
    [anon_sym_function] = ACTIONS(673),
    [anon_sym_byte] = ACTIONS(673),
    [anon_sym_address] = ACTIONS(673),
    [anon_sym_var] = ACTIONS(673),
    [anon_sym_mapping] = ACTIONS(673),
    [anon_sym_bool] = ACTIONS(673),
    [anon_sym_string] = ACTIONS(673),
    [anon_sym_int] = ACTIONS(673),
    [anon_sym_int8] = ACTIONS(673),
    [anon_sym_int16] = ACTIONS(673),
    [anon_sym_int24] = ACTIONS(673),
    [anon_sym_int32] = ACTIONS(673),
    [anon_sym_int40] = ACTIONS(673),
    [anon_sym_int48] = ACTIONS(673),
    [anon_sym_int56] = ACTIONS(673),
    [anon_sym_int64] = ACTIONS(673),
    [anon_sym_int72] = ACTIONS(673),
    [anon_sym_int80] = ACTIONS(673),
    [anon_sym_int88] = ACTIONS(673),
    [anon_sym_int96] = ACTIONS(673),
    [anon_sym_int104] = ACTIONS(673),
    [anon_sym_int112] = ACTIONS(673),
    [anon_sym_int120] = ACTIONS(673),
    [anon_sym_int128] = ACTIONS(673),
    [anon_sym_int136] = ACTIONS(673),
    [anon_sym_int144] = ACTIONS(673),
    [anon_sym_int152] = ACTIONS(673),
    [anon_sym_int160] = ACTIONS(673),
    [anon_sym_int168] = ACTIONS(673),
    [anon_sym_int176] = ACTIONS(673),
    [anon_sym_int184] = ACTIONS(673),
    [anon_sym_int192] = ACTIONS(673),
    [anon_sym_int200] = ACTIONS(673),
    [anon_sym_int208] = ACTIONS(673),
    [anon_sym_int216] = ACTIONS(673),
    [anon_sym_int224] = ACTIONS(673),
    [anon_sym_int232] = ACTIONS(673),
    [anon_sym_int240] = ACTIONS(673),
    [anon_sym_int248] = ACTIONS(673),
    [anon_sym_int256] = ACTIONS(673),
    [anon_sym_uint] = ACTIONS(673),
    [anon_sym_uint8] = ACTIONS(673),
    [anon_sym_uint16] = ACTIONS(673),
    [anon_sym_uint24] = ACTIONS(673),
    [anon_sym_uint32] = ACTIONS(673),
    [anon_sym_uint40] = ACTIONS(673),
    [anon_sym_uint48] = ACTIONS(673),
    [anon_sym_uint56] = ACTIONS(673),
    [anon_sym_uint64] = ACTIONS(673),
    [anon_sym_uint72] = ACTIONS(673),
    [anon_sym_uint80] = ACTIONS(673),
    [anon_sym_uint88] = ACTIONS(673),
    [anon_sym_uint96] = ACTIONS(673),
    [anon_sym_uint104] = ACTIONS(673),
    [anon_sym_uint112] = ACTIONS(673),
    [anon_sym_uint120] = ACTIONS(673),
    [anon_sym_uint128] = ACTIONS(673),
    [anon_sym_uint136] = ACTIONS(673),
    [anon_sym_uint144] = ACTIONS(673),
    [anon_sym_uint152] = ACTIONS(673),
    [anon_sym_uint160] = ACTIONS(673),
    [anon_sym_uint168] = ACTIONS(673),
    [anon_sym_uint176] = ACTIONS(673),
    [anon_sym_uint184] = ACTIONS(673),
    [anon_sym_uint192] = ACTIONS(673),
    [anon_sym_uint200] = ACTIONS(673),
    [anon_sym_uint208] = ACTIONS(673),
    [anon_sym_uint216] = ACTIONS(673),
    [anon_sym_uint224] = ACTIONS(673),
    [anon_sym_uint232] = ACTIONS(673),
    [anon_sym_uint240] = ACTIONS(673),
    [anon_sym_uint248] = ACTIONS(673),
    [anon_sym_uint256] = ACTIONS(673),
    [anon_sym_bytes] = ACTIONS(673),
    [anon_sym_bytes1] = ACTIONS(673),
    [anon_sym_bytes2] = ACTIONS(673),
    [anon_sym_bytes3] = ACTIONS(673),
    [anon_sym_bytes4] = ACTIONS(673),
    [anon_sym_bytes5] = ACTIONS(673),
    [anon_sym_bytes6] = ACTIONS(673),
    [anon_sym_bytes7] = ACTIONS(673),
    [anon_sym_bytes8] = ACTIONS(673),
    [anon_sym_bytes9] = ACTIONS(673),
    [anon_sym_bytes10] = ACTIONS(673),
    [anon_sym_bytes11] = ACTIONS(673),
    [anon_sym_bytes12] = ACTIONS(673),
    [anon_sym_bytes13] = ACTIONS(673),
    [anon_sym_bytes14] = ACTIONS(673),
    [anon_sym_bytes15] = ACTIONS(673),
    [anon_sym_bytes16] = ACTIONS(673),
    [anon_sym_bytes17] = ACTIONS(673),
    [anon_sym_bytes18] = ACTIONS(673),
    [anon_sym_bytes19] = ACTIONS(673),
    [anon_sym_bytes20] = ACTIONS(673),
    [anon_sym_bytes21] = ACTIONS(673),
    [anon_sym_bytes22] = ACTIONS(673),
    [anon_sym_bytes23] = ACTIONS(673),
    [anon_sym_bytes24] = ACTIONS(673),
    [anon_sym_bytes25] = ACTIONS(673),
    [anon_sym_bytes26] = ACTIONS(673),
    [anon_sym_bytes27] = ACTIONS(673),
    [anon_sym_bytes28] = ACTIONS(673),
    [anon_sym_bytes29] = ACTIONS(673),
    [anon_sym_bytes30] = ACTIONS(673),
    [anon_sym_bytes31] = ACTIONS(673),
    [anon_sym_bytes32] = ACTIONS(673),
    [anon_sym_fixed] = ACTIONS(673),
    [aux_sym__fixed_token1] = ACTIONS(673),
    [anon_sym_ufixed] = ACTIONS(673),
    [aux_sym__ufixed_token1] = ACTIONS(673),
    [sym_comment] = ACTIONS(3),
  },
  [168] = {
    [ts_builtin_sym_end] = ACTIONS(647),
    [sym_identifier] = ACTIONS(649),
    [anon_sym_pragma] = ACTIONS(649),
    [anon_sym_import] = ACTIONS(649),
    [anon_sym_type] = ACTIONS(649),
    [anon_sym_abstract] = ACTIONS(649),
    [anon_sym_contract] = ACTIONS(649),
    [anon_sym_error] = ACTIONS(649),
    [anon_sym_interface] = ACTIONS(649),
    [anon_sym_library] = ACTIONS(649),
    [anon_sym_struct] = ACTIONS(649),
    [anon_sym_enum] = ACTIONS(649),
    [anon_sym_using] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(649),
    [anon_sym_byte] = ACTIONS(649),
    [anon_sym_address] = ACTIONS(649),
    [anon_sym_var] = ACTIONS(649),
    [anon_sym_mapping] = ACTIONS(649),
    [anon_sym_bool] = ACTIONS(649),
    [anon_sym_string] = ACTIONS(649),
    [anon_sym_int] = ACTIONS(649),
    [anon_sym_int8] = ACTIONS(649),
    [anon_sym_int16] = ACTIONS(649),
    [anon_sym_int24] = ACTIONS(649),
    [anon_sym_int32] = ACTIONS(649),
    [anon_sym_int40] = ACTIONS(649),
    [anon_sym_int48] = ACTIONS(649),
    [anon_sym_int56] = ACTIONS(649),
    [anon_sym_int64] = ACTIONS(649),
    [anon_sym_int72] = ACTIONS(649),
    [anon_sym_int80] = ACTIONS(649),
    [anon_sym_int88] = ACTIONS(649),
    [anon_sym_int96] = ACTIONS(649),
    [anon_sym_int104] = ACTIONS(649),
    [anon_sym_int112] = ACTIONS(649),
    [anon_sym_int120] = ACTIONS(649),
    [anon_sym_int128] = ACTIONS(649),
    [anon_sym_int136] = ACTIONS(649),
    [anon_sym_int144] = ACTIONS(649),
    [anon_sym_int152] = ACTIONS(649),
    [anon_sym_int160] = ACTIONS(649),
    [anon_sym_int168] = ACTIONS(649),
    [anon_sym_int176] = ACTIONS(649),
    [anon_sym_int184] = ACTIONS(649),
    [anon_sym_int192] = ACTIONS(649),
    [anon_sym_int200] = ACTIONS(649),
    [anon_sym_int208] = ACTIONS(649),
    [anon_sym_int216] = ACTIONS(649),
    [anon_sym_int224] = ACTIONS(649),
    [anon_sym_int232] = ACTIONS(649),
    [anon_sym_int240] = ACTIONS(649),
    [anon_sym_int248] = ACTIONS(649),
    [anon_sym_int256] = ACTIONS(649),
    [anon_sym_uint] = ACTIONS(649),
    [anon_sym_uint8] = ACTIONS(649),
    [anon_sym_uint16] = ACTIONS(649),
    [anon_sym_uint24] = ACTIONS(649),
    [anon_sym_uint32] = ACTIONS(649),
    [anon_sym_uint40] = ACTIONS(649),
    [anon_sym_uint48] = ACTIONS(649),
    [anon_sym_uint56] = ACTIONS(649),
    [anon_sym_uint64] = ACTIONS(649),
    [anon_sym_uint72] = ACTIONS(649),
    [anon_sym_uint80] = ACTIONS(649),
    [anon_sym_uint88] = ACTIONS(649),
    [anon_sym_uint96] = ACTIONS(649),
    [anon_sym_uint104] = ACTIONS(649),
    [anon_sym_uint112] = ACTIONS(649),
    [anon_sym_uint120] = ACTIONS(649),
    [anon_sym_uint128] = ACTIONS(649),
    [anon_sym_uint136] = ACTIONS(649),
    [anon_sym_uint144] = ACTIONS(649),
    [anon_sym_uint152] = ACTIONS(649),
    [anon_sym_uint160] = ACTIONS(649),
    [anon_sym_uint168] = ACTIONS(649),
    [anon_sym_uint176] = ACTIONS(649),
    [anon_sym_uint184] = ACTIONS(649),
    [anon_sym_uint192] = ACTIONS(649),
    [anon_sym_uint200] = ACTIONS(649),
    [anon_sym_uint208] = ACTIONS(649),
    [anon_sym_uint216] = ACTIONS(649),
    [anon_sym_uint224] = ACTIONS(649),
    [anon_sym_uint232] = ACTIONS(649),
    [anon_sym_uint240] = ACTIONS(649),
    [anon_sym_uint248] = ACTIONS(649),
    [anon_sym_uint256] = ACTIONS(649),
    [anon_sym_bytes] = ACTIONS(649),
    [anon_sym_bytes1] = ACTIONS(649),
    [anon_sym_bytes2] = ACTIONS(649),
    [anon_sym_bytes3] = ACTIONS(649),
    [anon_sym_bytes4] = ACTIONS(649),
    [anon_sym_bytes5] = ACTIONS(649),
    [anon_sym_bytes6] = ACTIONS(649),
    [anon_sym_bytes7] = ACTIONS(649),
    [anon_sym_bytes8] = ACTIONS(649),
    [anon_sym_bytes9] = ACTIONS(649),
    [anon_sym_bytes10] = ACTIONS(649),
    [anon_sym_bytes11] = ACTIONS(649),
    [anon_sym_bytes12] = ACTIONS(649),
    [anon_sym_bytes13] = ACTIONS(649),
    [anon_sym_bytes14] = ACTIONS(649),
    [anon_sym_bytes15] = ACTIONS(649),
    [anon_sym_bytes16] = ACTIONS(649),
    [anon_sym_bytes17] = ACTIONS(649),
    [anon_sym_bytes18] = ACTIONS(649),
    [anon_sym_bytes19] = ACTIONS(649),
    [anon_sym_bytes20] = ACTIONS(649),
    [anon_sym_bytes21] = ACTIONS(649),
    [anon_sym_bytes22] = ACTIONS(649),
    [anon_sym_bytes23] = ACTIONS(649),
    [anon_sym_bytes24] = ACTIONS(649),
    [anon_sym_bytes25] = ACTIONS(649),
    [anon_sym_bytes26] = ACTIONS(649),
    [anon_sym_bytes27] = ACTIONS(649),
    [anon_sym_bytes28] = ACTIONS(649),
    [anon_sym_bytes29] = ACTIONS(649),
    [anon_sym_bytes30] = ACTIONS(649),
    [anon_sym_bytes31] = ACTIONS(649),
    [anon_sym_bytes32] = ACTIONS(649),
    [anon_sym_fixed] = ACTIONS(649),
    [aux_sym__fixed_token1] = ACTIONS(649),
    [anon_sym_ufixed] = ACTIONS(649),
    [aux_sym__ufixed_token1] = ACTIONS(649),
    [sym_comment] = ACTIONS(3),
  },
  [169] = {
    [ts_builtin_sym_end] = ACTIONS(675),
    [sym_identifier] = ACTIONS(677),
    [anon_sym_pragma] = ACTIONS(677),
    [anon_sym_import] = ACTIONS(677),
    [anon_sym_type] = ACTIONS(677),
    [anon_sym_abstract] = ACTIONS(677),
    [anon_sym_contract] = ACTIONS(677),
    [anon_sym_error] = ACTIONS(677),
    [anon_sym_interface] = ACTIONS(677),
    [anon_sym_library] = ACTIONS(677),
    [anon_sym_struct] = ACTIONS(677),
    [anon_sym_enum] = ACTIONS(677),
    [anon_sym_using] = ACTIONS(677),
    [anon_sym_function] = ACTIONS(677),
    [anon_sym_byte] = ACTIONS(677),
    [anon_sym_address] = ACTIONS(677),
    [anon_sym_var] = ACTIONS(677),
    [anon_sym_mapping] = ACTIONS(677),
    [anon_sym_bool] = ACTIONS(677),
    [anon_sym_string] = ACTIONS(677),
    [anon_sym_int] = ACTIONS(677),
    [anon_sym_int8] = ACTIONS(677),
    [anon_sym_int16] = ACTIONS(677),
    [anon_sym_int24] = ACTIONS(677),
    [anon_sym_int32] = ACTIONS(677),
    [anon_sym_int40] = ACTIONS(677),
    [anon_sym_int48] = ACTIONS(677),
    [anon_sym_int56] = ACTIONS(677),
    [anon_sym_int64] = ACTIONS(677),
    [anon_sym_int72] = ACTIONS(677),
    [anon_sym_int80] = ACTIONS(677),
    [anon_sym_int88] = ACTIONS(677),
    [anon_sym_int96] = ACTIONS(677),
    [anon_sym_int104] = ACTIONS(677),
    [anon_sym_int112] = ACTIONS(677),
    [anon_sym_int120] = ACTIONS(677),
    [anon_sym_int128] = ACTIONS(677),
    [anon_sym_int136] = ACTIONS(677),
    [anon_sym_int144] = ACTIONS(677),
    [anon_sym_int152] = ACTIONS(677),
    [anon_sym_int160] = ACTIONS(677),
    [anon_sym_int168] = ACTIONS(677),
    [anon_sym_int176] = ACTIONS(677),
    [anon_sym_int184] = ACTIONS(677),
    [anon_sym_int192] = ACTIONS(677),
    [anon_sym_int200] = ACTIONS(677),
    [anon_sym_int208] = ACTIONS(677),
    [anon_sym_int216] = ACTIONS(677),
    [anon_sym_int224] = ACTIONS(677),
    [anon_sym_int232] = ACTIONS(677),
    [anon_sym_int240] = ACTIONS(677),
    [anon_sym_int248] = ACTIONS(677),
    [anon_sym_int256] = ACTIONS(677),
    [anon_sym_uint] = ACTIONS(677),
    [anon_sym_uint8] = ACTIONS(677),
    [anon_sym_uint16] = ACTIONS(677),
    [anon_sym_uint24] = ACTIONS(677),
    [anon_sym_uint32] = ACTIONS(677),
    [anon_sym_uint40] = ACTIONS(677),
    [anon_sym_uint48] = ACTIONS(677),
    [anon_sym_uint56] = ACTIONS(677),
    [anon_sym_uint64] = ACTIONS(677),
    [anon_sym_uint72] = ACTIONS(677),
    [anon_sym_uint80] = ACTIONS(677),
    [anon_sym_uint88] = ACTIONS(677),
    [anon_sym_uint96] = ACTIONS(677),
    [anon_sym_uint104] = ACTIONS(677),
    [anon_sym_uint112] = ACTIONS(677),
    [anon_sym_uint120] = ACTIONS(677),
    [anon_sym_uint128] = ACTIONS(677),
    [anon_sym_uint136] = ACTIONS(677),
    [anon_sym_uint144] = ACTIONS(677),
    [anon_sym_uint152] = ACTIONS(677),
    [anon_sym_uint160] = ACTIONS(677),
    [anon_sym_uint168] = ACTIONS(677),
    [anon_sym_uint176] = ACTIONS(677),
    [anon_sym_uint184] = ACTIONS(677),
    [anon_sym_uint192] = ACTIONS(677),
    [anon_sym_uint200] = ACTIONS(677),
    [anon_sym_uint208] = ACTIONS(677),
    [anon_sym_uint216] = ACTIONS(677),
    [anon_sym_uint224] = ACTIONS(677),
    [anon_sym_uint232] = ACTIONS(677),
    [anon_sym_uint240] = ACTIONS(677),
    [anon_sym_uint248] = ACTIONS(677),
    [anon_sym_uint256] = ACTIONS(677),
    [anon_sym_bytes] = ACTIONS(677),
    [anon_sym_bytes1] = ACTIONS(677),
    [anon_sym_bytes2] = ACTIONS(677),
    [anon_sym_bytes3] = ACTIONS(677),
    [anon_sym_bytes4] = ACTIONS(677),
    [anon_sym_bytes5] = ACTIONS(677),
    [anon_sym_bytes6] = ACTIONS(677),
    [anon_sym_bytes7] = ACTIONS(677),
    [anon_sym_bytes8] = ACTIONS(677),
    [anon_sym_bytes9] = ACTIONS(677),
    [anon_sym_bytes10] = ACTIONS(677),
    [anon_sym_bytes11] = ACTIONS(677),
    [anon_sym_bytes12] = ACTIONS(677),
    [anon_sym_bytes13] = ACTIONS(677),
    [anon_sym_bytes14] = ACTIONS(677),
    [anon_sym_bytes15] = ACTIONS(677),
    [anon_sym_bytes16] = ACTIONS(677),
    [anon_sym_bytes17] = ACTIONS(677),
    [anon_sym_bytes18] = ACTIONS(677),
    [anon_sym_bytes19] = ACTIONS(677),
    [anon_sym_bytes20] = ACTIONS(677),
    [anon_sym_bytes21] = ACTIONS(677),
    [anon_sym_bytes22] = ACTIONS(677),
    [anon_sym_bytes23] = ACTIONS(677),
    [anon_sym_bytes24] = ACTIONS(677),
    [anon_sym_bytes25] = ACTIONS(677),
    [anon_sym_bytes26] = ACTIONS(677),
    [anon_sym_bytes27] = ACTIONS(677),
    [anon_sym_bytes28] = ACTIONS(677),
    [anon_sym_bytes29] = ACTIONS(677),
    [anon_sym_bytes30] = ACTIONS(677),
    [anon_sym_bytes31] = ACTIONS(677),
    [anon_sym_bytes32] = ACTIONS(677),
    [anon_sym_fixed] = ACTIONS(677),
    [aux_sym__fixed_token1] = ACTIONS(677),
    [anon_sym_ufixed] = ACTIONS(677),
    [aux_sym__ufixed_token1] = ACTIONS(677),
    [sym_comment] = ACTIONS(3),
  },
  [170] = {
    [ts_builtin_sym_end] = ACTIONS(679),
    [sym_identifier] = ACTIONS(681),
    [anon_sym_pragma] = ACTIONS(681),
    [anon_sym_import] = ACTIONS(681),
    [anon_sym_type] = ACTIONS(681),
    [anon_sym_abstract] = ACTIONS(681),
    [anon_sym_contract] = ACTIONS(681),
    [anon_sym_error] = ACTIONS(681),
    [anon_sym_interface] = ACTIONS(681),
    [anon_sym_library] = ACTIONS(681),
    [anon_sym_struct] = ACTIONS(681),
    [anon_sym_enum] = ACTIONS(681),
    [anon_sym_using] = ACTIONS(681),
    [anon_sym_function] = ACTIONS(681),
    [anon_sym_byte] = ACTIONS(681),
    [anon_sym_address] = ACTIONS(681),
    [anon_sym_var] = ACTIONS(681),
    [anon_sym_mapping] = ACTIONS(681),
    [anon_sym_bool] = ACTIONS(681),
    [anon_sym_string] = ACTIONS(681),
    [anon_sym_int] = ACTIONS(681),
    [anon_sym_int8] = ACTIONS(681),
    [anon_sym_int16] = ACTIONS(681),
    [anon_sym_int24] = ACTIONS(681),
    [anon_sym_int32] = ACTIONS(681),
    [anon_sym_int40] = ACTIONS(681),
    [anon_sym_int48] = ACTIONS(681),
    [anon_sym_int56] = ACTIONS(681),
    [anon_sym_int64] = ACTIONS(681),
    [anon_sym_int72] = ACTIONS(681),
    [anon_sym_int80] = ACTIONS(681),
    [anon_sym_int88] = ACTIONS(681),
    [anon_sym_int96] = ACTIONS(681),
    [anon_sym_int104] = ACTIONS(681),
    [anon_sym_int112] = ACTIONS(681),
    [anon_sym_int120] = ACTIONS(681),
    [anon_sym_int128] = ACTIONS(681),
    [anon_sym_int136] = ACTIONS(681),
    [anon_sym_int144] = ACTIONS(681),
    [anon_sym_int152] = ACTIONS(681),
    [anon_sym_int160] = ACTIONS(681),
    [anon_sym_int168] = ACTIONS(681),
    [anon_sym_int176] = ACTIONS(681),
    [anon_sym_int184] = ACTIONS(681),
    [anon_sym_int192] = ACTIONS(681),
    [anon_sym_int200] = ACTIONS(681),
    [anon_sym_int208] = ACTIONS(681),
    [anon_sym_int216] = ACTIONS(681),
    [anon_sym_int224] = ACTIONS(681),
    [anon_sym_int232] = ACTIONS(681),
    [anon_sym_int240] = ACTIONS(681),
    [anon_sym_int248] = ACTIONS(681),
    [anon_sym_int256] = ACTIONS(681),
    [anon_sym_uint] = ACTIONS(681),
    [anon_sym_uint8] = ACTIONS(681),
    [anon_sym_uint16] = ACTIONS(681),
    [anon_sym_uint24] = ACTIONS(681),
    [anon_sym_uint32] = ACTIONS(681),
    [anon_sym_uint40] = ACTIONS(681),
    [anon_sym_uint48] = ACTIONS(681),
    [anon_sym_uint56] = ACTIONS(681),
    [anon_sym_uint64] = ACTIONS(681),
    [anon_sym_uint72] = ACTIONS(681),
    [anon_sym_uint80] = ACTIONS(681),
    [anon_sym_uint88] = ACTIONS(681),
    [anon_sym_uint96] = ACTIONS(681),
    [anon_sym_uint104] = ACTIONS(681),
    [anon_sym_uint112] = ACTIONS(681),
    [anon_sym_uint120] = ACTIONS(681),
    [anon_sym_uint128] = ACTIONS(681),
    [anon_sym_uint136] = ACTIONS(681),
    [anon_sym_uint144] = ACTIONS(681),
    [anon_sym_uint152] = ACTIONS(681),
    [anon_sym_uint160] = ACTIONS(681),
    [anon_sym_uint168] = ACTIONS(681),
    [anon_sym_uint176] = ACTIONS(681),
    [anon_sym_uint184] = ACTIONS(681),
    [anon_sym_uint192] = ACTIONS(681),
    [anon_sym_uint200] = ACTIONS(681),
    [anon_sym_uint208] = ACTIONS(681),
    [anon_sym_uint216] = ACTIONS(681),
    [anon_sym_uint224] = ACTIONS(681),
    [anon_sym_uint232] = ACTIONS(681),
    [anon_sym_uint240] = ACTIONS(681),
    [anon_sym_uint248] = ACTIONS(681),
    [anon_sym_uint256] = ACTIONS(681),
    [anon_sym_bytes] = ACTIONS(681),
    [anon_sym_bytes1] = ACTIONS(681),
    [anon_sym_bytes2] = ACTIONS(681),
    [anon_sym_bytes3] = ACTIONS(681),
    [anon_sym_bytes4] = ACTIONS(681),
    [anon_sym_bytes5] = ACTIONS(681),
    [anon_sym_bytes6] = ACTIONS(681),
    [anon_sym_bytes7] = ACTIONS(681),
    [anon_sym_bytes8] = ACTIONS(681),
    [anon_sym_bytes9] = ACTIONS(681),
    [anon_sym_bytes10] = ACTIONS(681),
    [anon_sym_bytes11] = ACTIONS(681),
    [anon_sym_bytes12] = ACTIONS(681),
    [anon_sym_bytes13] = ACTIONS(681),
    [anon_sym_bytes14] = ACTIONS(681),
    [anon_sym_bytes15] = ACTIONS(681),
    [anon_sym_bytes16] = ACTIONS(681),
    [anon_sym_bytes17] = ACTIONS(681),
    [anon_sym_bytes18] = ACTIONS(681),
    [anon_sym_bytes19] = ACTIONS(681),
    [anon_sym_bytes20] = ACTIONS(681),
    [anon_sym_bytes21] = ACTIONS(681),
    [anon_sym_bytes22] = ACTIONS(681),
    [anon_sym_bytes23] = ACTIONS(681),
    [anon_sym_bytes24] = ACTIONS(681),
    [anon_sym_bytes25] = ACTIONS(681),
    [anon_sym_bytes26] = ACTIONS(681),
    [anon_sym_bytes27] = ACTIONS(681),
    [anon_sym_bytes28] = ACTIONS(681),
    [anon_sym_bytes29] = ACTIONS(681),
    [anon_sym_bytes30] = ACTIONS(681),
    [anon_sym_bytes31] = ACTIONS(681),
    [anon_sym_bytes32] = ACTIONS(681),
    [anon_sym_fixed] = ACTIONS(681),
    [aux_sym__fixed_token1] = ACTIONS(681),
    [anon_sym_ufixed] = ACTIONS(681),
    [aux_sym__ufixed_token1] = ACTIONS(681),
    [sym_comment] = ACTIONS(3),
  },
  [171] = {
    [ts_builtin_sym_end] = ACTIONS(683),
    [sym_identifier] = ACTIONS(685),
    [anon_sym_pragma] = ACTIONS(685),
    [anon_sym_import] = ACTIONS(685),
    [anon_sym_type] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(685),
    [anon_sym_contract] = ACTIONS(685),
    [anon_sym_error] = ACTIONS(685),
    [anon_sym_interface] = ACTIONS(685),
    [anon_sym_library] = ACTIONS(685),
    [anon_sym_struct] = ACTIONS(685),
    [anon_sym_enum] = ACTIONS(685),
    [anon_sym_using] = ACTIONS(685),
    [anon_sym_function] = ACTIONS(685),
    [anon_sym_byte] = ACTIONS(685),
    [anon_sym_address] = ACTIONS(685),
    [anon_sym_var] = ACTIONS(685),
    [anon_sym_mapping] = ACTIONS(685),
    [anon_sym_bool] = ACTIONS(685),
    [anon_sym_string] = ACTIONS(685),
    [anon_sym_int] = ACTIONS(685),
    [anon_sym_int8] = ACTIONS(685),
    [anon_sym_int16] = ACTIONS(685),
    [anon_sym_int24] = ACTIONS(685),
    [anon_sym_int32] = ACTIONS(685),
    [anon_sym_int40] = ACTIONS(685),
    [anon_sym_int48] = ACTIONS(685),
    [anon_sym_int56] = ACTIONS(685),
    [anon_sym_int64] = ACTIONS(685),
    [anon_sym_int72] = ACTIONS(685),
    [anon_sym_int80] = ACTIONS(685),
    [anon_sym_int88] = ACTIONS(685),
    [anon_sym_int96] = ACTIONS(685),
    [anon_sym_int104] = ACTIONS(685),
    [anon_sym_int112] = ACTIONS(685),
    [anon_sym_int120] = ACTIONS(685),
    [anon_sym_int128] = ACTIONS(685),
    [anon_sym_int136] = ACTIONS(685),
    [anon_sym_int144] = ACTIONS(685),
    [anon_sym_int152] = ACTIONS(685),
    [anon_sym_int160] = ACTIONS(685),
    [anon_sym_int168] = ACTIONS(685),
    [anon_sym_int176] = ACTIONS(685),
    [anon_sym_int184] = ACTIONS(685),
    [anon_sym_int192] = ACTIONS(685),
    [anon_sym_int200] = ACTIONS(685),
    [anon_sym_int208] = ACTIONS(685),
    [anon_sym_int216] = ACTIONS(685),
    [anon_sym_int224] = ACTIONS(685),
    [anon_sym_int232] = ACTIONS(685),
    [anon_sym_int240] = ACTIONS(685),
    [anon_sym_int248] = ACTIONS(685),
    [anon_sym_int256] = ACTIONS(685),
    [anon_sym_uint] = ACTIONS(685),
    [anon_sym_uint8] = ACTIONS(685),
    [anon_sym_uint16] = ACTIONS(685),
    [anon_sym_uint24] = ACTIONS(685),
    [anon_sym_uint32] = ACTIONS(685),
    [anon_sym_uint40] = ACTIONS(685),
    [anon_sym_uint48] = ACTIONS(685),
    [anon_sym_uint56] = ACTIONS(685),
    [anon_sym_uint64] = ACTIONS(685),
    [anon_sym_uint72] = ACTIONS(685),
    [anon_sym_uint80] = ACTIONS(685),
    [anon_sym_uint88] = ACTIONS(685),
    [anon_sym_uint96] = ACTIONS(685),
    [anon_sym_uint104] = ACTIONS(685),
    [anon_sym_uint112] = ACTIONS(685),
    [anon_sym_uint120] = ACTIONS(685),
    [anon_sym_uint128] = ACTIONS(685),
    [anon_sym_uint136] = ACTIONS(685),
    [anon_sym_uint144] = ACTIONS(685),
    [anon_sym_uint152] = ACTIONS(685),
    [anon_sym_uint160] = ACTIONS(685),
    [anon_sym_uint168] = ACTIONS(685),
    [anon_sym_uint176] = ACTIONS(685),
    [anon_sym_uint184] = ACTIONS(685),
    [anon_sym_uint192] = ACTIONS(685),
    [anon_sym_uint200] = ACTIONS(685),
    [anon_sym_uint208] = ACTIONS(685),
    [anon_sym_uint216] = ACTIONS(685),
    [anon_sym_uint224] = ACTIONS(685),
    [anon_sym_uint232] = ACTIONS(685),
    [anon_sym_uint240] = ACTIONS(685),
    [anon_sym_uint248] = ACTIONS(685),
    [anon_sym_uint256] = ACTIONS(685),
    [anon_sym_bytes] = ACTIONS(685),
    [anon_sym_bytes1] = ACTIONS(685),
    [anon_sym_bytes2] = ACTIONS(685),
    [anon_sym_bytes3] = ACTIONS(685),
    [anon_sym_bytes4] = ACTIONS(685),
    [anon_sym_bytes5] = ACTIONS(685),
    [anon_sym_bytes6] = ACTIONS(685),
    [anon_sym_bytes7] = ACTIONS(685),
    [anon_sym_bytes8] = ACTIONS(685),
    [anon_sym_bytes9] = ACTIONS(685),
    [anon_sym_bytes10] = ACTIONS(685),
    [anon_sym_bytes11] = ACTIONS(685),
    [anon_sym_bytes12] = ACTIONS(685),
    [anon_sym_bytes13] = ACTIONS(685),
    [anon_sym_bytes14] = ACTIONS(685),
    [anon_sym_bytes15] = ACTIONS(685),
    [anon_sym_bytes16] = ACTIONS(685),
    [anon_sym_bytes17] = ACTIONS(685),
    [anon_sym_bytes18] = ACTIONS(685),
    [anon_sym_bytes19] = ACTIONS(685),
    [anon_sym_bytes20] = ACTIONS(685),
    [anon_sym_bytes21] = ACTIONS(685),
    [anon_sym_bytes22] = ACTIONS(685),
    [anon_sym_bytes23] = ACTIONS(685),
    [anon_sym_bytes24] = ACTIONS(685),
    [anon_sym_bytes25] = ACTIONS(685),
    [anon_sym_bytes26] = ACTIONS(685),
    [anon_sym_bytes27] = ACTIONS(685),
    [anon_sym_bytes28] = ACTIONS(685),
    [anon_sym_bytes29] = ACTIONS(685),
    [anon_sym_bytes30] = ACTIONS(685),
    [anon_sym_bytes31] = ACTIONS(685),
    [anon_sym_bytes32] = ACTIONS(685),
    [anon_sym_fixed] = ACTIONS(685),
    [aux_sym__fixed_token1] = ACTIONS(685),
    [anon_sym_ufixed] = ACTIONS(685),
    [aux_sym__ufixed_token1] = ACTIONS(685),
    [sym_comment] = ACTIONS(3),
  },
  [172] = {
    [ts_builtin_sym_end] = ACTIONS(687),
    [sym_identifier] = ACTIONS(689),
    [anon_sym_pragma] = ACTIONS(689),
    [anon_sym_import] = ACTIONS(689),
    [anon_sym_type] = ACTIONS(689),
    [anon_sym_abstract] = ACTIONS(689),
    [anon_sym_contract] = ACTIONS(689),
    [anon_sym_error] = ACTIONS(689),
    [anon_sym_interface] = ACTIONS(689),
    [anon_sym_library] = ACTIONS(689),
    [anon_sym_struct] = ACTIONS(689),
    [anon_sym_enum] = ACTIONS(689),
    [anon_sym_using] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(689),
    [anon_sym_byte] = ACTIONS(689),
    [anon_sym_address] = ACTIONS(689),
    [anon_sym_var] = ACTIONS(689),
    [anon_sym_mapping] = ACTIONS(689),
    [anon_sym_bool] = ACTIONS(689),
    [anon_sym_string] = ACTIONS(689),
    [anon_sym_int] = ACTIONS(689),
    [anon_sym_int8] = ACTIONS(689),
    [anon_sym_int16] = ACTIONS(689),
    [anon_sym_int24] = ACTIONS(689),
    [anon_sym_int32] = ACTIONS(689),
    [anon_sym_int40] = ACTIONS(689),
    [anon_sym_int48] = ACTIONS(689),
    [anon_sym_int56] = ACTIONS(689),
    [anon_sym_int64] = ACTIONS(689),
    [anon_sym_int72] = ACTIONS(689),
    [anon_sym_int80] = ACTIONS(689),
    [anon_sym_int88] = ACTIONS(689),
    [anon_sym_int96] = ACTIONS(689),
    [anon_sym_int104] = ACTIONS(689),
    [anon_sym_int112] = ACTIONS(689),
    [anon_sym_int120] = ACTIONS(689),
    [anon_sym_int128] = ACTIONS(689),
    [anon_sym_int136] = ACTIONS(689),
    [anon_sym_int144] = ACTIONS(689),
    [anon_sym_int152] = ACTIONS(689),
    [anon_sym_int160] = ACTIONS(689),
    [anon_sym_int168] = ACTIONS(689),
    [anon_sym_int176] = ACTIONS(689),
    [anon_sym_int184] = ACTIONS(689),
    [anon_sym_int192] = ACTIONS(689),
    [anon_sym_int200] = ACTIONS(689),
    [anon_sym_int208] = ACTIONS(689),
    [anon_sym_int216] = ACTIONS(689),
    [anon_sym_int224] = ACTIONS(689),
    [anon_sym_int232] = ACTIONS(689),
    [anon_sym_int240] = ACTIONS(689),
    [anon_sym_int248] = ACTIONS(689),
    [anon_sym_int256] = ACTIONS(689),
    [anon_sym_uint] = ACTIONS(689),
    [anon_sym_uint8] = ACTIONS(689),
    [anon_sym_uint16] = ACTIONS(689),
    [anon_sym_uint24] = ACTIONS(689),
    [anon_sym_uint32] = ACTIONS(689),
    [anon_sym_uint40] = ACTIONS(689),
    [anon_sym_uint48] = ACTIONS(689),
    [anon_sym_uint56] = ACTIONS(689),
    [anon_sym_uint64] = ACTIONS(689),
    [anon_sym_uint72] = ACTIONS(689),
    [anon_sym_uint80] = ACTIONS(689),
    [anon_sym_uint88] = ACTIONS(689),
    [anon_sym_uint96] = ACTIONS(689),
    [anon_sym_uint104] = ACTIONS(689),
    [anon_sym_uint112] = ACTIONS(689),
    [anon_sym_uint120] = ACTIONS(689),
    [anon_sym_uint128] = ACTIONS(689),
    [anon_sym_uint136] = ACTIONS(689),
    [anon_sym_uint144] = ACTIONS(689),
    [anon_sym_uint152] = ACTIONS(689),
    [anon_sym_uint160] = ACTIONS(689),
    [anon_sym_uint168] = ACTIONS(689),
    [anon_sym_uint176] = ACTIONS(689),
    [anon_sym_uint184] = ACTIONS(689),
    [anon_sym_uint192] = ACTIONS(689),
    [anon_sym_uint200] = ACTIONS(689),
    [anon_sym_uint208] = ACTIONS(689),
    [anon_sym_uint216] = ACTIONS(689),
    [anon_sym_uint224] = ACTIONS(689),
    [anon_sym_uint232] = ACTIONS(689),
    [anon_sym_uint240] = ACTIONS(689),
    [anon_sym_uint248] = ACTIONS(689),
    [anon_sym_uint256] = ACTIONS(689),
    [anon_sym_bytes] = ACTIONS(689),
    [anon_sym_bytes1] = ACTIONS(689),
    [anon_sym_bytes2] = ACTIONS(689),
    [anon_sym_bytes3] = ACTIONS(689),
    [anon_sym_bytes4] = ACTIONS(689),
    [anon_sym_bytes5] = ACTIONS(689),
    [anon_sym_bytes6] = ACTIONS(689),
    [anon_sym_bytes7] = ACTIONS(689),
    [anon_sym_bytes8] = ACTIONS(689),
    [anon_sym_bytes9] = ACTIONS(689),
    [anon_sym_bytes10] = ACTIONS(689),
    [anon_sym_bytes11] = ACTIONS(689),
    [anon_sym_bytes12] = ACTIONS(689),
    [anon_sym_bytes13] = ACTIONS(689),
    [anon_sym_bytes14] = ACTIONS(689),
    [anon_sym_bytes15] = ACTIONS(689),
    [anon_sym_bytes16] = ACTIONS(689),
    [anon_sym_bytes17] = ACTIONS(689),
    [anon_sym_bytes18] = ACTIONS(689),
    [anon_sym_bytes19] = ACTIONS(689),
    [anon_sym_bytes20] = ACTIONS(689),
    [anon_sym_bytes21] = ACTIONS(689),
    [anon_sym_bytes22] = ACTIONS(689),
    [anon_sym_bytes23] = ACTIONS(689),
    [anon_sym_bytes24] = ACTIONS(689),
    [anon_sym_bytes25] = ACTIONS(689),
    [anon_sym_bytes26] = ACTIONS(689),
    [anon_sym_bytes27] = ACTIONS(689),
    [anon_sym_bytes28] = ACTIONS(689),
    [anon_sym_bytes29] = ACTIONS(689),
    [anon_sym_bytes30] = ACTIONS(689),
    [anon_sym_bytes31] = ACTIONS(689),
    [anon_sym_bytes32] = ACTIONS(689),
    [anon_sym_fixed] = ACTIONS(689),
    [aux_sym__fixed_token1] = ACTIONS(689),
    [anon_sym_ufixed] = ACTIONS(689),
    [aux_sym__ufixed_token1] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
  },
  [173] = {
    [ts_builtin_sym_end] = ACTIONS(691),
    [sym_identifier] = ACTIONS(693),
    [anon_sym_pragma] = ACTIONS(693),
    [anon_sym_import] = ACTIONS(693),
    [anon_sym_type] = ACTIONS(693),
    [anon_sym_abstract] = ACTIONS(693),
    [anon_sym_contract] = ACTIONS(693),
    [anon_sym_error] = ACTIONS(693),
    [anon_sym_interface] = ACTIONS(693),
    [anon_sym_library] = ACTIONS(693),
    [anon_sym_struct] = ACTIONS(693),
    [anon_sym_enum] = ACTIONS(693),
    [anon_sym_using] = ACTIONS(693),
    [anon_sym_function] = ACTIONS(693),
    [anon_sym_byte] = ACTIONS(693),
    [anon_sym_address] = ACTIONS(693),
    [anon_sym_var] = ACTIONS(693),
    [anon_sym_mapping] = ACTIONS(693),
    [anon_sym_bool] = ACTIONS(693),
    [anon_sym_string] = ACTIONS(693),
    [anon_sym_int] = ACTIONS(693),
    [anon_sym_int8] = ACTIONS(693),
    [anon_sym_int16] = ACTIONS(693),
    [anon_sym_int24] = ACTIONS(693),
    [anon_sym_int32] = ACTIONS(693),
    [anon_sym_int40] = ACTIONS(693),
    [anon_sym_int48] = ACTIONS(693),
    [anon_sym_int56] = ACTIONS(693),
    [anon_sym_int64] = ACTIONS(693),
    [anon_sym_int72] = ACTIONS(693),
    [anon_sym_int80] = ACTIONS(693),
    [anon_sym_int88] = ACTIONS(693),
    [anon_sym_int96] = ACTIONS(693),
    [anon_sym_int104] = ACTIONS(693),
    [anon_sym_int112] = ACTIONS(693),
    [anon_sym_int120] = ACTIONS(693),
    [anon_sym_int128] = ACTIONS(693),
    [anon_sym_int136] = ACTIONS(693),
    [anon_sym_int144] = ACTIONS(693),
    [anon_sym_int152] = ACTIONS(693),
    [anon_sym_int160] = ACTIONS(693),
    [anon_sym_int168] = ACTIONS(693),
    [anon_sym_int176] = ACTIONS(693),
    [anon_sym_int184] = ACTIONS(693),
    [anon_sym_int192] = ACTIONS(693),
    [anon_sym_int200] = ACTIONS(693),
    [anon_sym_int208] = ACTIONS(693),
    [anon_sym_int216] = ACTIONS(693),
    [anon_sym_int224] = ACTIONS(693),
    [anon_sym_int232] = ACTIONS(693),
    [anon_sym_int240] = ACTIONS(693),
    [anon_sym_int248] = ACTIONS(693),
    [anon_sym_int256] = ACTIONS(693),
    [anon_sym_uint] = ACTIONS(693),
    [anon_sym_uint8] = ACTIONS(693),
    [anon_sym_uint16] = ACTIONS(693),
    [anon_sym_uint24] = ACTIONS(693),
    [anon_sym_uint32] = ACTIONS(693),
    [anon_sym_uint40] = ACTIONS(693),
    [anon_sym_uint48] = ACTIONS(693),
    [anon_sym_uint56] = ACTIONS(693),
    [anon_sym_uint64] = ACTIONS(693),
    [anon_sym_uint72] = ACTIONS(693),
    [anon_sym_uint80] = ACTIONS(693),
    [anon_sym_uint88] = ACTIONS(693),
    [anon_sym_uint96] = ACTIONS(693),
    [anon_sym_uint104] = ACTIONS(693),
    [anon_sym_uint112] = ACTIONS(693),
    [anon_sym_uint120] = ACTIONS(693),
    [anon_sym_uint128] = ACTIONS(693),
    [anon_sym_uint136] = ACTIONS(693),
    [anon_sym_uint144] = ACTIONS(693),
    [anon_sym_uint152] = ACTIONS(693),
    [anon_sym_uint160] = ACTIONS(693),
    [anon_sym_uint168] = ACTIONS(693),
    [anon_sym_uint176] = ACTIONS(693),
    [anon_sym_uint184] = ACTIONS(693),
    [anon_sym_uint192] = ACTIONS(693),
    [anon_sym_uint200] = ACTIONS(693),
    [anon_sym_uint208] = ACTIONS(693),
    [anon_sym_uint216] = ACTIONS(693),
    [anon_sym_uint224] = ACTIONS(693),
    [anon_sym_uint232] = ACTIONS(693),
    [anon_sym_uint240] = ACTIONS(693),
    [anon_sym_uint248] = ACTIONS(693),
    [anon_sym_uint256] = ACTIONS(693),
    [anon_sym_bytes] = ACTIONS(693),
    [anon_sym_bytes1] = ACTIONS(693),
    [anon_sym_bytes2] = ACTIONS(693),
    [anon_sym_bytes3] = ACTIONS(693),
    [anon_sym_bytes4] = ACTIONS(693),
    [anon_sym_bytes5] = ACTIONS(693),
    [anon_sym_bytes6] = ACTIONS(693),
    [anon_sym_bytes7] = ACTIONS(693),
    [anon_sym_bytes8] = ACTIONS(693),
    [anon_sym_bytes9] = ACTIONS(693),
    [anon_sym_bytes10] = ACTIONS(693),
    [anon_sym_bytes11] = ACTIONS(693),
    [anon_sym_bytes12] = ACTIONS(693),
    [anon_sym_bytes13] = ACTIONS(693),
    [anon_sym_bytes14] = ACTIONS(693),
    [anon_sym_bytes15] = ACTIONS(693),
    [anon_sym_bytes16] = ACTIONS(693),
    [anon_sym_bytes17] = ACTIONS(693),
    [anon_sym_bytes18] = ACTIONS(693),
    [anon_sym_bytes19] = ACTIONS(693),
    [anon_sym_bytes20] = ACTIONS(693),
    [anon_sym_bytes21] = ACTIONS(693),
    [anon_sym_bytes22] = ACTIONS(693),
    [anon_sym_bytes23] = ACTIONS(693),
    [anon_sym_bytes24] = ACTIONS(693),
    [anon_sym_bytes25] = ACTIONS(693),
    [anon_sym_bytes26] = ACTIONS(693),
    [anon_sym_bytes27] = ACTIONS(693),
    [anon_sym_bytes28] = ACTIONS(693),
    [anon_sym_bytes29] = ACTIONS(693),
    [anon_sym_bytes30] = ACTIONS(693),
    [anon_sym_bytes31] = ACTIONS(693),
    [anon_sym_bytes32] = ACTIONS(693),
    [anon_sym_fixed] = ACTIONS(693),
    [aux_sym__fixed_token1] = ACTIONS(693),
    [anon_sym_ufixed] = ACTIONS(693),
    [aux_sym__ufixed_token1] = ACTIONS(693),
    [sym_comment] = ACTIONS(3),
  },
  [174] = {
    [ts_builtin_sym_end] = ACTIONS(695),
    [sym_identifier] = ACTIONS(697),
    [anon_sym_pragma] = ACTIONS(697),
    [anon_sym_import] = ACTIONS(697),
    [anon_sym_type] = ACTIONS(697),
    [anon_sym_abstract] = ACTIONS(697),
    [anon_sym_contract] = ACTIONS(697),
    [anon_sym_error] = ACTIONS(697),
    [anon_sym_interface] = ACTIONS(697),
    [anon_sym_library] = ACTIONS(697),
    [anon_sym_struct] = ACTIONS(697),
    [anon_sym_enum] = ACTIONS(697),
    [anon_sym_using] = ACTIONS(697),
    [anon_sym_function] = ACTIONS(697),
    [anon_sym_byte] = ACTIONS(697),
    [anon_sym_address] = ACTIONS(697),
    [anon_sym_var] = ACTIONS(697),
    [anon_sym_mapping] = ACTIONS(697),
    [anon_sym_bool] = ACTIONS(697),
    [anon_sym_string] = ACTIONS(697),
    [anon_sym_int] = ACTIONS(697),
    [anon_sym_int8] = ACTIONS(697),
    [anon_sym_int16] = ACTIONS(697),
    [anon_sym_int24] = ACTIONS(697),
    [anon_sym_int32] = ACTIONS(697),
    [anon_sym_int40] = ACTIONS(697),
    [anon_sym_int48] = ACTIONS(697),
    [anon_sym_int56] = ACTIONS(697),
    [anon_sym_int64] = ACTIONS(697),
    [anon_sym_int72] = ACTIONS(697),
    [anon_sym_int80] = ACTIONS(697),
    [anon_sym_int88] = ACTIONS(697),
    [anon_sym_int96] = ACTIONS(697),
    [anon_sym_int104] = ACTIONS(697),
    [anon_sym_int112] = ACTIONS(697),
    [anon_sym_int120] = ACTIONS(697),
    [anon_sym_int128] = ACTIONS(697),
    [anon_sym_int136] = ACTIONS(697),
    [anon_sym_int144] = ACTIONS(697),
    [anon_sym_int152] = ACTIONS(697),
    [anon_sym_int160] = ACTIONS(697),
    [anon_sym_int168] = ACTIONS(697),
    [anon_sym_int176] = ACTIONS(697),
    [anon_sym_int184] = ACTIONS(697),
    [anon_sym_int192] = ACTIONS(697),
    [anon_sym_int200] = ACTIONS(697),
    [anon_sym_int208] = ACTIONS(697),
    [anon_sym_int216] = ACTIONS(697),
    [anon_sym_int224] = ACTIONS(697),
    [anon_sym_int232] = ACTIONS(697),
    [anon_sym_int240] = ACTIONS(697),
    [anon_sym_int248] = ACTIONS(697),
    [anon_sym_int256] = ACTIONS(697),
    [anon_sym_uint] = ACTIONS(697),
    [anon_sym_uint8] = ACTIONS(697),
    [anon_sym_uint16] = ACTIONS(697),
    [anon_sym_uint24] = ACTIONS(697),
    [anon_sym_uint32] = ACTIONS(697),
    [anon_sym_uint40] = ACTIONS(697),
    [anon_sym_uint48] = ACTIONS(697),
    [anon_sym_uint56] = ACTIONS(697),
    [anon_sym_uint64] = ACTIONS(697),
    [anon_sym_uint72] = ACTIONS(697),
    [anon_sym_uint80] = ACTIONS(697),
    [anon_sym_uint88] = ACTIONS(697),
    [anon_sym_uint96] = ACTIONS(697),
    [anon_sym_uint104] = ACTIONS(697),
    [anon_sym_uint112] = ACTIONS(697),
    [anon_sym_uint120] = ACTIONS(697),
    [anon_sym_uint128] = ACTIONS(697),
    [anon_sym_uint136] = ACTIONS(697),
    [anon_sym_uint144] = ACTIONS(697),
    [anon_sym_uint152] = ACTIONS(697),
    [anon_sym_uint160] = ACTIONS(697),
    [anon_sym_uint168] = ACTIONS(697),
    [anon_sym_uint176] = ACTIONS(697),
    [anon_sym_uint184] = ACTIONS(697),
    [anon_sym_uint192] = ACTIONS(697),
    [anon_sym_uint200] = ACTIONS(697),
    [anon_sym_uint208] = ACTIONS(697),
    [anon_sym_uint216] = ACTIONS(697),
    [anon_sym_uint224] = ACTIONS(697),
    [anon_sym_uint232] = ACTIONS(697),
    [anon_sym_uint240] = ACTIONS(697),
    [anon_sym_uint248] = ACTIONS(697),
    [anon_sym_uint256] = ACTIONS(697),
    [anon_sym_bytes] = ACTIONS(697),
    [anon_sym_bytes1] = ACTIONS(697),
    [anon_sym_bytes2] = ACTIONS(697),
    [anon_sym_bytes3] = ACTIONS(697),
    [anon_sym_bytes4] = ACTIONS(697),
    [anon_sym_bytes5] = ACTIONS(697),
    [anon_sym_bytes6] = ACTIONS(697),
    [anon_sym_bytes7] = ACTIONS(697),
    [anon_sym_bytes8] = ACTIONS(697),
    [anon_sym_bytes9] = ACTIONS(697),
    [anon_sym_bytes10] = ACTIONS(697),
    [anon_sym_bytes11] = ACTIONS(697),
    [anon_sym_bytes12] = ACTIONS(697),
    [anon_sym_bytes13] = ACTIONS(697),
    [anon_sym_bytes14] = ACTIONS(697),
    [anon_sym_bytes15] = ACTIONS(697),
    [anon_sym_bytes16] = ACTIONS(697),
    [anon_sym_bytes17] = ACTIONS(697),
    [anon_sym_bytes18] = ACTIONS(697),
    [anon_sym_bytes19] = ACTIONS(697),
    [anon_sym_bytes20] = ACTIONS(697),
    [anon_sym_bytes21] = ACTIONS(697),
    [anon_sym_bytes22] = ACTIONS(697),
    [anon_sym_bytes23] = ACTIONS(697),
    [anon_sym_bytes24] = ACTIONS(697),
    [anon_sym_bytes25] = ACTIONS(697),
    [anon_sym_bytes26] = ACTIONS(697),
    [anon_sym_bytes27] = ACTIONS(697),
    [anon_sym_bytes28] = ACTIONS(697),
    [anon_sym_bytes29] = ACTIONS(697),
    [anon_sym_bytes30] = ACTIONS(697),
    [anon_sym_bytes31] = ACTIONS(697),
    [anon_sym_bytes32] = ACTIONS(697),
    [anon_sym_fixed] = ACTIONS(697),
    [aux_sym__fixed_token1] = ACTIONS(697),
    [anon_sym_ufixed] = ACTIONS(697),
    [aux_sym__ufixed_token1] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
  },
  [175] = {
    [ts_builtin_sym_end] = ACTIONS(699),
    [sym_identifier] = ACTIONS(701),
    [anon_sym_pragma] = ACTIONS(701),
    [anon_sym_import] = ACTIONS(701),
    [anon_sym_type] = ACTIONS(701),
    [anon_sym_abstract] = ACTIONS(701),
    [anon_sym_contract] = ACTIONS(701),
    [anon_sym_error] = ACTIONS(701),
    [anon_sym_interface] = ACTIONS(701),
    [anon_sym_library] = ACTIONS(701),
    [anon_sym_struct] = ACTIONS(701),
    [anon_sym_enum] = ACTIONS(701),
    [anon_sym_using] = ACTIONS(701),
    [anon_sym_function] = ACTIONS(701),
    [anon_sym_byte] = ACTIONS(701),
    [anon_sym_address] = ACTIONS(701),
    [anon_sym_var] = ACTIONS(701),
    [anon_sym_mapping] = ACTIONS(701),
    [anon_sym_bool] = ACTIONS(701),
    [anon_sym_string] = ACTIONS(701),
    [anon_sym_int] = ACTIONS(701),
    [anon_sym_int8] = ACTIONS(701),
    [anon_sym_int16] = ACTIONS(701),
    [anon_sym_int24] = ACTIONS(701),
    [anon_sym_int32] = ACTIONS(701),
    [anon_sym_int40] = ACTIONS(701),
    [anon_sym_int48] = ACTIONS(701),
    [anon_sym_int56] = ACTIONS(701),
    [anon_sym_int64] = ACTIONS(701),
    [anon_sym_int72] = ACTIONS(701),
    [anon_sym_int80] = ACTIONS(701),
    [anon_sym_int88] = ACTIONS(701),
    [anon_sym_int96] = ACTIONS(701),
    [anon_sym_int104] = ACTIONS(701),
    [anon_sym_int112] = ACTIONS(701),
    [anon_sym_int120] = ACTIONS(701),
    [anon_sym_int128] = ACTIONS(701),
    [anon_sym_int136] = ACTIONS(701),
    [anon_sym_int144] = ACTIONS(701),
    [anon_sym_int152] = ACTIONS(701),
    [anon_sym_int160] = ACTIONS(701),
    [anon_sym_int168] = ACTIONS(701),
    [anon_sym_int176] = ACTIONS(701),
    [anon_sym_int184] = ACTIONS(701),
    [anon_sym_int192] = ACTIONS(701),
    [anon_sym_int200] = ACTIONS(701),
    [anon_sym_int208] = ACTIONS(701),
    [anon_sym_int216] = ACTIONS(701),
    [anon_sym_int224] = ACTIONS(701),
    [anon_sym_int232] = ACTIONS(701),
    [anon_sym_int240] = ACTIONS(701),
    [anon_sym_int248] = ACTIONS(701),
    [anon_sym_int256] = ACTIONS(701),
    [anon_sym_uint] = ACTIONS(701),
    [anon_sym_uint8] = ACTIONS(701),
    [anon_sym_uint16] = ACTIONS(701),
    [anon_sym_uint24] = ACTIONS(701),
    [anon_sym_uint32] = ACTIONS(701),
    [anon_sym_uint40] = ACTIONS(701),
    [anon_sym_uint48] = ACTIONS(701),
    [anon_sym_uint56] = ACTIONS(701),
    [anon_sym_uint64] = ACTIONS(701),
    [anon_sym_uint72] = ACTIONS(701),
    [anon_sym_uint80] = ACTIONS(701),
    [anon_sym_uint88] = ACTIONS(701),
    [anon_sym_uint96] = ACTIONS(701),
    [anon_sym_uint104] = ACTIONS(701),
    [anon_sym_uint112] = ACTIONS(701),
    [anon_sym_uint120] = ACTIONS(701),
    [anon_sym_uint128] = ACTIONS(701),
    [anon_sym_uint136] = ACTIONS(701),
    [anon_sym_uint144] = ACTIONS(701),
    [anon_sym_uint152] = ACTIONS(701),
    [anon_sym_uint160] = ACTIONS(701),
    [anon_sym_uint168] = ACTIONS(701),
    [anon_sym_uint176] = ACTIONS(701),
    [anon_sym_uint184] = ACTIONS(701),
    [anon_sym_uint192] = ACTIONS(701),
    [anon_sym_uint200] = ACTIONS(701),
    [anon_sym_uint208] = ACTIONS(701),
    [anon_sym_uint216] = ACTIONS(701),
    [anon_sym_uint224] = ACTIONS(701),
    [anon_sym_uint232] = ACTIONS(701),
    [anon_sym_uint240] = ACTIONS(701),
    [anon_sym_uint248] = ACTIONS(701),
    [anon_sym_uint256] = ACTIONS(701),
    [anon_sym_bytes] = ACTIONS(701),
    [anon_sym_bytes1] = ACTIONS(701),
    [anon_sym_bytes2] = ACTIONS(701),
    [anon_sym_bytes3] = ACTIONS(701),
    [anon_sym_bytes4] = ACTIONS(701),
    [anon_sym_bytes5] = ACTIONS(701),
    [anon_sym_bytes6] = ACTIONS(701),
    [anon_sym_bytes7] = ACTIONS(701),
    [anon_sym_bytes8] = ACTIONS(701),
    [anon_sym_bytes9] = ACTIONS(701),
    [anon_sym_bytes10] = ACTIONS(701),
    [anon_sym_bytes11] = ACTIONS(701),
    [anon_sym_bytes12] = ACTIONS(701),
    [anon_sym_bytes13] = ACTIONS(701),
    [anon_sym_bytes14] = ACTIONS(701),
    [anon_sym_bytes15] = ACTIONS(701),
    [anon_sym_bytes16] = ACTIONS(701),
    [anon_sym_bytes17] = ACTIONS(701),
    [anon_sym_bytes18] = ACTIONS(701),
    [anon_sym_bytes19] = ACTIONS(701),
    [anon_sym_bytes20] = ACTIONS(701),
    [anon_sym_bytes21] = ACTIONS(701),
    [anon_sym_bytes22] = ACTIONS(701),
    [anon_sym_bytes23] = ACTIONS(701),
    [anon_sym_bytes24] = ACTIONS(701),
    [anon_sym_bytes25] = ACTIONS(701),
    [anon_sym_bytes26] = ACTIONS(701),
    [anon_sym_bytes27] = ACTIONS(701),
    [anon_sym_bytes28] = ACTIONS(701),
    [anon_sym_bytes29] = ACTIONS(701),
    [anon_sym_bytes30] = ACTIONS(701),
    [anon_sym_bytes31] = ACTIONS(701),
    [anon_sym_bytes32] = ACTIONS(701),
    [anon_sym_fixed] = ACTIONS(701),
    [aux_sym__fixed_token1] = ACTIONS(701),
    [anon_sym_ufixed] = ACTIONS(701),
    [aux_sym__ufixed_token1] = ACTIONS(701),
    [sym_comment] = ACTIONS(3),
  },
  [176] = {
    [ts_builtin_sym_end] = ACTIONS(703),
    [sym_identifier] = ACTIONS(705),
    [anon_sym_pragma] = ACTIONS(705),
    [anon_sym_import] = ACTIONS(705),
    [anon_sym_type] = ACTIONS(705),
    [anon_sym_abstract] = ACTIONS(705),
    [anon_sym_contract] = ACTIONS(705),
    [anon_sym_error] = ACTIONS(705),
    [anon_sym_interface] = ACTIONS(705),
    [anon_sym_library] = ACTIONS(705),
    [anon_sym_struct] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(705),
    [anon_sym_using] = ACTIONS(705),
    [anon_sym_function] = ACTIONS(705),
    [anon_sym_byte] = ACTIONS(705),
    [anon_sym_address] = ACTIONS(705),
    [anon_sym_var] = ACTIONS(705),
    [anon_sym_mapping] = ACTIONS(705),
    [anon_sym_bool] = ACTIONS(705),
    [anon_sym_string] = ACTIONS(705),
    [anon_sym_int] = ACTIONS(705),
    [anon_sym_int8] = ACTIONS(705),
    [anon_sym_int16] = ACTIONS(705),
    [anon_sym_int24] = ACTIONS(705),
    [anon_sym_int32] = ACTIONS(705),
    [anon_sym_int40] = ACTIONS(705),
    [anon_sym_int48] = ACTIONS(705),
    [anon_sym_int56] = ACTIONS(705),
    [anon_sym_int64] = ACTIONS(705),
    [anon_sym_int72] = ACTIONS(705),
    [anon_sym_int80] = ACTIONS(705),
    [anon_sym_int88] = ACTIONS(705),
    [anon_sym_int96] = ACTIONS(705),
    [anon_sym_int104] = ACTIONS(705),
    [anon_sym_int112] = ACTIONS(705),
    [anon_sym_int120] = ACTIONS(705),
    [anon_sym_int128] = ACTIONS(705),
    [anon_sym_int136] = ACTIONS(705),
    [anon_sym_int144] = ACTIONS(705),
    [anon_sym_int152] = ACTIONS(705),
    [anon_sym_int160] = ACTIONS(705),
    [anon_sym_int168] = ACTIONS(705),
    [anon_sym_int176] = ACTIONS(705),
    [anon_sym_int184] = ACTIONS(705),
    [anon_sym_int192] = ACTIONS(705),
    [anon_sym_int200] = ACTIONS(705),
    [anon_sym_int208] = ACTIONS(705),
    [anon_sym_int216] = ACTIONS(705),
    [anon_sym_int224] = ACTIONS(705),
    [anon_sym_int232] = ACTIONS(705),
    [anon_sym_int240] = ACTIONS(705),
    [anon_sym_int248] = ACTIONS(705),
    [anon_sym_int256] = ACTIONS(705),
    [anon_sym_uint] = ACTIONS(705),
    [anon_sym_uint8] = ACTIONS(705),
    [anon_sym_uint16] = ACTIONS(705),
    [anon_sym_uint24] = ACTIONS(705),
    [anon_sym_uint32] = ACTIONS(705),
    [anon_sym_uint40] = ACTIONS(705),
    [anon_sym_uint48] = ACTIONS(705),
    [anon_sym_uint56] = ACTIONS(705),
    [anon_sym_uint64] = ACTIONS(705),
    [anon_sym_uint72] = ACTIONS(705),
    [anon_sym_uint80] = ACTIONS(705),
    [anon_sym_uint88] = ACTIONS(705),
    [anon_sym_uint96] = ACTIONS(705),
    [anon_sym_uint104] = ACTIONS(705),
    [anon_sym_uint112] = ACTIONS(705),
    [anon_sym_uint120] = ACTIONS(705),
    [anon_sym_uint128] = ACTIONS(705),
    [anon_sym_uint136] = ACTIONS(705),
    [anon_sym_uint144] = ACTIONS(705),
    [anon_sym_uint152] = ACTIONS(705),
    [anon_sym_uint160] = ACTIONS(705),
    [anon_sym_uint168] = ACTIONS(705),
    [anon_sym_uint176] = ACTIONS(705),
    [anon_sym_uint184] = ACTIONS(705),
    [anon_sym_uint192] = ACTIONS(705),
    [anon_sym_uint200] = ACTIONS(705),
    [anon_sym_uint208] = ACTIONS(705),
    [anon_sym_uint216] = ACTIONS(705),
    [anon_sym_uint224] = ACTIONS(705),
    [anon_sym_uint232] = ACTIONS(705),
    [anon_sym_uint240] = ACTIONS(705),
    [anon_sym_uint248] = ACTIONS(705),
    [anon_sym_uint256] = ACTIONS(705),
    [anon_sym_bytes] = ACTIONS(705),
    [anon_sym_bytes1] = ACTIONS(705),
    [anon_sym_bytes2] = ACTIONS(705),
    [anon_sym_bytes3] = ACTIONS(705),
    [anon_sym_bytes4] = ACTIONS(705),
    [anon_sym_bytes5] = ACTIONS(705),
    [anon_sym_bytes6] = ACTIONS(705),
    [anon_sym_bytes7] = ACTIONS(705),
    [anon_sym_bytes8] = ACTIONS(705),
    [anon_sym_bytes9] = ACTIONS(705),
    [anon_sym_bytes10] = ACTIONS(705),
    [anon_sym_bytes11] = ACTIONS(705),
    [anon_sym_bytes12] = ACTIONS(705),
    [anon_sym_bytes13] = ACTIONS(705),
    [anon_sym_bytes14] = ACTIONS(705),
    [anon_sym_bytes15] = ACTIONS(705),
    [anon_sym_bytes16] = ACTIONS(705),
    [anon_sym_bytes17] = ACTIONS(705),
    [anon_sym_bytes18] = ACTIONS(705),
    [anon_sym_bytes19] = ACTIONS(705),
    [anon_sym_bytes20] = ACTIONS(705),
    [anon_sym_bytes21] = ACTIONS(705),
    [anon_sym_bytes22] = ACTIONS(705),
    [anon_sym_bytes23] = ACTIONS(705),
    [anon_sym_bytes24] = ACTIONS(705),
    [anon_sym_bytes25] = ACTIONS(705),
    [anon_sym_bytes26] = ACTIONS(705),
    [anon_sym_bytes27] = ACTIONS(705),
    [anon_sym_bytes28] = ACTIONS(705),
    [anon_sym_bytes29] = ACTIONS(705),
    [anon_sym_bytes30] = ACTIONS(705),
    [anon_sym_bytes31] = ACTIONS(705),
    [anon_sym_bytes32] = ACTIONS(705),
    [anon_sym_fixed] = ACTIONS(705),
    [aux_sym__fixed_token1] = ACTIONS(705),
    [anon_sym_ufixed] = ACTIONS(705),
    [aux_sym__ufixed_token1] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
  },
  [177] = {
    [ts_builtin_sym_end] = ACTIONS(707),
    [sym_identifier] = ACTIONS(709),
    [anon_sym_pragma] = ACTIONS(709),
    [anon_sym_import] = ACTIONS(709),
    [anon_sym_type] = ACTIONS(709),
    [anon_sym_abstract] = ACTIONS(709),
    [anon_sym_contract] = ACTIONS(709),
    [anon_sym_error] = ACTIONS(709),
    [anon_sym_interface] = ACTIONS(709),
    [anon_sym_library] = ACTIONS(709),
    [anon_sym_struct] = ACTIONS(709),
    [anon_sym_enum] = ACTIONS(709),
    [anon_sym_using] = ACTIONS(709),
    [anon_sym_function] = ACTIONS(709),
    [anon_sym_byte] = ACTIONS(709),
    [anon_sym_address] = ACTIONS(709),
    [anon_sym_var] = ACTIONS(709),
    [anon_sym_mapping] = ACTIONS(709),
    [anon_sym_bool] = ACTIONS(709),
    [anon_sym_string] = ACTIONS(709),
    [anon_sym_int] = ACTIONS(709),
    [anon_sym_int8] = ACTIONS(709),
    [anon_sym_int16] = ACTIONS(709),
    [anon_sym_int24] = ACTIONS(709),
    [anon_sym_int32] = ACTIONS(709),
    [anon_sym_int40] = ACTIONS(709),
    [anon_sym_int48] = ACTIONS(709),
    [anon_sym_int56] = ACTIONS(709),
    [anon_sym_int64] = ACTIONS(709),
    [anon_sym_int72] = ACTIONS(709),
    [anon_sym_int80] = ACTIONS(709),
    [anon_sym_int88] = ACTIONS(709),
    [anon_sym_int96] = ACTIONS(709),
    [anon_sym_int104] = ACTIONS(709),
    [anon_sym_int112] = ACTIONS(709),
    [anon_sym_int120] = ACTIONS(709),
    [anon_sym_int128] = ACTIONS(709),
    [anon_sym_int136] = ACTIONS(709),
    [anon_sym_int144] = ACTIONS(709),
    [anon_sym_int152] = ACTIONS(709),
    [anon_sym_int160] = ACTIONS(709),
    [anon_sym_int168] = ACTIONS(709),
    [anon_sym_int176] = ACTIONS(709),
    [anon_sym_int184] = ACTIONS(709),
    [anon_sym_int192] = ACTIONS(709),
    [anon_sym_int200] = ACTIONS(709),
    [anon_sym_int208] = ACTIONS(709),
    [anon_sym_int216] = ACTIONS(709),
    [anon_sym_int224] = ACTIONS(709),
    [anon_sym_int232] = ACTIONS(709),
    [anon_sym_int240] = ACTIONS(709),
    [anon_sym_int248] = ACTIONS(709),
    [anon_sym_int256] = ACTIONS(709),
    [anon_sym_uint] = ACTIONS(709),
    [anon_sym_uint8] = ACTIONS(709),
    [anon_sym_uint16] = ACTIONS(709),
    [anon_sym_uint24] = ACTIONS(709),
    [anon_sym_uint32] = ACTIONS(709),
    [anon_sym_uint40] = ACTIONS(709),
    [anon_sym_uint48] = ACTIONS(709),
    [anon_sym_uint56] = ACTIONS(709),
    [anon_sym_uint64] = ACTIONS(709),
    [anon_sym_uint72] = ACTIONS(709),
    [anon_sym_uint80] = ACTIONS(709),
    [anon_sym_uint88] = ACTIONS(709),
    [anon_sym_uint96] = ACTIONS(709),
    [anon_sym_uint104] = ACTIONS(709),
    [anon_sym_uint112] = ACTIONS(709),
    [anon_sym_uint120] = ACTIONS(709),
    [anon_sym_uint128] = ACTIONS(709),
    [anon_sym_uint136] = ACTIONS(709),
    [anon_sym_uint144] = ACTIONS(709),
    [anon_sym_uint152] = ACTIONS(709),
    [anon_sym_uint160] = ACTIONS(709),
    [anon_sym_uint168] = ACTIONS(709),
    [anon_sym_uint176] = ACTIONS(709),
    [anon_sym_uint184] = ACTIONS(709),
    [anon_sym_uint192] = ACTIONS(709),
    [anon_sym_uint200] = ACTIONS(709),
    [anon_sym_uint208] = ACTIONS(709),
    [anon_sym_uint216] = ACTIONS(709),
    [anon_sym_uint224] = ACTIONS(709),
    [anon_sym_uint232] = ACTIONS(709),
    [anon_sym_uint240] = ACTIONS(709),
    [anon_sym_uint248] = ACTIONS(709),
    [anon_sym_uint256] = ACTIONS(709),
    [anon_sym_bytes] = ACTIONS(709),
    [anon_sym_bytes1] = ACTIONS(709),
    [anon_sym_bytes2] = ACTIONS(709),
    [anon_sym_bytes3] = ACTIONS(709),
    [anon_sym_bytes4] = ACTIONS(709),
    [anon_sym_bytes5] = ACTIONS(709),
    [anon_sym_bytes6] = ACTIONS(709),
    [anon_sym_bytes7] = ACTIONS(709),
    [anon_sym_bytes8] = ACTIONS(709),
    [anon_sym_bytes9] = ACTIONS(709),
    [anon_sym_bytes10] = ACTIONS(709),
    [anon_sym_bytes11] = ACTIONS(709),
    [anon_sym_bytes12] = ACTIONS(709),
    [anon_sym_bytes13] = ACTIONS(709),
    [anon_sym_bytes14] = ACTIONS(709),
    [anon_sym_bytes15] = ACTIONS(709),
    [anon_sym_bytes16] = ACTIONS(709),
    [anon_sym_bytes17] = ACTIONS(709),
    [anon_sym_bytes18] = ACTIONS(709),
    [anon_sym_bytes19] = ACTIONS(709),
    [anon_sym_bytes20] = ACTIONS(709),
    [anon_sym_bytes21] = ACTIONS(709),
    [anon_sym_bytes22] = ACTIONS(709),
    [anon_sym_bytes23] = ACTIONS(709),
    [anon_sym_bytes24] = ACTIONS(709),
    [anon_sym_bytes25] = ACTIONS(709),
    [anon_sym_bytes26] = ACTIONS(709),
    [anon_sym_bytes27] = ACTIONS(709),
    [anon_sym_bytes28] = ACTIONS(709),
    [anon_sym_bytes29] = ACTIONS(709),
    [anon_sym_bytes30] = ACTIONS(709),
    [anon_sym_bytes31] = ACTIONS(709),
    [anon_sym_bytes32] = ACTIONS(709),
    [anon_sym_fixed] = ACTIONS(709),
    [aux_sym__fixed_token1] = ACTIONS(709),
    [anon_sym_ufixed] = ACTIONS(709),
    [aux_sym__ufixed_token1] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
  },
  [178] = {
    [sym_type_name] = STATE(662),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [179] = {
    [ts_builtin_sym_end] = ACTIONS(711),
    [sym_identifier] = ACTIONS(713),
    [anon_sym_pragma] = ACTIONS(713),
    [anon_sym_import] = ACTIONS(713),
    [anon_sym_type] = ACTIONS(713),
    [anon_sym_abstract] = ACTIONS(713),
    [anon_sym_contract] = ACTIONS(713),
    [anon_sym_error] = ACTIONS(713),
    [anon_sym_interface] = ACTIONS(713),
    [anon_sym_library] = ACTIONS(713),
    [anon_sym_struct] = ACTIONS(713),
    [anon_sym_enum] = ACTIONS(713),
    [anon_sym_using] = ACTIONS(713),
    [anon_sym_function] = ACTIONS(713),
    [anon_sym_byte] = ACTIONS(713),
    [anon_sym_address] = ACTIONS(713),
    [anon_sym_var] = ACTIONS(713),
    [anon_sym_mapping] = ACTIONS(713),
    [anon_sym_bool] = ACTIONS(713),
    [anon_sym_string] = ACTIONS(713),
    [anon_sym_int] = ACTIONS(713),
    [anon_sym_int8] = ACTIONS(713),
    [anon_sym_int16] = ACTIONS(713),
    [anon_sym_int24] = ACTIONS(713),
    [anon_sym_int32] = ACTIONS(713),
    [anon_sym_int40] = ACTIONS(713),
    [anon_sym_int48] = ACTIONS(713),
    [anon_sym_int56] = ACTIONS(713),
    [anon_sym_int64] = ACTIONS(713),
    [anon_sym_int72] = ACTIONS(713),
    [anon_sym_int80] = ACTIONS(713),
    [anon_sym_int88] = ACTIONS(713),
    [anon_sym_int96] = ACTIONS(713),
    [anon_sym_int104] = ACTIONS(713),
    [anon_sym_int112] = ACTIONS(713),
    [anon_sym_int120] = ACTIONS(713),
    [anon_sym_int128] = ACTIONS(713),
    [anon_sym_int136] = ACTIONS(713),
    [anon_sym_int144] = ACTIONS(713),
    [anon_sym_int152] = ACTIONS(713),
    [anon_sym_int160] = ACTIONS(713),
    [anon_sym_int168] = ACTIONS(713),
    [anon_sym_int176] = ACTIONS(713),
    [anon_sym_int184] = ACTIONS(713),
    [anon_sym_int192] = ACTIONS(713),
    [anon_sym_int200] = ACTIONS(713),
    [anon_sym_int208] = ACTIONS(713),
    [anon_sym_int216] = ACTIONS(713),
    [anon_sym_int224] = ACTIONS(713),
    [anon_sym_int232] = ACTIONS(713),
    [anon_sym_int240] = ACTIONS(713),
    [anon_sym_int248] = ACTIONS(713),
    [anon_sym_int256] = ACTIONS(713),
    [anon_sym_uint] = ACTIONS(713),
    [anon_sym_uint8] = ACTIONS(713),
    [anon_sym_uint16] = ACTIONS(713),
    [anon_sym_uint24] = ACTIONS(713),
    [anon_sym_uint32] = ACTIONS(713),
    [anon_sym_uint40] = ACTIONS(713),
    [anon_sym_uint48] = ACTIONS(713),
    [anon_sym_uint56] = ACTIONS(713),
    [anon_sym_uint64] = ACTIONS(713),
    [anon_sym_uint72] = ACTIONS(713),
    [anon_sym_uint80] = ACTIONS(713),
    [anon_sym_uint88] = ACTIONS(713),
    [anon_sym_uint96] = ACTIONS(713),
    [anon_sym_uint104] = ACTIONS(713),
    [anon_sym_uint112] = ACTIONS(713),
    [anon_sym_uint120] = ACTIONS(713),
    [anon_sym_uint128] = ACTIONS(713),
    [anon_sym_uint136] = ACTIONS(713),
    [anon_sym_uint144] = ACTIONS(713),
    [anon_sym_uint152] = ACTIONS(713),
    [anon_sym_uint160] = ACTIONS(713),
    [anon_sym_uint168] = ACTIONS(713),
    [anon_sym_uint176] = ACTIONS(713),
    [anon_sym_uint184] = ACTIONS(713),
    [anon_sym_uint192] = ACTIONS(713),
    [anon_sym_uint200] = ACTIONS(713),
    [anon_sym_uint208] = ACTIONS(713),
    [anon_sym_uint216] = ACTIONS(713),
    [anon_sym_uint224] = ACTIONS(713),
    [anon_sym_uint232] = ACTIONS(713),
    [anon_sym_uint240] = ACTIONS(713),
    [anon_sym_uint248] = ACTIONS(713),
    [anon_sym_uint256] = ACTIONS(713),
    [anon_sym_bytes] = ACTIONS(713),
    [anon_sym_bytes1] = ACTIONS(713),
    [anon_sym_bytes2] = ACTIONS(713),
    [anon_sym_bytes3] = ACTIONS(713),
    [anon_sym_bytes4] = ACTIONS(713),
    [anon_sym_bytes5] = ACTIONS(713),
    [anon_sym_bytes6] = ACTIONS(713),
    [anon_sym_bytes7] = ACTIONS(713),
    [anon_sym_bytes8] = ACTIONS(713),
    [anon_sym_bytes9] = ACTIONS(713),
    [anon_sym_bytes10] = ACTIONS(713),
    [anon_sym_bytes11] = ACTIONS(713),
    [anon_sym_bytes12] = ACTIONS(713),
    [anon_sym_bytes13] = ACTIONS(713),
    [anon_sym_bytes14] = ACTIONS(713),
    [anon_sym_bytes15] = ACTIONS(713),
    [anon_sym_bytes16] = ACTIONS(713),
    [anon_sym_bytes17] = ACTIONS(713),
    [anon_sym_bytes18] = ACTIONS(713),
    [anon_sym_bytes19] = ACTIONS(713),
    [anon_sym_bytes20] = ACTIONS(713),
    [anon_sym_bytes21] = ACTIONS(713),
    [anon_sym_bytes22] = ACTIONS(713),
    [anon_sym_bytes23] = ACTIONS(713),
    [anon_sym_bytes24] = ACTIONS(713),
    [anon_sym_bytes25] = ACTIONS(713),
    [anon_sym_bytes26] = ACTIONS(713),
    [anon_sym_bytes27] = ACTIONS(713),
    [anon_sym_bytes28] = ACTIONS(713),
    [anon_sym_bytes29] = ACTIONS(713),
    [anon_sym_bytes30] = ACTIONS(713),
    [anon_sym_bytes31] = ACTIONS(713),
    [anon_sym_bytes32] = ACTIONS(713),
    [anon_sym_fixed] = ACTIONS(713),
    [aux_sym__fixed_token1] = ACTIONS(713),
    [anon_sym_ufixed] = ACTIONS(713),
    [aux_sym__ufixed_token1] = ACTIONS(713),
    [sym_comment] = ACTIONS(3),
  },
  [180] = {
    [ts_builtin_sym_end] = ACTIONS(715),
    [sym_identifier] = ACTIONS(717),
    [anon_sym_pragma] = ACTIONS(717),
    [anon_sym_import] = ACTIONS(717),
    [anon_sym_type] = ACTIONS(717),
    [anon_sym_abstract] = ACTIONS(717),
    [anon_sym_contract] = ACTIONS(717),
    [anon_sym_error] = ACTIONS(717),
    [anon_sym_interface] = ACTIONS(717),
    [anon_sym_library] = ACTIONS(717),
    [anon_sym_struct] = ACTIONS(717),
    [anon_sym_enum] = ACTIONS(717),
    [anon_sym_using] = ACTIONS(717),
    [anon_sym_function] = ACTIONS(717),
    [anon_sym_byte] = ACTIONS(717),
    [anon_sym_address] = ACTIONS(717),
    [anon_sym_var] = ACTIONS(717),
    [anon_sym_mapping] = ACTIONS(717),
    [anon_sym_bool] = ACTIONS(717),
    [anon_sym_string] = ACTIONS(717),
    [anon_sym_int] = ACTIONS(717),
    [anon_sym_int8] = ACTIONS(717),
    [anon_sym_int16] = ACTIONS(717),
    [anon_sym_int24] = ACTIONS(717),
    [anon_sym_int32] = ACTIONS(717),
    [anon_sym_int40] = ACTIONS(717),
    [anon_sym_int48] = ACTIONS(717),
    [anon_sym_int56] = ACTIONS(717),
    [anon_sym_int64] = ACTIONS(717),
    [anon_sym_int72] = ACTIONS(717),
    [anon_sym_int80] = ACTIONS(717),
    [anon_sym_int88] = ACTIONS(717),
    [anon_sym_int96] = ACTIONS(717),
    [anon_sym_int104] = ACTIONS(717),
    [anon_sym_int112] = ACTIONS(717),
    [anon_sym_int120] = ACTIONS(717),
    [anon_sym_int128] = ACTIONS(717),
    [anon_sym_int136] = ACTIONS(717),
    [anon_sym_int144] = ACTIONS(717),
    [anon_sym_int152] = ACTIONS(717),
    [anon_sym_int160] = ACTIONS(717),
    [anon_sym_int168] = ACTIONS(717),
    [anon_sym_int176] = ACTIONS(717),
    [anon_sym_int184] = ACTIONS(717),
    [anon_sym_int192] = ACTIONS(717),
    [anon_sym_int200] = ACTIONS(717),
    [anon_sym_int208] = ACTIONS(717),
    [anon_sym_int216] = ACTIONS(717),
    [anon_sym_int224] = ACTIONS(717),
    [anon_sym_int232] = ACTIONS(717),
    [anon_sym_int240] = ACTIONS(717),
    [anon_sym_int248] = ACTIONS(717),
    [anon_sym_int256] = ACTIONS(717),
    [anon_sym_uint] = ACTIONS(717),
    [anon_sym_uint8] = ACTIONS(717),
    [anon_sym_uint16] = ACTIONS(717),
    [anon_sym_uint24] = ACTIONS(717),
    [anon_sym_uint32] = ACTIONS(717),
    [anon_sym_uint40] = ACTIONS(717),
    [anon_sym_uint48] = ACTIONS(717),
    [anon_sym_uint56] = ACTIONS(717),
    [anon_sym_uint64] = ACTIONS(717),
    [anon_sym_uint72] = ACTIONS(717),
    [anon_sym_uint80] = ACTIONS(717),
    [anon_sym_uint88] = ACTIONS(717),
    [anon_sym_uint96] = ACTIONS(717),
    [anon_sym_uint104] = ACTIONS(717),
    [anon_sym_uint112] = ACTIONS(717),
    [anon_sym_uint120] = ACTIONS(717),
    [anon_sym_uint128] = ACTIONS(717),
    [anon_sym_uint136] = ACTIONS(717),
    [anon_sym_uint144] = ACTIONS(717),
    [anon_sym_uint152] = ACTIONS(717),
    [anon_sym_uint160] = ACTIONS(717),
    [anon_sym_uint168] = ACTIONS(717),
    [anon_sym_uint176] = ACTIONS(717),
    [anon_sym_uint184] = ACTIONS(717),
    [anon_sym_uint192] = ACTIONS(717),
    [anon_sym_uint200] = ACTIONS(717),
    [anon_sym_uint208] = ACTIONS(717),
    [anon_sym_uint216] = ACTIONS(717),
    [anon_sym_uint224] = ACTIONS(717),
    [anon_sym_uint232] = ACTIONS(717),
    [anon_sym_uint240] = ACTIONS(717),
    [anon_sym_uint248] = ACTIONS(717),
    [anon_sym_uint256] = ACTIONS(717),
    [anon_sym_bytes] = ACTIONS(717),
    [anon_sym_bytes1] = ACTIONS(717),
    [anon_sym_bytes2] = ACTIONS(717),
    [anon_sym_bytes3] = ACTIONS(717),
    [anon_sym_bytes4] = ACTIONS(717),
    [anon_sym_bytes5] = ACTIONS(717),
    [anon_sym_bytes6] = ACTIONS(717),
    [anon_sym_bytes7] = ACTIONS(717),
    [anon_sym_bytes8] = ACTIONS(717),
    [anon_sym_bytes9] = ACTIONS(717),
    [anon_sym_bytes10] = ACTIONS(717),
    [anon_sym_bytes11] = ACTIONS(717),
    [anon_sym_bytes12] = ACTIONS(717),
    [anon_sym_bytes13] = ACTIONS(717),
    [anon_sym_bytes14] = ACTIONS(717),
    [anon_sym_bytes15] = ACTIONS(717),
    [anon_sym_bytes16] = ACTIONS(717),
    [anon_sym_bytes17] = ACTIONS(717),
    [anon_sym_bytes18] = ACTIONS(717),
    [anon_sym_bytes19] = ACTIONS(717),
    [anon_sym_bytes20] = ACTIONS(717),
    [anon_sym_bytes21] = ACTIONS(717),
    [anon_sym_bytes22] = ACTIONS(717),
    [anon_sym_bytes23] = ACTIONS(717),
    [anon_sym_bytes24] = ACTIONS(717),
    [anon_sym_bytes25] = ACTIONS(717),
    [anon_sym_bytes26] = ACTIONS(717),
    [anon_sym_bytes27] = ACTIONS(717),
    [anon_sym_bytes28] = ACTIONS(717),
    [anon_sym_bytes29] = ACTIONS(717),
    [anon_sym_bytes30] = ACTIONS(717),
    [anon_sym_bytes31] = ACTIONS(717),
    [anon_sym_bytes32] = ACTIONS(717),
    [anon_sym_fixed] = ACTIONS(717),
    [aux_sym__fixed_token1] = ACTIONS(717),
    [anon_sym_ufixed] = ACTIONS(717),
    [aux_sym__ufixed_token1] = ACTIONS(717),
    [sym_comment] = ACTIONS(3),
  },
  [181] = {
    [ts_builtin_sym_end] = ACTIONS(719),
    [sym_identifier] = ACTIONS(721),
    [anon_sym_pragma] = ACTIONS(721),
    [anon_sym_import] = ACTIONS(721),
    [anon_sym_type] = ACTIONS(721),
    [anon_sym_abstract] = ACTIONS(721),
    [anon_sym_contract] = ACTIONS(721),
    [anon_sym_error] = ACTIONS(721),
    [anon_sym_interface] = ACTIONS(721),
    [anon_sym_library] = ACTIONS(721),
    [anon_sym_struct] = ACTIONS(721),
    [anon_sym_enum] = ACTIONS(721),
    [anon_sym_using] = ACTIONS(721),
    [anon_sym_function] = ACTIONS(721),
    [anon_sym_byte] = ACTIONS(721),
    [anon_sym_address] = ACTIONS(721),
    [anon_sym_var] = ACTIONS(721),
    [anon_sym_mapping] = ACTIONS(721),
    [anon_sym_bool] = ACTIONS(721),
    [anon_sym_string] = ACTIONS(721),
    [anon_sym_int] = ACTIONS(721),
    [anon_sym_int8] = ACTIONS(721),
    [anon_sym_int16] = ACTIONS(721),
    [anon_sym_int24] = ACTIONS(721),
    [anon_sym_int32] = ACTIONS(721),
    [anon_sym_int40] = ACTIONS(721),
    [anon_sym_int48] = ACTIONS(721),
    [anon_sym_int56] = ACTIONS(721),
    [anon_sym_int64] = ACTIONS(721),
    [anon_sym_int72] = ACTIONS(721),
    [anon_sym_int80] = ACTIONS(721),
    [anon_sym_int88] = ACTIONS(721),
    [anon_sym_int96] = ACTIONS(721),
    [anon_sym_int104] = ACTIONS(721),
    [anon_sym_int112] = ACTIONS(721),
    [anon_sym_int120] = ACTIONS(721),
    [anon_sym_int128] = ACTIONS(721),
    [anon_sym_int136] = ACTIONS(721),
    [anon_sym_int144] = ACTIONS(721),
    [anon_sym_int152] = ACTIONS(721),
    [anon_sym_int160] = ACTIONS(721),
    [anon_sym_int168] = ACTIONS(721),
    [anon_sym_int176] = ACTIONS(721),
    [anon_sym_int184] = ACTIONS(721),
    [anon_sym_int192] = ACTIONS(721),
    [anon_sym_int200] = ACTIONS(721),
    [anon_sym_int208] = ACTIONS(721),
    [anon_sym_int216] = ACTIONS(721),
    [anon_sym_int224] = ACTIONS(721),
    [anon_sym_int232] = ACTIONS(721),
    [anon_sym_int240] = ACTIONS(721),
    [anon_sym_int248] = ACTIONS(721),
    [anon_sym_int256] = ACTIONS(721),
    [anon_sym_uint] = ACTIONS(721),
    [anon_sym_uint8] = ACTIONS(721),
    [anon_sym_uint16] = ACTIONS(721),
    [anon_sym_uint24] = ACTIONS(721),
    [anon_sym_uint32] = ACTIONS(721),
    [anon_sym_uint40] = ACTIONS(721),
    [anon_sym_uint48] = ACTIONS(721),
    [anon_sym_uint56] = ACTIONS(721),
    [anon_sym_uint64] = ACTIONS(721),
    [anon_sym_uint72] = ACTIONS(721),
    [anon_sym_uint80] = ACTIONS(721),
    [anon_sym_uint88] = ACTIONS(721),
    [anon_sym_uint96] = ACTIONS(721),
    [anon_sym_uint104] = ACTIONS(721),
    [anon_sym_uint112] = ACTIONS(721),
    [anon_sym_uint120] = ACTIONS(721),
    [anon_sym_uint128] = ACTIONS(721),
    [anon_sym_uint136] = ACTIONS(721),
    [anon_sym_uint144] = ACTIONS(721),
    [anon_sym_uint152] = ACTIONS(721),
    [anon_sym_uint160] = ACTIONS(721),
    [anon_sym_uint168] = ACTIONS(721),
    [anon_sym_uint176] = ACTIONS(721),
    [anon_sym_uint184] = ACTIONS(721),
    [anon_sym_uint192] = ACTIONS(721),
    [anon_sym_uint200] = ACTIONS(721),
    [anon_sym_uint208] = ACTIONS(721),
    [anon_sym_uint216] = ACTIONS(721),
    [anon_sym_uint224] = ACTIONS(721),
    [anon_sym_uint232] = ACTIONS(721),
    [anon_sym_uint240] = ACTIONS(721),
    [anon_sym_uint248] = ACTIONS(721),
    [anon_sym_uint256] = ACTIONS(721),
    [anon_sym_bytes] = ACTIONS(721),
    [anon_sym_bytes1] = ACTIONS(721),
    [anon_sym_bytes2] = ACTIONS(721),
    [anon_sym_bytes3] = ACTIONS(721),
    [anon_sym_bytes4] = ACTIONS(721),
    [anon_sym_bytes5] = ACTIONS(721),
    [anon_sym_bytes6] = ACTIONS(721),
    [anon_sym_bytes7] = ACTIONS(721),
    [anon_sym_bytes8] = ACTIONS(721),
    [anon_sym_bytes9] = ACTIONS(721),
    [anon_sym_bytes10] = ACTIONS(721),
    [anon_sym_bytes11] = ACTIONS(721),
    [anon_sym_bytes12] = ACTIONS(721),
    [anon_sym_bytes13] = ACTIONS(721),
    [anon_sym_bytes14] = ACTIONS(721),
    [anon_sym_bytes15] = ACTIONS(721),
    [anon_sym_bytes16] = ACTIONS(721),
    [anon_sym_bytes17] = ACTIONS(721),
    [anon_sym_bytes18] = ACTIONS(721),
    [anon_sym_bytes19] = ACTIONS(721),
    [anon_sym_bytes20] = ACTIONS(721),
    [anon_sym_bytes21] = ACTIONS(721),
    [anon_sym_bytes22] = ACTIONS(721),
    [anon_sym_bytes23] = ACTIONS(721),
    [anon_sym_bytes24] = ACTIONS(721),
    [anon_sym_bytes25] = ACTIONS(721),
    [anon_sym_bytes26] = ACTIONS(721),
    [anon_sym_bytes27] = ACTIONS(721),
    [anon_sym_bytes28] = ACTIONS(721),
    [anon_sym_bytes29] = ACTIONS(721),
    [anon_sym_bytes30] = ACTIONS(721),
    [anon_sym_bytes31] = ACTIONS(721),
    [anon_sym_bytes32] = ACTIONS(721),
    [anon_sym_fixed] = ACTIONS(721),
    [aux_sym__fixed_token1] = ACTIONS(721),
    [anon_sym_ufixed] = ACTIONS(721),
    [aux_sym__ufixed_token1] = ACTIONS(721),
    [sym_comment] = ACTIONS(3),
  },
  [182] = {
    [ts_builtin_sym_end] = ACTIONS(723),
    [sym_identifier] = ACTIONS(725),
    [anon_sym_pragma] = ACTIONS(725),
    [anon_sym_import] = ACTIONS(725),
    [anon_sym_type] = ACTIONS(725),
    [anon_sym_abstract] = ACTIONS(725),
    [anon_sym_contract] = ACTIONS(725),
    [anon_sym_error] = ACTIONS(725),
    [anon_sym_interface] = ACTIONS(725),
    [anon_sym_library] = ACTIONS(725),
    [anon_sym_struct] = ACTIONS(725),
    [anon_sym_enum] = ACTIONS(725),
    [anon_sym_using] = ACTIONS(725),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_byte] = ACTIONS(725),
    [anon_sym_address] = ACTIONS(725),
    [anon_sym_var] = ACTIONS(725),
    [anon_sym_mapping] = ACTIONS(725),
    [anon_sym_bool] = ACTIONS(725),
    [anon_sym_string] = ACTIONS(725),
    [anon_sym_int] = ACTIONS(725),
    [anon_sym_int8] = ACTIONS(725),
    [anon_sym_int16] = ACTIONS(725),
    [anon_sym_int24] = ACTIONS(725),
    [anon_sym_int32] = ACTIONS(725),
    [anon_sym_int40] = ACTIONS(725),
    [anon_sym_int48] = ACTIONS(725),
    [anon_sym_int56] = ACTIONS(725),
    [anon_sym_int64] = ACTIONS(725),
    [anon_sym_int72] = ACTIONS(725),
    [anon_sym_int80] = ACTIONS(725),
    [anon_sym_int88] = ACTIONS(725),
    [anon_sym_int96] = ACTIONS(725),
    [anon_sym_int104] = ACTIONS(725),
    [anon_sym_int112] = ACTIONS(725),
    [anon_sym_int120] = ACTIONS(725),
    [anon_sym_int128] = ACTIONS(725),
    [anon_sym_int136] = ACTIONS(725),
    [anon_sym_int144] = ACTIONS(725),
    [anon_sym_int152] = ACTIONS(725),
    [anon_sym_int160] = ACTIONS(725),
    [anon_sym_int168] = ACTIONS(725),
    [anon_sym_int176] = ACTIONS(725),
    [anon_sym_int184] = ACTIONS(725),
    [anon_sym_int192] = ACTIONS(725),
    [anon_sym_int200] = ACTIONS(725),
    [anon_sym_int208] = ACTIONS(725),
    [anon_sym_int216] = ACTIONS(725),
    [anon_sym_int224] = ACTIONS(725),
    [anon_sym_int232] = ACTIONS(725),
    [anon_sym_int240] = ACTIONS(725),
    [anon_sym_int248] = ACTIONS(725),
    [anon_sym_int256] = ACTIONS(725),
    [anon_sym_uint] = ACTIONS(725),
    [anon_sym_uint8] = ACTIONS(725),
    [anon_sym_uint16] = ACTIONS(725),
    [anon_sym_uint24] = ACTIONS(725),
    [anon_sym_uint32] = ACTIONS(725),
    [anon_sym_uint40] = ACTIONS(725),
    [anon_sym_uint48] = ACTIONS(725),
    [anon_sym_uint56] = ACTIONS(725),
    [anon_sym_uint64] = ACTIONS(725),
    [anon_sym_uint72] = ACTIONS(725),
    [anon_sym_uint80] = ACTIONS(725),
    [anon_sym_uint88] = ACTIONS(725),
    [anon_sym_uint96] = ACTIONS(725),
    [anon_sym_uint104] = ACTIONS(725),
    [anon_sym_uint112] = ACTIONS(725),
    [anon_sym_uint120] = ACTIONS(725),
    [anon_sym_uint128] = ACTIONS(725),
    [anon_sym_uint136] = ACTIONS(725),
    [anon_sym_uint144] = ACTIONS(725),
    [anon_sym_uint152] = ACTIONS(725),
    [anon_sym_uint160] = ACTIONS(725),
    [anon_sym_uint168] = ACTIONS(725),
    [anon_sym_uint176] = ACTIONS(725),
    [anon_sym_uint184] = ACTIONS(725),
    [anon_sym_uint192] = ACTIONS(725),
    [anon_sym_uint200] = ACTIONS(725),
    [anon_sym_uint208] = ACTIONS(725),
    [anon_sym_uint216] = ACTIONS(725),
    [anon_sym_uint224] = ACTIONS(725),
    [anon_sym_uint232] = ACTIONS(725),
    [anon_sym_uint240] = ACTIONS(725),
    [anon_sym_uint248] = ACTIONS(725),
    [anon_sym_uint256] = ACTIONS(725),
    [anon_sym_bytes] = ACTIONS(725),
    [anon_sym_bytes1] = ACTIONS(725),
    [anon_sym_bytes2] = ACTIONS(725),
    [anon_sym_bytes3] = ACTIONS(725),
    [anon_sym_bytes4] = ACTIONS(725),
    [anon_sym_bytes5] = ACTIONS(725),
    [anon_sym_bytes6] = ACTIONS(725),
    [anon_sym_bytes7] = ACTIONS(725),
    [anon_sym_bytes8] = ACTIONS(725),
    [anon_sym_bytes9] = ACTIONS(725),
    [anon_sym_bytes10] = ACTIONS(725),
    [anon_sym_bytes11] = ACTIONS(725),
    [anon_sym_bytes12] = ACTIONS(725),
    [anon_sym_bytes13] = ACTIONS(725),
    [anon_sym_bytes14] = ACTIONS(725),
    [anon_sym_bytes15] = ACTIONS(725),
    [anon_sym_bytes16] = ACTIONS(725),
    [anon_sym_bytes17] = ACTIONS(725),
    [anon_sym_bytes18] = ACTIONS(725),
    [anon_sym_bytes19] = ACTIONS(725),
    [anon_sym_bytes20] = ACTIONS(725),
    [anon_sym_bytes21] = ACTIONS(725),
    [anon_sym_bytes22] = ACTIONS(725),
    [anon_sym_bytes23] = ACTIONS(725),
    [anon_sym_bytes24] = ACTIONS(725),
    [anon_sym_bytes25] = ACTIONS(725),
    [anon_sym_bytes26] = ACTIONS(725),
    [anon_sym_bytes27] = ACTIONS(725),
    [anon_sym_bytes28] = ACTIONS(725),
    [anon_sym_bytes29] = ACTIONS(725),
    [anon_sym_bytes30] = ACTIONS(725),
    [anon_sym_bytes31] = ACTIONS(725),
    [anon_sym_bytes32] = ACTIONS(725),
    [anon_sym_fixed] = ACTIONS(725),
    [aux_sym__fixed_token1] = ACTIONS(725),
    [anon_sym_ufixed] = ACTIONS(725),
    [aux_sym__ufixed_token1] = ACTIONS(725),
    [sym_comment] = ACTIONS(3),
  },
  [183] = {
    [ts_builtin_sym_end] = ACTIONS(727),
    [sym_identifier] = ACTIONS(729),
    [anon_sym_pragma] = ACTIONS(729),
    [anon_sym_import] = ACTIONS(729),
    [anon_sym_type] = ACTIONS(729),
    [anon_sym_abstract] = ACTIONS(729),
    [anon_sym_contract] = ACTIONS(729),
    [anon_sym_error] = ACTIONS(729),
    [anon_sym_interface] = ACTIONS(729),
    [anon_sym_library] = ACTIONS(729),
    [anon_sym_struct] = ACTIONS(729),
    [anon_sym_enum] = ACTIONS(729),
    [anon_sym_using] = ACTIONS(729),
    [anon_sym_function] = ACTIONS(729),
    [anon_sym_byte] = ACTIONS(729),
    [anon_sym_address] = ACTIONS(729),
    [anon_sym_var] = ACTIONS(729),
    [anon_sym_mapping] = ACTIONS(729),
    [anon_sym_bool] = ACTIONS(729),
    [anon_sym_string] = ACTIONS(729),
    [anon_sym_int] = ACTIONS(729),
    [anon_sym_int8] = ACTIONS(729),
    [anon_sym_int16] = ACTIONS(729),
    [anon_sym_int24] = ACTIONS(729),
    [anon_sym_int32] = ACTIONS(729),
    [anon_sym_int40] = ACTIONS(729),
    [anon_sym_int48] = ACTIONS(729),
    [anon_sym_int56] = ACTIONS(729),
    [anon_sym_int64] = ACTIONS(729),
    [anon_sym_int72] = ACTIONS(729),
    [anon_sym_int80] = ACTIONS(729),
    [anon_sym_int88] = ACTIONS(729),
    [anon_sym_int96] = ACTIONS(729),
    [anon_sym_int104] = ACTIONS(729),
    [anon_sym_int112] = ACTIONS(729),
    [anon_sym_int120] = ACTIONS(729),
    [anon_sym_int128] = ACTIONS(729),
    [anon_sym_int136] = ACTIONS(729),
    [anon_sym_int144] = ACTIONS(729),
    [anon_sym_int152] = ACTIONS(729),
    [anon_sym_int160] = ACTIONS(729),
    [anon_sym_int168] = ACTIONS(729),
    [anon_sym_int176] = ACTIONS(729),
    [anon_sym_int184] = ACTIONS(729),
    [anon_sym_int192] = ACTIONS(729),
    [anon_sym_int200] = ACTIONS(729),
    [anon_sym_int208] = ACTIONS(729),
    [anon_sym_int216] = ACTIONS(729),
    [anon_sym_int224] = ACTIONS(729),
    [anon_sym_int232] = ACTIONS(729),
    [anon_sym_int240] = ACTIONS(729),
    [anon_sym_int248] = ACTIONS(729),
    [anon_sym_int256] = ACTIONS(729),
    [anon_sym_uint] = ACTIONS(729),
    [anon_sym_uint8] = ACTIONS(729),
    [anon_sym_uint16] = ACTIONS(729),
    [anon_sym_uint24] = ACTIONS(729),
    [anon_sym_uint32] = ACTIONS(729),
    [anon_sym_uint40] = ACTIONS(729),
    [anon_sym_uint48] = ACTIONS(729),
    [anon_sym_uint56] = ACTIONS(729),
    [anon_sym_uint64] = ACTIONS(729),
    [anon_sym_uint72] = ACTIONS(729),
    [anon_sym_uint80] = ACTIONS(729),
    [anon_sym_uint88] = ACTIONS(729),
    [anon_sym_uint96] = ACTIONS(729),
    [anon_sym_uint104] = ACTIONS(729),
    [anon_sym_uint112] = ACTIONS(729),
    [anon_sym_uint120] = ACTIONS(729),
    [anon_sym_uint128] = ACTIONS(729),
    [anon_sym_uint136] = ACTIONS(729),
    [anon_sym_uint144] = ACTIONS(729),
    [anon_sym_uint152] = ACTIONS(729),
    [anon_sym_uint160] = ACTIONS(729),
    [anon_sym_uint168] = ACTIONS(729),
    [anon_sym_uint176] = ACTIONS(729),
    [anon_sym_uint184] = ACTIONS(729),
    [anon_sym_uint192] = ACTIONS(729),
    [anon_sym_uint200] = ACTIONS(729),
    [anon_sym_uint208] = ACTIONS(729),
    [anon_sym_uint216] = ACTIONS(729),
    [anon_sym_uint224] = ACTIONS(729),
    [anon_sym_uint232] = ACTIONS(729),
    [anon_sym_uint240] = ACTIONS(729),
    [anon_sym_uint248] = ACTIONS(729),
    [anon_sym_uint256] = ACTIONS(729),
    [anon_sym_bytes] = ACTIONS(729),
    [anon_sym_bytes1] = ACTIONS(729),
    [anon_sym_bytes2] = ACTIONS(729),
    [anon_sym_bytes3] = ACTIONS(729),
    [anon_sym_bytes4] = ACTIONS(729),
    [anon_sym_bytes5] = ACTIONS(729),
    [anon_sym_bytes6] = ACTIONS(729),
    [anon_sym_bytes7] = ACTIONS(729),
    [anon_sym_bytes8] = ACTIONS(729),
    [anon_sym_bytes9] = ACTIONS(729),
    [anon_sym_bytes10] = ACTIONS(729),
    [anon_sym_bytes11] = ACTIONS(729),
    [anon_sym_bytes12] = ACTIONS(729),
    [anon_sym_bytes13] = ACTIONS(729),
    [anon_sym_bytes14] = ACTIONS(729),
    [anon_sym_bytes15] = ACTIONS(729),
    [anon_sym_bytes16] = ACTIONS(729),
    [anon_sym_bytes17] = ACTIONS(729),
    [anon_sym_bytes18] = ACTIONS(729),
    [anon_sym_bytes19] = ACTIONS(729),
    [anon_sym_bytes20] = ACTIONS(729),
    [anon_sym_bytes21] = ACTIONS(729),
    [anon_sym_bytes22] = ACTIONS(729),
    [anon_sym_bytes23] = ACTIONS(729),
    [anon_sym_bytes24] = ACTIONS(729),
    [anon_sym_bytes25] = ACTIONS(729),
    [anon_sym_bytes26] = ACTIONS(729),
    [anon_sym_bytes27] = ACTIONS(729),
    [anon_sym_bytes28] = ACTIONS(729),
    [anon_sym_bytes29] = ACTIONS(729),
    [anon_sym_bytes30] = ACTIONS(729),
    [anon_sym_bytes31] = ACTIONS(729),
    [anon_sym_bytes32] = ACTIONS(729),
    [anon_sym_fixed] = ACTIONS(729),
    [aux_sym__fixed_token1] = ACTIONS(729),
    [anon_sym_ufixed] = ACTIONS(729),
    [aux_sym__ufixed_token1] = ACTIONS(729),
    [sym_comment] = ACTIONS(3),
  },
  [184] = {
    [ts_builtin_sym_end] = ACTIONS(731),
    [sym_identifier] = ACTIONS(733),
    [anon_sym_pragma] = ACTIONS(733),
    [anon_sym_import] = ACTIONS(733),
    [anon_sym_type] = ACTIONS(733),
    [anon_sym_abstract] = ACTIONS(733),
    [anon_sym_contract] = ACTIONS(733),
    [anon_sym_error] = ACTIONS(733),
    [anon_sym_interface] = ACTIONS(733),
    [anon_sym_library] = ACTIONS(733),
    [anon_sym_struct] = ACTIONS(733),
    [anon_sym_enum] = ACTIONS(733),
    [anon_sym_using] = ACTIONS(733),
    [anon_sym_function] = ACTIONS(733),
    [anon_sym_byte] = ACTIONS(733),
    [anon_sym_address] = ACTIONS(733),
    [anon_sym_var] = ACTIONS(733),
    [anon_sym_mapping] = ACTIONS(733),
    [anon_sym_bool] = ACTIONS(733),
    [anon_sym_string] = ACTIONS(733),
    [anon_sym_int] = ACTIONS(733),
    [anon_sym_int8] = ACTIONS(733),
    [anon_sym_int16] = ACTIONS(733),
    [anon_sym_int24] = ACTIONS(733),
    [anon_sym_int32] = ACTIONS(733),
    [anon_sym_int40] = ACTIONS(733),
    [anon_sym_int48] = ACTIONS(733),
    [anon_sym_int56] = ACTIONS(733),
    [anon_sym_int64] = ACTIONS(733),
    [anon_sym_int72] = ACTIONS(733),
    [anon_sym_int80] = ACTIONS(733),
    [anon_sym_int88] = ACTIONS(733),
    [anon_sym_int96] = ACTIONS(733),
    [anon_sym_int104] = ACTIONS(733),
    [anon_sym_int112] = ACTIONS(733),
    [anon_sym_int120] = ACTIONS(733),
    [anon_sym_int128] = ACTIONS(733),
    [anon_sym_int136] = ACTIONS(733),
    [anon_sym_int144] = ACTIONS(733),
    [anon_sym_int152] = ACTIONS(733),
    [anon_sym_int160] = ACTIONS(733),
    [anon_sym_int168] = ACTIONS(733),
    [anon_sym_int176] = ACTIONS(733),
    [anon_sym_int184] = ACTIONS(733),
    [anon_sym_int192] = ACTIONS(733),
    [anon_sym_int200] = ACTIONS(733),
    [anon_sym_int208] = ACTIONS(733),
    [anon_sym_int216] = ACTIONS(733),
    [anon_sym_int224] = ACTIONS(733),
    [anon_sym_int232] = ACTIONS(733),
    [anon_sym_int240] = ACTIONS(733),
    [anon_sym_int248] = ACTIONS(733),
    [anon_sym_int256] = ACTIONS(733),
    [anon_sym_uint] = ACTIONS(733),
    [anon_sym_uint8] = ACTIONS(733),
    [anon_sym_uint16] = ACTIONS(733),
    [anon_sym_uint24] = ACTIONS(733),
    [anon_sym_uint32] = ACTIONS(733),
    [anon_sym_uint40] = ACTIONS(733),
    [anon_sym_uint48] = ACTIONS(733),
    [anon_sym_uint56] = ACTIONS(733),
    [anon_sym_uint64] = ACTIONS(733),
    [anon_sym_uint72] = ACTIONS(733),
    [anon_sym_uint80] = ACTIONS(733),
    [anon_sym_uint88] = ACTIONS(733),
    [anon_sym_uint96] = ACTIONS(733),
    [anon_sym_uint104] = ACTIONS(733),
    [anon_sym_uint112] = ACTIONS(733),
    [anon_sym_uint120] = ACTIONS(733),
    [anon_sym_uint128] = ACTIONS(733),
    [anon_sym_uint136] = ACTIONS(733),
    [anon_sym_uint144] = ACTIONS(733),
    [anon_sym_uint152] = ACTIONS(733),
    [anon_sym_uint160] = ACTIONS(733),
    [anon_sym_uint168] = ACTIONS(733),
    [anon_sym_uint176] = ACTIONS(733),
    [anon_sym_uint184] = ACTIONS(733),
    [anon_sym_uint192] = ACTIONS(733),
    [anon_sym_uint200] = ACTIONS(733),
    [anon_sym_uint208] = ACTIONS(733),
    [anon_sym_uint216] = ACTIONS(733),
    [anon_sym_uint224] = ACTIONS(733),
    [anon_sym_uint232] = ACTIONS(733),
    [anon_sym_uint240] = ACTIONS(733),
    [anon_sym_uint248] = ACTIONS(733),
    [anon_sym_uint256] = ACTIONS(733),
    [anon_sym_bytes] = ACTIONS(733),
    [anon_sym_bytes1] = ACTIONS(733),
    [anon_sym_bytes2] = ACTIONS(733),
    [anon_sym_bytes3] = ACTIONS(733),
    [anon_sym_bytes4] = ACTIONS(733),
    [anon_sym_bytes5] = ACTIONS(733),
    [anon_sym_bytes6] = ACTIONS(733),
    [anon_sym_bytes7] = ACTIONS(733),
    [anon_sym_bytes8] = ACTIONS(733),
    [anon_sym_bytes9] = ACTIONS(733),
    [anon_sym_bytes10] = ACTIONS(733),
    [anon_sym_bytes11] = ACTIONS(733),
    [anon_sym_bytes12] = ACTIONS(733),
    [anon_sym_bytes13] = ACTIONS(733),
    [anon_sym_bytes14] = ACTIONS(733),
    [anon_sym_bytes15] = ACTIONS(733),
    [anon_sym_bytes16] = ACTIONS(733),
    [anon_sym_bytes17] = ACTIONS(733),
    [anon_sym_bytes18] = ACTIONS(733),
    [anon_sym_bytes19] = ACTIONS(733),
    [anon_sym_bytes20] = ACTIONS(733),
    [anon_sym_bytes21] = ACTIONS(733),
    [anon_sym_bytes22] = ACTIONS(733),
    [anon_sym_bytes23] = ACTIONS(733),
    [anon_sym_bytes24] = ACTIONS(733),
    [anon_sym_bytes25] = ACTIONS(733),
    [anon_sym_bytes26] = ACTIONS(733),
    [anon_sym_bytes27] = ACTIONS(733),
    [anon_sym_bytes28] = ACTIONS(733),
    [anon_sym_bytes29] = ACTIONS(733),
    [anon_sym_bytes30] = ACTIONS(733),
    [anon_sym_bytes31] = ACTIONS(733),
    [anon_sym_bytes32] = ACTIONS(733),
    [anon_sym_fixed] = ACTIONS(733),
    [aux_sym__fixed_token1] = ACTIONS(733),
    [anon_sym_ufixed] = ACTIONS(733),
    [aux_sym__ufixed_token1] = ACTIONS(733),
    [sym_comment] = ACTIONS(3),
  },
  [185] = {
    [ts_builtin_sym_end] = ACTIONS(735),
    [sym_identifier] = ACTIONS(737),
    [anon_sym_pragma] = ACTIONS(737),
    [anon_sym_import] = ACTIONS(737),
    [anon_sym_type] = ACTIONS(737),
    [anon_sym_abstract] = ACTIONS(737),
    [anon_sym_contract] = ACTIONS(737),
    [anon_sym_error] = ACTIONS(737),
    [anon_sym_interface] = ACTIONS(737),
    [anon_sym_library] = ACTIONS(737),
    [anon_sym_struct] = ACTIONS(737),
    [anon_sym_enum] = ACTIONS(737),
    [anon_sym_using] = ACTIONS(737),
    [anon_sym_function] = ACTIONS(737),
    [anon_sym_byte] = ACTIONS(737),
    [anon_sym_address] = ACTIONS(737),
    [anon_sym_var] = ACTIONS(737),
    [anon_sym_mapping] = ACTIONS(737),
    [anon_sym_bool] = ACTIONS(737),
    [anon_sym_string] = ACTIONS(737),
    [anon_sym_int] = ACTIONS(737),
    [anon_sym_int8] = ACTIONS(737),
    [anon_sym_int16] = ACTIONS(737),
    [anon_sym_int24] = ACTIONS(737),
    [anon_sym_int32] = ACTIONS(737),
    [anon_sym_int40] = ACTIONS(737),
    [anon_sym_int48] = ACTIONS(737),
    [anon_sym_int56] = ACTIONS(737),
    [anon_sym_int64] = ACTIONS(737),
    [anon_sym_int72] = ACTIONS(737),
    [anon_sym_int80] = ACTIONS(737),
    [anon_sym_int88] = ACTIONS(737),
    [anon_sym_int96] = ACTIONS(737),
    [anon_sym_int104] = ACTIONS(737),
    [anon_sym_int112] = ACTIONS(737),
    [anon_sym_int120] = ACTIONS(737),
    [anon_sym_int128] = ACTIONS(737),
    [anon_sym_int136] = ACTIONS(737),
    [anon_sym_int144] = ACTIONS(737),
    [anon_sym_int152] = ACTIONS(737),
    [anon_sym_int160] = ACTIONS(737),
    [anon_sym_int168] = ACTIONS(737),
    [anon_sym_int176] = ACTIONS(737),
    [anon_sym_int184] = ACTIONS(737),
    [anon_sym_int192] = ACTIONS(737),
    [anon_sym_int200] = ACTIONS(737),
    [anon_sym_int208] = ACTIONS(737),
    [anon_sym_int216] = ACTIONS(737),
    [anon_sym_int224] = ACTIONS(737),
    [anon_sym_int232] = ACTIONS(737),
    [anon_sym_int240] = ACTIONS(737),
    [anon_sym_int248] = ACTIONS(737),
    [anon_sym_int256] = ACTIONS(737),
    [anon_sym_uint] = ACTIONS(737),
    [anon_sym_uint8] = ACTIONS(737),
    [anon_sym_uint16] = ACTIONS(737),
    [anon_sym_uint24] = ACTIONS(737),
    [anon_sym_uint32] = ACTIONS(737),
    [anon_sym_uint40] = ACTIONS(737),
    [anon_sym_uint48] = ACTIONS(737),
    [anon_sym_uint56] = ACTIONS(737),
    [anon_sym_uint64] = ACTIONS(737),
    [anon_sym_uint72] = ACTIONS(737),
    [anon_sym_uint80] = ACTIONS(737),
    [anon_sym_uint88] = ACTIONS(737),
    [anon_sym_uint96] = ACTIONS(737),
    [anon_sym_uint104] = ACTIONS(737),
    [anon_sym_uint112] = ACTIONS(737),
    [anon_sym_uint120] = ACTIONS(737),
    [anon_sym_uint128] = ACTIONS(737),
    [anon_sym_uint136] = ACTIONS(737),
    [anon_sym_uint144] = ACTIONS(737),
    [anon_sym_uint152] = ACTIONS(737),
    [anon_sym_uint160] = ACTIONS(737),
    [anon_sym_uint168] = ACTIONS(737),
    [anon_sym_uint176] = ACTIONS(737),
    [anon_sym_uint184] = ACTIONS(737),
    [anon_sym_uint192] = ACTIONS(737),
    [anon_sym_uint200] = ACTIONS(737),
    [anon_sym_uint208] = ACTIONS(737),
    [anon_sym_uint216] = ACTIONS(737),
    [anon_sym_uint224] = ACTIONS(737),
    [anon_sym_uint232] = ACTIONS(737),
    [anon_sym_uint240] = ACTIONS(737),
    [anon_sym_uint248] = ACTIONS(737),
    [anon_sym_uint256] = ACTIONS(737),
    [anon_sym_bytes] = ACTIONS(737),
    [anon_sym_bytes1] = ACTIONS(737),
    [anon_sym_bytes2] = ACTIONS(737),
    [anon_sym_bytes3] = ACTIONS(737),
    [anon_sym_bytes4] = ACTIONS(737),
    [anon_sym_bytes5] = ACTIONS(737),
    [anon_sym_bytes6] = ACTIONS(737),
    [anon_sym_bytes7] = ACTIONS(737),
    [anon_sym_bytes8] = ACTIONS(737),
    [anon_sym_bytes9] = ACTIONS(737),
    [anon_sym_bytes10] = ACTIONS(737),
    [anon_sym_bytes11] = ACTIONS(737),
    [anon_sym_bytes12] = ACTIONS(737),
    [anon_sym_bytes13] = ACTIONS(737),
    [anon_sym_bytes14] = ACTIONS(737),
    [anon_sym_bytes15] = ACTIONS(737),
    [anon_sym_bytes16] = ACTIONS(737),
    [anon_sym_bytes17] = ACTIONS(737),
    [anon_sym_bytes18] = ACTIONS(737),
    [anon_sym_bytes19] = ACTIONS(737),
    [anon_sym_bytes20] = ACTIONS(737),
    [anon_sym_bytes21] = ACTIONS(737),
    [anon_sym_bytes22] = ACTIONS(737),
    [anon_sym_bytes23] = ACTIONS(737),
    [anon_sym_bytes24] = ACTIONS(737),
    [anon_sym_bytes25] = ACTIONS(737),
    [anon_sym_bytes26] = ACTIONS(737),
    [anon_sym_bytes27] = ACTIONS(737),
    [anon_sym_bytes28] = ACTIONS(737),
    [anon_sym_bytes29] = ACTIONS(737),
    [anon_sym_bytes30] = ACTIONS(737),
    [anon_sym_bytes31] = ACTIONS(737),
    [anon_sym_bytes32] = ACTIONS(737),
    [anon_sym_fixed] = ACTIONS(737),
    [aux_sym__fixed_token1] = ACTIONS(737),
    [anon_sym_ufixed] = ACTIONS(737),
    [aux_sym__ufixed_token1] = ACTIONS(737),
    [sym_comment] = ACTIONS(3),
  },
  [186] = {
    [ts_builtin_sym_end] = ACTIONS(739),
    [sym_identifier] = ACTIONS(741),
    [anon_sym_pragma] = ACTIONS(741),
    [anon_sym_import] = ACTIONS(741),
    [anon_sym_type] = ACTIONS(741),
    [anon_sym_abstract] = ACTIONS(741),
    [anon_sym_contract] = ACTIONS(741),
    [anon_sym_error] = ACTIONS(741),
    [anon_sym_interface] = ACTIONS(741),
    [anon_sym_library] = ACTIONS(741),
    [anon_sym_struct] = ACTIONS(741),
    [anon_sym_enum] = ACTIONS(741),
    [anon_sym_using] = ACTIONS(741),
    [anon_sym_function] = ACTIONS(741),
    [anon_sym_byte] = ACTIONS(741),
    [anon_sym_address] = ACTIONS(741),
    [anon_sym_var] = ACTIONS(741),
    [anon_sym_mapping] = ACTIONS(741),
    [anon_sym_bool] = ACTIONS(741),
    [anon_sym_string] = ACTIONS(741),
    [anon_sym_int] = ACTIONS(741),
    [anon_sym_int8] = ACTIONS(741),
    [anon_sym_int16] = ACTIONS(741),
    [anon_sym_int24] = ACTIONS(741),
    [anon_sym_int32] = ACTIONS(741),
    [anon_sym_int40] = ACTIONS(741),
    [anon_sym_int48] = ACTIONS(741),
    [anon_sym_int56] = ACTIONS(741),
    [anon_sym_int64] = ACTIONS(741),
    [anon_sym_int72] = ACTIONS(741),
    [anon_sym_int80] = ACTIONS(741),
    [anon_sym_int88] = ACTIONS(741),
    [anon_sym_int96] = ACTIONS(741),
    [anon_sym_int104] = ACTIONS(741),
    [anon_sym_int112] = ACTIONS(741),
    [anon_sym_int120] = ACTIONS(741),
    [anon_sym_int128] = ACTIONS(741),
    [anon_sym_int136] = ACTIONS(741),
    [anon_sym_int144] = ACTIONS(741),
    [anon_sym_int152] = ACTIONS(741),
    [anon_sym_int160] = ACTIONS(741),
    [anon_sym_int168] = ACTIONS(741),
    [anon_sym_int176] = ACTIONS(741),
    [anon_sym_int184] = ACTIONS(741),
    [anon_sym_int192] = ACTIONS(741),
    [anon_sym_int200] = ACTIONS(741),
    [anon_sym_int208] = ACTIONS(741),
    [anon_sym_int216] = ACTIONS(741),
    [anon_sym_int224] = ACTIONS(741),
    [anon_sym_int232] = ACTIONS(741),
    [anon_sym_int240] = ACTIONS(741),
    [anon_sym_int248] = ACTIONS(741),
    [anon_sym_int256] = ACTIONS(741),
    [anon_sym_uint] = ACTIONS(741),
    [anon_sym_uint8] = ACTIONS(741),
    [anon_sym_uint16] = ACTIONS(741),
    [anon_sym_uint24] = ACTIONS(741),
    [anon_sym_uint32] = ACTIONS(741),
    [anon_sym_uint40] = ACTIONS(741),
    [anon_sym_uint48] = ACTIONS(741),
    [anon_sym_uint56] = ACTIONS(741),
    [anon_sym_uint64] = ACTIONS(741),
    [anon_sym_uint72] = ACTIONS(741),
    [anon_sym_uint80] = ACTIONS(741),
    [anon_sym_uint88] = ACTIONS(741),
    [anon_sym_uint96] = ACTIONS(741),
    [anon_sym_uint104] = ACTIONS(741),
    [anon_sym_uint112] = ACTIONS(741),
    [anon_sym_uint120] = ACTIONS(741),
    [anon_sym_uint128] = ACTIONS(741),
    [anon_sym_uint136] = ACTIONS(741),
    [anon_sym_uint144] = ACTIONS(741),
    [anon_sym_uint152] = ACTIONS(741),
    [anon_sym_uint160] = ACTIONS(741),
    [anon_sym_uint168] = ACTIONS(741),
    [anon_sym_uint176] = ACTIONS(741),
    [anon_sym_uint184] = ACTIONS(741),
    [anon_sym_uint192] = ACTIONS(741),
    [anon_sym_uint200] = ACTIONS(741),
    [anon_sym_uint208] = ACTIONS(741),
    [anon_sym_uint216] = ACTIONS(741),
    [anon_sym_uint224] = ACTIONS(741),
    [anon_sym_uint232] = ACTIONS(741),
    [anon_sym_uint240] = ACTIONS(741),
    [anon_sym_uint248] = ACTIONS(741),
    [anon_sym_uint256] = ACTIONS(741),
    [anon_sym_bytes] = ACTIONS(741),
    [anon_sym_bytes1] = ACTIONS(741),
    [anon_sym_bytes2] = ACTIONS(741),
    [anon_sym_bytes3] = ACTIONS(741),
    [anon_sym_bytes4] = ACTIONS(741),
    [anon_sym_bytes5] = ACTIONS(741),
    [anon_sym_bytes6] = ACTIONS(741),
    [anon_sym_bytes7] = ACTIONS(741),
    [anon_sym_bytes8] = ACTIONS(741),
    [anon_sym_bytes9] = ACTIONS(741),
    [anon_sym_bytes10] = ACTIONS(741),
    [anon_sym_bytes11] = ACTIONS(741),
    [anon_sym_bytes12] = ACTIONS(741),
    [anon_sym_bytes13] = ACTIONS(741),
    [anon_sym_bytes14] = ACTIONS(741),
    [anon_sym_bytes15] = ACTIONS(741),
    [anon_sym_bytes16] = ACTIONS(741),
    [anon_sym_bytes17] = ACTIONS(741),
    [anon_sym_bytes18] = ACTIONS(741),
    [anon_sym_bytes19] = ACTIONS(741),
    [anon_sym_bytes20] = ACTIONS(741),
    [anon_sym_bytes21] = ACTIONS(741),
    [anon_sym_bytes22] = ACTIONS(741),
    [anon_sym_bytes23] = ACTIONS(741),
    [anon_sym_bytes24] = ACTIONS(741),
    [anon_sym_bytes25] = ACTIONS(741),
    [anon_sym_bytes26] = ACTIONS(741),
    [anon_sym_bytes27] = ACTIONS(741),
    [anon_sym_bytes28] = ACTIONS(741),
    [anon_sym_bytes29] = ACTIONS(741),
    [anon_sym_bytes30] = ACTIONS(741),
    [anon_sym_bytes31] = ACTIONS(741),
    [anon_sym_bytes32] = ACTIONS(741),
    [anon_sym_fixed] = ACTIONS(741),
    [aux_sym__fixed_token1] = ACTIONS(741),
    [anon_sym_ufixed] = ACTIONS(741),
    [aux_sym__ufixed_token1] = ACTIONS(741),
    [sym_comment] = ACTIONS(3),
  },
  [187] = {
    [ts_builtin_sym_end] = ACTIONS(743),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_pragma] = ACTIONS(745),
    [anon_sym_import] = ACTIONS(745),
    [anon_sym_type] = ACTIONS(745),
    [anon_sym_abstract] = ACTIONS(745),
    [anon_sym_contract] = ACTIONS(745),
    [anon_sym_error] = ACTIONS(745),
    [anon_sym_interface] = ACTIONS(745),
    [anon_sym_library] = ACTIONS(745),
    [anon_sym_struct] = ACTIONS(745),
    [anon_sym_enum] = ACTIONS(745),
    [anon_sym_using] = ACTIONS(745),
    [anon_sym_function] = ACTIONS(745),
    [anon_sym_byte] = ACTIONS(745),
    [anon_sym_address] = ACTIONS(745),
    [anon_sym_var] = ACTIONS(745),
    [anon_sym_mapping] = ACTIONS(745),
    [anon_sym_bool] = ACTIONS(745),
    [anon_sym_string] = ACTIONS(745),
    [anon_sym_int] = ACTIONS(745),
    [anon_sym_int8] = ACTIONS(745),
    [anon_sym_int16] = ACTIONS(745),
    [anon_sym_int24] = ACTIONS(745),
    [anon_sym_int32] = ACTIONS(745),
    [anon_sym_int40] = ACTIONS(745),
    [anon_sym_int48] = ACTIONS(745),
    [anon_sym_int56] = ACTIONS(745),
    [anon_sym_int64] = ACTIONS(745),
    [anon_sym_int72] = ACTIONS(745),
    [anon_sym_int80] = ACTIONS(745),
    [anon_sym_int88] = ACTIONS(745),
    [anon_sym_int96] = ACTIONS(745),
    [anon_sym_int104] = ACTIONS(745),
    [anon_sym_int112] = ACTIONS(745),
    [anon_sym_int120] = ACTIONS(745),
    [anon_sym_int128] = ACTIONS(745),
    [anon_sym_int136] = ACTIONS(745),
    [anon_sym_int144] = ACTIONS(745),
    [anon_sym_int152] = ACTIONS(745),
    [anon_sym_int160] = ACTIONS(745),
    [anon_sym_int168] = ACTIONS(745),
    [anon_sym_int176] = ACTIONS(745),
    [anon_sym_int184] = ACTIONS(745),
    [anon_sym_int192] = ACTIONS(745),
    [anon_sym_int200] = ACTIONS(745),
    [anon_sym_int208] = ACTIONS(745),
    [anon_sym_int216] = ACTIONS(745),
    [anon_sym_int224] = ACTIONS(745),
    [anon_sym_int232] = ACTIONS(745),
    [anon_sym_int240] = ACTIONS(745),
    [anon_sym_int248] = ACTIONS(745),
    [anon_sym_int256] = ACTIONS(745),
    [anon_sym_uint] = ACTIONS(745),
    [anon_sym_uint8] = ACTIONS(745),
    [anon_sym_uint16] = ACTIONS(745),
    [anon_sym_uint24] = ACTIONS(745),
    [anon_sym_uint32] = ACTIONS(745),
    [anon_sym_uint40] = ACTIONS(745),
    [anon_sym_uint48] = ACTIONS(745),
    [anon_sym_uint56] = ACTIONS(745),
    [anon_sym_uint64] = ACTIONS(745),
    [anon_sym_uint72] = ACTIONS(745),
    [anon_sym_uint80] = ACTIONS(745),
    [anon_sym_uint88] = ACTIONS(745),
    [anon_sym_uint96] = ACTIONS(745),
    [anon_sym_uint104] = ACTIONS(745),
    [anon_sym_uint112] = ACTIONS(745),
    [anon_sym_uint120] = ACTIONS(745),
    [anon_sym_uint128] = ACTIONS(745),
    [anon_sym_uint136] = ACTIONS(745),
    [anon_sym_uint144] = ACTIONS(745),
    [anon_sym_uint152] = ACTIONS(745),
    [anon_sym_uint160] = ACTIONS(745),
    [anon_sym_uint168] = ACTIONS(745),
    [anon_sym_uint176] = ACTIONS(745),
    [anon_sym_uint184] = ACTIONS(745),
    [anon_sym_uint192] = ACTIONS(745),
    [anon_sym_uint200] = ACTIONS(745),
    [anon_sym_uint208] = ACTIONS(745),
    [anon_sym_uint216] = ACTIONS(745),
    [anon_sym_uint224] = ACTIONS(745),
    [anon_sym_uint232] = ACTIONS(745),
    [anon_sym_uint240] = ACTIONS(745),
    [anon_sym_uint248] = ACTIONS(745),
    [anon_sym_uint256] = ACTIONS(745),
    [anon_sym_bytes] = ACTIONS(745),
    [anon_sym_bytes1] = ACTIONS(745),
    [anon_sym_bytes2] = ACTIONS(745),
    [anon_sym_bytes3] = ACTIONS(745),
    [anon_sym_bytes4] = ACTIONS(745),
    [anon_sym_bytes5] = ACTIONS(745),
    [anon_sym_bytes6] = ACTIONS(745),
    [anon_sym_bytes7] = ACTIONS(745),
    [anon_sym_bytes8] = ACTIONS(745),
    [anon_sym_bytes9] = ACTIONS(745),
    [anon_sym_bytes10] = ACTIONS(745),
    [anon_sym_bytes11] = ACTIONS(745),
    [anon_sym_bytes12] = ACTIONS(745),
    [anon_sym_bytes13] = ACTIONS(745),
    [anon_sym_bytes14] = ACTIONS(745),
    [anon_sym_bytes15] = ACTIONS(745),
    [anon_sym_bytes16] = ACTIONS(745),
    [anon_sym_bytes17] = ACTIONS(745),
    [anon_sym_bytes18] = ACTIONS(745),
    [anon_sym_bytes19] = ACTIONS(745),
    [anon_sym_bytes20] = ACTIONS(745),
    [anon_sym_bytes21] = ACTIONS(745),
    [anon_sym_bytes22] = ACTIONS(745),
    [anon_sym_bytes23] = ACTIONS(745),
    [anon_sym_bytes24] = ACTIONS(745),
    [anon_sym_bytes25] = ACTIONS(745),
    [anon_sym_bytes26] = ACTIONS(745),
    [anon_sym_bytes27] = ACTIONS(745),
    [anon_sym_bytes28] = ACTIONS(745),
    [anon_sym_bytes29] = ACTIONS(745),
    [anon_sym_bytes30] = ACTIONS(745),
    [anon_sym_bytes31] = ACTIONS(745),
    [anon_sym_bytes32] = ACTIONS(745),
    [anon_sym_fixed] = ACTIONS(745),
    [aux_sym__fixed_token1] = ACTIONS(745),
    [anon_sym_ufixed] = ACTIONS(745),
    [aux_sym__ufixed_token1] = ACTIONS(745),
    [sym_comment] = ACTIONS(3),
  },
  [188] = {
    [ts_builtin_sym_end] = ACTIONS(747),
    [sym_identifier] = ACTIONS(749),
    [anon_sym_pragma] = ACTIONS(749),
    [anon_sym_import] = ACTIONS(749),
    [anon_sym_type] = ACTIONS(749),
    [anon_sym_abstract] = ACTIONS(749),
    [anon_sym_contract] = ACTIONS(749),
    [anon_sym_error] = ACTIONS(749),
    [anon_sym_interface] = ACTIONS(749),
    [anon_sym_library] = ACTIONS(749),
    [anon_sym_struct] = ACTIONS(749),
    [anon_sym_enum] = ACTIONS(749),
    [anon_sym_using] = ACTIONS(749),
    [anon_sym_function] = ACTIONS(749),
    [anon_sym_byte] = ACTIONS(749),
    [anon_sym_address] = ACTIONS(749),
    [anon_sym_var] = ACTIONS(749),
    [anon_sym_mapping] = ACTIONS(749),
    [anon_sym_bool] = ACTIONS(749),
    [anon_sym_string] = ACTIONS(749),
    [anon_sym_int] = ACTIONS(749),
    [anon_sym_int8] = ACTIONS(749),
    [anon_sym_int16] = ACTIONS(749),
    [anon_sym_int24] = ACTIONS(749),
    [anon_sym_int32] = ACTIONS(749),
    [anon_sym_int40] = ACTIONS(749),
    [anon_sym_int48] = ACTIONS(749),
    [anon_sym_int56] = ACTIONS(749),
    [anon_sym_int64] = ACTIONS(749),
    [anon_sym_int72] = ACTIONS(749),
    [anon_sym_int80] = ACTIONS(749),
    [anon_sym_int88] = ACTIONS(749),
    [anon_sym_int96] = ACTIONS(749),
    [anon_sym_int104] = ACTIONS(749),
    [anon_sym_int112] = ACTIONS(749),
    [anon_sym_int120] = ACTIONS(749),
    [anon_sym_int128] = ACTIONS(749),
    [anon_sym_int136] = ACTIONS(749),
    [anon_sym_int144] = ACTIONS(749),
    [anon_sym_int152] = ACTIONS(749),
    [anon_sym_int160] = ACTIONS(749),
    [anon_sym_int168] = ACTIONS(749),
    [anon_sym_int176] = ACTIONS(749),
    [anon_sym_int184] = ACTIONS(749),
    [anon_sym_int192] = ACTIONS(749),
    [anon_sym_int200] = ACTIONS(749),
    [anon_sym_int208] = ACTIONS(749),
    [anon_sym_int216] = ACTIONS(749),
    [anon_sym_int224] = ACTIONS(749),
    [anon_sym_int232] = ACTIONS(749),
    [anon_sym_int240] = ACTIONS(749),
    [anon_sym_int248] = ACTIONS(749),
    [anon_sym_int256] = ACTIONS(749),
    [anon_sym_uint] = ACTIONS(749),
    [anon_sym_uint8] = ACTIONS(749),
    [anon_sym_uint16] = ACTIONS(749),
    [anon_sym_uint24] = ACTIONS(749),
    [anon_sym_uint32] = ACTIONS(749),
    [anon_sym_uint40] = ACTIONS(749),
    [anon_sym_uint48] = ACTIONS(749),
    [anon_sym_uint56] = ACTIONS(749),
    [anon_sym_uint64] = ACTIONS(749),
    [anon_sym_uint72] = ACTIONS(749),
    [anon_sym_uint80] = ACTIONS(749),
    [anon_sym_uint88] = ACTIONS(749),
    [anon_sym_uint96] = ACTIONS(749),
    [anon_sym_uint104] = ACTIONS(749),
    [anon_sym_uint112] = ACTIONS(749),
    [anon_sym_uint120] = ACTIONS(749),
    [anon_sym_uint128] = ACTIONS(749),
    [anon_sym_uint136] = ACTIONS(749),
    [anon_sym_uint144] = ACTIONS(749),
    [anon_sym_uint152] = ACTIONS(749),
    [anon_sym_uint160] = ACTIONS(749),
    [anon_sym_uint168] = ACTIONS(749),
    [anon_sym_uint176] = ACTIONS(749),
    [anon_sym_uint184] = ACTIONS(749),
    [anon_sym_uint192] = ACTIONS(749),
    [anon_sym_uint200] = ACTIONS(749),
    [anon_sym_uint208] = ACTIONS(749),
    [anon_sym_uint216] = ACTIONS(749),
    [anon_sym_uint224] = ACTIONS(749),
    [anon_sym_uint232] = ACTIONS(749),
    [anon_sym_uint240] = ACTIONS(749),
    [anon_sym_uint248] = ACTIONS(749),
    [anon_sym_uint256] = ACTIONS(749),
    [anon_sym_bytes] = ACTIONS(749),
    [anon_sym_bytes1] = ACTIONS(749),
    [anon_sym_bytes2] = ACTIONS(749),
    [anon_sym_bytes3] = ACTIONS(749),
    [anon_sym_bytes4] = ACTIONS(749),
    [anon_sym_bytes5] = ACTIONS(749),
    [anon_sym_bytes6] = ACTIONS(749),
    [anon_sym_bytes7] = ACTIONS(749),
    [anon_sym_bytes8] = ACTIONS(749),
    [anon_sym_bytes9] = ACTIONS(749),
    [anon_sym_bytes10] = ACTIONS(749),
    [anon_sym_bytes11] = ACTIONS(749),
    [anon_sym_bytes12] = ACTIONS(749),
    [anon_sym_bytes13] = ACTIONS(749),
    [anon_sym_bytes14] = ACTIONS(749),
    [anon_sym_bytes15] = ACTIONS(749),
    [anon_sym_bytes16] = ACTIONS(749),
    [anon_sym_bytes17] = ACTIONS(749),
    [anon_sym_bytes18] = ACTIONS(749),
    [anon_sym_bytes19] = ACTIONS(749),
    [anon_sym_bytes20] = ACTIONS(749),
    [anon_sym_bytes21] = ACTIONS(749),
    [anon_sym_bytes22] = ACTIONS(749),
    [anon_sym_bytes23] = ACTIONS(749),
    [anon_sym_bytes24] = ACTIONS(749),
    [anon_sym_bytes25] = ACTIONS(749),
    [anon_sym_bytes26] = ACTIONS(749),
    [anon_sym_bytes27] = ACTIONS(749),
    [anon_sym_bytes28] = ACTIONS(749),
    [anon_sym_bytes29] = ACTIONS(749),
    [anon_sym_bytes30] = ACTIONS(749),
    [anon_sym_bytes31] = ACTIONS(749),
    [anon_sym_bytes32] = ACTIONS(749),
    [anon_sym_fixed] = ACTIONS(749),
    [aux_sym__fixed_token1] = ACTIONS(749),
    [anon_sym_ufixed] = ACTIONS(749),
    [aux_sym__ufixed_token1] = ACTIONS(749),
    [sym_comment] = ACTIONS(3),
  },
  [189] = {
    [ts_builtin_sym_end] = ACTIONS(731),
    [sym_identifier] = ACTIONS(733),
    [anon_sym_pragma] = ACTIONS(733),
    [anon_sym_import] = ACTIONS(733),
    [anon_sym_type] = ACTIONS(733),
    [anon_sym_abstract] = ACTIONS(733),
    [anon_sym_contract] = ACTIONS(733),
    [anon_sym_error] = ACTIONS(733),
    [anon_sym_interface] = ACTIONS(733),
    [anon_sym_library] = ACTIONS(733),
    [anon_sym_struct] = ACTIONS(733),
    [anon_sym_enum] = ACTIONS(733),
    [anon_sym_using] = ACTIONS(733),
    [anon_sym_function] = ACTIONS(733),
    [anon_sym_byte] = ACTIONS(733),
    [anon_sym_address] = ACTIONS(733),
    [anon_sym_var] = ACTIONS(733),
    [anon_sym_mapping] = ACTIONS(733),
    [anon_sym_bool] = ACTIONS(733),
    [anon_sym_string] = ACTIONS(733),
    [anon_sym_int] = ACTIONS(733),
    [anon_sym_int8] = ACTIONS(733),
    [anon_sym_int16] = ACTIONS(733),
    [anon_sym_int24] = ACTIONS(733),
    [anon_sym_int32] = ACTIONS(733),
    [anon_sym_int40] = ACTIONS(733),
    [anon_sym_int48] = ACTIONS(733),
    [anon_sym_int56] = ACTIONS(733),
    [anon_sym_int64] = ACTIONS(733),
    [anon_sym_int72] = ACTIONS(733),
    [anon_sym_int80] = ACTIONS(733),
    [anon_sym_int88] = ACTIONS(733),
    [anon_sym_int96] = ACTIONS(733),
    [anon_sym_int104] = ACTIONS(733),
    [anon_sym_int112] = ACTIONS(733),
    [anon_sym_int120] = ACTIONS(733),
    [anon_sym_int128] = ACTIONS(733),
    [anon_sym_int136] = ACTIONS(733),
    [anon_sym_int144] = ACTIONS(733),
    [anon_sym_int152] = ACTIONS(733),
    [anon_sym_int160] = ACTIONS(733),
    [anon_sym_int168] = ACTIONS(733),
    [anon_sym_int176] = ACTIONS(733),
    [anon_sym_int184] = ACTIONS(733),
    [anon_sym_int192] = ACTIONS(733),
    [anon_sym_int200] = ACTIONS(733),
    [anon_sym_int208] = ACTIONS(733),
    [anon_sym_int216] = ACTIONS(733),
    [anon_sym_int224] = ACTIONS(733),
    [anon_sym_int232] = ACTIONS(733),
    [anon_sym_int240] = ACTIONS(733),
    [anon_sym_int248] = ACTIONS(733),
    [anon_sym_int256] = ACTIONS(733),
    [anon_sym_uint] = ACTIONS(733),
    [anon_sym_uint8] = ACTIONS(733),
    [anon_sym_uint16] = ACTIONS(733),
    [anon_sym_uint24] = ACTIONS(733),
    [anon_sym_uint32] = ACTIONS(733),
    [anon_sym_uint40] = ACTIONS(733),
    [anon_sym_uint48] = ACTIONS(733),
    [anon_sym_uint56] = ACTIONS(733),
    [anon_sym_uint64] = ACTIONS(733),
    [anon_sym_uint72] = ACTIONS(733),
    [anon_sym_uint80] = ACTIONS(733),
    [anon_sym_uint88] = ACTIONS(733),
    [anon_sym_uint96] = ACTIONS(733),
    [anon_sym_uint104] = ACTIONS(733),
    [anon_sym_uint112] = ACTIONS(733),
    [anon_sym_uint120] = ACTIONS(733),
    [anon_sym_uint128] = ACTIONS(733),
    [anon_sym_uint136] = ACTIONS(733),
    [anon_sym_uint144] = ACTIONS(733),
    [anon_sym_uint152] = ACTIONS(733),
    [anon_sym_uint160] = ACTIONS(733),
    [anon_sym_uint168] = ACTIONS(733),
    [anon_sym_uint176] = ACTIONS(733),
    [anon_sym_uint184] = ACTIONS(733),
    [anon_sym_uint192] = ACTIONS(733),
    [anon_sym_uint200] = ACTIONS(733),
    [anon_sym_uint208] = ACTIONS(733),
    [anon_sym_uint216] = ACTIONS(733),
    [anon_sym_uint224] = ACTIONS(733),
    [anon_sym_uint232] = ACTIONS(733),
    [anon_sym_uint240] = ACTIONS(733),
    [anon_sym_uint248] = ACTIONS(733),
    [anon_sym_uint256] = ACTIONS(733),
    [anon_sym_bytes] = ACTIONS(733),
    [anon_sym_bytes1] = ACTIONS(733),
    [anon_sym_bytes2] = ACTIONS(733),
    [anon_sym_bytes3] = ACTIONS(733),
    [anon_sym_bytes4] = ACTIONS(733),
    [anon_sym_bytes5] = ACTIONS(733),
    [anon_sym_bytes6] = ACTIONS(733),
    [anon_sym_bytes7] = ACTIONS(733),
    [anon_sym_bytes8] = ACTIONS(733),
    [anon_sym_bytes9] = ACTIONS(733),
    [anon_sym_bytes10] = ACTIONS(733),
    [anon_sym_bytes11] = ACTIONS(733),
    [anon_sym_bytes12] = ACTIONS(733),
    [anon_sym_bytes13] = ACTIONS(733),
    [anon_sym_bytes14] = ACTIONS(733),
    [anon_sym_bytes15] = ACTIONS(733),
    [anon_sym_bytes16] = ACTIONS(733),
    [anon_sym_bytes17] = ACTIONS(733),
    [anon_sym_bytes18] = ACTIONS(733),
    [anon_sym_bytes19] = ACTIONS(733),
    [anon_sym_bytes20] = ACTIONS(733),
    [anon_sym_bytes21] = ACTIONS(733),
    [anon_sym_bytes22] = ACTIONS(733),
    [anon_sym_bytes23] = ACTIONS(733),
    [anon_sym_bytes24] = ACTIONS(733),
    [anon_sym_bytes25] = ACTIONS(733),
    [anon_sym_bytes26] = ACTIONS(733),
    [anon_sym_bytes27] = ACTIONS(733),
    [anon_sym_bytes28] = ACTIONS(733),
    [anon_sym_bytes29] = ACTIONS(733),
    [anon_sym_bytes30] = ACTIONS(733),
    [anon_sym_bytes31] = ACTIONS(733),
    [anon_sym_bytes32] = ACTIONS(733),
    [anon_sym_fixed] = ACTIONS(733),
    [aux_sym__fixed_token1] = ACTIONS(733),
    [anon_sym_ufixed] = ACTIONS(733),
    [aux_sym__ufixed_token1] = ACTIONS(733),
    [sym_comment] = ACTIONS(3),
  },
  [190] = {
    [ts_builtin_sym_end] = ACTIONS(751),
    [sym_identifier] = ACTIONS(753),
    [anon_sym_pragma] = ACTIONS(753),
    [anon_sym_import] = ACTIONS(753),
    [anon_sym_type] = ACTIONS(753),
    [anon_sym_abstract] = ACTIONS(753),
    [anon_sym_contract] = ACTIONS(753),
    [anon_sym_error] = ACTIONS(753),
    [anon_sym_interface] = ACTIONS(753),
    [anon_sym_library] = ACTIONS(753),
    [anon_sym_struct] = ACTIONS(753),
    [anon_sym_enum] = ACTIONS(753),
    [anon_sym_using] = ACTIONS(753),
    [anon_sym_function] = ACTIONS(753),
    [anon_sym_byte] = ACTIONS(753),
    [anon_sym_address] = ACTIONS(753),
    [anon_sym_var] = ACTIONS(753),
    [anon_sym_mapping] = ACTIONS(753),
    [anon_sym_bool] = ACTIONS(753),
    [anon_sym_string] = ACTIONS(753),
    [anon_sym_int] = ACTIONS(753),
    [anon_sym_int8] = ACTIONS(753),
    [anon_sym_int16] = ACTIONS(753),
    [anon_sym_int24] = ACTIONS(753),
    [anon_sym_int32] = ACTIONS(753),
    [anon_sym_int40] = ACTIONS(753),
    [anon_sym_int48] = ACTIONS(753),
    [anon_sym_int56] = ACTIONS(753),
    [anon_sym_int64] = ACTIONS(753),
    [anon_sym_int72] = ACTIONS(753),
    [anon_sym_int80] = ACTIONS(753),
    [anon_sym_int88] = ACTIONS(753),
    [anon_sym_int96] = ACTIONS(753),
    [anon_sym_int104] = ACTIONS(753),
    [anon_sym_int112] = ACTIONS(753),
    [anon_sym_int120] = ACTIONS(753),
    [anon_sym_int128] = ACTIONS(753),
    [anon_sym_int136] = ACTIONS(753),
    [anon_sym_int144] = ACTIONS(753),
    [anon_sym_int152] = ACTIONS(753),
    [anon_sym_int160] = ACTIONS(753),
    [anon_sym_int168] = ACTIONS(753),
    [anon_sym_int176] = ACTIONS(753),
    [anon_sym_int184] = ACTIONS(753),
    [anon_sym_int192] = ACTIONS(753),
    [anon_sym_int200] = ACTIONS(753),
    [anon_sym_int208] = ACTIONS(753),
    [anon_sym_int216] = ACTIONS(753),
    [anon_sym_int224] = ACTIONS(753),
    [anon_sym_int232] = ACTIONS(753),
    [anon_sym_int240] = ACTIONS(753),
    [anon_sym_int248] = ACTIONS(753),
    [anon_sym_int256] = ACTIONS(753),
    [anon_sym_uint] = ACTIONS(753),
    [anon_sym_uint8] = ACTIONS(753),
    [anon_sym_uint16] = ACTIONS(753),
    [anon_sym_uint24] = ACTIONS(753),
    [anon_sym_uint32] = ACTIONS(753),
    [anon_sym_uint40] = ACTIONS(753),
    [anon_sym_uint48] = ACTIONS(753),
    [anon_sym_uint56] = ACTIONS(753),
    [anon_sym_uint64] = ACTIONS(753),
    [anon_sym_uint72] = ACTIONS(753),
    [anon_sym_uint80] = ACTIONS(753),
    [anon_sym_uint88] = ACTIONS(753),
    [anon_sym_uint96] = ACTIONS(753),
    [anon_sym_uint104] = ACTIONS(753),
    [anon_sym_uint112] = ACTIONS(753),
    [anon_sym_uint120] = ACTIONS(753),
    [anon_sym_uint128] = ACTIONS(753),
    [anon_sym_uint136] = ACTIONS(753),
    [anon_sym_uint144] = ACTIONS(753),
    [anon_sym_uint152] = ACTIONS(753),
    [anon_sym_uint160] = ACTIONS(753),
    [anon_sym_uint168] = ACTIONS(753),
    [anon_sym_uint176] = ACTIONS(753),
    [anon_sym_uint184] = ACTIONS(753),
    [anon_sym_uint192] = ACTIONS(753),
    [anon_sym_uint200] = ACTIONS(753),
    [anon_sym_uint208] = ACTIONS(753),
    [anon_sym_uint216] = ACTIONS(753),
    [anon_sym_uint224] = ACTIONS(753),
    [anon_sym_uint232] = ACTIONS(753),
    [anon_sym_uint240] = ACTIONS(753),
    [anon_sym_uint248] = ACTIONS(753),
    [anon_sym_uint256] = ACTIONS(753),
    [anon_sym_bytes] = ACTIONS(753),
    [anon_sym_bytes1] = ACTIONS(753),
    [anon_sym_bytes2] = ACTIONS(753),
    [anon_sym_bytes3] = ACTIONS(753),
    [anon_sym_bytes4] = ACTIONS(753),
    [anon_sym_bytes5] = ACTIONS(753),
    [anon_sym_bytes6] = ACTIONS(753),
    [anon_sym_bytes7] = ACTIONS(753),
    [anon_sym_bytes8] = ACTIONS(753),
    [anon_sym_bytes9] = ACTIONS(753),
    [anon_sym_bytes10] = ACTIONS(753),
    [anon_sym_bytes11] = ACTIONS(753),
    [anon_sym_bytes12] = ACTIONS(753),
    [anon_sym_bytes13] = ACTIONS(753),
    [anon_sym_bytes14] = ACTIONS(753),
    [anon_sym_bytes15] = ACTIONS(753),
    [anon_sym_bytes16] = ACTIONS(753),
    [anon_sym_bytes17] = ACTIONS(753),
    [anon_sym_bytes18] = ACTIONS(753),
    [anon_sym_bytes19] = ACTIONS(753),
    [anon_sym_bytes20] = ACTIONS(753),
    [anon_sym_bytes21] = ACTIONS(753),
    [anon_sym_bytes22] = ACTIONS(753),
    [anon_sym_bytes23] = ACTIONS(753),
    [anon_sym_bytes24] = ACTIONS(753),
    [anon_sym_bytes25] = ACTIONS(753),
    [anon_sym_bytes26] = ACTIONS(753),
    [anon_sym_bytes27] = ACTIONS(753),
    [anon_sym_bytes28] = ACTIONS(753),
    [anon_sym_bytes29] = ACTIONS(753),
    [anon_sym_bytes30] = ACTIONS(753),
    [anon_sym_bytes31] = ACTIONS(753),
    [anon_sym_bytes32] = ACTIONS(753),
    [anon_sym_fixed] = ACTIONS(753),
    [aux_sym__fixed_token1] = ACTIONS(753),
    [anon_sym_ufixed] = ACTIONS(753),
    [aux_sym__ufixed_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(3),
  },
  [191] = {
    [ts_builtin_sym_end] = ACTIONS(735),
    [sym_identifier] = ACTIONS(737),
    [anon_sym_pragma] = ACTIONS(737),
    [anon_sym_import] = ACTIONS(737),
    [anon_sym_type] = ACTIONS(737),
    [anon_sym_abstract] = ACTIONS(737),
    [anon_sym_contract] = ACTIONS(737),
    [anon_sym_error] = ACTIONS(737),
    [anon_sym_interface] = ACTIONS(737),
    [anon_sym_library] = ACTIONS(737),
    [anon_sym_struct] = ACTIONS(737),
    [anon_sym_enum] = ACTIONS(737),
    [anon_sym_using] = ACTIONS(737),
    [anon_sym_function] = ACTIONS(737),
    [anon_sym_byte] = ACTIONS(737),
    [anon_sym_address] = ACTIONS(737),
    [anon_sym_var] = ACTIONS(737),
    [anon_sym_mapping] = ACTIONS(737),
    [anon_sym_bool] = ACTIONS(737),
    [anon_sym_string] = ACTIONS(737),
    [anon_sym_int] = ACTIONS(737),
    [anon_sym_int8] = ACTIONS(737),
    [anon_sym_int16] = ACTIONS(737),
    [anon_sym_int24] = ACTIONS(737),
    [anon_sym_int32] = ACTIONS(737),
    [anon_sym_int40] = ACTIONS(737),
    [anon_sym_int48] = ACTIONS(737),
    [anon_sym_int56] = ACTIONS(737),
    [anon_sym_int64] = ACTIONS(737),
    [anon_sym_int72] = ACTIONS(737),
    [anon_sym_int80] = ACTIONS(737),
    [anon_sym_int88] = ACTIONS(737),
    [anon_sym_int96] = ACTIONS(737),
    [anon_sym_int104] = ACTIONS(737),
    [anon_sym_int112] = ACTIONS(737),
    [anon_sym_int120] = ACTIONS(737),
    [anon_sym_int128] = ACTIONS(737),
    [anon_sym_int136] = ACTIONS(737),
    [anon_sym_int144] = ACTIONS(737),
    [anon_sym_int152] = ACTIONS(737),
    [anon_sym_int160] = ACTIONS(737),
    [anon_sym_int168] = ACTIONS(737),
    [anon_sym_int176] = ACTIONS(737),
    [anon_sym_int184] = ACTIONS(737),
    [anon_sym_int192] = ACTIONS(737),
    [anon_sym_int200] = ACTIONS(737),
    [anon_sym_int208] = ACTIONS(737),
    [anon_sym_int216] = ACTIONS(737),
    [anon_sym_int224] = ACTIONS(737),
    [anon_sym_int232] = ACTIONS(737),
    [anon_sym_int240] = ACTIONS(737),
    [anon_sym_int248] = ACTIONS(737),
    [anon_sym_int256] = ACTIONS(737),
    [anon_sym_uint] = ACTIONS(737),
    [anon_sym_uint8] = ACTIONS(737),
    [anon_sym_uint16] = ACTIONS(737),
    [anon_sym_uint24] = ACTIONS(737),
    [anon_sym_uint32] = ACTIONS(737),
    [anon_sym_uint40] = ACTIONS(737),
    [anon_sym_uint48] = ACTIONS(737),
    [anon_sym_uint56] = ACTIONS(737),
    [anon_sym_uint64] = ACTIONS(737),
    [anon_sym_uint72] = ACTIONS(737),
    [anon_sym_uint80] = ACTIONS(737),
    [anon_sym_uint88] = ACTIONS(737),
    [anon_sym_uint96] = ACTIONS(737),
    [anon_sym_uint104] = ACTIONS(737),
    [anon_sym_uint112] = ACTIONS(737),
    [anon_sym_uint120] = ACTIONS(737),
    [anon_sym_uint128] = ACTIONS(737),
    [anon_sym_uint136] = ACTIONS(737),
    [anon_sym_uint144] = ACTIONS(737),
    [anon_sym_uint152] = ACTIONS(737),
    [anon_sym_uint160] = ACTIONS(737),
    [anon_sym_uint168] = ACTIONS(737),
    [anon_sym_uint176] = ACTIONS(737),
    [anon_sym_uint184] = ACTIONS(737),
    [anon_sym_uint192] = ACTIONS(737),
    [anon_sym_uint200] = ACTIONS(737),
    [anon_sym_uint208] = ACTIONS(737),
    [anon_sym_uint216] = ACTIONS(737),
    [anon_sym_uint224] = ACTIONS(737),
    [anon_sym_uint232] = ACTIONS(737),
    [anon_sym_uint240] = ACTIONS(737),
    [anon_sym_uint248] = ACTIONS(737),
    [anon_sym_uint256] = ACTIONS(737),
    [anon_sym_bytes] = ACTIONS(737),
    [anon_sym_bytes1] = ACTIONS(737),
    [anon_sym_bytes2] = ACTIONS(737),
    [anon_sym_bytes3] = ACTIONS(737),
    [anon_sym_bytes4] = ACTIONS(737),
    [anon_sym_bytes5] = ACTIONS(737),
    [anon_sym_bytes6] = ACTIONS(737),
    [anon_sym_bytes7] = ACTIONS(737),
    [anon_sym_bytes8] = ACTIONS(737),
    [anon_sym_bytes9] = ACTIONS(737),
    [anon_sym_bytes10] = ACTIONS(737),
    [anon_sym_bytes11] = ACTIONS(737),
    [anon_sym_bytes12] = ACTIONS(737),
    [anon_sym_bytes13] = ACTIONS(737),
    [anon_sym_bytes14] = ACTIONS(737),
    [anon_sym_bytes15] = ACTIONS(737),
    [anon_sym_bytes16] = ACTIONS(737),
    [anon_sym_bytes17] = ACTIONS(737),
    [anon_sym_bytes18] = ACTIONS(737),
    [anon_sym_bytes19] = ACTIONS(737),
    [anon_sym_bytes20] = ACTIONS(737),
    [anon_sym_bytes21] = ACTIONS(737),
    [anon_sym_bytes22] = ACTIONS(737),
    [anon_sym_bytes23] = ACTIONS(737),
    [anon_sym_bytes24] = ACTIONS(737),
    [anon_sym_bytes25] = ACTIONS(737),
    [anon_sym_bytes26] = ACTIONS(737),
    [anon_sym_bytes27] = ACTIONS(737),
    [anon_sym_bytes28] = ACTIONS(737),
    [anon_sym_bytes29] = ACTIONS(737),
    [anon_sym_bytes30] = ACTIONS(737),
    [anon_sym_bytes31] = ACTIONS(737),
    [anon_sym_bytes32] = ACTIONS(737),
    [anon_sym_fixed] = ACTIONS(737),
    [aux_sym__fixed_token1] = ACTIONS(737),
    [anon_sym_ufixed] = ACTIONS(737),
    [aux_sym__ufixed_token1] = ACTIONS(737),
    [sym_comment] = ACTIONS(3),
  },
  [192] = {
    [sym_type_name] = STATE(706),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [193] = {
    [ts_builtin_sym_end] = ACTIONS(751),
    [sym_identifier] = ACTIONS(753),
    [anon_sym_pragma] = ACTIONS(753),
    [anon_sym_import] = ACTIONS(753),
    [anon_sym_type] = ACTIONS(753),
    [anon_sym_abstract] = ACTIONS(753),
    [anon_sym_contract] = ACTIONS(753),
    [anon_sym_error] = ACTIONS(753),
    [anon_sym_interface] = ACTIONS(753),
    [anon_sym_library] = ACTIONS(753),
    [anon_sym_struct] = ACTIONS(753),
    [anon_sym_enum] = ACTIONS(753),
    [anon_sym_using] = ACTIONS(753),
    [anon_sym_function] = ACTIONS(753),
    [anon_sym_byte] = ACTIONS(753),
    [anon_sym_address] = ACTIONS(753),
    [anon_sym_var] = ACTIONS(753),
    [anon_sym_mapping] = ACTIONS(753),
    [anon_sym_bool] = ACTIONS(753),
    [anon_sym_string] = ACTIONS(753),
    [anon_sym_int] = ACTIONS(753),
    [anon_sym_int8] = ACTIONS(753),
    [anon_sym_int16] = ACTIONS(753),
    [anon_sym_int24] = ACTIONS(753),
    [anon_sym_int32] = ACTIONS(753),
    [anon_sym_int40] = ACTIONS(753),
    [anon_sym_int48] = ACTIONS(753),
    [anon_sym_int56] = ACTIONS(753),
    [anon_sym_int64] = ACTIONS(753),
    [anon_sym_int72] = ACTIONS(753),
    [anon_sym_int80] = ACTIONS(753),
    [anon_sym_int88] = ACTIONS(753),
    [anon_sym_int96] = ACTIONS(753),
    [anon_sym_int104] = ACTIONS(753),
    [anon_sym_int112] = ACTIONS(753),
    [anon_sym_int120] = ACTIONS(753),
    [anon_sym_int128] = ACTIONS(753),
    [anon_sym_int136] = ACTIONS(753),
    [anon_sym_int144] = ACTIONS(753),
    [anon_sym_int152] = ACTIONS(753),
    [anon_sym_int160] = ACTIONS(753),
    [anon_sym_int168] = ACTIONS(753),
    [anon_sym_int176] = ACTIONS(753),
    [anon_sym_int184] = ACTIONS(753),
    [anon_sym_int192] = ACTIONS(753),
    [anon_sym_int200] = ACTIONS(753),
    [anon_sym_int208] = ACTIONS(753),
    [anon_sym_int216] = ACTIONS(753),
    [anon_sym_int224] = ACTIONS(753),
    [anon_sym_int232] = ACTIONS(753),
    [anon_sym_int240] = ACTIONS(753),
    [anon_sym_int248] = ACTIONS(753),
    [anon_sym_int256] = ACTIONS(753),
    [anon_sym_uint] = ACTIONS(753),
    [anon_sym_uint8] = ACTIONS(753),
    [anon_sym_uint16] = ACTIONS(753),
    [anon_sym_uint24] = ACTIONS(753),
    [anon_sym_uint32] = ACTIONS(753),
    [anon_sym_uint40] = ACTIONS(753),
    [anon_sym_uint48] = ACTIONS(753),
    [anon_sym_uint56] = ACTIONS(753),
    [anon_sym_uint64] = ACTIONS(753),
    [anon_sym_uint72] = ACTIONS(753),
    [anon_sym_uint80] = ACTIONS(753),
    [anon_sym_uint88] = ACTIONS(753),
    [anon_sym_uint96] = ACTIONS(753),
    [anon_sym_uint104] = ACTIONS(753),
    [anon_sym_uint112] = ACTIONS(753),
    [anon_sym_uint120] = ACTIONS(753),
    [anon_sym_uint128] = ACTIONS(753),
    [anon_sym_uint136] = ACTIONS(753),
    [anon_sym_uint144] = ACTIONS(753),
    [anon_sym_uint152] = ACTIONS(753),
    [anon_sym_uint160] = ACTIONS(753),
    [anon_sym_uint168] = ACTIONS(753),
    [anon_sym_uint176] = ACTIONS(753),
    [anon_sym_uint184] = ACTIONS(753),
    [anon_sym_uint192] = ACTIONS(753),
    [anon_sym_uint200] = ACTIONS(753),
    [anon_sym_uint208] = ACTIONS(753),
    [anon_sym_uint216] = ACTIONS(753),
    [anon_sym_uint224] = ACTIONS(753),
    [anon_sym_uint232] = ACTIONS(753),
    [anon_sym_uint240] = ACTIONS(753),
    [anon_sym_uint248] = ACTIONS(753),
    [anon_sym_uint256] = ACTIONS(753),
    [anon_sym_bytes] = ACTIONS(753),
    [anon_sym_bytes1] = ACTIONS(753),
    [anon_sym_bytes2] = ACTIONS(753),
    [anon_sym_bytes3] = ACTIONS(753),
    [anon_sym_bytes4] = ACTIONS(753),
    [anon_sym_bytes5] = ACTIONS(753),
    [anon_sym_bytes6] = ACTIONS(753),
    [anon_sym_bytes7] = ACTIONS(753),
    [anon_sym_bytes8] = ACTIONS(753),
    [anon_sym_bytes9] = ACTIONS(753),
    [anon_sym_bytes10] = ACTIONS(753),
    [anon_sym_bytes11] = ACTIONS(753),
    [anon_sym_bytes12] = ACTIONS(753),
    [anon_sym_bytes13] = ACTIONS(753),
    [anon_sym_bytes14] = ACTIONS(753),
    [anon_sym_bytes15] = ACTIONS(753),
    [anon_sym_bytes16] = ACTIONS(753),
    [anon_sym_bytes17] = ACTIONS(753),
    [anon_sym_bytes18] = ACTIONS(753),
    [anon_sym_bytes19] = ACTIONS(753),
    [anon_sym_bytes20] = ACTIONS(753),
    [anon_sym_bytes21] = ACTIONS(753),
    [anon_sym_bytes22] = ACTIONS(753),
    [anon_sym_bytes23] = ACTIONS(753),
    [anon_sym_bytes24] = ACTIONS(753),
    [anon_sym_bytes25] = ACTIONS(753),
    [anon_sym_bytes26] = ACTIONS(753),
    [anon_sym_bytes27] = ACTIONS(753),
    [anon_sym_bytes28] = ACTIONS(753),
    [anon_sym_bytes29] = ACTIONS(753),
    [anon_sym_bytes30] = ACTIONS(753),
    [anon_sym_bytes31] = ACTIONS(753),
    [anon_sym_bytes32] = ACTIONS(753),
    [anon_sym_fixed] = ACTIONS(753),
    [aux_sym__fixed_token1] = ACTIONS(753),
    [anon_sym_ufixed] = ACTIONS(753),
    [aux_sym__ufixed_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(3),
  },
  [194] = {
    [ts_builtin_sym_end] = ACTIONS(755),
    [sym_identifier] = ACTIONS(757),
    [anon_sym_pragma] = ACTIONS(757),
    [anon_sym_import] = ACTIONS(757),
    [anon_sym_type] = ACTIONS(757),
    [anon_sym_abstract] = ACTIONS(757),
    [anon_sym_contract] = ACTIONS(757),
    [anon_sym_error] = ACTIONS(757),
    [anon_sym_interface] = ACTIONS(757),
    [anon_sym_library] = ACTIONS(757),
    [anon_sym_struct] = ACTIONS(757),
    [anon_sym_enum] = ACTIONS(757),
    [anon_sym_using] = ACTIONS(757),
    [anon_sym_function] = ACTIONS(757),
    [anon_sym_byte] = ACTIONS(757),
    [anon_sym_address] = ACTIONS(757),
    [anon_sym_var] = ACTIONS(757),
    [anon_sym_mapping] = ACTIONS(757),
    [anon_sym_bool] = ACTIONS(757),
    [anon_sym_string] = ACTIONS(757),
    [anon_sym_int] = ACTIONS(757),
    [anon_sym_int8] = ACTIONS(757),
    [anon_sym_int16] = ACTIONS(757),
    [anon_sym_int24] = ACTIONS(757),
    [anon_sym_int32] = ACTIONS(757),
    [anon_sym_int40] = ACTIONS(757),
    [anon_sym_int48] = ACTIONS(757),
    [anon_sym_int56] = ACTIONS(757),
    [anon_sym_int64] = ACTIONS(757),
    [anon_sym_int72] = ACTIONS(757),
    [anon_sym_int80] = ACTIONS(757),
    [anon_sym_int88] = ACTIONS(757),
    [anon_sym_int96] = ACTIONS(757),
    [anon_sym_int104] = ACTIONS(757),
    [anon_sym_int112] = ACTIONS(757),
    [anon_sym_int120] = ACTIONS(757),
    [anon_sym_int128] = ACTIONS(757),
    [anon_sym_int136] = ACTIONS(757),
    [anon_sym_int144] = ACTIONS(757),
    [anon_sym_int152] = ACTIONS(757),
    [anon_sym_int160] = ACTIONS(757),
    [anon_sym_int168] = ACTIONS(757),
    [anon_sym_int176] = ACTIONS(757),
    [anon_sym_int184] = ACTIONS(757),
    [anon_sym_int192] = ACTIONS(757),
    [anon_sym_int200] = ACTIONS(757),
    [anon_sym_int208] = ACTIONS(757),
    [anon_sym_int216] = ACTIONS(757),
    [anon_sym_int224] = ACTIONS(757),
    [anon_sym_int232] = ACTIONS(757),
    [anon_sym_int240] = ACTIONS(757),
    [anon_sym_int248] = ACTIONS(757),
    [anon_sym_int256] = ACTIONS(757),
    [anon_sym_uint] = ACTIONS(757),
    [anon_sym_uint8] = ACTIONS(757),
    [anon_sym_uint16] = ACTIONS(757),
    [anon_sym_uint24] = ACTIONS(757),
    [anon_sym_uint32] = ACTIONS(757),
    [anon_sym_uint40] = ACTIONS(757),
    [anon_sym_uint48] = ACTIONS(757),
    [anon_sym_uint56] = ACTIONS(757),
    [anon_sym_uint64] = ACTIONS(757),
    [anon_sym_uint72] = ACTIONS(757),
    [anon_sym_uint80] = ACTIONS(757),
    [anon_sym_uint88] = ACTIONS(757),
    [anon_sym_uint96] = ACTIONS(757),
    [anon_sym_uint104] = ACTIONS(757),
    [anon_sym_uint112] = ACTIONS(757),
    [anon_sym_uint120] = ACTIONS(757),
    [anon_sym_uint128] = ACTIONS(757),
    [anon_sym_uint136] = ACTIONS(757),
    [anon_sym_uint144] = ACTIONS(757),
    [anon_sym_uint152] = ACTIONS(757),
    [anon_sym_uint160] = ACTIONS(757),
    [anon_sym_uint168] = ACTIONS(757),
    [anon_sym_uint176] = ACTIONS(757),
    [anon_sym_uint184] = ACTIONS(757),
    [anon_sym_uint192] = ACTIONS(757),
    [anon_sym_uint200] = ACTIONS(757),
    [anon_sym_uint208] = ACTIONS(757),
    [anon_sym_uint216] = ACTIONS(757),
    [anon_sym_uint224] = ACTIONS(757),
    [anon_sym_uint232] = ACTIONS(757),
    [anon_sym_uint240] = ACTIONS(757),
    [anon_sym_uint248] = ACTIONS(757),
    [anon_sym_uint256] = ACTIONS(757),
    [anon_sym_bytes] = ACTIONS(757),
    [anon_sym_bytes1] = ACTIONS(757),
    [anon_sym_bytes2] = ACTIONS(757),
    [anon_sym_bytes3] = ACTIONS(757),
    [anon_sym_bytes4] = ACTIONS(757),
    [anon_sym_bytes5] = ACTIONS(757),
    [anon_sym_bytes6] = ACTIONS(757),
    [anon_sym_bytes7] = ACTIONS(757),
    [anon_sym_bytes8] = ACTIONS(757),
    [anon_sym_bytes9] = ACTIONS(757),
    [anon_sym_bytes10] = ACTIONS(757),
    [anon_sym_bytes11] = ACTIONS(757),
    [anon_sym_bytes12] = ACTIONS(757),
    [anon_sym_bytes13] = ACTIONS(757),
    [anon_sym_bytes14] = ACTIONS(757),
    [anon_sym_bytes15] = ACTIONS(757),
    [anon_sym_bytes16] = ACTIONS(757),
    [anon_sym_bytes17] = ACTIONS(757),
    [anon_sym_bytes18] = ACTIONS(757),
    [anon_sym_bytes19] = ACTIONS(757),
    [anon_sym_bytes20] = ACTIONS(757),
    [anon_sym_bytes21] = ACTIONS(757),
    [anon_sym_bytes22] = ACTIONS(757),
    [anon_sym_bytes23] = ACTIONS(757),
    [anon_sym_bytes24] = ACTIONS(757),
    [anon_sym_bytes25] = ACTIONS(757),
    [anon_sym_bytes26] = ACTIONS(757),
    [anon_sym_bytes27] = ACTIONS(757),
    [anon_sym_bytes28] = ACTIONS(757),
    [anon_sym_bytes29] = ACTIONS(757),
    [anon_sym_bytes30] = ACTIONS(757),
    [anon_sym_bytes31] = ACTIONS(757),
    [anon_sym_bytes32] = ACTIONS(757),
    [anon_sym_fixed] = ACTIONS(757),
    [aux_sym__fixed_token1] = ACTIONS(757),
    [anon_sym_ufixed] = ACTIONS(757),
    [aux_sym__ufixed_token1] = ACTIONS(757),
    [sym_comment] = ACTIONS(3),
  },
  [195] = {
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_identifier] = ACTIONS(761),
    [anon_sym_pragma] = ACTIONS(761),
    [anon_sym_import] = ACTIONS(761),
    [anon_sym_type] = ACTIONS(761),
    [anon_sym_abstract] = ACTIONS(761),
    [anon_sym_contract] = ACTIONS(761),
    [anon_sym_error] = ACTIONS(761),
    [anon_sym_interface] = ACTIONS(761),
    [anon_sym_library] = ACTIONS(761),
    [anon_sym_struct] = ACTIONS(761),
    [anon_sym_enum] = ACTIONS(761),
    [anon_sym_using] = ACTIONS(761),
    [anon_sym_function] = ACTIONS(761),
    [anon_sym_byte] = ACTIONS(761),
    [anon_sym_address] = ACTIONS(761),
    [anon_sym_var] = ACTIONS(761),
    [anon_sym_mapping] = ACTIONS(761),
    [anon_sym_bool] = ACTIONS(761),
    [anon_sym_string] = ACTIONS(761),
    [anon_sym_int] = ACTIONS(761),
    [anon_sym_int8] = ACTIONS(761),
    [anon_sym_int16] = ACTIONS(761),
    [anon_sym_int24] = ACTIONS(761),
    [anon_sym_int32] = ACTIONS(761),
    [anon_sym_int40] = ACTIONS(761),
    [anon_sym_int48] = ACTIONS(761),
    [anon_sym_int56] = ACTIONS(761),
    [anon_sym_int64] = ACTIONS(761),
    [anon_sym_int72] = ACTIONS(761),
    [anon_sym_int80] = ACTIONS(761),
    [anon_sym_int88] = ACTIONS(761),
    [anon_sym_int96] = ACTIONS(761),
    [anon_sym_int104] = ACTIONS(761),
    [anon_sym_int112] = ACTIONS(761),
    [anon_sym_int120] = ACTIONS(761),
    [anon_sym_int128] = ACTIONS(761),
    [anon_sym_int136] = ACTIONS(761),
    [anon_sym_int144] = ACTIONS(761),
    [anon_sym_int152] = ACTIONS(761),
    [anon_sym_int160] = ACTIONS(761),
    [anon_sym_int168] = ACTIONS(761),
    [anon_sym_int176] = ACTIONS(761),
    [anon_sym_int184] = ACTIONS(761),
    [anon_sym_int192] = ACTIONS(761),
    [anon_sym_int200] = ACTIONS(761),
    [anon_sym_int208] = ACTIONS(761),
    [anon_sym_int216] = ACTIONS(761),
    [anon_sym_int224] = ACTIONS(761),
    [anon_sym_int232] = ACTIONS(761),
    [anon_sym_int240] = ACTIONS(761),
    [anon_sym_int248] = ACTIONS(761),
    [anon_sym_int256] = ACTIONS(761),
    [anon_sym_uint] = ACTIONS(761),
    [anon_sym_uint8] = ACTIONS(761),
    [anon_sym_uint16] = ACTIONS(761),
    [anon_sym_uint24] = ACTIONS(761),
    [anon_sym_uint32] = ACTIONS(761),
    [anon_sym_uint40] = ACTIONS(761),
    [anon_sym_uint48] = ACTIONS(761),
    [anon_sym_uint56] = ACTIONS(761),
    [anon_sym_uint64] = ACTIONS(761),
    [anon_sym_uint72] = ACTIONS(761),
    [anon_sym_uint80] = ACTIONS(761),
    [anon_sym_uint88] = ACTIONS(761),
    [anon_sym_uint96] = ACTIONS(761),
    [anon_sym_uint104] = ACTIONS(761),
    [anon_sym_uint112] = ACTIONS(761),
    [anon_sym_uint120] = ACTIONS(761),
    [anon_sym_uint128] = ACTIONS(761),
    [anon_sym_uint136] = ACTIONS(761),
    [anon_sym_uint144] = ACTIONS(761),
    [anon_sym_uint152] = ACTIONS(761),
    [anon_sym_uint160] = ACTIONS(761),
    [anon_sym_uint168] = ACTIONS(761),
    [anon_sym_uint176] = ACTIONS(761),
    [anon_sym_uint184] = ACTIONS(761),
    [anon_sym_uint192] = ACTIONS(761),
    [anon_sym_uint200] = ACTIONS(761),
    [anon_sym_uint208] = ACTIONS(761),
    [anon_sym_uint216] = ACTIONS(761),
    [anon_sym_uint224] = ACTIONS(761),
    [anon_sym_uint232] = ACTIONS(761),
    [anon_sym_uint240] = ACTIONS(761),
    [anon_sym_uint248] = ACTIONS(761),
    [anon_sym_uint256] = ACTIONS(761),
    [anon_sym_bytes] = ACTIONS(761),
    [anon_sym_bytes1] = ACTIONS(761),
    [anon_sym_bytes2] = ACTIONS(761),
    [anon_sym_bytes3] = ACTIONS(761),
    [anon_sym_bytes4] = ACTIONS(761),
    [anon_sym_bytes5] = ACTIONS(761),
    [anon_sym_bytes6] = ACTIONS(761),
    [anon_sym_bytes7] = ACTIONS(761),
    [anon_sym_bytes8] = ACTIONS(761),
    [anon_sym_bytes9] = ACTIONS(761),
    [anon_sym_bytes10] = ACTIONS(761),
    [anon_sym_bytes11] = ACTIONS(761),
    [anon_sym_bytes12] = ACTIONS(761),
    [anon_sym_bytes13] = ACTIONS(761),
    [anon_sym_bytes14] = ACTIONS(761),
    [anon_sym_bytes15] = ACTIONS(761),
    [anon_sym_bytes16] = ACTIONS(761),
    [anon_sym_bytes17] = ACTIONS(761),
    [anon_sym_bytes18] = ACTIONS(761),
    [anon_sym_bytes19] = ACTIONS(761),
    [anon_sym_bytes20] = ACTIONS(761),
    [anon_sym_bytes21] = ACTIONS(761),
    [anon_sym_bytes22] = ACTIONS(761),
    [anon_sym_bytes23] = ACTIONS(761),
    [anon_sym_bytes24] = ACTIONS(761),
    [anon_sym_bytes25] = ACTIONS(761),
    [anon_sym_bytes26] = ACTIONS(761),
    [anon_sym_bytes27] = ACTIONS(761),
    [anon_sym_bytes28] = ACTIONS(761),
    [anon_sym_bytes29] = ACTIONS(761),
    [anon_sym_bytes30] = ACTIONS(761),
    [anon_sym_bytes31] = ACTIONS(761),
    [anon_sym_bytes32] = ACTIONS(761),
    [anon_sym_fixed] = ACTIONS(761),
    [aux_sym__fixed_token1] = ACTIONS(761),
    [anon_sym_ufixed] = ACTIONS(761),
    [aux_sym__ufixed_token1] = ACTIONS(761),
    [sym_comment] = ACTIONS(3),
  },
  [196] = {
    [sym_type_name] = STATE(887),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [197] = {
    [ts_builtin_sym_end] = ACTIONS(763),
    [sym_identifier] = ACTIONS(765),
    [anon_sym_pragma] = ACTIONS(765),
    [anon_sym_import] = ACTIONS(765),
    [anon_sym_type] = ACTIONS(765),
    [anon_sym_abstract] = ACTIONS(765),
    [anon_sym_contract] = ACTIONS(765),
    [anon_sym_error] = ACTIONS(765),
    [anon_sym_interface] = ACTIONS(765),
    [anon_sym_library] = ACTIONS(765),
    [anon_sym_struct] = ACTIONS(765),
    [anon_sym_enum] = ACTIONS(765),
    [anon_sym_using] = ACTIONS(765),
    [anon_sym_function] = ACTIONS(765),
    [anon_sym_byte] = ACTIONS(765),
    [anon_sym_address] = ACTIONS(765),
    [anon_sym_var] = ACTIONS(765),
    [anon_sym_mapping] = ACTIONS(765),
    [anon_sym_bool] = ACTIONS(765),
    [anon_sym_string] = ACTIONS(765),
    [anon_sym_int] = ACTIONS(765),
    [anon_sym_int8] = ACTIONS(765),
    [anon_sym_int16] = ACTIONS(765),
    [anon_sym_int24] = ACTIONS(765),
    [anon_sym_int32] = ACTIONS(765),
    [anon_sym_int40] = ACTIONS(765),
    [anon_sym_int48] = ACTIONS(765),
    [anon_sym_int56] = ACTIONS(765),
    [anon_sym_int64] = ACTIONS(765),
    [anon_sym_int72] = ACTIONS(765),
    [anon_sym_int80] = ACTIONS(765),
    [anon_sym_int88] = ACTIONS(765),
    [anon_sym_int96] = ACTIONS(765),
    [anon_sym_int104] = ACTIONS(765),
    [anon_sym_int112] = ACTIONS(765),
    [anon_sym_int120] = ACTIONS(765),
    [anon_sym_int128] = ACTIONS(765),
    [anon_sym_int136] = ACTIONS(765),
    [anon_sym_int144] = ACTIONS(765),
    [anon_sym_int152] = ACTIONS(765),
    [anon_sym_int160] = ACTIONS(765),
    [anon_sym_int168] = ACTIONS(765),
    [anon_sym_int176] = ACTIONS(765),
    [anon_sym_int184] = ACTIONS(765),
    [anon_sym_int192] = ACTIONS(765),
    [anon_sym_int200] = ACTIONS(765),
    [anon_sym_int208] = ACTIONS(765),
    [anon_sym_int216] = ACTIONS(765),
    [anon_sym_int224] = ACTIONS(765),
    [anon_sym_int232] = ACTIONS(765),
    [anon_sym_int240] = ACTIONS(765),
    [anon_sym_int248] = ACTIONS(765),
    [anon_sym_int256] = ACTIONS(765),
    [anon_sym_uint] = ACTIONS(765),
    [anon_sym_uint8] = ACTIONS(765),
    [anon_sym_uint16] = ACTIONS(765),
    [anon_sym_uint24] = ACTIONS(765),
    [anon_sym_uint32] = ACTIONS(765),
    [anon_sym_uint40] = ACTIONS(765),
    [anon_sym_uint48] = ACTIONS(765),
    [anon_sym_uint56] = ACTIONS(765),
    [anon_sym_uint64] = ACTIONS(765),
    [anon_sym_uint72] = ACTIONS(765),
    [anon_sym_uint80] = ACTIONS(765),
    [anon_sym_uint88] = ACTIONS(765),
    [anon_sym_uint96] = ACTIONS(765),
    [anon_sym_uint104] = ACTIONS(765),
    [anon_sym_uint112] = ACTIONS(765),
    [anon_sym_uint120] = ACTIONS(765),
    [anon_sym_uint128] = ACTIONS(765),
    [anon_sym_uint136] = ACTIONS(765),
    [anon_sym_uint144] = ACTIONS(765),
    [anon_sym_uint152] = ACTIONS(765),
    [anon_sym_uint160] = ACTIONS(765),
    [anon_sym_uint168] = ACTIONS(765),
    [anon_sym_uint176] = ACTIONS(765),
    [anon_sym_uint184] = ACTIONS(765),
    [anon_sym_uint192] = ACTIONS(765),
    [anon_sym_uint200] = ACTIONS(765),
    [anon_sym_uint208] = ACTIONS(765),
    [anon_sym_uint216] = ACTIONS(765),
    [anon_sym_uint224] = ACTIONS(765),
    [anon_sym_uint232] = ACTIONS(765),
    [anon_sym_uint240] = ACTIONS(765),
    [anon_sym_uint248] = ACTIONS(765),
    [anon_sym_uint256] = ACTIONS(765),
    [anon_sym_bytes] = ACTIONS(765),
    [anon_sym_bytes1] = ACTIONS(765),
    [anon_sym_bytes2] = ACTIONS(765),
    [anon_sym_bytes3] = ACTIONS(765),
    [anon_sym_bytes4] = ACTIONS(765),
    [anon_sym_bytes5] = ACTIONS(765),
    [anon_sym_bytes6] = ACTIONS(765),
    [anon_sym_bytes7] = ACTIONS(765),
    [anon_sym_bytes8] = ACTIONS(765),
    [anon_sym_bytes9] = ACTIONS(765),
    [anon_sym_bytes10] = ACTIONS(765),
    [anon_sym_bytes11] = ACTIONS(765),
    [anon_sym_bytes12] = ACTIONS(765),
    [anon_sym_bytes13] = ACTIONS(765),
    [anon_sym_bytes14] = ACTIONS(765),
    [anon_sym_bytes15] = ACTIONS(765),
    [anon_sym_bytes16] = ACTIONS(765),
    [anon_sym_bytes17] = ACTIONS(765),
    [anon_sym_bytes18] = ACTIONS(765),
    [anon_sym_bytes19] = ACTIONS(765),
    [anon_sym_bytes20] = ACTIONS(765),
    [anon_sym_bytes21] = ACTIONS(765),
    [anon_sym_bytes22] = ACTIONS(765),
    [anon_sym_bytes23] = ACTIONS(765),
    [anon_sym_bytes24] = ACTIONS(765),
    [anon_sym_bytes25] = ACTIONS(765),
    [anon_sym_bytes26] = ACTIONS(765),
    [anon_sym_bytes27] = ACTIONS(765),
    [anon_sym_bytes28] = ACTIONS(765),
    [anon_sym_bytes29] = ACTIONS(765),
    [anon_sym_bytes30] = ACTIONS(765),
    [anon_sym_bytes31] = ACTIONS(765),
    [anon_sym_bytes32] = ACTIONS(765),
    [anon_sym_fixed] = ACTIONS(765),
    [aux_sym__fixed_token1] = ACTIONS(765),
    [anon_sym_ufixed] = ACTIONS(765),
    [aux_sym__ufixed_token1] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
  },
  [198] = {
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_pragma] = ACTIONS(769),
    [anon_sym_import] = ACTIONS(769),
    [anon_sym_type] = ACTIONS(769),
    [anon_sym_abstract] = ACTIONS(769),
    [anon_sym_contract] = ACTIONS(769),
    [anon_sym_error] = ACTIONS(769),
    [anon_sym_interface] = ACTIONS(769),
    [anon_sym_library] = ACTIONS(769),
    [anon_sym_struct] = ACTIONS(769),
    [anon_sym_enum] = ACTIONS(769),
    [anon_sym_using] = ACTIONS(769),
    [anon_sym_function] = ACTIONS(769),
    [anon_sym_byte] = ACTIONS(769),
    [anon_sym_address] = ACTIONS(769),
    [anon_sym_var] = ACTIONS(769),
    [anon_sym_mapping] = ACTIONS(769),
    [anon_sym_bool] = ACTIONS(769),
    [anon_sym_string] = ACTIONS(769),
    [anon_sym_int] = ACTIONS(769),
    [anon_sym_int8] = ACTIONS(769),
    [anon_sym_int16] = ACTIONS(769),
    [anon_sym_int24] = ACTIONS(769),
    [anon_sym_int32] = ACTIONS(769),
    [anon_sym_int40] = ACTIONS(769),
    [anon_sym_int48] = ACTIONS(769),
    [anon_sym_int56] = ACTIONS(769),
    [anon_sym_int64] = ACTIONS(769),
    [anon_sym_int72] = ACTIONS(769),
    [anon_sym_int80] = ACTIONS(769),
    [anon_sym_int88] = ACTIONS(769),
    [anon_sym_int96] = ACTIONS(769),
    [anon_sym_int104] = ACTIONS(769),
    [anon_sym_int112] = ACTIONS(769),
    [anon_sym_int120] = ACTIONS(769),
    [anon_sym_int128] = ACTIONS(769),
    [anon_sym_int136] = ACTIONS(769),
    [anon_sym_int144] = ACTIONS(769),
    [anon_sym_int152] = ACTIONS(769),
    [anon_sym_int160] = ACTIONS(769),
    [anon_sym_int168] = ACTIONS(769),
    [anon_sym_int176] = ACTIONS(769),
    [anon_sym_int184] = ACTIONS(769),
    [anon_sym_int192] = ACTIONS(769),
    [anon_sym_int200] = ACTIONS(769),
    [anon_sym_int208] = ACTIONS(769),
    [anon_sym_int216] = ACTIONS(769),
    [anon_sym_int224] = ACTIONS(769),
    [anon_sym_int232] = ACTIONS(769),
    [anon_sym_int240] = ACTIONS(769),
    [anon_sym_int248] = ACTIONS(769),
    [anon_sym_int256] = ACTIONS(769),
    [anon_sym_uint] = ACTIONS(769),
    [anon_sym_uint8] = ACTIONS(769),
    [anon_sym_uint16] = ACTIONS(769),
    [anon_sym_uint24] = ACTIONS(769),
    [anon_sym_uint32] = ACTIONS(769),
    [anon_sym_uint40] = ACTIONS(769),
    [anon_sym_uint48] = ACTIONS(769),
    [anon_sym_uint56] = ACTIONS(769),
    [anon_sym_uint64] = ACTIONS(769),
    [anon_sym_uint72] = ACTIONS(769),
    [anon_sym_uint80] = ACTIONS(769),
    [anon_sym_uint88] = ACTIONS(769),
    [anon_sym_uint96] = ACTIONS(769),
    [anon_sym_uint104] = ACTIONS(769),
    [anon_sym_uint112] = ACTIONS(769),
    [anon_sym_uint120] = ACTIONS(769),
    [anon_sym_uint128] = ACTIONS(769),
    [anon_sym_uint136] = ACTIONS(769),
    [anon_sym_uint144] = ACTIONS(769),
    [anon_sym_uint152] = ACTIONS(769),
    [anon_sym_uint160] = ACTIONS(769),
    [anon_sym_uint168] = ACTIONS(769),
    [anon_sym_uint176] = ACTIONS(769),
    [anon_sym_uint184] = ACTIONS(769),
    [anon_sym_uint192] = ACTIONS(769),
    [anon_sym_uint200] = ACTIONS(769),
    [anon_sym_uint208] = ACTIONS(769),
    [anon_sym_uint216] = ACTIONS(769),
    [anon_sym_uint224] = ACTIONS(769),
    [anon_sym_uint232] = ACTIONS(769),
    [anon_sym_uint240] = ACTIONS(769),
    [anon_sym_uint248] = ACTIONS(769),
    [anon_sym_uint256] = ACTIONS(769),
    [anon_sym_bytes] = ACTIONS(769),
    [anon_sym_bytes1] = ACTIONS(769),
    [anon_sym_bytes2] = ACTIONS(769),
    [anon_sym_bytes3] = ACTIONS(769),
    [anon_sym_bytes4] = ACTIONS(769),
    [anon_sym_bytes5] = ACTIONS(769),
    [anon_sym_bytes6] = ACTIONS(769),
    [anon_sym_bytes7] = ACTIONS(769),
    [anon_sym_bytes8] = ACTIONS(769),
    [anon_sym_bytes9] = ACTIONS(769),
    [anon_sym_bytes10] = ACTIONS(769),
    [anon_sym_bytes11] = ACTIONS(769),
    [anon_sym_bytes12] = ACTIONS(769),
    [anon_sym_bytes13] = ACTIONS(769),
    [anon_sym_bytes14] = ACTIONS(769),
    [anon_sym_bytes15] = ACTIONS(769),
    [anon_sym_bytes16] = ACTIONS(769),
    [anon_sym_bytes17] = ACTIONS(769),
    [anon_sym_bytes18] = ACTIONS(769),
    [anon_sym_bytes19] = ACTIONS(769),
    [anon_sym_bytes20] = ACTIONS(769),
    [anon_sym_bytes21] = ACTIONS(769),
    [anon_sym_bytes22] = ACTIONS(769),
    [anon_sym_bytes23] = ACTIONS(769),
    [anon_sym_bytes24] = ACTIONS(769),
    [anon_sym_bytes25] = ACTIONS(769),
    [anon_sym_bytes26] = ACTIONS(769),
    [anon_sym_bytes27] = ACTIONS(769),
    [anon_sym_bytes28] = ACTIONS(769),
    [anon_sym_bytes29] = ACTIONS(769),
    [anon_sym_bytes30] = ACTIONS(769),
    [anon_sym_bytes31] = ACTIONS(769),
    [anon_sym_bytes32] = ACTIONS(769),
    [anon_sym_fixed] = ACTIONS(769),
    [aux_sym__fixed_token1] = ACTIONS(769),
    [anon_sym_ufixed] = ACTIONS(769),
    [aux_sym__ufixed_token1] = ACTIONS(769),
    [sym_comment] = ACTIONS(3),
  },
  [199] = {
    [ts_builtin_sym_end] = ACTIONS(771),
    [sym_identifier] = ACTIONS(773),
    [anon_sym_pragma] = ACTIONS(773),
    [anon_sym_import] = ACTIONS(773),
    [anon_sym_type] = ACTIONS(773),
    [anon_sym_abstract] = ACTIONS(773),
    [anon_sym_contract] = ACTIONS(773),
    [anon_sym_error] = ACTIONS(773),
    [anon_sym_interface] = ACTIONS(773),
    [anon_sym_library] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(773),
    [anon_sym_enum] = ACTIONS(773),
    [anon_sym_using] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(773),
    [anon_sym_byte] = ACTIONS(773),
    [anon_sym_address] = ACTIONS(773),
    [anon_sym_var] = ACTIONS(773),
    [anon_sym_mapping] = ACTIONS(773),
    [anon_sym_bool] = ACTIONS(773),
    [anon_sym_string] = ACTIONS(773),
    [anon_sym_int] = ACTIONS(773),
    [anon_sym_int8] = ACTIONS(773),
    [anon_sym_int16] = ACTIONS(773),
    [anon_sym_int24] = ACTIONS(773),
    [anon_sym_int32] = ACTIONS(773),
    [anon_sym_int40] = ACTIONS(773),
    [anon_sym_int48] = ACTIONS(773),
    [anon_sym_int56] = ACTIONS(773),
    [anon_sym_int64] = ACTIONS(773),
    [anon_sym_int72] = ACTIONS(773),
    [anon_sym_int80] = ACTIONS(773),
    [anon_sym_int88] = ACTIONS(773),
    [anon_sym_int96] = ACTIONS(773),
    [anon_sym_int104] = ACTIONS(773),
    [anon_sym_int112] = ACTIONS(773),
    [anon_sym_int120] = ACTIONS(773),
    [anon_sym_int128] = ACTIONS(773),
    [anon_sym_int136] = ACTIONS(773),
    [anon_sym_int144] = ACTIONS(773),
    [anon_sym_int152] = ACTIONS(773),
    [anon_sym_int160] = ACTIONS(773),
    [anon_sym_int168] = ACTIONS(773),
    [anon_sym_int176] = ACTIONS(773),
    [anon_sym_int184] = ACTIONS(773),
    [anon_sym_int192] = ACTIONS(773),
    [anon_sym_int200] = ACTIONS(773),
    [anon_sym_int208] = ACTIONS(773),
    [anon_sym_int216] = ACTIONS(773),
    [anon_sym_int224] = ACTIONS(773),
    [anon_sym_int232] = ACTIONS(773),
    [anon_sym_int240] = ACTIONS(773),
    [anon_sym_int248] = ACTIONS(773),
    [anon_sym_int256] = ACTIONS(773),
    [anon_sym_uint] = ACTIONS(773),
    [anon_sym_uint8] = ACTIONS(773),
    [anon_sym_uint16] = ACTIONS(773),
    [anon_sym_uint24] = ACTIONS(773),
    [anon_sym_uint32] = ACTIONS(773),
    [anon_sym_uint40] = ACTIONS(773),
    [anon_sym_uint48] = ACTIONS(773),
    [anon_sym_uint56] = ACTIONS(773),
    [anon_sym_uint64] = ACTIONS(773),
    [anon_sym_uint72] = ACTIONS(773),
    [anon_sym_uint80] = ACTIONS(773),
    [anon_sym_uint88] = ACTIONS(773),
    [anon_sym_uint96] = ACTIONS(773),
    [anon_sym_uint104] = ACTIONS(773),
    [anon_sym_uint112] = ACTIONS(773),
    [anon_sym_uint120] = ACTIONS(773),
    [anon_sym_uint128] = ACTIONS(773),
    [anon_sym_uint136] = ACTIONS(773),
    [anon_sym_uint144] = ACTIONS(773),
    [anon_sym_uint152] = ACTIONS(773),
    [anon_sym_uint160] = ACTIONS(773),
    [anon_sym_uint168] = ACTIONS(773),
    [anon_sym_uint176] = ACTIONS(773),
    [anon_sym_uint184] = ACTIONS(773),
    [anon_sym_uint192] = ACTIONS(773),
    [anon_sym_uint200] = ACTIONS(773),
    [anon_sym_uint208] = ACTIONS(773),
    [anon_sym_uint216] = ACTIONS(773),
    [anon_sym_uint224] = ACTIONS(773),
    [anon_sym_uint232] = ACTIONS(773),
    [anon_sym_uint240] = ACTIONS(773),
    [anon_sym_uint248] = ACTIONS(773),
    [anon_sym_uint256] = ACTIONS(773),
    [anon_sym_bytes] = ACTIONS(773),
    [anon_sym_bytes1] = ACTIONS(773),
    [anon_sym_bytes2] = ACTIONS(773),
    [anon_sym_bytes3] = ACTIONS(773),
    [anon_sym_bytes4] = ACTIONS(773),
    [anon_sym_bytes5] = ACTIONS(773),
    [anon_sym_bytes6] = ACTIONS(773),
    [anon_sym_bytes7] = ACTIONS(773),
    [anon_sym_bytes8] = ACTIONS(773),
    [anon_sym_bytes9] = ACTIONS(773),
    [anon_sym_bytes10] = ACTIONS(773),
    [anon_sym_bytes11] = ACTIONS(773),
    [anon_sym_bytes12] = ACTIONS(773),
    [anon_sym_bytes13] = ACTIONS(773),
    [anon_sym_bytes14] = ACTIONS(773),
    [anon_sym_bytes15] = ACTIONS(773),
    [anon_sym_bytes16] = ACTIONS(773),
    [anon_sym_bytes17] = ACTIONS(773),
    [anon_sym_bytes18] = ACTIONS(773),
    [anon_sym_bytes19] = ACTIONS(773),
    [anon_sym_bytes20] = ACTIONS(773),
    [anon_sym_bytes21] = ACTIONS(773),
    [anon_sym_bytes22] = ACTIONS(773),
    [anon_sym_bytes23] = ACTIONS(773),
    [anon_sym_bytes24] = ACTIONS(773),
    [anon_sym_bytes25] = ACTIONS(773),
    [anon_sym_bytes26] = ACTIONS(773),
    [anon_sym_bytes27] = ACTIONS(773),
    [anon_sym_bytes28] = ACTIONS(773),
    [anon_sym_bytes29] = ACTIONS(773),
    [anon_sym_bytes30] = ACTIONS(773),
    [anon_sym_bytes31] = ACTIONS(773),
    [anon_sym_bytes32] = ACTIONS(773),
    [anon_sym_fixed] = ACTIONS(773),
    [aux_sym__fixed_token1] = ACTIONS(773),
    [anon_sym_ufixed] = ACTIONS(773),
    [aux_sym__ufixed_token1] = ACTIONS(773),
    [sym_comment] = ACTIONS(3),
  },
  [200] = {
    [ts_builtin_sym_end] = ACTIONS(775),
    [sym_identifier] = ACTIONS(777),
    [anon_sym_pragma] = ACTIONS(777),
    [anon_sym_import] = ACTIONS(777),
    [anon_sym_type] = ACTIONS(777),
    [anon_sym_abstract] = ACTIONS(777),
    [anon_sym_contract] = ACTIONS(777),
    [anon_sym_error] = ACTIONS(777),
    [anon_sym_interface] = ACTIONS(777),
    [anon_sym_library] = ACTIONS(777),
    [anon_sym_struct] = ACTIONS(777),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_using] = ACTIONS(777),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_byte] = ACTIONS(777),
    [anon_sym_address] = ACTIONS(777),
    [anon_sym_var] = ACTIONS(777),
    [anon_sym_mapping] = ACTIONS(777),
    [anon_sym_bool] = ACTIONS(777),
    [anon_sym_string] = ACTIONS(777),
    [anon_sym_int] = ACTIONS(777),
    [anon_sym_int8] = ACTIONS(777),
    [anon_sym_int16] = ACTIONS(777),
    [anon_sym_int24] = ACTIONS(777),
    [anon_sym_int32] = ACTIONS(777),
    [anon_sym_int40] = ACTIONS(777),
    [anon_sym_int48] = ACTIONS(777),
    [anon_sym_int56] = ACTIONS(777),
    [anon_sym_int64] = ACTIONS(777),
    [anon_sym_int72] = ACTIONS(777),
    [anon_sym_int80] = ACTIONS(777),
    [anon_sym_int88] = ACTIONS(777),
    [anon_sym_int96] = ACTIONS(777),
    [anon_sym_int104] = ACTIONS(777),
    [anon_sym_int112] = ACTIONS(777),
    [anon_sym_int120] = ACTIONS(777),
    [anon_sym_int128] = ACTIONS(777),
    [anon_sym_int136] = ACTIONS(777),
    [anon_sym_int144] = ACTIONS(777),
    [anon_sym_int152] = ACTIONS(777),
    [anon_sym_int160] = ACTIONS(777),
    [anon_sym_int168] = ACTIONS(777),
    [anon_sym_int176] = ACTIONS(777),
    [anon_sym_int184] = ACTIONS(777),
    [anon_sym_int192] = ACTIONS(777),
    [anon_sym_int200] = ACTIONS(777),
    [anon_sym_int208] = ACTIONS(777),
    [anon_sym_int216] = ACTIONS(777),
    [anon_sym_int224] = ACTIONS(777),
    [anon_sym_int232] = ACTIONS(777),
    [anon_sym_int240] = ACTIONS(777),
    [anon_sym_int248] = ACTIONS(777),
    [anon_sym_int256] = ACTIONS(777),
    [anon_sym_uint] = ACTIONS(777),
    [anon_sym_uint8] = ACTIONS(777),
    [anon_sym_uint16] = ACTIONS(777),
    [anon_sym_uint24] = ACTIONS(777),
    [anon_sym_uint32] = ACTIONS(777),
    [anon_sym_uint40] = ACTIONS(777),
    [anon_sym_uint48] = ACTIONS(777),
    [anon_sym_uint56] = ACTIONS(777),
    [anon_sym_uint64] = ACTIONS(777),
    [anon_sym_uint72] = ACTIONS(777),
    [anon_sym_uint80] = ACTIONS(777),
    [anon_sym_uint88] = ACTIONS(777),
    [anon_sym_uint96] = ACTIONS(777),
    [anon_sym_uint104] = ACTIONS(777),
    [anon_sym_uint112] = ACTIONS(777),
    [anon_sym_uint120] = ACTIONS(777),
    [anon_sym_uint128] = ACTIONS(777),
    [anon_sym_uint136] = ACTIONS(777),
    [anon_sym_uint144] = ACTIONS(777),
    [anon_sym_uint152] = ACTIONS(777),
    [anon_sym_uint160] = ACTIONS(777),
    [anon_sym_uint168] = ACTIONS(777),
    [anon_sym_uint176] = ACTIONS(777),
    [anon_sym_uint184] = ACTIONS(777),
    [anon_sym_uint192] = ACTIONS(777),
    [anon_sym_uint200] = ACTIONS(777),
    [anon_sym_uint208] = ACTIONS(777),
    [anon_sym_uint216] = ACTIONS(777),
    [anon_sym_uint224] = ACTIONS(777),
    [anon_sym_uint232] = ACTIONS(777),
    [anon_sym_uint240] = ACTIONS(777),
    [anon_sym_uint248] = ACTIONS(777),
    [anon_sym_uint256] = ACTIONS(777),
    [anon_sym_bytes] = ACTIONS(777),
    [anon_sym_bytes1] = ACTIONS(777),
    [anon_sym_bytes2] = ACTIONS(777),
    [anon_sym_bytes3] = ACTIONS(777),
    [anon_sym_bytes4] = ACTIONS(777),
    [anon_sym_bytes5] = ACTIONS(777),
    [anon_sym_bytes6] = ACTIONS(777),
    [anon_sym_bytes7] = ACTIONS(777),
    [anon_sym_bytes8] = ACTIONS(777),
    [anon_sym_bytes9] = ACTIONS(777),
    [anon_sym_bytes10] = ACTIONS(777),
    [anon_sym_bytes11] = ACTIONS(777),
    [anon_sym_bytes12] = ACTIONS(777),
    [anon_sym_bytes13] = ACTIONS(777),
    [anon_sym_bytes14] = ACTIONS(777),
    [anon_sym_bytes15] = ACTIONS(777),
    [anon_sym_bytes16] = ACTIONS(777),
    [anon_sym_bytes17] = ACTIONS(777),
    [anon_sym_bytes18] = ACTIONS(777),
    [anon_sym_bytes19] = ACTIONS(777),
    [anon_sym_bytes20] = ACTIONS(777),
    [anon_sym_bytes21] = ACTIONS(777),
    [anon_sym_bytes22] = ACTIONS(777),
    [anon_sym_bytes23] = ACTIONS(777),
    [anon_sym_bytes24] = ACTIONS(777),
    [anon_sym_bytes25] = ACTIONS(777),
    [anon_sym_bytes26] = ACTIONS(777),
    [anon_sym_bytes27] = ACTIONS(777),
    [anon_sym_bytes28] = ACTIONS(777),
    [anon_sym_bytes29] = ACTIONS(777),
    [anon_sym_bytes30] = ACTIONS(777),
    [anon_sym_bytes31] = ACTIONS(777),
    [anon_sym_bytes32] = ACTIONS(777),
    [anon_sym_fixed] = ACTIONS(777),
    [aux_sym__fixed_token1] = ACTIONS(777),
    [anon_sym_ufixed] = ACTIONS(777),
    [aux_sym__ufixed_token1] = ACTIONS(777),
    [sym_comment] = ACTIONS(3),
  },
  [201] = {
    [ts_builtin_sym_end] = ACTIONS(779),
    [sym_identifier] = ACTIONS(781),
    [anon_sym_pragma] = ACTIONS(781),
    [anon_sym_import] = ACTIONS(781),
    [anon_sym_type] = ACTIONS(781),
    [anon_sym_abstract] = ACTIONS(781),
    [anon_sym_contract] = ACTIONS(781),
    [anon_sym_error] = ACTIONS(781),
    [anon_sym_interface] = ACTIONS(781),
    [anon_sym_library] = ACTIONS(781),
    [anon_sym_struct] = ACTIONS(781),
    [anon_sym_enum] = ACTIONS(781),
    [anon_sym_using] = ACTIONS(781),
    [anon_sym_function] = ACTIONS(781),
    [anon_sym_byte] = ACTIONS(781),
    [anon_sym_address] = ACTIONS(781),
    [anon_sym_var] = ACTIONS(781),
    [anon_sym_mapping] = ACTIONS(781),
    [anon_sym_bool] = ACTIONS(781),
    [anon_sym_string] = ACTIONS(781),
    [anon_sym_int] = ACTIONS(781),
    [anon_sym_int8] = ACTIONS(781),
    [anon_sym_int16] = ACTIONS(781),
    [anon_sym_int24] = ACTIONS(781),
    [anon_sym_int32] = ACTIONS(781),
    [anon_sym_int40] = ACTIONS(781),
    [anon_sym_int48] = ACTIONS(781),
    [anon_sym_int56] = ACTIONS(781),
    [anon_sym_int64] = ACTIONS(781),
    [anon_sym_int72] = ACTIONS(781),
    [anon_sym_int80] = ACTIONS(781),
    [anon_sym_int88] = ACTIONS(781),
    [anon_sym_int96] = ACTIONS(781),
    [anon_sym_int104] = ACTIONS(781),
    [anon_sym_int112] = ACTIONS(781),
    [anon_sym_int120] = ACTIONS(781),
    [anon_sym_int128] = ACTIONS(781),
    [anon_sym_int136] = ACTIONS(781),
    [anon_sym_int144] = ACTIONS(781),
    [anon_sym_int152] = ACTIONS(781),
    [anon_sym_int160] = ACTIONS(781),
    [anon_sym_int168] = ACTIONS(781),
    [anon_sym_int176] = ACTIONS(781),
    [anon_sym_int184] = ACTIONS(781),
    [anon_sym_int192] = ACTIONS(781),
    [anon_sym_int200] = ACTIONS(781),
    [anon_sym_int208] = ACTIONS(781),
    [anon_sym_int216] = ACTIONS(781),
    [anon_sym_int224] = ACTIONS(781),
    [anon_sym_int232] = ACTIONS(781),
    [anon_sym_int240] = ACTIONS(781),
    [anon_sym_int248] = ACTIONS(781),
    [anon_sym_int256] = ACTIONS(781),
    [anon_sym_uint] = ACTIONS(781),
    [anon_sym_uint8] = ACTIONS(781),
    [anon_sym_uint16] = ACTIONS(781),
    [anon_sym_uint24] = ACTIONS(781),
    [anon_sym_uint32] = ACTIONS(781),
    [anon_sym_uint40] = ACTIONS(781),
    [anon_sym_uint48] = ACTIONS(781),
    [anon_sym_uint56] = ACTIONS(781),
    [anon_sym_uint64] = ACTIONS(781),
    [anon_sym_uint72] = ACTIONS(781),
    [anon_sym_uint80] = ACTIONS(781),
    [anon_sym_uint88] = ACTIONS(781),
    [anon_sym_uint96] = ACTIONS(781),
    [anon_sym_uint104] = ACTIONS(781),
    [anon_sym_uint112] = ACTIONS(781),
    [anon_sym_uint120] = ACTIONS(781),
    [anon_sym_uint128] = ACTIONS(781),
    [anon_sym_uint136] = ACTIONS(781),
    [anon_sym_uint144] = ACTIONS(781),
    [anon_sym_uint152] = ACTIONS(781),
    [anon_sym_uint160] = ACTIONS(781),
    [anon_sym_uint168] = ACTIONS(781),
    [anon_sym_uint176] = ACTIONS(781),
    [anon_sym_uint184] = ACTIONS(781),
    [anon_sym_uint192] = ACTIONS(781),
    [anon_sym_uint200] = ACTIONS(781),
    [anon_sym_uint208] = ACTIONS(781),
    [anon_sym_uint216] = ACTIONS(781),
    [anon_sym_uint224] = ACTIONS(781),
    [anon_sym_uint232] = ACTIONS(781),
    [anon_sym_uint240] = ACTIONS(781),
    [anon_sym_uint248] = ACTIONS(781),
    [anon_sym_uint256] = ACTIONS(781),
    [anon_sym_bytes] = ACTIONS(781),
    [anon_sym_bytes1] = ACTIONS(781),
    [anon_sym_bytes2] = ACTIONS(781),
    [anon_sym_bytes3] = ACTIONS(781),
    [anon_sym_bytes4] = ACTIONS(781),
    [anon_sym_bytes5] = ACTIONS(781),
    [anon_sym_bytes6] = ACTIONS(781),
    [anon_sym_bytes7] = ACTIONS(781),
    [anon_sym_bytes8] = ACTIONS(781),
    [anon_sym_bytes9] = ACTIONS(781),
    [anon_sym_bytes10] = ACTIONS(781),
    [anon_sym_bytes11] = ACTIONS(781),
    [anon_sym_bytes12] = ACTIONS(781),
    [anon_sym_bytes13] = ACTIONS(781),
    [anon_sym_bytes14] = ACTIONS(781),
    [anon_sym_bytes15] = ACTIONS(781),
    [anon_sym_bytes16] = ACTIONS(781),
    [anon_sym_bytes17] = ACTIONS(781),
    [anon_sym_bytes18] = ACTIONS(781),
    [anon_sym_bytes19] = ACTIONS(781),
    [anon_sym_bytes20] = ACTIONS(781),
    [anon_sym_bytes21] = ACTIONS(781),
    [anon_sym_bytes22] = ACTIONS(781),
    [anon_sym_bytes23] = ACTIONS(781),
    [anon_sym_bytes24] = ACTIONS(781),
    [anon_sym_bytes25] = ACTIONS(781),
    [anon_sym_bytes26] = ACTIONS(781),
    [anon_sym_bytes27] = ACTIONS(781),
    [anon_sym_bytes28] = ACTIONS(781),
    [anon_sym_bytes29] = ACTIONS(781),
    [anon_sym_bytes30] = ACTIONS(781),
    [anon_sym_bytes31] = ACTIONS(781),
    [anon_sym_bytes32] = ACTIONS(781),
    [anon_sym_fixed] = ACTIONS(781),
    [aux_sym__fixed_token1] = ACTIONS(781),
    [anon_sym_ufixed] = ACTIONS(781),
    [aux_sym__ufixed_token1] = ACTIONS(781),
    [sym_comment] = ACTIONS(3),
  },
  [202] = {
    [ts_builtin_sym_end] = ACTIONS(783),
    [sym_identifier] = ACTIONS(785),
    [anon_sym_pragma] = ACTIONS(785),
    [anon_sym_import] = ACTIONS(785),
    [anon_sym_type] = ACTIONS(785),
    [anon_sym_abstract] = ACTIONS(785),
    [anon_sym_contract] = ACTIONS(785),
    [anon_sym_error] = ACTIONS(785),
    [anon_sym_interface] = ACTIONS(785),
    [anon_sym_library] = ACTIONS(785),
    [anon_sym_struct] = ACTIONS(785),
    [anon_sym_enum] = ACTIONS(785),
    [anon_sym_using] = ACTIONS(785),
    [anon_sym_function] = ACTIONS(785),
    [anon_sym_byte] = ACTIONS(785),
    [anon_sym_address] = ACTIONS(785),
    [anon_sym_var] = ACTIONS(785),
    [anon_sym_mapping] = ACTIONS(785),
    [anon_sym_bool] = ACTIONS(785),
    [anon_sym_string] = ACTIONS(785),
    [anon_sym_int] = ACTIONS(785),
    [anon_sym_int8] = ACTIONS(785),
    [anon_sym_int16] = ACTIONS(785),
    [anon_sym_int24] = ACTIONS(785),
    [anon_sym_int32] = ACTIONS(785),
    [anon_sym_int40] = ACTIONS(785),
    [anon_sym_int48] = ACTIONS(785),
    [anon_sym_int56] = ACTIONS(785),
    [anon_sym_int64] = ACTIONS(785),
    [anon_sym_int72] = ACTIONS(785),
    [anon_sym_int80] = ACTIONS(785),
    [anon_sym_int88] = ACTIONS(785),
    [anon_sym_int96] = ACTIONS(785),
    [anon_sym_int104] = ACTIONS(785),
    [anon_sym_int112] = ACTIONS(785),
    [anon_sym_int120] = ACTIONS(785),
    [anon_sym_int128] = ACTIONS(785),
    [anon_sym_int136] = ACTIONS(785),
    [anon_sym_int144] = ACTIONS(785),
    [anon_sym_int152] = ACTIONS(785),
    [anon_sym_int160] = ACTIONS(785),
    [anon_sym_int168] = ACTIONS(785),
    [anon_sym_int176] = ACTIONS(785),
    [anon_sym_int184] = ACTIONS(785),
    [anon_sym_int192] = ACTIONS(785),
    [anon_sym_int200] = ACTIONS(785),
    [anon_sym_int208] = ACTIONS(785),
    [anon_sym_int216] = ACTIONS(785),
    [anon_sym_int224] = ACTIONS(785),
    [anon_sym_int232] = ACTIONS(785),
    [anon_sym_int240] = ACTIONS(785),
    [anon_sym_int248] = ACTIONS(785),
    [anon_sym_int256] = ACTIONS(785),
    [anon_sym_uint] = ACTIONS(785),
    [anon_sym_uint8] = ACTIONS(785),
    [anon_sym_uint16] = ACTIONS(785),
    [anon_sym_uint24] = ACTIONS(785),
    [anon_sym_uint32] = ACTIONS(785),
    [anon_sym_uint40] = ACTIONS(785),
    [anon_sym_uint48] = ACTIONS(785),
    [anon_sym_uint56] = ACTIONS(785),
    [anon_sym_uint64] = ACTIONS(785),
    [anon_sym_uint72] = ACTIONS(785),
    [anon_sym_uint80] = ACTIONS(785),
    [anon_sym_uint88] = ACTIONS(785),
    [anon_sym_uint96] = ACTIONS(785),
    [anon_sym_uint104] = ACTIONS(785),
    [anon_sym_uint112] = ACTIONS(785),
    [anon_sym_uint120] = ACTIONS(785),
    [anon_sym_uint128] = ACTIONS(785),
    [anon_sym_uint136] = ACTIONS(785),
    [anon_sym_uint144] = ACTIONS(785),
    [anon_sym_uint152] = ACTIONS(785),
    [anon_sym_uint160] = ACTIONS(785),
    [anon_sym_uint168] = ACTIONS(785),
    [anon_sym_uint176] = ACTIONS(785),
    [anon_sym_uint184] = ACTIONS(785),
    [anon_sym_uint192] = ACTIONS(785),
    [anon_sym_uint200] = ACTIONS(785),
    [anon_sym_uint208] = ACTIONS(785),
    [anon_sym_uint216] = ACTIONS(785),
    [anon_sym_uint224] = ACTIONS(785),
    [anon_sym_uint232] = ACTIONS(785),
    [anon_sym_uint240] = ACTIONS(785),
    [anon_sym_uint248] = ACTIONS(785),
    [anon_sym_uint256] = ACTIONS(785),
    [anon_sym_bytes] = ACTIONS(785),
    [anon_sym_bytes1] = ACTIONS(785),
    [anon_sym_bytes2] = ACTIONS(785),
    [anon_sym_bytes3] = ACTIONS(785),
    [anon_sym_bytes4] = ACTIONS(785),
    [anon_sym_bytes5] = ACTIONS(785),
    [anon_sym_bytes6] = ACTIONS(785),
    [anon_sym_bytes7] = ACTIONS(785),
    [anon_sym_bytes8] = ACTIONS(785),
    [anon_sym_bytes9] = ACTIONS(785),
    [anon_sym_bytes10] = ACTIONS(785),
    [anon_sym_bytes11] = ACTIONS(785),
    [anon_sym_bytes12] = ACTIONS(785),
    [anon_sym_bytes13] = ACTIONS(785),
    [anon_sym_bytes14] = ACTIONS(785),
    [anon_sym_bytes15] = ACTIONS(785),
    [anon_sym_bytes16] = ACTIONS(785),
    [anon_sym_bytes17] = ACTIONS(785),
    [anon_sym_bytes18] = ACTIONS(785),
    [anon_sym_bytes19] = ACTIONS(785),
    [anon_sym_bytes20] = ACTIONS(785),
    [anon_sym_bytes21] = ACTIONS(785),
    [anon_sym_bytes22] = ACTIONS(785),
    [anon_sym_bytes23] = ACTIONS(785),
    [anon_sym_bytes24] = ACTIONS(785),
    [anon_sym_bytes25] = ACTIONS(785),
    [anon_sym_bytes26] = ACTIONS(785),
    [anon_sym_bytes27] = ACTIONS(785),
    [anon_sym_bytes28] = ACTIONS(785),
    [anon_sym_bytes29] = ACTIONS(785),
    [anon_sym_bytes30] = ACTIONS(785),
    [anon_sym_bytes31] = ACTIONS(785),
    [anon_sym_bytes32] = ACTIONS(785),
    [anon_sym_fixed] = ACTIONS(785),
    [aux_sym__fixed_token1] = ACTIONS(785),
    [anon_sym_ufixed] = ACTIONS(785),
    [aux_sym__ufixed_token1] = ACTIONS(785),
    [sym_comment] = ACTIONS(3),
  },
  [203] = {
    [ts_builtin_sym_end] = ACTIONS(787),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_pragma] = ACTIONS(789),
    [anon_sym_import] = ACTIONS(789),
    [anon_sym_type] = ACTIONS(789),
    [anon_sym_abstract] = ACTIONS(789),
    [anon_sym_contract] = ACTIONS(789),
    [anon_sym_error] = ACTIONS(789),
    [anon_sym_interface] = ACTIONS(789),
    [anon_sym_library] = ACTIONS(789),
    [anon_sym_struct] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(789),
    [anon_sym_using] = ACTIONS(789),
    [anon_sym_function] = ACTIONS(789),
    [anon_sym_byte] = ACTIONS(789),
    [anon_sym_address] = ACTIONS(789),
    [anon_sym_var] = ACTIONS(789),
    [anon_sym_mapping] = ACTIONS(789),
    [anon_sym_bool] = ACTIONS(789),
    [anon_sym_string] = ACTIONS(789),
    [anon_sym_int] = ACTIONS(789),
    [anon_sym_int8] = ACTIONS(789),
    [anon_sym_int16] = ACTIONS(789),
    [anon_sym_int24] = ACTIONS(789),
    [anon_sym_int32] = ACTIONS(789),
    [anon_sym_int40] = ACTIONS(789),
    [anon_sym_int48] = ACTIONS(789),
    [anon_sym_int56] = ACTIONS(789),
    [anon_sym_int64] = ACTIONS(789),
    [anon_sym_int72] = ACTIONS(789),
    [anon_sym_int80] = ACTIONS(789),
    [anon_sym_int88] = ACTIONS(789),
    [anon_sym_int96] = ACTIONS(789),
    [anon_sym_int104] = ACTIONS(789),
    [anon_sym_int112] = ACTIONS(789),
    [anon_sym_int120] = ACTIONS(789),
    [anon_sym_int128] = ACTIONS(789),
    [anon_sym_int136] = ACTIONS(789),
    [anon_sym_int144] = ACTIONS(789),
    [anon_sym_int152] = ACTIONS(789),
    [anon_sym_int160] = ACTIONS(789),
    [anon_sym_int168] = ACTIONS(789),
    [anon_sym_int176] = ACTIONS(789),
    [anon_sym_int184] = ACTIONS(789),
    [anon_sym_int192] = ACTIONS(789),
    [anon_sym_int200] = ACTIONS(789),
    [anon_sym_int208] = ACTIONS(789),
    [anon_sym_int216] = ACTIONS(789),
    [anon_sym_int224] = ACTIONS(789),
    [anon_sym_int232] = ACTIONS(789),
    [anon_sym_int240] = ACTIONS(789),
    [anon_sym_int248] = ACTIONS(789),
    [anon_sym_int256] = ACTIONS(789),
    [anon_sym_uint] = ACTIONS(789),
    [anon_sym_uint8] = ACTIONS(789),
    [anon_sym_uint16] = ACTIONS(789),
    [anon_sym_uint24] = ACTIONS(789),
    [anon_sym_uint32] = ACTIONS(789),
    [anon_sym_uint40] = ACTIONS(789),
    [anon_sym_uint48] = ACTIONS(789),
    [anon_sym_uint56] = ACTIONS(789),
    [anon_sym_uint64] = ACTIONS(789),
    [anon_sym_uint72] = ACTIONS(789),
    [anon_sym_uint80] = ACTIONS(789),
    [anon_sym_uint88] = ACTIONS(789),
    [anon_sym_uint96] = ACTIONS(789),
    [anon_sym_uint104] = ACTIONS(789),
    [anon_sym_uint112] = ACTIONS(789),
    [anon_sym_uint120] = ACTIONS(789),
    [anon_sym_uint128] = ACTIONS(789),
    [anon_sym_uint136] = ACTIONS(789),
    [anon_sym_uint144] = ACTIONS(789),
    [anon_sym_uint152] = ACTIONS(789),
    [anon_sym_uint160] = ACTIONS(789),
    [anon_sym_uint168] = ACTIONS(789),
    [anon_sym_uint176] = ACTIONS(789),
    [anon_sym_uint184] = ACTIONS(789),
    [anon_sym_uint192] = ACTIONS(789),
    [anon_sym_uint200] = ACTIONS(789),
    [anon_sym_uint208] = ACTIONS(789),
    [anon_sym_uint216] = ACTIONS(789),
    [anon_sym_uint224] = ACTIONS(789),
    [anon_sym_uint232] = ACTIONS(789),
    [anon_sym_uint240] = ACTIONS(789),
    [anon_sym_uint248] = ACTIONS(789),
    [anon_sym_uint256] = ACTIONS(789),
    [anon_sym_bytes] = ACTIONS(789),
    [anon_sym_bytes1] = ACTIONS(789),
    [anon_sym_bytes2] = ACTIONS(789),
    [anon_sym_bytes3] = ACTIONS(789),
    [anon_sym_bytes4] = ACTIONS(789),
    [anon_sym_bytes5] = ACTIONS(789),
    [anon_sym_bytes6] = ACTIONS(789),
    [anon_sym_bytes7] = ACTIONS(789),
    [anon_sym_bytes8] = ACTIONS(789),
    [anon_sym_bytes9] = ACTIONS(789),
    [anon_sym_bytes10] = ACTIONS(789),
    [anon_sym_bytes11] = ACTIONS(789),
    [anon_sym_bytes12] = ACTIONS(789),
    [anon_sym_bytes13] = ACTIONS(789),
    [anon_sym_bytes14] = ACTIONS(789),
    [anon_sym_bytes15] = ACTIONS(789),
    [anon_sym_bytes16] = ACTIONS(789),
    [anon_sym_bytes17] = ACTIONS(789),
    [anon_sym_bytes18] = ACTIONS(789),
    [anon_sym_bytes19] = ACTIONS(789),
    [anon_sym_bytes20] = ACTIONS(789),
    [anon_sym_bytes21] = ACTIONS(789),
    [anon_sym_bytes22] = ACTIONS(789),
    [anon_sym_bytes23] = ACTIONS(789),
    [anon_sym_bytes24] = ACTIONS(789),
    [anon_sym_bytes25] = ACTIONS(789),
    [anon_sym_bytes26] = ACTIONS(789),
    [anon_sym_bytes27] = ACTIONS(789),
    [anon_sym_bytes28] = ACTIONS(789),
    [anon_sym_bytes29] = ACTIONS(789),
    [anon_sym_bytes30] = ACTIONS(789),
    [anon_sym_bytes31] = ACTIONS(789),
    [anon_sym_bytes32] = ACTIONS(789),
    [anon_sym_fixed] = ACTIONS(789),
    [aux_sym__fixed_token1] = ACTIONS(789),
    [anon_sym_ufixed] = ACTIONS(789),
    [aux_sym__ufixed_token1] = ACTIONS(789),
    [sym_comment] = ACTIONS(3),
  },
  [204] = {
    [ts_builtin_sym_end] = ACTIONS(791),
    [sym_identifier] = ACTIONS(793),
    [anon_sym_pragma] = ACTIONS(793),
    [anon_sym_import] = ACTIONS(793),
    [anon_sym_type] = ACTIONS(793),
    [anon_sym_abstract] = ACTIONS(793),
    [anon_sym_contract] = ACTIONS(793),
    [anon_sym_error] = ACTIONS(793),
    [anon_sym_interface] = ACTIONS(793),
    [anon_sym_library] = ACTIONS(793),
    [anon_sym_struct] = ACTIONS(793),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_using] = ACTIONS(793),
    [anon_sym_function] = ACTIONS(793),
    [anon_sym_byte] = ACTIONS(793),
    [anon_sym_address] = ACTIONS(793),
    [anon_sym_var] = ACTIONS(793),
    [anon_sym_mapping] = ACTIONS(793),
    [anon_sym_bool] = ACTIONS(793),
    [anon_sym_string] = ACTIONS(793),
    [anon_sym_int] = ACTIONS(793),
    [anon_sym_int8] = ACTIONS(793),
    [anon_sym_int16] = ACTIONS(793),
    [anon_sym_int24] = ACTIONS(793),
    [anon_sym_int32] = ACTIONS(793),
    [anon_sym_int40] = ACTIONS(793),
    [anon_sym_int48] = ACTIONS(793),
    [anon_sym_int56] = ACTIONS(793),
    [anon_sym_int64] = ACTIONS(793),
    [anon_sym_int72] = ACTIONS(793),
    [anon_sym_int80] = ACTIONS(793),
    [anon_sym_int88] = ACTIONS(793),
    [anon_sym_int96] = ACTIONS(793),
    [anon_sym_int104] = ACTIONS(793),
    [anon_sym_int112] = ACTIONS(793),
    [anon_sym_int120] = ACTIONS(793),
    [anon_sym_int128] = ACTIONS(793),
    [anon_sym_int136] = ACTIONS(793),
    [anon_sym_int144] = ACTIONS(793),
    [anon_sym_int152] = ACTIONS(793),
    [anon_sym_int160] = ACTIONS(793),
    [anon_sym_int168] = ACTIONS(793),
    [anon_sym_int176] = ACTIONS(793),
    [anon_sym_int184] = ACTIONS(793),
    [anon_sym_int192] = ACTIONS(793),
    [anon_sym_int200] = ACTIONS(793),
    [anon_sym_int208] = ACTIONS(793),
    [anon_sym_int216] = ACTIONS(793),
    [anon_sym_int224] = ACTIONS(793),
    [anon_sym_int232] = ACTIONS(793),
    [anon_sym_int240] = ACTIONS(793),
    [anon_sym_int248] = ACTIONS(793),
    [anon_sym_int256] = ACTIONS(793),
    [anon_sym_uint] = ACTIONS(793),
    [anon_sym_uint8] = ACTIONS(793),
    [anon_sym_uint16] = ACTIONS(793),
    [anon_sym_uint24] = ACTIONS(793),
    [anon_sym_uint32] = ACTIONS(793),
    [anon_sym_uint40] = ACTIONS(793),
    [anon_sym_uint48] = ACTIONS(793),
    [anon_sym_uint56] = ACTIONS(793),
    [anon_sym_uint64] = ACTIONS(793),
    [anon_sym_uint72] = ACTIONS(793),
    [anon_sym_uint80] = ACTIONS(793),
    [anon_sym_uint88] = ACTIONS(793),
    [anon_sym_uint96] = ACTIONS(793),
    [anon_sym_uint104] = ACTIONS(793),
    [anon_sym_uint112] = ACTIONS(793),
    [anon_sym_uint120] = ACTIONS(793),
    [anon_sym_uint128] = ACTIONS(793),
    [anon_sym_uint136] = ACTIONS(793),
    [anon_sym_uint144] = ACTIONS(793),
    [anon_sym_uint152] = ACTIONS(793),
    [anon_sym_uint160] = ACTIONS(793),
    [anon_sym_uint168] = ACTIONS(793),
    [anon_sym_uint176] = ACTIONS(793),
    [anon_sym_uint184] = ACTIONS(793),
    [anon_sym_uint192] = ACTIONS(793),
    [anon_sym_uint200] = ACTIONS(793),
    [anon_sym_uint208] = ACTIONS(793),
    [anon_sym_uint216] = ACTIONS(793),
    [anon_sym_uint224] = ACTIONS(793),
    [anon_sym_uint232] = ACTIONS(793),
    [anon_sym_uint240] = ACTIONS(793),
    [anon_sym_uint248] = ACTIONS(793),
    [anon_sym_uint256] = ACTIONS(793),
    [anon_sym_bytes] = ACTIONS(793),
    [anon_sym_bytes1] = ACTIONS(793),
    [anon_sym_bytes2] = ACTIONS(793),
    [anon_sym_bytes3] = ACTIONS(793),
    [anon_sym_bytes4] = ACTIONS(793),
    [anon_sym_bytes5] = ACTIONS(793),
    [anon_sym_bytes6] = ACTIONS(793),
    [anon_sym_bytes7] = ACTIONS(793),
    [anon_sym_bytes8] = ACTIONS(793),
    [anon_sym_bytes9] = ACTIONS(793),
    [anon_sym_bytes10] = ACTIONS(793),
    [anon_sym_bytes11] = ACTIONS(793),
    [anon_sym_bytes12] = ACTIONS(793),
    [anon_sym_bytes13] = ACTIONS(793),
    [anon_sym_bytes14] = ACTIONS(793),
    [anon_sym_bytes15] = ACTIONS(793),
    [anon_sym_bytes16] = ACTIONS(793),
    [anon_sym_bytes17] = ACTIONS(793),
    [anon_sym_bytes18] = ACTIONS(793),
    [anon_sym_bytes19] = ACTIONS(793),
    [anon_sym_bytes20] = ACTIONS(793),
    [anon_sym_bytes21] = ACTIONS(793),
    [anon_sym_bytes22] = ACTIONS(793),
    [anon_sym_bytes23] = ACTIONS(793),
    [anon_sym_bytes24] = ACTIONS(793),
    [anon_sym_bytes25] = ACTIONS(793),
    [anon_sym_bytes26] = ACTIONS(793),
    [anon_sym_bytes27] = ACTIONS(793),
    [anon_sym_bytes28] = ACTIONS(793),
    [anon_sym_bytes29] = ACTIONS(793),
    [anon_sym_bytes30] = ACTIONS(793),
    [anon_sym_bytes31] = ACTIONS(793),
    [anon_sym_bytes32] = ACTIONS(793),
    [anon_sym_fixed] = ACTIONS(793),
    [aux_sym__fixed_token1] = ACTIONS(793),
    [anon_sym_ufixed] = ACTIONS(793),
    [aux_sym__ufixed_token1] = ACTIONS(793),
    [sym_comment] = ACTIONS(3),
  },
  [205] = {
    [ts_builtin_sym_end] = ACTIONS(795),
    [sym_identifier] = ACTIONS(797),
    [anon_sym_pragma] = ACTIONS(797),
    [anon_sym_import] = ACTIONS(797),
    [anon_sym_type] = ACTIONS(797),
    [anon_sym_abstract] = ACTIONS(797),
    [anon_sym_contract] = ACTIONS(797),
    [anon_sym_error] = ACTIONS(797),
    [anon_sym_interface] = ACTIONS(797),
    [anon_sym_library] = ACTIONS(797),
    [anon_sym_struct] = ACTIONS(797),
    [anon_sym_enum] = ACTIONS(797),
    [anon_sym_using] = ACTIONS(797),
    [anon_sym_function] = ACTIONS(797),
    [anon_sym_byte] = ACTIONS(797),
    [anon_sym_address] = ACTIONS(797),
    [anon_sym_var] = ACTIONS(797),
    [anon_sym_mapping] = ACTIONS(797),
    [anon_sym_bool] = ACTIONS(797),
    [anon_sym_string] = ACTIONS(797),
    [anon_sym_int] = ACTIONS(797),
    [anon_sym_int8] = ACTIONS(797),
    [anon_sym_int16] = ACTIONS(797),
    [anon_sym_int24] = ACTIONS(797),
    [anon_sym_int32] = ACTIONS(797),
    [anon_sym_int40] = ACTIONS(797),
    [anon_sym_int48] = ACTIONS(797),
    [anon_sym_int56] = ACTIONS(797),
    [anon_sym_int64] = ACTIONS(797),
    [anon_sym_int72] = ACTIONS(797),
    [anon_sym_int80] = ACTIONS(797),
    [anon_sym_int88] = ACTIONS(797),
    [anon_sym_int96] = ACTIONS(797),
    [anon_sym_int104] = ACTIONS(797),
    [anon_sym_int112] = ACTIONS(797),
    [anon_sym_int120] = ACTIONS(797),
    [anon_sym_int128] = ACTIONS(797),
    [anon_sym_int136] = ACTIONS(797),
    [anon_sym_int144] = ACTIONS(797),
    [anon_sym_int152] = ACTIONS(797),
    [anon_sym_int160] = ACTIONS(797),
    [anon_sym_int168] = ACTIONS(797),
    [anon_sym_int176] = ACTIONS(797),
    [anon_sym_int184] = ACTIONS(797),
    [anon_sym_int192] = ACTIONS(797),
    [anon_sym_int200] = ACTIONS(797),
    [anon_sym_int208] = ACTIONS(797),
    [anon_sym_int216] = ACTIONS(797),
    [anon_sym_int224] = ACTIONS(797),
    [anon_sym_int232] = ACTIONS(797),
    [anon_sym_int240] = ACTIONS(797),
    [anon_sym_int248] = ACTIONS(797),
    [anon_sym_int256] = ACTIONS(797),
    [anon_sym_uint] = ACTIONS(797),
    [anon_sym_uint8] = ACTIONS(797),
    [anon_sym_uint16] = ACTIONS(797),
    [anon_sym_uint24] = ACTIONS(797),
    [anon_sym_uint32] = ACTIONS(797),
    [anon_sym_uint40] = ACTIONS(797),
    [anon_sym_uint48] = ACTIONS(797),
    [anon_sym_uint56] = ACTIONS(797),
    [anon_sym_uint64] = ACTIONS(797),
    [anon_sym_uint72] = ACTIONS(797),
    [anon_sym_uint80] = ACTIONS(797),
    [anon_sym_uint88] = ACTIONS(797),
    [anon_sym_uint96] = ACTIONS(797),
    [anon_sym_uint104] = ACTIONS(797),
    [anon_sym_uint112] = ACTIONS(797),
    [anon_sym_uint120] = ACTIONS(797),
    [anon_sym_uint128] = ACTIONS(797),
    [anon_sym_uint136] = ACTIONS(797),
    [anon_sym_uint144] = ACTIONS(797),
    [anon_sym_uint152] = ACTIONS(797),
    [anon_sym_uint160] = ACTIONS(797),
    [anon_sym_uint168] = ACTIONS(797),
    [anon_sym_uint176] = ACTIONS(797),
    [anon_sym_uint184] = ACTIONS(797),
    [anon_sym_uint192] = ACTIONS(797),
    [anon_sym_uint200] = ACTIONS(797),
    [anon_sym_uint208] = ACTIONS(797),
    [anon_sym_uint216] = ACTIONS(797),
    [anon_sym_uint224] = ACTIONS(797),
    [anon_sym_uint232] = ACTIONS(797),
    [anon_sym_uint240] = ACTIONS(797),
    [anon_sym_uint248] = ACTIONS(797),
    [anon_sym_uint256] = ACTIONS(797),
    [anon_sym_bytes] = ACTIONS(797),
    [anon_sym_bytes1] = ACTIONS(797),
    [anon_sym_bytes2] = ACTIONS(797),
    [anon_sym_bytes3] = ACTIONS(797),
    [anon_sym_bytes4] = ACTIONS(797),
    [anon_sym_bytes5] = ACTIONS(797),
    [anon_sym_bytes6] = ACTIONS(797),
    [anon_sym_bytes7] = ACTIONS(797),
    [anon_sym_bytes8] = ACTIONS(797),
    [anon_sym_bytes9] = ACTIONS(797),
    [anon_sym_bytes10] = ACTIONS(797),
    [anon_sym_bytes11] = ACTIONS(797),
    [anon_sym_bytes12] = ACTIONS(797),
    [anon_sym_bytes13] = ACTIONS(797),
    [anon_sym_bytes14] = ACTIONS(797),
    [anon_sym_bytes15] = ACTIONS(797),
    [anon_sym_bytes16] = ACTIONS(797),
    [anon_sym_bytes17] = ACTIONS(797),
    [anon_sym_bytes18] = ACTIONS(797),
    [anon_sym_bytes19] = ACTIONS(797),
    [anon_sym_bytes20] = ACTIONS(797),
    [anon_sym_bytes21] = ACTIONS(797),
    [anon_sym_bytes22] = ACTIONS(797),
    [anon_sym_bytes23] = ACTIONS(797),
    [anon_sym_bytes24] = ACTIONS(797),
    [anon_sym_bytes25] = ACTIONS(797),
    [anon_sym_bytes26] = ACTIONS(797),
    [anon_sym_bytes27] = ACTIONS(797),
    [anon_sym_bytes28] = ACTIONS(797),
    [anon_sym_bytes29] = ACTIONS(797),
    [anon_sym_bytes30] = ACTIONS(797),
    [anon_sym_bytes31] = ACTIONS(797),
    [anon_sym_bytes32] = ACTIONS(797),
    [anon_sym_fixed] = ACTIONS(797),
    [aux_sym__fixed_token1] = ACTIONS(797),
    [anon_sym_ufixed] = ACTIONS(797),
    [aux_sym__ufixed_token1] = ACTIONS(797),
    [sym_comment] = ACTIONS(3),
  },
  [206] = {
    [ts_builtin_sym_end] = ACTIONS(799),
    [sym_identifier] = ACTIONS(801),
    [anon_sym_pragma] = ACTIONS(801),
    [anon_sym_import] = ACTIONS(801),
    [anon_sym_type] = ACTIONS(801),
    [anon_sym_abstract] = ACTIONS(801),
    [anon_sym_contract] = ACTIONS(801),
    [anon_sym_error] = ACTIONS(801),
    [anon_sym_interface] = ACTIONS(801),
    [anon_sym_library] = ACTIONS(801),
    [anon_sym_struct] = ACTIONS(801),
    [anon_sym_enum] = ACTIONS(801),
    [anon_sym_using] = ACTIONS(801),
    [anon_sym_function] = ACTIONS(801),
    [anon_sym_byte] = ACTIONS(801),
    [anon_sym_address] = ACTIONS(801),
    [anon_sym_var] = ACTIONS(801),
    [anon_sym_mapping] = ACTIONS(801),
    [anon_sym_bool] = ACTIONS(801),
    [anon_sym_string] = ACTIONS(801),
    [anon_sym_int] = ACTIONS(801),
    [anon_sym_int8] = ACTIONS(801),
    [anon_sym_int16] = ACTIONS(801),
    [anon_sym_int24] = ACTIONS(801),
    [anon_sym_int32] = ACTIONS(801),
    [anon_sym_int40] = ACTIONS(801),
    [anon_sym_int48] = ACTIONS(801),
    [anon_sym_int56] = ACTIONS(801),
    [anon_sym_int64] = ACTIONS(801),
    [anon_sym_int72] = ACTIONS(801),
    [anon_sym_int80] = ACTIONS(801),
    [anon_sym_int88] = ACTIONS(801),
    [anon_sym_int96] = ACTIONS(801),
    [anon_sym_int104] = ACTIONS(801),
    [anon_sym_int112] = ACTIONS(801),
    [anon_sym_int120] = ACTIONS(801),
    [anon_sym_int128] = ACTIONS(801),
    [anon_sym_int136] = ACTIONS(801),
    [anon_sym_int144] = ACTIONS(801),
    [anon_sym_int152] = ACTIONS(801),
    [anon_sym_int160] = ACTIONS(801),
    [anon_sym_int168] = ACTIONS(801),
    [anon_sym_int176] = ACTIONS(801),
    [anon_sym_int184] = ACTIONS(801),
    [anon_sym_int192] = ACTIONS(801),
    [anon_sym_int200] = ACTIONS(801),
    [anon_sym_int208] = ACTIONS(801),
    [anon_sym_int216] = ACTIONS(801),
    [anon_sym_int224] = ACTIONS(801),
    [anon_sym_int232] = ACTIONS(801),
    [anon_sym_int240] = ACTIONS(801),
    [anon_sym_int248] = ACTIONS(801),
    [anon_sym_int256] = ACTIONS(801),
    [anon_sym_uint] = ACTIONS(801),
    [anon_sym_uint8] = ACTIONS(801),
    [anon_sym_uint16] = ACTIONS(801),
    [anon_sym_uint24] = ACTIONS(801),
    [anon_sym_uint32] = ACTIONS(801),
    [anon_sym_uint40] = ACTIONS(801),
    [anon_sym_uint48] = ACTIONS(801),
    [anon_sym_uint56] = ACTIONS(801),
    [anon_sym_uint64] = ACTIONS(801),
    [anon_sym_uint72] = ACTIONS(801),
    [anon_sym_uint80] = ACTIONS(801),
    [anon_sym_uint88] = ACTIONS(801),
    [anon_sym_uint96] = ACTIONS(801),
    [anon_sym_uint104] = ACTIONS(801),
    [anon_sym_uint112] = ACTIONS(801),
    [anon_sym_uint120] = ACTIONS(801),
    [anon_sym_uint128] = ACTIONS(801),
    [anon_sym_uint136] = ACTIONS(801),
    [anon_sym_uint144] = ACTIONS(801),
    [anon_sym_uint152] = ACTIONS(801),
    [anon_sym_uint160] = ACTIONS(801),
    [anon_sym_uint168] = ACTIONS(801),
    [anon_sym_uint176] = ACTIONS(801),
    [anon_sym_uint184] = ACTIONS(801),
    [anon_sym_uint192] = ACTIONS(801),
    [anon_sym_uint200] = ACTIONS(801),
    [anon_sym_uint208] = ACTIONS(801),
    [anon_sym_uint216] = ACTIONS(801),
    [anon_sym_uint224] = ACTIONS(801),
    [anon_sym_uint232] = ACTIONS(801),
    [anon_sym_uint240] = ACTIONS(801),
    [anon_sym_uint248] = ACTIONS(801),
    [anon_sym_uint256] = ACTIONS(801),
    [anon_sym_bytes] = ACTIONS(801),
    [anon_sym_bytes1] = ACTIONS(801),
    [anon_sym_bytes2] = ACTIONS(801),
    [anon_sym_bytes3] = ACTIONS(801),
    [anon_sym_bytes4] = ACTIONS(801),
    [anon_sym_bytes5] = ACTIONS(801),
    [anon_sym_bytes6] = ACTIONS(801),
    [anon_sym_bytes7] = ACTIONS(801),
    [anon_sym_bytes8] = ACTIONS(801),
    [anon_sym_bytes9] = ACTIONS(801),
    [anon_sym_bytes10] = ACTIONS(801),
    [anon_sym_bytes11] = ACTIONS(801),
    [anon_sym_bytes12] = ACTIONS(801),
    [anon_sym_bytes13] = ACTIONS(801),
    [anon_sym_bytes14] = ACTIONS(801),
    [anon_sym_bytes15] = ACTIONS(801),
    [anon_sym_bytes16] = ACTIONS(801),
    [anon_sym_bytes17] = ACTIONS(801),
    [anon_sym_bytes18] = ACTIONS(801),
    [anon_sym_bytes19] = ACTIONS(801),
    [anon_sym_bytes20] = ACTIONS(801),
    [anon_sym_bytes21] = ACTIONS(801),
    [anon_sym_bytes22] = ACTIONS(801),
    [anon_sym_bytes23] = ACTIONS(801),
    [anon_sym_bytes24] = ACTIONS(801),
    [anon_sym_bytes25] = ACTIONS(801),
    [anon_sym_bytes26] = ACTIONS(801),
    [anon_sym_bytes27] = ACTIONS(801),
    [anon_sym_bytes28] = ACTIONS(801),
    [anon_sym_bytes29] = ACTIONS(801),
    [anon_sym_bytes30] = ACTIONS(801),
    [anon_sym_bytes31] = ACTIONS(801),
    [anon_sym_bytes32] = ACTIONS(801),
    [anon_sym_fixed] = ACTIONS(801),
    [aux_sym__fixed_token1] = ACTIONS(801),
    [anon_sym_ufixed] = ACTIONS(801),
    [aux_sym__ufixed_token1] = ACTIONS(801),
    [sym_comment] = ACTIONS(3),
  },
  [207] = {
    [ts_builtin_sym_end] = ACTIONS(803),
    [sym_identifier] = ACTIONS(805),
    [anon_sym_pragma] = ACTIONS(805),
    [anon_sym_import] = ACTIONS(805),
    [anon_sym_type] = ACTIONS(805),
    [anon_sym_abstract] = ACTIONS(805),
    [anon_sym_contract] = ACTIONS(805),
    [anon_sym_error] = ACTIONS(805),
    [anon_sym_interface] = ACTIONS(805),
    [anon_sym_library] = ACTIONS(805),
    [anon_sym_struct] = ACTIONS(805),
    [anon_sym_enum] = ACTIONS(805),
    [anon_sym_using] = ACTIONS(805),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_byte] = ACTIONS(805),
    [anon_sym_address] = ACTIONS(805),
    [anon_sym_var] = ACTIONS(805),
    [anon_sym_mapping] = ACTIONS(805),
    [anon_sym_bool] = ACTIONS(805),
    [anon_sym_string] = ACTIONS(805),
    [anon_sym_int] = ACTIONS(805),
    [anon_sym_int8] = ACTIONS(805),
    [anon_sym_int16] = ACTIONS(805),
    [anon_sym_int24] = ACTIONS(805),
    [anon_sym_int32] = ACTIONS(805),
    [anon_sym_int40] = ACTIONS(805),
    [anon_sym_int48] = ACTIONS(805),
    [anon_sym_int56] = ACTIONS(805),
    [anon_sym_int64] = ACTIONS(805),
    [anon_sym_int72] = ACTIONS(805),
    [anon_sym_int80] = ACTIONS(805),
    [anon_sym_int88] = ACTIONS(805),
    [anon_sym_int96] = ACTIONS(805),
    [anon_sym_int104] = ACTIONS(805),
    [anon_sym_int112] = ACTIONS(805),
    [anon_sym_int120] = ACTIONS(805),
    [anon_sym_int128] = ACTIONS(805),
    [anon_sym_int136] = ACTIONS(805),
    [anon_sym_int144] = ACTIONS(805),
    [anon_sym_int152] = ACTIONS(805),
    [anon_sym_int160] = ACTIONS(805),
    [anon_sym_int168] = ACTIONS(805),
    [anon_sym_int176] = ACTIONS(805),
    [anon_sym_int184] = ACTIONS(805),
    [anon_sym_int192] = ACTIONS(805),
    [anon_sym_int200] = ACTIONS(805),
    [anon_sym_int208] = ACTIONS(805),
    [anon_sym_int216] = ACTIONS(805),
    [anon_sym_int224] = ACTIONS(805),
    [anon_sym_int232] = ACTIONS(805),
    [anon_sym_int240] = ACTIONS(805),
    [anon_sym_int248] = ACTIONS(805),
    [anon_sym_int256] = ACTIONS(805),
    [anon_sym_uint] = ACTIONS(805),
    [anon_sym_uint8] = ACTIONS(805),
    [anon_sym_uint16] = ACTIONS(805),
    [anon_sym_uint24] = ACTIONS(805),
    [anon_sym_uint32] = ACTIONS(805),
    [anon_sym_uint40] = ACTIONS(805),
    [anon_sym_uint48] = ACTIONS(805),
    [anon_sym_uint56] = ACTIONS(805),
    [anon_sym_uint64] = ACTIONS(805),
    [anon_sym_uint72] = ACTIONS(805),
    [anon_sym_uint80] = ACTIONS(805),
    [anon_sym_uint88] = ACTIONS(805),
    [anon_sym_uint96] = ACTIONS(805),
    [anon_sym_uint104] = ACTIONS(805),
    [anon_sym_uint112] = ACTIONS(805),
    [anon_sym_uint120] = ACTIONS(805),
    [anon_sym_uint128] = ACTIONS(805),
    [anon_sym_uint136] = ACTIONS(805),
    [anon_sym_uint144] = ACTIONS(805),
    [anon_sym_uint152] = ACTIONS(805),
    [anon_sym_uint160] = ACTIONS(805),
    [anon_sym_uint168] = ACTIONS(805),
    [anon_sym_uint176] = ACTIONS(805),
    [anon_sym_uint184] = ACTIONS(805),
    [anon_sym_uint192] = ACTIONS(805),
    [anon_sym_uint200] = ACTIONS(805),
    [anon_sym_uint208] = ACTIONS(805),
    [anon_sym_uint216] = ACTIONS(805),
    [anon_sym_uint224] = ACTIONS(805),
    [anon_sym_uint232] = ACTIONS(805),
    [anon_sym_uint240] = ACTIONS(805),
    [anon_sym_uint248] = ACTIONS(805),
    [anon_sym_uint256] = ACTIONS(805),
    [anon_sym_bytes] = ACTIONS(805),
    [anon_sym_bytes1] = ACTIONS(805),
    [anon_sym_bytes2] = ACTIONS(805),
    [anon_sym_bytes3] = ACTIONS(805),
    [anon_sym_bytes4] = ACTIONS(805),
    [anon_sym_bytes5] = ACTIONS(805),
    [anon_sym_bytes6] = ACTIONS(805),
    [anon_sym_bytes7] = ACTIONS(805),
    [anon_sym_bytes8] = ACTIONS(805),
    [anon_sym_bytes9] = ACTIONS(805),
    [anon_sym_bytes10] = ACTIONS(805),
    [anon_sym_bytes11] = ACTIONS(805),
    [anon_sym_bytes12] = ACTIONS(805),
    [anon_sym_bytes13] = ACTIONS(805),
    [anon_sym_bytes14] = ACTIONS(805),
    [anon_sym_bytes15] = ACTIONS(805),
    [anon_sym_bytes16] = ACTIONS(805),
    [anon_sym_bytes17] = ACTIONS(805),
    [anon_sym_bytes18] = ACTIONS(805),
    [anon_sym_bytes19] = ACTIONS(805),
    [anon_sym_bytes20] = ACTIONS(805),
    [anon_sym_bytes21] = ACTIONS(805),
    [anon_sym_bytes22] = ACTIONS(805),
    [anon_sym_bytes23] = ACTIONS(805),
    [anon_sym_bytes24] = ACTIONS(805),
    [anon_sym_bytes25] = ACTIONS(805),
    [anon_sym_bytes26] = ACTIONS(805),
    [anon_sym_bytes27] = ACTIONS(805),
    [anon_sym_bytes28] = ACTIONS(805),
    [anon_sym_bytes29] = ACTIONS(805),
    [anon_sym_bytes30] = ACTIONS(805),
    [anon_sym_bytes31] = ACTIONS(805),
    [anon_sym_bytes32] = ACTIONS(805),
    [anon_sym_fixed] = ACTIONS(805),
    [aux_sym__fixed_token1] = ACTIONS(805),
    [anon_sym_ufixed] = ACTIONS(805),
    [aux_sym__ufixed_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(3),
  },
  [208] = {
    [ts_builtin_sym_end] = ACTIONS(807),
    [sym_identifier] = ACTIONS(809),
    [anon_sym_pragma] = ACTIONS(809),
    [anon_sym_import] = ACTIONS(809),
    [anon_sym_type] = ACTIONS(809),
    [anon_sym_abstract] = ACTIONS(809),
    [anon_sym_contract] = ACTIONS(809),
    [anon_sym_error] = ACTIONS(809),
    [anon_sym_interface] = ACTIONS(809),
    [anon_sym_library] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(809),
    [anon_sym_enum] = ACTIONS(809),
    [anon_sym_using] = ACTIONS(809),
    [anon_sym_function] = ACTIONS(809),
    [anon_sym_byte] = ACTIONS(809),
    [anon_sym_address] = ACTIONS(809),
    [anon_sym_var] = ACTIONS(809),
    [anon_sym_mapping] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_int8] = ACTIONS(809),
    [anon_sym_int16] = ACTIONS(809),
    [anon_sym_int24] = ACTIONS(809),
    [anon_sym_int32] = ACTIONS(809),
    [anon_sym_int40] = ACTIONS(809),
    [anon_sym_int48] = ACTIONS(809),
    [anon_sym_int56] = ACTIONS(809),
    [anon_sym_int64] = ACTIONS(809),
    [anon_sym_int72] = ACTIONS(809),
    [anon_sym_int80] = ACTIONS(809),
    [anon_sym_int88] = ACTIONS(809),
    [anon_sym_int96] = ACTIONS(809),
    [anon_sym_int104] = ACTIONS(809),
    [anon_sym_int112] = ACTIONS(809),
    [anon_sym_int120] = ACTIONS(809),
    [anon_sym_int128] = ACTIONS(809),
    [anon_sym_int136] = ACTIONS(809),
    [anon_sym_int144] = ACTIONS(809),
    [anon_sym_int152] = ACTIONS(809),
    [anon_sym_int160] = ACTIONS(809),
    [anon_sym_int168] = ACTIONS(809),
    [anon_sym_int176] = ACTIONS(809),
    [anon_sym_int184] = ACTIONS(809),
    [anon_sym_int192] = ACTIONS(809),
    [anon_sym_int200] = ACTIONS(809),
    [anon_sym_int208] = ACTIONS(809),
    [anon_sym_int216] = ACTIONS(809),
    [anon_sym_int224] = ACTIONS(809),
    [anon_sym_int232] = ACTIONS(809),
    [anon_sym_int240] = ACTIONS(809),
    [anon_sym_int248] = ACTIONS(809),
    [anon_sym_int256] = ACTIONS(809),
    [anon_sym_uint] = ACTIONS(809),
    [anon_sym_uint8] = ACTIONS(809),
    [anon_sym_uint16] = ACTIONS(809),
    [anon_sym_uint24] = ACTIONS(809),
    [anon_sym_uint32] = ACTIONS(809),
    [anon_sym_uint40] = ACTIONS(809),
    [anon_sym_uint48] = ACTIONS(809),
    [anon_sym_uint56] = ACTIONS(809),
    [anon_sym_uint64] = ACTIONS(809),
    [anon_sym_uint72] = ACTIONS(809),
    [anon_sym_uint80] = ACTIONS(809),
    [anon_sym_uint88] = ACTIONS(809),
    [anon_sym_uint96] = ACTIONS(809),
    [anon_sym_uint104] = ACTIONS(809),
    [anon_sym_uint112] = ACTIONS(809),
    [anon_sym_uint120] = ACTIONS(809),
    [anon_sym_uint128] = ACTIONS(809),
    [anon_sym_uint136] = ACTIONS(809),
    [anon_sym_uint144] = ACTIONS(809),
    [anon_sym_uint152] = ACTIONS(809),
    [anon_sym_uint160] = ACTIONS(809),
    [anon_sym_uint168] = ACTIONS(809),
    [anon_sym_uint176] = ACTIONS(809),
    [anon_sym_uint184] = ACTIONS(809),
    [anon_sym_uint192] = ACTIONS(809),
    [anon_sym_uint200] = ACTIONS(809),
    [anon_sym_uint208] = ACTIONS(809),
    [anon_sym_uint216] = ACTIONS(809),
    [anon_sym_uint224] = ACTIONS(809),
    [anon_sym_uint232] = ACTIONS(809),
    [anon_sym_uint240] = ACTIONS(809),
    [anon_sym_uint248] = ACTIONS(809),
    [anon_sym_uint256] = ACTIONS(809),
    [anon_sym_bytes] = ACTIONS(809),
    [anon_sym_bytes1] = ACTIONS(809),
    [anon_sym_bytes2] = ACTIONS(809),
    [anon_sym_bytes3] = ACTIONS(809),
    [anon_sym_bytes4] = ACTIONS(809),
    [anon_sym_bytes5] = ACTIONS(809),
    [anon_sym_bytes6] = ACTIONS(809),
    [anon_sym_bytes7] = ACTIONS(809),
    [anon_sym_bytes8] = ACTIONS(809),
    [anon_sym_bytes9] = ACTIONS(809),
    [anon_sym_bytes10] = ACTIONS(809),
    [anon_sym_bytes11] = ACTIONS(809),
    [anon_sym_bytes12] = ACTIONS(809),
    [anon_sym_bytes13] = ACTIONS(809),
    [anon_sym_bytes14] = ACTIONS(809),
    [anon_sym_bytes15] = ACTIONS(809),
    [anon_sym_bytes16] = ACTIONS(809),
    [anon_sym_bytes17] = ACTIONS(809),
    [anon_sym_bytes18] = ACTIONS(809),
    [anon_sym_bytes19] = ACTIONS(809),
    [anon_sym_bytes20] = ACTIONS(809),
    [anon_sym_bytes21] = ACTIONS(809),
    [anon_sym_bytes22] = ACTIONS(809),
    [anon_sym_bytes23] = ACTIONS(809),
    [anon_sym_bytes24] = ACTIONS(809),
    [anon_sym_bytes25] = ACTIONS(809),
    [anon_sym_bytes26] = ACTIONS(809),
    [anon_sym_bytes27] = ACTIONS(809),
    [anon_sym_bytes28] = ACTIONS(809),
    [anon_sym_bytes29] = ACTIONS(809),
    [anon_sym_bytes30] = ACTIONS(809),
    [anon_sym_bytes31] = ACTIONS(809),
    [anon_sym_bytes32] = ACTIONS(809),
    [anon_sym_fixed] = ACTIONS(809),
    [aux_sym__fixed_token1] = ACTIONS(809),
    [anon_sym_ufixed] = ACTIONS(809),
    [aux_sym__ufixed_token1] = ACTIONS(809),
    [sym_comment] = ACTIONS(3),
  },
  [209] = {
    [ts_builtin_sym_end] = ACTIONS(811),
    [sym_identifier] = ACTIONS(813),
    [anon_sym_pragma] = ACTIONS(813),
    [anon_sym_import] = ACTIONS(813),
    [anon_sym_type] = ACTIONS(813),
    [anon_sym_abstract] = ACTIONS(813),
    [anon_sym_contract] = ACTIONS(813),
    [anon_sym_error] = ACTIONS(813),
    [anon_sym_interface] = ACTIONS(813),
    [anon_sym_library] = ACTIONS(813),
    [anon_sym_struct] = ACTIONS(813),
    [anon_sym_enum] = ACTIONS(813),
    [anon_sym_using] = ACTIONS(813),
    [anon_sym_function] = ACTIONS(813),
    [anon_sym_byte] = ACTIONS(813),
    [anon_sym_address] = ACTIONS(813),
    [anon_sym_var] = ACTIONS(813),
    [anon_sym_mapping] = ACTIONS(813),
    [anon_sym_bool] = ACTIONS(813),
    [anon_sym_string] = ACTIONS(813),
    [anon_sym_int] = ACTIONS(813),
    [anon_sym_int8] = ACTIONS(813),
    [anon_sym_int16] = ACTIONS(813),
    [anon_sym_int24] = ACTIONS(813),
    [anon_sym_int32] = ACTIONS(813),
    [anon_sym_int40] = ACTIONS(813),
    [anon_sym_int48] = ACTIONS(813),
    [anon_sym_int56] = ACTIONS(813),
    [anon_sym_int64] = ACTIONS(813),
    [anon_sym_int72] = ACTIONS(813),
    [anon_sym_int80] = ACTIONS(813),
    [anon_sym_int88] = ACTIONS(813),
    [anon_sym_int96] = ACTIONS(813),
    [anon_sym_int104] = ACTIONS(813),
    [anon_sym_int112] = ACTIONS(813),
    [anon_sym_int120] = ACTIONS(813),
    [anon_sym_int128] = ACTIONS(813),
    [anon_sym_int136] = ACTIONS(813),
    [anon_sym_int144] = ACTIONS(813),
    [anon_sym_int152] = ACTIONS(813),
    [anon_sym_int160] = ACTIONS(813),
    [anon_sym_int168] = ACTIONS(813),
    [anon_sym_int176] = ACTIONS(813),
    [anon_sym_int184] = ACTIONS(813),
    [anon_sym_int192] = ACTIONS(813),
    [anon_sym_int200] = ACTIONS(813),
    [anon_sym_int208] = ACTIONS(813),
    [anon_sym_int216] = ACTIONS(813),
    [anon_sym_int224] = ACTIONS(813),
    [anon_sym_int232] = ACTIONS(813),
    [anon_sym_int240] = ACTIONS(813),
    [anon_sym_int248] = ACTIONS(813),
    [anon_sym_int256] = ACTIONS(813),
    [anon_sym_uint] = ACTIONS(813),
    [anon_sym_uint8] = ACTIONS(813),
    [anon_sym_uint16] = ACTIONS(813),
    [anon_sym_uint24] = ACTIONS(813),
    [anon_sym_uint32] = ACTIONS(813),
    [anon_sym_uint40] = ACTIONS(813),
    [anon_sym_uint48] = ACTIONS(813),
    [anon_sym_uint56] = ACTIONS(813),
    [anon_sym_uint64] = ACTIONS(813),
    [anon_sym_uint72] = ACTIONS(813),
    [anon_sym_uint80] = ACTIONS(813),
    [anon_sym_uint88] = ACTIONS(813),
    [anon_sym_uint96] = ACTIONS(813),
    [anon_sym_uint104] = ACTIONS(813),
    [anon_sym_uint112] = ACTIONS(813),
    [anon_sym_uint120] = ACTIONS(813),
    [anon_sym_uint128] = ACTIONS(813),
    [anon_sym_uint136] = ACTIONS(813),
    [anon_sym_uint144] = ACTIONS(813),
    [anon_sym_uint152] = ACTIONS(813),
    [anon_sym_uint160] = ACTIONS(813),
    [anon_sym_uint168] = ACTIONS(813),
    [anon_sym_uint176] = ACTIONS(813),
    [anon_sym_uint184] = ACTIONS(813),
    [anon_sym_uint192] = ACTIONS(813),
    [anon_sym_uint200] = ACTIONS(813),
    [anon_sym_uint208] = ACTIONS(813),
    [anon_sym_uint216] = ACTIONS(813),
    [anon_sym_uint224] = ACTIONS(813),
    [anon_sym_uint232] = ACTIONS(813),
    [anon_sym_uint240] = ACTIONS(813),
    [anon_sym_uint248] = ACTIONS(813),
    [anon_sym_uint256] = ACTIONS(813),
    [anon_sym_bytes] = ACTIONS(813),
    [anon_sym_bytes1] = ACTIONS(813),
    [anon_sym_bytes2] = ACTIONS(813),
    [anon_sym_bytes3] = ACTIONS(813),
    [anon_sym_bytes4] = ACTIONS(813),
    [anon_sym_bytes5] = ACTIONS(813),
    [anon_sym_bytes6] = ACTIONS(813),
    [anon_sym_bytes7] = ACTIONS(813),
    [anon_sym_bytes8] = ACTIONS(813),
    [anon_sym_bytes9] = ACTIONS(813),
    [anon_sym_bytes10] = ACTIONS(813),
    [anon_sym_bytes11] = ACTIONS(813),
    [anon_sym_bytes12] = ACTIONS(813),
    [anon_sym_bytes13] = ACTIONS(813),
    [anon_sym_bytes14] = ACTIONS(813),
    [anon_sym_bytes15] = ACTIONS(813),
    [anon_sym_bytes16] = ACTIONS(813),
    [anon_sym_bytes17] = ACTIONS(813),
    [anon_sym_bytes18] = ACTIONS(813),
    [anon_sym_bytes19] = ACTIONS(813),
    [anon_sym_bytes20] = ACTIONS(813),
    [anon_sym_bytes21] = ACTIONS(813),
    [anon_sym_bytes22] = ACTIONS(813),
    [anon_sym_bytes23] = ACTIONS(813),
    [anon_sym_bytes24] = ACTIONS(813),
    [anon_sym_bytes25] = ACTIONS(813),
    [anon_sym_bytes26] = ACTIONS(813),
    [anon_sym_bytes27] = ACTIONS(813),
    [anon_sym_bytes28] = ACTIONS(813),
    [anon_sym_bytes29] = ACTIONS(813),
    [anon_sym_bytes30] = ACTIONS(813),
    [anon_sym_bytes31] = ACTIONS(813),
    [anon_sym_bytes32] = ACTIONS(813),
    [anon_sym_fixed] = ACTIONS(813),
    [aux_sym__fixed_token1] = ACTIONS(813),
    [anon_sym_ufixed] = ACTIONS(813),
    [aux_sym__ufixed_token1] = ACTIONS(813),
    [sym_comment] = ACTIONS(3),
  },
  [210] = {
    [ts_builtin_sym_end] = ACTIONS(815),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_pragma] = ACTIONS(817),
    [anon_sym_import] = ACTIONS(817),
    [anon_sym_type] = ACTIONS(817),
    [anon_sym_abstract] = ACTIONS(817),
    [anon_sym_contract] = ACTIONS(817),
    [anon_sym_error] = ACTIONS(817),
    [anon_sym_interface] = ACTIONS(817),
    [anon_sym_library] = ACTIONS(817),
    [anon_sym_struct] = ACTIONS(817),
    [anon_sym_enum] = ACTIONS(817),
    [anon_sym_using] = ACTIONS(817),
    [anon_sym_function] = ACTIONS(817),
    [anon_sym_byte] = ACTIONS(817),
    [anon_sym_address] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_mapping] = ACTIONS(817),
    [anon_sym_bool] = ACTIONS(817),
    [anon_sym_string] = ACTIONS(817),
    [anon_sym_int] = ACTIONS(817),
    [anon_sym_int8] = ACTIONS(817),
    [anon_sym_int16] = ACTIONS(817),
    [anon_sym_int24] = ACTIONS(817),
    [anon_sym_int32] = ACTIONS(817),
    [anon_sym_int40] = ACTIONS(817),
    [anon_sym_int48] = ACTIONS(817),
    [anon_sym_int56] = ACTIONS(817),
    [anon_sym_int64] = ACTIONS(817),
    [anon_sym_int72] = ACTIONS(817),
    [anon_sym_int80] = ACTIONS(817),
    [anon_sym_int88] = ACTIONS(817),
    [anon_sym_int96] = ACTIONS(817),
    [anon_sym_int104] = ACTIONS(817),
    [anon_sym_int112] = ACTIONS(817),
    [anon_sym_int120] = ACTIONS(817),
    [anon_sym_int128] = ACTIONS(817),
    [anon_sym_int136] = ACTIONS(817),
    [anon_sym_int144] = ACTIONS(817),
    [anon_sym_int152] = ACTIONS(817),
    [anon_sym_int160] = ACTIONS(817),
    [anon_sym_int168] = ACTIONS(817),
    [anon_sym_int176] = ACTIONS(817),
    [anon_sym_int184] = ACTIONS(817),
    [anon_sym_int192] = ACTIONS(817),
    [anon_sym_int200] = ACTIONS(817),
    [anon_sym_int208] = ACTIONS(817),
    [anon_sym_int216] = ACTIONS(817),
    [anon_sym_int224] = ACTIONS(817),
    [anon_sym_int232] = ACTIONS(817),
    [anon_sym_int240] = ACTIONS(817),
    [anon_sym_int248] = ACTIONS(817),
    [anon_sym_int256] = ACTIONS(817),
    [anon_sym_uint] = ACTIONS(817),
    [anon_sym_uint8] = ACTIONS(817),
    [anon_sym_uint16] = ACTIONS(817),
    [anon_sym_uint24] = ACTIONS(817),
    [anon_sym_uint32] = ACTIONS(817),
    [anon_sym_uint40] = ACTIONS(817),
    [anon_sym_uint48] = ACTIONS(817),
    [anon_sym_uint56] = ACTIONS(817),
    [anon_sym_uint64] = ACTIONS(817),
    [anon_sym_uint72] = ACTIONS(817),
    [anon_sym_uint80] = ACTIONS(817),
    [anon_sym_uint88] = ACTIONS(817),
    [anon_sym_uint96] = ACTIONS(817),
    [anon_sym_uint104] = ACTIONS(817),
    [anon_sym_uint112] = ACTIONS(817),
    [anon_sym_uint120] = ACTIONS(817),
    [anon_sym_uint128] = ACTIONS(817),
    [anon_sym_uint136] = ACTIONS(817),
    [anon_sym_uint144] = ACTIONS(817),
    [anon_sym_uint152] = ACTIONS(817),
    [anon_sym_uint160] = ACTIONS(817),
    [anon_sym_uint168] = ACTIONS(817),
    [anon_sym_uint176] = ACTIONS(817),
    [anon_sym_uint184] = ACTIONS(817),
    [anon_sym_uint192] = ACTIONS(817),
    [anon_sym_uint200] = ACTIONS(817),
    [anon_sym_uint208] = ACTIONS(817),
    [anon_sym_uint216] = ACTIONS(817),
    [anon_sym_uint224] = ACTIONS(817),
    [anon_sym_uint232] = ACTIONS(817),
    [anon_sym_uint240] = ACTIONS(817),
    [anon_sym_uint248] = ACTIONS(817),
    [anon_sym_uint256] = ACTIONS(817),
    [anon_sym_bytes] = ACTIONS(817),
    [anon_sym_bytes1] = ACTIONS(817),
    [anon_sym_bytes2] = ACTIONS(817),
    [anon_sym_bytes3] = ACTIONS(817),
    [anon_sym_bytes4] = ACTIONS(817),
    [anon_sym_bytes5] = ACTIONS(817),
    [anon_sym_bytes6] = ACTIONS(817),
    [anon_sym_bytes7] = ACTIONS(817),
    [anon_sym_bytes8] = ACTIONS(817),
    [anon_sym_bytes9] = ACTIONS(817),
    [anon_sym_bytes10] = ACTIONS(817),
    [anon_sym_bytes11] = ACTIONS(817),
    [anon_sym_bytes12] = ACTIONS(817),
    [anon_sym_bytes13] = ACTIONS(817),
    [anon_sym_bytes14] = ACTIONS(817),
    [anon_sym_bytes15] = ACTIONS(817),
    [anon_sym_bytes16] = ACTIONS(817),
    [anon_sym_bytes17] = ACTIONS(817),
    [anon_sym_bytes18] = ACTIONS(817),
    [anon_sym_bytes19] = ACTIONS(817),
    [anon_sym_bytes20] = ACTIONS(817),
    [anon_sym_bytes21] = ACTIONS(817),
    [anon_sym_bytes22] = ACTIONS(817),
    [anon_sym_bytes23] = ACTIONS(817),
    [anon_sym_bytes24] = ACTIONS(817),
    [anon_sym_bytes25] = ACTIONS(817),
    [anon_sym_bytes26] = ACTIONS(817),
    [anon_sym_bytes27] = ACTIONS(817),
    [anon_sym_bytes28] = ACTIONS(817),
    [anon_sym_bytes29] = ACTIONS(817),
    [anon_sym_bytes30] = ACTIONS(817),
    [anon_sym_bytes31] = ACTIONS(817),
    [anon_sym_bytes32] = ACTIONS(817),
    [anon_sym_fixed] = ACTIONS(817),
    [aux_sym__fixed_token1] = ACTIONS(817),
    [anon_sym_ufixed] = ACTIONS(817),
    [aux_sym__ufixed_token1] = ACTIONS(817),
    [sym_comment] = ACTIONS(3),
  },
  [211] = {
    [sym_type_name] = STATE(448),
    [sym__array_type] = STATE(411),
    [sym__function_type] = STATE(409),
    [sym_user_defined_type] = STATE(411),
    [sym__identifier_path] = STATE(399),
    [sym__mapping] = STATE(403),
    [sym_primitive_type] = STATE(411),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(819),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_mapping] = ACTIONS(37),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [212] = {
    [ts_builtin_sym_end] = ACTIONS(815),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_pragma] = ACTIONS(817),
    [anon_sym_import] = ACTIONS(817),
    [anon_sym_type] = ACTIONS(817),
    [anon_sym_abstract] = ACTIONS(817),
    [anon_sym_contract] = ACTIONS(817),
    [anon_sym_error] = ACTIONS(817),
    [anon_sym_interface] = ACTIONS(817),
    [anon_sym_library] = ACTIONS(817),
    [anon_sym_struct] = ACTIONS(817),
    [anon_sym_enum] = ACTIONS(817),
    [anon_sym_using] = ACTIONS(817),
    [anon_sym_function] = ACTIONS(817),
    [anon_sym_byte] = ACTIONS(817),
    [anon_sym_address] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_mapping] = ACTIONS(817),
    [anon_sym_bool] = ACTIONS(817),
    [anon_sym_string] = ACTIONS(817),
    [anon_sym_int] = ACTIONS(817),
    [anon_sym_int8] = ACTIONS(817),
    [anon_sym_int16] = ACTIONS(817),
    [anon_sym_int24] = ACTIONS(817),
    [anon_sym_int32] = ACTIONS(817),
    [anon_sym_int40] = ACTIONS(817),
    [anon_sym_int48] = ACTIONS(817),
    [anon_sym_int56] = ACTIONS(817),
    [anon_sym_int64] = ACTIONS(817),
    [anon_sym_int72] = ACTIONS(817),
    [anon_sym_int80] = ACTIONS(817),
    [anon_sym_int88] = ACTIONS(817),
    [anon_sym_int96] = ACTIONS(817),
    [anon_sym_int104] = ACTIONS(817),
    [anon_sym_int112] = ACTIONS(817),
    [anon_sym_int120] = ACTIONS(817),
    [anon_sym_int128] = ACTIONS(817),
    [anon_sym_int136] = ACTIONS(817),
    [anon_sym_int144] = ACTIONS(817),
    [anon_sym_int152] = ACTIONS(817),
    [anon_sym_int160] = ACTIONS(817),
    [anon_sym_int168] = ACTIONS(817),
    [anon_sym_int176] = ACTIONS(817),
    [anon_sym_int184] = ACTIONS(817),
    [anon_sym_int192] = ACTIONS(817),
    [anon_sym_int200] = ACTIONS(817),
    [anon_sym_int208] = ACTIONS(817),
    [anon_sym_int216] = ACTIONS(817),
    [anon_sym_int224] = ACTIONS(817),
    [anon_sym_int232] = ACTIONS(817),
    [anon_sym_int240] = ACTIONS(817),
    [anon_sym_int248] = ACTIONS(817),
    [anon_sym_int256] = ACTIONS(817),
    [anon_sym_uint] = ACTIONS(817),
    [anon_sym_uint8] = ACTIONS(817),
    [anon_sym_uint16] = ACTIONS(817),
    [anon_sym_uint24] = ACTIONS(817),
    [anon_sym_uint32] = ACTIONS(817),
    [anon_sym_uint40] = ACTIONS(817),
    [anon_sym_uint48] = ACTIONS(817),
    [anon_sym_uint56] = ACTIONS(817),
    [anon_sym_uint64] = ACTIONS(817),
    [anon_sym_uint72] = ACTIONS(817),
    [anon_sym_uint80] = ACTIONS(817),
    [anon_sym_uint88] = ACTIONS(817),
    [anon_sym_uint96] = ACTIONS(817),
    [anon_sym_uint104] = ACTIONS(817),
    [anon_sym_uint112] = ACTIONS(817),
    [anon_sym_uint120] = ACTIONS(817),
    [anon_sym_uint128] = ACTIONS(817),
    [anon_sym_uint136] = ACTIONS(817),
    [anon_sym_uint144] = ACTIONS(817),
    [anon_sym_uint152] = ACTIONS(817),
    [anon_sym_uint160] = ACTIONS(817),
    [anon_sym_uint168] = ACTIONS(817),
    [anon_sym_uint176] = ACTIONS(817),
    [anon_sym_uint184] = ACTIONS(817),
    [anon_sym_uint192] = ACTIONS(817),
    [anon_sym_uint200] = ACTIONS(817),
    [anon_sym_uint208] = ACTIONS(817),
    [anon_sym_uint216] = ACTIONS(817),
    [anon_sym_uint224] = ACTIONS(817),
    [anon_sym_uint232] = ACTIONS(817),
    [anon_sym_uint240] = ACTIONS(817),
    [anon_sym_uint248] = ACTIONS(817),
    [anon_sym_uint256] = ACTIONS(817),
    [anon_sym_bytes] = ACTIONS(817),
    [anon_sym_bytes1] = ACTIONS(817),
    [anon_sym_bytes2] = ACTIONS(817),
    [anon_sym_bytes3] = ACTIONS(817),
    [anon_sym_bytes4] = ACTIONS(817),
    [anon_sym_bytes5] = ACTIONS(817),
    [anon_sym_bytes6] = ACTIONS(817),
    [anon_sym_bytes7] = ACTIONS(817),
    [anon_sym_bytes8] = ACTIONS(817),
    [anon_sym_bytes9] = ACTIONS(817),
    [anon_sym_bytes10] = ACTIONS(817),
    [anon_sym_bytes11] = ACTIONS(817),
    [anon_sym_bytes12] = ACTIONS(817),
    [anon_sym_bytes13] = ACTIONS(817),
    [anon_sym_bytes14] = ACTIONS(817),
    [anon_sym_bytes15] = ACTIONS(817),
    [anon_sym_bytes16] = ACTIONS(817),
    [anon_sym_bytes17] = ACTIONS(817),
    [anon_sym_bytes18] = ACTIONS(817),
    [anon_sym_bytes19] = ACTIONS(817),
    [anon_sym_bytes20] = ACTIONS(817),
    [anon_sym_bytes21] = ACTIONS(817),
    [anon_sym_bytes22] = ACTIONS(817),
    [anon_sym_bytes23] = ACTIONS(817),
    [anon_sym_bytes24] = ACTIONS(817),
    [anon_sym_bytes25] = ACTIONS(817),
    [anon_sym_bytes26] = ACTIONS(817),
    [anon_sym_bytes27] = ACTIONS(817),
    [anon_sym_bytes28] = ACTIONS(817),
    [anon_sym_bytes29] = ACTIONS(817),
    [anon_sym_bytes30] = ACTIONS(817),
    [anon_sym_bytes31] = ACTIONS(817),
    [anon_sym_bytes32] = ACTIONS(817),
    [anon_sym_fixed] = ACTIONS(817),
    [aux_sym__fixed_token1] = ACTIONS(817),
    [anon_sym_ufixed] = ACTIONS(817),
    [aux_sym__ufixed_token1] = ACTIONS(817),
    [sym_comment] = ACTIONS(3),
  },
  [213] = {
    [ts_builtin_sym_end] = ACTIONS(799),
    [sym_identifier] = ACTIONS(801),
    [anon_sym_pragma] = ACTIONS(801),
    [anon_sym_import] = ACTIONS(801),
    [anon_sym_type] = ACTIONS(801),
    [anon_sym_abstract] = ACTIONS(801),
    [anon_sym_contract] = ACTIONS(801),
    [anon_sym_error] = ACTIONS(801),
    [anon_sym_interface] = ACTIONS(801),
    [anon_sym_library] = ACTIONS(801),
    [anon_sym_struct] = ACTIONS(801),
    [anon_sym_enum] = ACTIONS(801),
    [anon_sym_using] = ACTIONS(801),
    [anon_sym_function] = ACTIONS(801),
    [anon_sym_byte] = ACTIONS(801),
    [anon_sym_address] = ACTIONS(801),
    [anon_sym_var] = ACTIONS(801),
    [anon_sym_mapping] = ACTIONS(801),
    [anon_sym_bool] = ACTIONS(801),
    [anon_sym_string] = ACTIONS(801),
    [anon_sym_int] = ACTIONS(801),
    [anon_sym_int8] = ACTIONS(801),
    [anon_sym_int16] = ACTIONS(801),
    [anon_sym_int24] = ACTIONS(801),
    [anon_sym_int32] = ACTIONS(801),
    [anon_sym_int40] = ACTIONS(801),
    [anon_sym_int48] = ACTIONS(801),
    [anon_sym_int56] = ACTIONS(801),
    [anon_sym_int64] = ACTIONS(801),
    [anon_sym_int72] = ACTIONS(801),
    [anon_sym_int80] = ACTIONS(801),
    [anon_sym_int88] = ACTIONS(801),
    [anon_sym_int96] = ACTIONS(801),
    [anon_sym_int104] = ACTIONS(801),
    [anon_sym_int112] = ACTIONS(801),
    [anon_sym_int120] = ACTIONS(801),
    [anon_sym_int128] = ACTIONS(801),
    [anon_sym_int136] = ACTIONS(801),
    [anon_sym_int144] = ACTIONS(801),
    [anon_sym_int152] = ACTIONS(801),
    [anon_sym_int160] = ACTIONS(801),
    [anon_sym_int168] = ACTIONS(801),
    [anon_sym_int176] = ACTIONS(801),
    [anon_sym_int184] = ACTIONS(801),
    [anon_sym_int192] = ACTIONS(801),
    [anon_sym_int200] = ACTIONS(801),
    [anon_sym_int208] = ACTIONS(801),
    [anon_sym_int216] = ACTIONS(801),
    [anon_sym_int224] = ACTIONS(801),
    [anon_sym_int232] = ACTIONS(801),
    [anon_sym_int240] = ACTIONS(801),
    [anon_sym_int248] = ACTIONS(801),
    [anon_sym_int256] = ACTIONS(801),
    [anon_sym_uint] = ACTIONS(801),
    [anon_sym_uint8] = ACTIONS(801),
    [anon_sym_uint16] = ACTIONS(801),
    [anon_sym_uint24] = ACTIONS(801),
    [anon_sym_uint32] = ACTIONS(801),
    [anon_sym_uint40] = ACTIONS(801),
    [anon_sym_uint48] = ACTIONS(801),
    [anon_sym_uint56] = ACTIONS(801),
    [anon_sym_uint64] = ACTIONS(801),
    [anon_sym_uint72] = ACTIONS(801),
    [anon_sym_uint80] = ACTIONS(801),
    [anon_sym_uint88] = ACTIONS(801),
    [anon_sym_uint96] = ACTIONS(801),
    [anon_sym_uint104] = ACTIONS(801),
    [anon_sym_uint112] = ACTIONS(801),
    [anon_sym_uint120] = ACTIONS(801),
    [anon_sym_uint128] = ACTIONS(801),
    [anon_sym_uint136] = ACTIONS(801),
    [anon_sym_uint144] = ACTIONS(801),
    [anon_sym_uint152] = ACTIONS(801),
    [anon_sym_uint160] = ACTIONS(801),
    [anon_sym_uint168] = ACTIONS(801),
    [anon_sym_uint176] = ACTIONS(801),
    [anon_sym_uint184] = ACTIONS(801),
    [anon_sym_uint192] = ACTIONS(801),
    [anon_sym_uint200] = ACTIONS(801),
    [anon_sym_uint208] = ACTIONS(801),
    [anon_sym_uint216] = ACTIONS(801),
    [anon_sym_uint224] = ACTIONS(801),
    [anon_sym_uint232] = ACTIONS(801),
    [anon_sym_uint240] = ACTIONS(801),
    [anon_sym_uint248] = ACTIONS(801),
    [anon_sym_uint256] = ACTIONS(801),
    [anon_sym_bytes] = ACTIONS(801),
    [anon_sym_bytes1] = ACTIONS(801),
    [anon_sym_bytes2] = ACTIONS(801),
    [anon_sym_bytes3] = ACTIONS(801),
    [anon_sym_bytes4] = ACTIONS(801),
    [anon_sym_bytes5] = ACTIONS(801),
    [anon_sym_bytes6] = ACTIONS(801),
    [anon_sym_bytes7] = ACTIONS(801),
    [anon_sym_bytes8] = ACTIONS(801),
    [anon_sym_bytes9] = ACTIONS(801),
    [anon_sym_bytes10] = ACTIONS(801),
    [anon_sym_bytes11] = ACTIONS(801),
    [anon_sym_bytes12] = ACTIONS(801),
    [anon_sym_bytes13] = ACTIONS(801),
    [anon_sym_bytes14] = ACTIONS(801),
    [anon_sym_bytes15] = ACTIONS(801),
    [anon_sym_bytes16] = ACTIONS(801),
    [anon_sym_bytes17] = ACTIONS(801),
    [anon_sym_bytes18] = ACTIONS(801),
    [anon_sym_bytes19] = ACTIONS(801),
    [anon_sym_bytes20] = ACTIONS(801),
    [anon_sym_bytes21] = ACTIONS(801),
    [anon_sym_bytes22] = ACTIONS(801),
    [anon_sym_bytes23] = ACTIONS(801),
    [anon_sym_bytes24] = ACTIONS(801),
    [anon_sym_bytes25] = ACTIONS(801),
    [anon_sym_bytes26] = ACTIONS(801),
    [anon_sym_bytes27] = ACTIONS(801),
    [anon_sym_bytes28] = ACTIONS(801),
    [anon_sym_bytes29] = ACTIONS(801),
    [anon_sym_bytes30] = ACTIONS(801),
    [anon_sym_bytes31] = ACTIONS(801),
    [anon_sym_bytes32] = ACTIONS(801),
    [anon_sym_fixed] = ACTIONS(801),
    [aux_sym__fixed_token1] = ACTIONS(801),
    [anon_sym_ufixed] = ACTIONS(801),
    [aux_sym__ufixed_token1] = ACTIONS(801),
    [sym_comment] = ACTIONS(3),
  },
  [214] = {
    [ts_builtin_sym_end] = ACTIONS(821),
    [sym_identifier] = ACTIONS(823),
    [anon_sym_pragma] = ACTIONS(823),
    [anon_sym_import] = ACTIONS(823),
    [anon_sym_type] = ACTIONS(823),
    [anon_sym_abstract] = ACTIONS(823),
    [anon_sym_contract] = ACTIONS(823),
    [anon_sym_error] = ACTIONS(823),
    [anon_sym_interface] = ACTIONS(823),
    [anon_sym_library] = ACTIONS(823),
    [anon_sym_struct] = ACTIONS(823),
    [anon_sym_enum] = ACTIONS(823),
    [anon_sym_using] = ACTIONS(823),
    [anon_sym_function] = ACTIONS(823),
    [anon_sym_byte] = ACTIONS(823),
    [anon_sym_address] = ACTIONS(823),
    [anon_sym_var] = ACTIONS(823),
    [anon_sym_mapping] = ACTIONS(823),
    [anon_sym_bool] = ACTIONS(823),
    [anon_sym_string] = ACTIONS(823),
    [anon_sym_int] = ACTIONS(823),
    [anon_sym_int8] = ACTIONS(823),
    [anon_sym_int16] = ACTIONS(823),
    [anon_sym_int24] = ACTIONS(823),
    [anon_sym_int32] = ACTIONS(823),
    [anon_sym_int40] = ACTIONS(823),
    [anon_sym_int48] = ACTIONS(823),
    [anon_sym_int56] = ACTIONS(823),
    [anon_sym_int64] = ACTIONS(823),
    [anon_sym_int72] = ACTIONS(823),
    [anon_sym_int80] = ACTIONS(823),
    [anon_sym_int88] = ACTIONS(823),
    [anon_sym_int96] = ACTIONS(823),
    [anon_sym_int104] = ACTIONS(823),
    [anon_sym_int112] = ACTIONS(823),
    [anon_sym_int120] = ACTIONS(823),
    [anon_sym_int128] = ACTIONS(823),
    [anon_sym_int136] = ACTIONS(823),
    [anon_sym_int144] = ACTIONS(823),
    [anon_sym_int152] = ACTIONS(823),
    [anon_sym_int160] = ACTIONS(823),
    [anon_sym_int168] = ACTIONS(823),
    [anon_sym_int176] = ACTIONS(823),
    [anon_sym_int184] = ACTIONS(823),
    [anon_sym_int192] = ACTIONS(823),
    [anon_sym_int200] = ACTIONS(823),
    [anon_sym_int208] = ACTIONS(823),
    [anon_sym_int216] = ACTIONS(823),
    [anon_sym_int224] = ACTIONS(823),
    [anon_sym_int232] = ACTIONS(823),
    [anon_sym_int240] = ACTIONS(823),
    [anon_sym_int248] = ACTIONS(823),
    [anon_sym_int256] = ACTIONS(823),
    [anon_sym_uint] = ACTIONS(823),
    [anon_sym_uint8] = ACTIONS(823),
    [anon_sym_uint16] = ACTIONS(823),
    [anon_sym_uint24] = ACTIONS(823),
    [anon_sym_uint32] = ACTIONS(823),
    [anon_sym_uint40] = ACTIONS(823),
    [anon_sym_uint48] = ACTIONS(823),
    [anon_sym_uint56] = ACTIONS(823),
    [anon_sym_uint64] = ACTIONS(823),
    [anon_sym_uint72] = ACTIONS(823),
    [anon_sym_uint80] = ACTIONS(823),
    [anon_sym_uint88] = ACTIONS(823),
    [anon_sym_uint96] = ACTIONS(823),
    [anon_sym_uint104] = ACTIONS(823),
    [anon_sym_uint112] = ACTIONS(823),
    [anon_sym_uint120] = ACTIONS(823),
    [anon_sym_uint128] = ACTIONS(823),
    [anon_sym_uint136] = ACTIONS(823),
    [anon_sym_uint144] = ACTIONS(823),
    [anon_sym_uint152] = ACTIONS(823),
    [anon_sym_uint160] = ACTIONS(823),
    [anon_sym_uint168] = ACTIONS(823),
    [anon_sym_uint176] = ACTIONS(823),
    [anon_sym_uint184] = ACTIONS(823),
    [anon_sym_uint192] = ACTIONS(823),
    [anon_sym_uint200] = ACTIONS(823),
    [anon_sym_uint208] = ACTIONS(823),
    [anon_sym_uint216] = ACTIONS(823),
    [anon_sym_uint224] = ACTIONS(823),
    [anon_sym_uint232] = ACTIONS(823),
    [anon_sym_uint240] = ACTIONS(823),
    [anon_sym_uint248] = ACTIONS(823),
    [anon_sym_uint256] = ACTIONS(823),
    [anon_sym_bytes] = ACTIONS(823),
    [anon_sym_bytes1] = ACTIONS(823),
    [anon_sym_bytes2] = ACTIONS(823),
    [anon_sym_bytes3] = ACTIONS(823),
    [anon_sym_bytes4] = ACTIONS(823),
    [anon_sym_bytes5] = ACTIONS(823),
    [anon_sym_bytes6] = ACTIONS(823),
    [anon_sym_bytes7] = ACTIONS(823),
    [anon_sym_bytes8] = ACTIONS(823),
    [anon_sym_bytes9] = ACTIONS(823),
    [anon_sym_bytes10] = ACTIONS(823),
    [anon_sym_bytes11] = ACTIONS(823),
    [anon_sym_bytes12] = ACTIONS(823),
    [anon_sym_bytes13] = ACTIONS(823),
    [anon_sym_bytes14] = ACTIONS(823),
    [anon_sym_bytes15] = ACTIONS(823),
    [anon_sym_bytes16] = ACTIONS(823),
    [anon_sym_bytes17] = ACTIONS(823),
    [anon_sym_bytes18] = ACTIONS(823),
    [anon_sym_bytes19] = ACTIONS(823),
    [anon_sym_bytes20] = ACTIONS(823),
    [anon_sym_bytes21] = ACTIONS(823),
    [anon_sym_bytes22] = ACTIONS(823),
    [anon_sym_bytes23] = ACTIONS(823),
    [anon_sym_bytes24] = ACTIONS(823),
    [anon_sym_bytes25] = ACTIONS(823),
    [anon_sym_bytes26] = ACTIONS(823),
    [anon_sym_bytes27] = ACTIONS(823),
    [anon_sym_bytes28] = ACTIONS(823),
    [anon_sym_bytes29] = ACTIONS(823),
    [anon_sym_bytes30] = ACTIONS(823),
    [anon_sym_bytes31] = ACTIONS(823),
    [anon_sym_bytes32] = ACTIONS(823),
    [anon_sym_fixed] = ACTIONS(823),
    [aux_sym__fixed_token1] = ACTIONS(823),
    [anon_sym_ufixed] = ACTIONS(823),
    [aux_sym__ufixed_token1] = ACTIONS(823),
    [sym_comment] = ACTIONS(3),
  },
  [215] = {
    [ts_builtin_sym_end] = ACTIONS(821),
    [sym_identifier] = ACTIONS(823),
    [anon_sym_pragma] = ACTIONS(823),
    [anon_sym_import] = ACTIONS(823),
    [anon_sym_type] = ACTIONS(823),
    [anon_sym_abstract] = ACTIONS(823),
    [anon_sym_contract] = ACTIONS(823),
    [anon_sym_error] = ACTIONS(823),
    [anon_sym_interface] = ACTIONS(823),
    [anon_sym_library] = ACTIONS(823),
    [anon_sym_struct] = ACTIONS(823),
    [anon_sym_enum] = ACTIONS(823),
    [anon_sym_using] = ACTIONS(823),
    [anon_sym_function] = ACTIONS(823),
    [anon_sym_byte] = ACTIONS(823),
    [anon_sym_address] = ACTIONS(823),
    [anon_sym_var] = ACTIONS(823),
    [anon_sym_mapping] = ACTIONS(823),
    [anon_sym_bool] = ACTIONS(823),
    [anon_sym_string] = ACTIONS(823),
    [anon_sym_int] = ACTIONS(823),
    [anon_sym_int8] = ACTIONS(823),
    [anon_sym_int16] = ACTIONS(823),
    [anon_sym_int24] = ACTIONS(823),
    [anon_sym_int32] = ACTIONS(823),
    [anon_sym_int40] = ACTIONS(823),
    [anon_sym_int48] = ACTIONS(823),
    [anon_sym_int56] = ACTIONS(823),
    [anon_sym_int64] = ACTIONS(823),
    [anon_sym_int72] = ACTIONS(823),
    [anon_sym_int80] = ACTIONS(823),
    [anon_sym_int88] = ACTIONS(823),
    [anon_sym_int96] = ACTIONS(823),
    [anon_sym_int104] = ACTIONS(823),
    [anon_sym_int112] = ACTIONS(823),
    [anon_sym_int120] = ACTIONS(823),
    [anon_sym_int128] = ACTIONS(823),
    [anon_sym_int136] = ACTIONS(823),
    [anon_sym_int144] = ACTIONS(823),
    [anon_sym_int152] = ACTIONS(823),
    [anon_sym_int160] = ACTIONS(823),
    [anon_sym_int168] = ACTIONS(823),
    [anon_sym_int176] = ACTIONS(823),
    [anon_sym_int184] = ACTIONS(823),
    [anon_sym_int192] = ACTIONS(823),
    [anon_sym_int200] = ACTIONS(823),
    [anon_sym_int208] = ACTIONS(823),
    [anon_sym_int216] = ACTIONS(823),
    [anon_sym_int224] = ACTIONS(823),
    [anon_sym_int232] = ACTIONS(823),
    [anon_sym_int240] = ACTIONS(823),
    [anon_sym_int248] = ACTIONS(823),
    [anon_sym_int256] = ACTIONS(823),
    [anon_sym_uint] = ACTIONS(823),
    [anon_sym_uint8] = ACTIONS(823),
    [anon_sym_uint16] = ACTIONS(823),
    [anon_sym_uint24] = ACTIONS(823),
    [anon_sym_uint32] = ACTIONS(823),
    [anon_sym_uint40] = ACTIONS(823),
    [anon_sym_uint48] = ACTIONS(823),
    [anon_sym_uint56] = ACTIONS(823),
    [anon_sym_uint64] = ACTIONS(823),
    [anon_sym_uint72] = ACTIONS(823),
    [anon_sym_uint80] = ACTIONS(823),
    [anon_sym_uint88] = ACTIONS(823),
    [anon_sym_uint96] = ACTIONS(823),
    [anon_sym_uint104] = ACTIONS(823),
    [anon_sym_uint112] = ACTIONS(823),
    [anon_sym_uint120] = ACTIONS(823),
    [anon_sym_uint128] = ACTIONS(823),
    [anon_sym_uint136] = ACTIONS(823),
    [anon_sym_uint144] = ACTIONS(823),
    [anon_sym_uint152] = ACTIONS(823),
    [anon_sym_uint160] = ACTIONS(823),
    [anon_sym_uint168] = ACTIONS(823),
    [anon_sym_uint176] = ACTIONS(823),
    [anon_sym_uint184] = ACTIONS(823),
    [anon_sym_uint192] = ACTIONS(823),
    [anon_sym_uint200] = ACTIONS(823),
    [anon_sym_uint208] = ACTIONS(823),
    [anon_sym_uint216] = ACTIONS(823),
    [anon_sym_uint224] = ACTIONS(823),
    [anon_sym_uint232] = ACTIONS(823),
    [anon_sym_uint240] = ACTIONS(823),
    [anon_sym_uint248] = ACTIONS(823),
    [anon_sym_uint256] = ACTIONS(823),
    [anon_sym_bytes] = ACTIONS(823),
    [anon_sym_bytes1] = ACTIONS(823),
    [anon_sym_bytes2] = ACTIONS(823),
    [anon_sym_bytes3] = ACTIONS(823),
    [anon_sym_bytes4] = ACTIONS(823),
    [anon_sym_bytes5] = ACTIONS(823),
    [anon_sym_bytes6] = ACTIONS(823),
    [anon_sym_bytes7] = ACTIONS(823),
    [anon_sym_bytes8] = ACTIONS(823),
    [anon_sym_bytes9] = ACTIONS(823),
    [anon_sym_bytes10] = ACTIONS(823),
    [anon_sym_bytes11] = ACTIONS(823),
    [anon_sym_bytes12] = ACTIONS(823),
    [anon_sym_bytes13] = ACTIONS(823),
    [anon_sym_bytes14] = ACTIONS(823),
    [anon_sym_bytes15] = ACTIONS(823),
    [anon_sym_bytes16] = ACTIONS(823),
    [anon_sym_bytes17] = ACTIONS(823),
    [anon_sym_bytes18] = ACTIONS(823),
    [anon_sym_bytes19] = ACTIONS(823),
    [anon_sym_bytes20] = ACTIONS(823),
    [anon_sym_bytes21] = ACTIONS(823),
    [anon_sym_bytes22] = ACTIONS(823),
    [anon_sym_bytes23] = ACTIONS(823),
    [anon_sym_bytes24] = ACTIONS(823),
    [anon_sym_bytes25] = ACTIONS(823),
    [anon_sym_bytes26] = ACTIONS(823),
    [anon_sym_bytes27] = ACTIONS(823),
    [anon_sym_bytes28] = ACTIONS(823),
    [anon_sym_bytes29] = ACTIONS(823),
    [anon_sym_bytes30] = ACTIONS(823),
    [anon_sym_bytes31] = ACTIONS(823),
    [anon_sym_bytes32] = ACTIONS(823),
    [anon_sym_fixed] = ACTIONS(823),
    [aux_sym__fixed_token1] = ACTIONS(823),
    [anon_sym_ufixed] = ACTIONS(823),
    [aux_sym__ufixed_token1] = ACTIONS(823),
    [sym_comment] = ACTIONS(3),
  },
  [216] = {
    [sym_identifier] = ACTIONS(689),
    [anon_sym_RBRACE] = ACTIONS(687),
    [anon_sym_type] = ACTIONS(689),
    [anon_sym_error] = ACTIONS(689),
    [anon_sym_struct] = ACTIONS(689),
    [anon_sym_enum] = ACTIONS(689),
    [anon_sym_event] = ACTIONS(689),
    [anon_sym_using] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(689),
    [anon_sym_byte] = ACTIONS(689),
    [anon_sym_address] = ACTIONS(689),
    [anon_sym_var] = ACTIONS(689),
    [anon_sym_modifier] = ACTIONS(689),
    [anon_sym_constructor] = ACTIONS(689),
    [anon_sym_fallback] = ACTIONS(689),
    [anon_sym_receive] = ACTIONS(689),
    [anon_sym_mapping] = ACTIONS(689),
    [anon_sym_bool] = ACTIONS(689),
    [anon_sym_string] = ACTIONS(689),
    [anon_sym_int] = ACTIONS(689),
    [anon_sym_int8] = ACTIONS(689),
    [anon_sym_int16] = ACTIONS(689),
    [anon_sym_int24] = ACTIONS(689),
    [anon_sym_int32] = ACTIONS(689),
    [anon_sym_int40] = ACTIONS(689),
    [anon_sym_int48] = ACTIONS(689),
    [anon_sym_int56] = ACTIONS(689),
    [anon_sym_int64] = ACTIONS(689),
    [anon_sym_int72] = ACTIONS(689),
    [anon_sym_int80] = ACTIONS(689),
    [anon_sym_int88] = ACTIONS(689),
    [anon_sym_int96] = ACTIONS(689),
    [anon_sym_int104] = ACTIONS(689),
    [anon_sym_int112] = ACTIONS(689),
    [anon_sym_int120] = ACTIONS(689),
    [anon_sym_int128] = ACTIONS(689),
    [anon_sym_int136] = ACTIONS(689),
    [anon_sym_int144] = ACTIONS(689),
    [anon_sym_int152] = ACTIONS(689),
    [anon_sym_int160] = ACTIONS(689),
    [anon_sym_int168] = ACTIONS(689),
    [anon_sym_int176] = ACTIONS(689),
    [anon_sym_int184] = ACTIONS(689),
    [anon_sym_int192] = ACTIONS(689),
    [anon_sym_int200] = ACTIONS(689),
    [anon_sym_int208] = ACTIONS(689),
    [anon_sym_int216] = ACTIONS(689),
    [anon_sym_int224] = ACTIONS(689),
    [anon_sym_int232] = ACTIONS(689),
    [anon_sym_int240] = ACTIONS(689),
    [anon_sym_int248] = ACTIONS(689),
    [anon_sym_int256] = ACTIONS(689),
    [anon_sym_uint] = ACTIONS(689),
    [anon_sym_uint8] = ACTIONS(689),
    [anon_sym_uint16] = ACTIONS(689),
    [anon_sym_uint24] = ACTIONS(689),
    [anon_sym_uint32] = ACTIONS(689),
    [anon_sym_uint40] = ACTIONS(689),
    [anon_sym_uint48] = ACTIONS(689),
    [anon_sym_uint56] = ACTIONS(689),
    [anon_sym_uint64] = ACTIONS(689),
    [anon_sym_uint72] = ACTIONS(689),
    [anon_sym_uint80] = ACTIONS(689),
    [anon_sym_uint88] = ACTIONS(689),
    [anon_sym_uint96] = ACTIONS(689),
    [anon_sym_uint104] = ACTIONS(689),
    [anon_sym_uint112] = ACTIONS(689),
    [anon_sym_uint120] = ACTIONS(689),
    [anon_sym_uint128] = ACTIONS(689),
    [anon_sym_uint136] = ACTIONS(689),
    [anon_sym_uint144] = ACTIONS(689),
    [anon_sym_uint152] = ACTIONS(689),
    [anon_sym_uint160] = ACTIONS(689),
    [anon_sym_uint168] = ACTIONS(689),
    [anon_sym_uint176] = ACTIONS(689),
    [anon_sym_uint184] = ACTIONS(689),
    [anon_sym_uint192] = ACTIONS(689),
    [anon_sym_uint200] = ACTIONS(689),
    [anon_sym_uint208] = ACTIONS(689),
    [anon_sym_uint216] = ACTIONS(689),
    [anon_sym_uint224] = ACTIONS(689),
    [anon_sym_uint232] = ACTIONS(689),
    [anon_sym_uint240] = ACTIONS(689),
    [anon_sym_uint248] = ACTIONS(689),
    [anon_sym_uint256] = ACTIONS(689),
    [anon_sym_bytes] = ACTIONS(689),
    [anon_sym_bytes1] = ACTIONS(689),
    [anon_sym_bytes2] = ACTIONS(689),
    [anon_sym_bytes3] = ACTIONS(689),
    [anon_sym_bytes4] = ACTIONS(689),
    [anon_sym_bytes5] = ACTIONS(689),
    [anon_sym_bytes6] = ACTIONS(689),
    [anon_sym_bytes7] = ACTIONS(689),
    [anon_sym_bytes8] = ACTIONS(689),
    [anon_sym_bytes9] = ACTIONS(689),
    [anon_sym_bytes10] = ACTIONS(689),
    [anon_sym_bytes11] = ACTIONS(689),
    [anon_sym_bytes12] = ACTIONS(689),
    [anon_sym_bytes13] = ACTIONS(689),
    [anon_sym_bytes14] = ACTIONS(689),
    [anon_sym_bytes15] = ACTIONS(689),
    [anon_sym_bytes16] = ACTIONS(689),
    [anon_sym_bytes17] = ACTIONS(689),
    [anon_sym_bytes18] = ACTIONS(689),
    [anon_sym_bytes19] = ACTIONS(689),
    [anon_sym_bytes20] = ACTIONS(689),
    [anon_sym_bytes21] = ACTIONS(689),
    [anon_sym_bytes22] = ACTIONS(689),
    [anon_sym_bytes23] = ACTIONS(689),
    [anon_sym_bytes24] = ACTIONS(689),
    [anon_sym_bytes25] = ACTIONS(689),
    [anon_sym_bytes26] = ACTIONS(689),
    [anon_sym_bytes27] = ACTIONS(689),
    [anon_sym_bytes28] = ACTIONS(689),
    [anon_sym_bytes29] = ACTIONS(689),
    [anon_sym_bytes30] = ACTIONS(689),
    [anon_sym_bytes31] = ACTIONS(689),
    [anon_sym_bytes32] = ACTIONS(689),
    [anon_sym_fixed] = ACTIONS(689),
    [aux_sym__fixed_token1] = ACTIONS(689),
    [anon_sym_ufixed] = ACTIONS(689),
    [aux_sym__ufixed_token1] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
  },
  [217] = {
    [sym_identifier] = ACTIONS(701),
    [anon_sym_RBRACE] = ACTIONS(699),
    [anon_sym_type] = ACTIONS(701),
    [anon_sym_error] = ACTIONS(701),
    [anon_sym_struct] = ACTIONS(701),
    [anon_sym_enum] = ACTIONS(701),
    [anon_sym_event] = ACTIONS(701),
    [anon_sym_using] = ACTIONS(701),
    [anon_sym_function] = ACTIONS(701),
    [anon_sym_byte] = ACTIONS(701),
    [anon_sym_address] = ACTIONS(701),
    [anon_sym_var] = ACTIONS(701),
    [anon_sym_modifier] = ACTIONS(701),
    [anon_sym_constructor] = ACTIONS(701),
    [anon_sym_fallback] = ACTIONS(701),
    [anon_sym_receive] = ACTIONS(701),
    [anon_sym_mapping] = ACTIONS(701),
    [anon_sym_bool] = ACTIONS(701),
    [anon_sym_string] = ACTIONS(701),
    [anon_sym_int] = ACTIONS(701),
    [anon_sym_int8] = ACTIONS(701),
    [anon_sym_int16] = ACTIONS(701),
    [anon_sym_int24] = ACTIONS(701),
    [anon_sym_int32] = ACTIONS(701),
    [anon_sym_int40] = ACTIONS(701),
    [anon_sym_int48] = ACTIONS(701),
    [anon_sym_int56] = ACTIONS(701),
    [anon_sym_int64] = ACTIONS(701),
    [anon_sym_int72] = ACTIONS(701),
    [anon_sym_int80] = ACTIONS(701),
    [anon_sym_int88] = ACTIONS(701),
    [anon_sym_int96] = ACTIONS(701),
    [anon_sym_int104] = ACTIONS(701),
    [anon_sym_int112] = ACTIONS(701),
    [anon_sym_int120] = ACTIONS(701),
    [anon_sym_int128] = ACTIONS(701),
    [anon_sym_int136] = ACTIONS(701),
    [anon_sym_int144] = ACTIONS(701),
    [anon_sym_int152] = ACTIONS(701),
    [anon_sym_int160] = ACTIONS(701),
    [anon_sym_int168] = ACTIONS(701),
    [anon_sym_int176] = ACTIONS(701),
    [anon_sym_int184] = ACTIONS(701),
    [anon_sym_int192] = ACTIONS(701),
    [anon_sym_int200] = ACTIONS(701),
    [anon_sym_int208] = ACTIONS(701),
    [anon_sym_int216] = ACTIONS(701),
    [anon_sym_int224] = ACTIONS(701),
    [anon_sym_int232] = ACTIONS(701),
    [anon_sym_int240] = ACTIONS(701),
    [anon_sym_int248] = ACTIONS(701),
    [anon_sym_int256] = ACTIONS(701),
    [anon_sym_uint] = ACTIONS(701),
    [anon_sym_uint8] = ACTIONS(701),
    [anon_sym_uint16] = ACTIONS(701),
    [anon_sym_uint24] = ACTIONS(701),
    [anon_sym_uint32] = ACTIONS(701),
    [anon_sym_uint40] = ACTIONS(701),
    [anon_sym_uint48] = ACTIONS(701),
    [anon_sym_uint56] = ACTIONS(701),
    [anon_sym_uint64] = ACTIONS(701),
    [anon_sym_uint72] = ACTIONS(701),
    [anon_sym_uint80] = ACTIONS(701),
    [anon_sym_uint88] = ACTIONS(701),
    [anon_sym_uint96] = ACTIONS(701),
    [anon_sym_uint104] = ACTIONS(701),
    [anon_sym_uint112] = ACTIONS(701),
    [anon_sym_uint120] = ACTIONS(701),
    [anon_sym_uint128] = ACTIONS(701),
    [anon_sym_uint136] = ACTIONS(701),
    [anon_sym_uint144] = ACTIONS(701),
    [anon_sym_uint152] = ACTIONS(701),
    [anon_sym_uint160] = ACTIONS(701),
    [anon_sym_uint168] = ACTIONS(701),
    [anon_sym_uint176] = ACTIONS(701),
    [anon_sym_uint184] = ACTIONS(701),
    [anon_sym_uint192] = ACTIONS(701),
    [anon_sym_uint200] = ACTIONS(701),
    [anon_sym_uint208] = ACTIONS(701),
    [anon_sym_uint216] = ACTIONS(701),
    [anon_sym_uint224] = ACTIONS(701),
    [anon_sym_uint232] = ACTIONS(701),
    [anon_sym_uint240] = ACTIONS(701),
    [anon_sym_uint248] = ACTIONS(701),
    [anon_sym_uint256] = ACTIONS(701),
    [anon_sym_bytes] = ACTIONS(701),
    [anon_sym_bytes1] = ACTIONS(701),
    [anon_sym_bytes2] = ACTIONS(701),
    [anon_sym_bytes3] = ACTIONS(701),
    [anon_sym_bytes4] = ACTIONS(701),
    [anon_sym_bytes5] = ACTIONS(701),
    [anon_sym_bytes6] = ACTIONS(701),
    [anon_sym_bytes7] = ACTIONS(701),
    [anon_sym_bytes8] = ACTIONS(701),
    [anon_sym_bytes9] = ACTIONS(701),
    [anon_sym_bytes10] = ACTIONS(701),
    [anon_sym_bytes11] = ACTIONS(701),
    [anon_sym_bytes12] = ACTIONS(701),
    [anon_sym_bytes13] = ACTIONS(701),
    [anon_sym_bytes14] = ACTIONS(701),
    [anon_sym_bytes15] = ACTIONS(701),
    [anon_sym_bytes16] = ACTIONS(701),
    [anon_sym_bytes17] = ACTIONS(701),
    [anon_sym_bytes18] = ACTIONS(701),
    [anon_sym_bytes19] = ACTIONS(701),
    [anon_sym_bytes20] = ACTIONS(701),
    [anon_sym_bytes21] = ACTIONS(701),
    [anon_sym_bytes22] = ACTIONS(701),
    [anon_sym_bytes23] = ACTIONS(701),
    [anon_sym_bytes24] = ACTIONS(701),
    [anon_sym_bytes25] = ACTIONS(701),
    [anon_sym_bytes26] = ACTIONS(701),
    [anon_sym_bytes27] = ACTIONS(701),
    [anon_sym_bytes28] = ACTIONS(701),
    [anon_sym_bytes29] = ACTIONS(701),
    [anon_sym_bytes30] = ACTIONS(701),
    [anon_sym_bytes31] = ACTIONS(701),
    [anon_sym_bytes32] = ACTIONS(701),
    [anon_sym_fixed] = ACTIONS(701),
    [aux_sym__fixed_token1] = ACTIONS(701),
    [anon_sym_ufixed] = ACTIONS(701),
    [aux_sym__ufixed_token1] = ACTIONS(701),
    [sym_comment] = ACTIONS(3),
  },
  [218] = {
    [sym_identifier] = ACTIONS(825),
    [anon_sym_RBRACE] = ACTIONS(827),
    [anon_sym_type] = ACTIONS(825),
    [anon_sym_error] = ACTIONS(825),
    [anon_sym_struct] = ACTIONS(825),
    [anon_sym_enum] = ACTIONS(825),
    [anon_sym_event] = ACTIONS(825),
    [anon_sym_using] = ACTIONS(825),
    [anon_sym_function] = ACTIONS(825),
    [anon_sym_byte] = ACTIONS(825),
    [anon_sym_address] = ACTIONS(825),
    [anon_sym_var] = ACTIONS(825),
    [anon_sym_modifier] = ACTIONS(825),
    [anon_sym_constructor] = ACTIONS(825),
    [anon_sym_fallback] = ACTIONS(825),
    [anon_sym_receive] = ACTIONS(825),
    [anon_sym_mapping] = ACTIONS(825),
    [anon_sym_bool] = ACTIONS(825),
    [anon_sym_string] = ACTIONS(825),
    [anon_sym_int] = ACTIONS(825),
    [anon_sym_int8] = ACTIONS(825),
    [anon_sym_int16] = ACTIONS(825),
    [anon_sym_int24] = ACTIONS(825),
    [anon_sym_int32] = ACTIONS(825),
    [anon_sym_int40] = ACTIONS(825),
    [anon_sym_int48] = ACTIONS(825),
    [anon_sym_int56] = ACTIONS(825),
    [anon_sym_int64] = ACTIONS(825),
    [anon_sym_int72] = ACTIONS(825),
    [anon_sym_int80] = ACTIONS(825),
    [anon_sym_int88] = ACTIONS(825),
    [anon_sym_int96] = ACTIONS(825),
    [anon_sym_int104] = ACTIONS(825),
    [anon_sym_int112] = ACTIONS(825),
    [anon_sym_int120] = ACTIONS(825),
    [anon_sym_int128] = ACTIONS(825),
    [anon_sym_int136] = ACTIONS(825),
    [anon_sym_int144] = ACTIONS(825),
    [anon_sym_int152] = ACTIONS(825),
    [anon_sym_int160] = ACTIONS(825),
    [anon_sym_int168] = ACTIONS(825),
    [anon_sym_int176] = ACTIONS(825),
    [anon_sym_int184] = ACTIONS(825),
    [anon_sym_int192] = ACTIONS(825),
    [anon_sym_int200] = ACTIONS(825),
    [anon_sym_int208] = ACTIONS(825),
    [anon_sym_int216] = ACTIONS(825),
    [anon_sym_int224] = ACTIONS(825),
    [anon_sym_int232] = ACTIONS(825),
    [anon_sym_int240] = ACTIONS(825),
    [anon_sym_int248] = ACTIONS(825),
    [anon_sym_int256] = ACTIONS(825),
    [anon_sym_uint] = ACTIONS(825),
    [anon_sym_uint8] = ACTIONS(825),
    [anon_sym_uint16] = ACTIONS(825),
    [anon_sym_uint24] = ACTIONS(825),
    [anon_sym_uint32] = ACTIONS(825),
    [anon_sym_uint40] = ACTIONS(825),
    [anon_sym_uint48] = ACTIONS(825),
    [anon_sym_uint56] = ACTIONS(825),
    [anon_sym_uint64] = ACTIONS(825),
    [anon_sym_uint72] = ACTIONS(825),
    [anon_sym_uint80] = ACTIONS(825),
    [anon_sym_uint88] = ACTIONS(825),
    [anon_sym_uint96] = ACTIONS(825),
    [anon_sym_uint104] = ACTIONS(825),
    [anon_sym_uint112] = ACTIONS(825),
    [anon_sym_uint120] = ACTIONS(825),
    [anon_sym_uint128] = ACTIONS(825),
    [anon_sym_uint136] = ACTIONS(825),
    [anon_sym_uint144] = ACTIONS(825),
    [anon_sym_uint152] = ACTIONS(825),
    [anon_sym_uint160] = ACTIONS(825),
    [anon_sym_uint168] = ACTIONS(825),
    [anon_sym_uint176] = ACTIONS(825),
    [anon_sym_uint184] = ACTIONS(825),
    [anon_sym_uint192] = ACTIONS(825),
    [anon_sym_uint200] = ACTIONS(825),
    [anon_sym_uint208] = ACTIONS(825),
    [anon_sym_uint216] = ACTIONS(825),
    [anon_sym_uint224] = ACTIONS(825),
    [anon_sym_uint232] = ACTIONS(825),
    [anon_sym_uint240] = ACTIONS(825),
    [anon_sym_uint248] = ACTIONS(825),
    [anon_sym_uint256] = ACTIONS(825),
    [anon_sym_bytes] = ACTIONS(825),
    [anon_sym_bytes1] = ACTIONS(825),
    [anon_sym_bytes2] = ACTIONS(825),
    [anon_sym_bytes3] = ACTIONS(825),
    [anon_sym_bytes4] = ACTIONS(825),
    [anon_sym_bytes5] = ACTIONS(825),
    [anon_sym_bytes6] = ACTIONS(825),
    [anon_sym_bytes7] = ACTIONS(825),
    [anon_sym_bytes8] = ACTIONS(825),
    [anon_sym_bytes9] = ACTIONS(825),
    [anon_sym_bytes10] = ACTIONS(825),
    [anon_sym_bytes11] = ACTIONS(825),
    [anon_sym_bytes12] = ACTIONS(825),
    [anon_sym_bytes13] = ACTIONS(825),
    [anon_sym_bytes14] = ACTIONS(825),
    [anon_sym_bytes15] = ACTIONS(825),
    [anon_sym_bytes16] = ACTIONS(825),
    [anon_sym_bytes17] = ACTIONS(825),
    [anon_sym_bytes18] = ACTIONS(825),
    [anon_sym_bytes19] = ACTIONS(825),
    [anon_sym_bytes20] = ACTIONS(825),
    [anon_sym_bytes21] = ACTIONS(825),
    [anon_sym_bytes22] = ACTIONS(825),
    [anon_sym_bytes23] = ACTIONS(825),
    [anon_sym_bytes24] = ACTIONS(825),
    [anon_sym_bytes25] = ACTIONS(825),
    [anon_sym_bytes26] = ACTIONS(825),
    [anon_sym_bytes27] = ACTIONS(825),
    [anon_sym_bytes28] = ACTIONS(825),
    [anon_sym_bytes29] = ACTIONS(825),
    [anon_sym_bytes30] = ACTIONS(825),
    [anon_sym_bytes31] = ACTIONS(825),
    [anon_sym_bytes32] = ACTIONS(825),
    [anon_sym_fixed] = ACTIONS(825),
    [aux_sym__fixed_token1] = ACTIONS(825),
    [anon_sym_ufixed] = ACTIONS(825),
    [aux_sym__ufixed_token1] = ACTIONS(825),
    [sym_comment] = ACTIONS(3),
  },
  [219] = {
    [sym_identifier] = ACTIONS(753),
    [anon_sym_RBRACE] = ACTIONS(751),
    [anon_sym_type] = ACTIONS(753),
    [anon_sym_error] = ACTIONS(753),
    [anon_sym_struct] = ACTIONS(753),
    [anon_sym_enum] = ACTIONS(753),
    [anon_sym_event] = ACTIONS(753),
    [anon_sym_using] = ACTIONS(753),
    [anon_sym_function] = ACTIONS(753),
    [anon_sym_byte] = ACTIONS(753),
    [anon_sym_address] = ACTIONS(753),
    [anon_sym_var] = ACTIONS(753),
    [anon_sym_modifier] = ACTIONS(753),
    [anon_sym_constructor] = ACTIONS(753),
    [anon_sym_fallback] = ACTIONS(753),
    [anon_sym_receive] = ACTIONS(753),
    [anon_sym_mapping] = ACTIONS(753),
    [anon_sym_bool] = ACTIONS(753),
    [anon_sym_string] = ACTIONS(753),
    [anon_sym_int] = ACTIONS(753),
    [anon_sym_int8] = ACTIONS(753),
    [anon_sym_int16] = ACTIONS(753),
    [anon_sym_int24] = ACTIONS(753),
    [anon_sym_int32] = ACTIONS(753),
    [anon_sym_int40] = ACTIONS(753),
    [anon_sym_int48] = ACTIONS(753),
    [anon_sym_int56] = ACTIONS(753),
    [anon_sym_int64] = ACTIONS(753),
    [anon_sym_int72] = ACTIONS(753),
    [anon_sym_int80] = ACTIONS(753),
    [anon_sym_int88] = ACTIONS(753),
    [anon_sym_int96] = ACTIONS(753),
    [anon_sym_int104] = ACTIONS(753),
    [anon_sym_int112] = ACTIONS(753),
    [anon_sym_int120] = ACTIONS(753),
    [anon_sym_int128] = ACTIONS(753),
    [anon_sym_int136] = ACTIONS(753),
    [anon_sym_int144] = ACTIONS(753),
    [anon_sym_int152] = ACTIONS(753),
    [anon_sym_int160] = ACTIONS(753),
    [anon_sym_int168] = ACTIONS(753),
    [anon_sym_int176] = ACTIONS(753),
    [anon_sym_int184] = ACTIONS(753),
    [anon_sym_int192] = ACTIONS(753),
    [anon_sym_int200] = ACTIONS(753),
    [anon_sym_int208] = ACTIONS(753),
    [anon_sym_int216] = ACTIONS(753),
    [anon_sym_int224] = ACTIONS(753),
    [anon_sym_int232] = ACTIONS(753),
    [anon_sym_int240] = ACTIONS(753),
    [anon_sym_int248] = ACTIONS(753),
    [anon_sym_int256] = ACTIONS(753),
    [anon_sym_uint] = ACTIONS(753),
    [anon_sym_uint8] = ACTIONS(753),
    [anon_sym_uint16] = ACTIONS(753),
    [anon_sym_uint24] = ACTIONS(753),
    [anon_sym_uint32] = ACTIONS(753),
    [anon_sym_uint40] = ACTIONS(753),
    [anon_sym_uint48] = ACTIONS(753),
    [anon_sym_uint56] = ACTIONS(753),
    [anon_sym_uint64] = ACTIONS(753),
    [anon_sym_uint72] = ACTIONS(753),
    [anon_sym_uint80] = ACTIONS(753),
    [anon_sym_uint88] = ACTIONS(753),
    [anon_sym_uint96] = ACTIONS(753),
    [anon_sym_uint104] = ACTIONS(753),
    [anon_sym_uint112] = ACTIONS(753),
    [anon_sym_uint120] = ACTIONS(753),
    [anon_sym_uint128] = ACTIONS(753),
    [anon_sym_uint136] = ACTIONS(753),
    [anon_sym_uint144] = ACTIONS(753),
    [anon_sym_uint152] = ACTIONS(753),
    [anon_sym_uint160] = ACTIONS(753),
    [anon_sym_uint168] = ACTIONS(753),
    [anon_sym_uint176] = ACTIONS(753),
    [anon_sym_uint184] = ACTIONS(753),
    [anon_sym_uint192] = ACTIONS(753),
    [anon_sym_uint200] = ACTIONS(753),
    [anon_sym_uint208] = ACTIONS(753),
    [anon_sym_uint216] = ACTIONS(753),
    [anon_sym_uint224] = ACTIONS(753),
    [anon_sym_uint232] = ACTIONS(753),
    [anon_sym_uint240] = ACTIONS(753),
    [anon_sym_uint248] = ACTIONS(753),
    [anon_sym_uint256] = ACTIONS(753),
    [anon_sym_bytes] = ACTIONS(753),
    [anon_sym_bytes1] = ACTIONS(753),
    [anon_sym_bytes2] = ACTIONS(753),
    [anon_sym_bytes3] = ACTIONS(753),
    [anon_sym_bytes4] = ACTIONS(753),
    [anon_sym_bytes5] = ACTIONS(753),
    [anon_sym_bytes6] = ACTIONS(753),
    [anon_sym_bytes7] = ACTIONS(753),
    [anon_sym_bytes8] = ACTIONS(753),
    [anon_sym_bytes9] = ACTIONS(753),
    [anon_sym_bytes10] = ACTIONS(753),
    [anon_sym_bytes11] = ACTIONS(753),
    [anon_sym_bytes12] = ACTIONS(753),
    [anon_sym_bytes13] = ACTIONS(753),
    [anon_sym_bytes14] = ACTIONS(753),
    [anon_sym_bytes15] = ACTIONS(753),
    [anon_sym_bytes16] = ACTIONS(753),
    [anon_sym_bytes17] = ACTIONS(753),
    [anon_sym_bytes18] = ACTIONS(753),
    [anon_sym_bytes19] = ACTIONS(753),
    [anon_sym_bytes20] = ACTIONS(753),
    [anon_sym_bytes21] = ACTIONS(753),
    [anon_sym_bytes22] = ACTIONS(753),
    [anon_sym_bytes23] = ACTIONS(753),
    [anon_sym_bytes24] = ACTIONS(753),
    [anon_sym_bytes25] = ACTIONS(753),
    [anon_sym_bytes26] = ACTIONS(753),
    [anon_sym_bytes27] = ACTIONS(753),
    [anon_sym_bytes28] = ACTIONS(753),
    [anon_sym_bytes29] = ACTIONS(753),
    [anon_sym_bytes30] = ACTIONS(753),
    [anon_sym_bytes31] = ACTIONS(753),
    [anon_sym_bytes32] = ACTIONS(753),
    [anon_sym_fixed] = ACTIONS(753),
    [aux_sym__fixed_token1] = ACTIONS(753),
    [anon_sym_ufixed] = ACTIONS(753),
    [aux_sym__ufixed_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(3),
  },
  [220] = {
    [sym_identifier] = ACTIONS(829),
    [anon_sym_RBRACE] = ACTIONS(831),
    [anon_sym_type] = ACTIONS(829),
    [anon_sym_error] = ACTIONS(829),
    [anon_sym_struct] = ACTIONS(829),
    [anon_sym_enum] = ACTIONS(829),
    [anon_sym_event] = ACTIONS(829),
    [anon_sym_using] = ACTIONS(829),
    [anon_sym_function] = ACTIONS(829),
    [anon_sym_byte] = ACTIONS(829),
    [anon_sym_address] = ACTIONS(829),
    [anon_sym_var] = ACTIONS(829),
    [anon_sym_modifier] = ACTIONS(829),
    [anon_sym_constructor] = ACTIONS(829),
    [anon_sym_fallback] = ACTIONS(829),
    [anon_sym_receive] = ACTIONS(829),
    [anon_sym_mapping] = ACTIONS(829),
    [anon_sym_bool] = ACTIONS(829),
    [anon_sym_string] = ACTIONS(829),
    [anon_sym_int] = ACTIONS(829),
    [anon_sym_int8] = ACTIONS(829),
    [anon_sym_int16] = ACTIONS(829),
    [anon_sym_int24] = ACTIONS(829),
    [anon_sym_int32] = ACTIONS(829),
    [anon_sym_int40] = ACTIONS(829),
    [anon_sym_int48] = ACTIONS(829),
    [anon_sym_int56] = ACTIONS(829),
    [anon_sym_int64] = ACTIONS(829),
    [anon_sym_int72] = ACTIONS(829),
    [anon_sym_int80] = ACTIONS(829),
    [anon_sym_int88] = ACTIONS(829),
    [anon_sym_int96] = ACTIONS(829),
    [anon_sym_int104] = ACTIONS(829),
    [anon_sym_int112] = ACTIONS(829),
    [anon_sym_int120] = ACTIONS(829),
    [anon_sym_int128] = ACTIONS(829),
    [anon_sym_int136] = ACTIONS(829),
    [anon_sym_int144] = ACTIONS(829),
    [anon_sym_int152] = ACTIONS(829),
    [anon_sym_int160] = ACTIONS(829),
    [anon_sym_int168] = ACTIONS(829),
    [anon_sym_int176] = ACTIONS(829),
    [anon_sym_int184] = ACTIONS(829),
    [anon_sym_int192] = ACTIONS(829),
    [anon_sym_int200] = ACTIONS(829),
    [anon_sym_int208] = ACTIONS(829),
    [anon_sym_int216] = ACTIONS(829),
    [anon_sym_int224] = ACTIONS(829),
    [anon_sym_int232] = ACTIONS(829),
    [anon_sym_int240] = ACTIONS(829),
    [anon_sym_int248] = ACTIONS(829),
    [anon_sym_int256] = ACTIONS(829),
    [anon_sym_uint] = ACTIONS(829),
    [anon_sym_uint8] = ACTIONS(829),
    [anon_sym_uint16] = ACTIONS(829),
    [anon_sym_uint24] = ACTIONS(829),
    [anon_sym_uint32] = ACTIONS(829),
    [anon_sym_uint40] = ACTIONS(829),
    [anon_sym_uint48] = ACTIONS(829),
    [anon_sym_uint56] = ACTIONS(829),
    [anon_sym_uint64] = ACTIONS(829),
    [anon_sym_uint72] = ACTIONS(829),
    [anon_sym_uint80] = ACTIONS(829),
    [anon_sym_uint88] = ACTIONS(829),
    [anon_sym_uint96] = ACTIONS(829),
    [anon_sym_uint104] = ACTIONS(829),
    [anon_sym_uint112] = ACTIONS(829),
    [anon_sym_uint120] = ACTIONS(829),
    [anon_sym_uint128] = ACTIONS(829),
    [anon_sym_uint136] = ACTIONS(829),
    [anon_sym_uint144] = ACTIONS(829),
    [anon_sym_uint152] = ACTIONS(829),
    [anon_sym_uint160] = ACTIONS(829),
    [anon_sym_uint168] = ACTIONS(829),
    [anon_sym_uint176] = ACTIONS(829),
    [anon_sym_uint184] = ACTIONS(829),
    [anon_sym_uint192] = ACTIONS(829),
    [anon_sym_uint200] = ACTIONS(829),
    [anon_sym_uint208] = ACTIONS(829),
    [anon_sym_uint216] = ACTIONS(829),
    [anon_sym_uint224] = ACTIONS(829),
    [anon_sym_uint232] = ACTIONS(829),
    [anon_sym_uint240] = ACTIONS(829),
    [anon_sym_uint248] = ACTIONS(829),
    [anon_sym_uint256] = ACTIONS(829),
    [anon_sym_bytes] = ACTIONS(829),
    [anon_sym_bytes1] = ACTIONS(829),
    [anon_sym_bytes2] = ACTIONS(829),
    [anon_sym_bytes3] = ACTIONS(829),
    [anon_sym_bytes4] = ACTIONS(829),
    [anon_sym_bytes5] = ACTIONS(829),
    [anon_sym_bytes6] = ACTIONS(829),
    [anon_sym_bytes7] = ACTIONS(829),
    [anon_sym_bytes8] = ACTIONS(829),
    [anon_sym_bytes9] = ACTIONS(829),
    [anon_sym_bytes10] = ACTIONS(829),
    [anon_sym_bytes11] = ACTIONS(829),
    [anon_sym_bytes12] = ACTIONS(829),
    [anon_sym_bytes13] = ACTIONS(829),
    [anon_sym_bytes14] = ACTIONS(829),
    [anon_sym_bytes15] = ACTIONS(829),
    [anon_sym_bytes16] = ACTIONS(829),
    [anon_sym_bytes17] = ACTIONS(829),
    [anon_sym_bytes18] = ACTIONS(829),
    [anon_sym_bytes19] = ACTIONS(829),
    [anon_sym_bytes20] = ACTIONS(829),
    [anon_sym_bytes21] = ACTIONS(829),
    [anon_sym_bytes22] = ACTIONS(829),
    [anon_sym_bytes23] = ACTIONS(829),
    [anon_sym_bytes24] = ACTIONS(829),
    [anon_sym_bytes25] = ACTIONS(829),
    [anon_sym_bytes26] = ACTIONS(829),
    [anon_sym_bytes27] = ACTIONS(829),
    [anon_sym_bytes28] = ACTIONS(829),
    [anon_sym_bytes29] = ACTIONS(829),
    [anon_sym_bytes30] = ACTIONS(829),
    [anon_sym_bytes31] = ACTIONS(829),
    [anon_sym_bytes32] = ACTIONS(829),
    [anon_sym_fixed] = ACTIONS(829),
    [aux_sym__fixed_token1] = ACTIONS(829),
    [anon_sym_ufixed] = ACTIONS(829),
    [aux_sym__ufixed_token1] = ACTIONS(829),
    [sym_comment] = ACTIONS(3),
  },
  [221] = {
    [sym_identifier] = ACTIONS(777),
    [anon_sym_RBRACE] = ACTIONS(775),
    [anon_sym_type] = ACTIONS(777),
    [anon_sym_error] = ACTIONS(777),
    [anon_sym_struct] = ACTIONS(777),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_event] = ACTIONS(777),
    [anon_sym_using] = ACTIONS(777),
    [anon_sym_function] = ACTIONS(777),
    [anon_sym_byte] = ACTIONS(777),
    [anon_sym_address] = ACTIONS(777),
    [anon_sym_var] = ACTIONS(777),
    [anon_sym_modifier] = ACTIONS(777),
    [anon_sym_constructor] = ACTIONS(777),
    [anon_sym_fallback] = ACTIONS(777),
    [anon_sym_receive] = ACTIONS(777),
    [anon_sym_mapping] = ACTIONS(777),
    [anon_sym_bool] = ACTIONS(777),
    [anon_sym_string] = ACTIONS(777),
    [anon_sym_int] = ACTIONS(777),
    [anon_sym_int8] = ACTIONS(777),
    [anon_sym_int16] = ACTIONS(777),
    [anon_sym_int24] = ACTIONS(777),
    [anon_sym_int32] = ACTIONS(777),
    [anon_sym_int40] = ACTIONS(777),
    [anon_sym_int48] = ACTIONS(777),
    [anon_sym_int56] = ACTIONS(777),
    [anon_sym_int64] = ACTIONS(777),
    [anon_sym_int72] = ACTIONS(777),
    [anon_sym_int80] = ACTIONS(777),
    [anon_sym_int88] = ACTIONS(777),
    [anon_sym_int96] = ACTIONS(777),
    [anon_sym_int104] = ACTIONS(777),
    [anon_sym_int112] = ACTIONS(777),
    [anon_sym_int120] = ACTIONS(777),
    [anon_sym_int128] = ACTIONS(777),
    [anon_sym_int136] = ACTIONS(777),
    [anon_sym_int144] = ACTIONS(777),
    [anon_sym_int152] = ACTIONS(777),
    [anon_sym_int160] = ACTIONS(777),
    [anon_sym_int168] = ACTIONS(777),
    [anon_sym_int176] = ACTIONS(777),
    [anon_sym_int184] = ACTIONS(777),
    [anon_sym_int192] = ACTIONS(777),
    [anon_sym_int200] = ACTIONS(777),
    [anon_sym_int208] = ACTIONS(777),
    [anon_sym_int216] = ACTIONS(777),
    [anon_sym_int224] = ACTIONS(777),
    [anon_sym_int232] = ACTIONS(777),
    [anon_sym_int240] = ACTIONS(777),
    [anon_sym_int248] = ACTIONS(777),
    [anon_sym_int256] = ACTIONS(777),
    [anon_sym_uint] = ACTIONS(777),
    [anon_sym_uint8] = ACTIONS(777),
    [anon_sym_uint16] = ACTIONS(777),
    [anon_sym_uint24] = ACTIONS(777),
    [anon_sym_uint32] = ACTIONS(777),
    [anon_sym_uint40] = ACTIONS(777),
    [anon_sym_uint48] = ACTIONS(777),
    [anon_sym_uint56] = ACTIONS(777),
    [anon_sym_uint64] = ACTIONS(777),
    [anon_sym_uint72] = ACTIONS(777),
    [anon_sym_uint80] = ACTIONS(777),
    [anon_sym_uint88] = ACTIONS(777),
    [anon_sym_uint96] = ACTIONS(777),
    [anon_sym_uint104] = ACTIONS(777),
    [anon_sym_uint112] = ACTIONS(777),
    [anon_sym_uint120] = ACTIONS(777),
    [anon_sym_uint128] = ACTIONS(777),
    [anon_sym_uint136] = ACTIONS(777),
    [anon_sym_uint144] = ACTIONS(777),
    [anon_sym_uint152] = ACTIONS(777),
    [anon_sym_uint160] = ACTIONS(777),
    [anon_sym_uint168] = ACTIONS(777),
    [anon_sym_uint176] = ACTIONS(777),
    [anon_sym_uint184] = ACTIONS(777),
    [anon_sym_uint192] = ACTIONS(777),
    [anon_sym_uint200] = ACTIONS(777),
    [anon_sym_uint208] = ACTIONS(777),
    [anon_sym_uint216] = ACTIONS(777),
    [anon_sym_uint224] = ACTIONS(777),
    [anon_sym_uint232] = ACTIONS(777),
    [anon_sym_uint240] = ACTIONS(777),
    [anon_sym_uint248] = ACTIONS(777),
    [anon_sym_uint256] = ACTIONS(777),
    [anon_sym_bytes] = ACTIONS(777),
    [anon_sym_bytes1] = ACTIONS(777),
    [anon_sym_bytes2] = ACTIONS(777),
    [anon_sym_bytes3] = ACTIONS(777),
    [anon_sym_bytes4] = ACTIONS(777),
    [anon_sym_bytes5] = ACTIONS(777),
    [anon_sym_bytes6] = ACTIONS(777),
    [anon_sym_bytes7] = ACTIONS(777),
    [anon_sym_bytes8] = ACTIONS(777),
    [anon_sym_bytes9] = ACTIONS(777),
    [anon_sym_bytes10] = ACTIONS(777),
    [anon_sym_bytes11] = ACTIONS(777),
    [anon_sym_bytes12] = ACTIONS(777),
    [anon_sym_bytes13] = ACTIONS(777),
    [anon_sym_bytes14] = ACTIONS(777),
    [anon_sym_bytes15] = ACTIONS(777),
    [anon_sym_bytes16] = ACTIONS(777),
    [anon_sym_bytes17] = ACTIONS(777),
    [anon_sym_bytes18] = ACTIONS(777),
    [anon_sym_bytes19] = ACTIONS(777),
    [anon_sym_bytes20] = ACTIONS(777),
    [anon_sym_bytes21] = ACTIONS(777),
    [anon_sym_bytes22] = ACTIONS(777),
    [anon_sym_bytes23] = ACTIONS(777),
    [anon_sym_bytes24] = ACTIONS(777),
    [anon_sym_bytes25] = ACTIONS(777),
    [anon_sym_bytes26] = ACTIONS(777),
    [anon_sym_bytes27] = ACTIONS(777),
    [anon_sym_bytes28] = ACTIONS(777),
    [anon_sym_bytes29] = ACTIONS(777),
    [anon_sym_bytes30] = ACTIONS(777),
    [anon_sym_bytes31] = ACTIONS(777),
    [anon_sym_bytes32] = ACTIONS(777),
    [anon_sym_fixed] = ACTIONS(777),
    [aux_sym__fixed_token1] = ACTIONS(777),
    [anon_sym_ufixed] = ACTIONS(777),
    [aux_sym__ufixed_token1] = ACTIONS(777),
    [sym_comment] = ACTIONS(3),
  },
  [222] = {
    [sym_identifier] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(835),
    [anon_sym_type] = ACTIONS(833),
    [anon_sym_error] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(833),
    [anon_sym_enum] = ACTIONS(833),
    [anon_sym_event] = ACTIONS(833),
    [anon_sym_using] = ACTIONS(833),
    [anon_sym_function] = ACTIONS(833),
    [anon_sym_byte] = ACTIONS(833),
    [anon_sym_address] = ACTIONS(833),
    [anon_sym_var] = ACTIONS(833),
    [anon_sym_modifier] = ACTIONS(833),
    [anon_sym_constructor] = ACTIONS(833),
    [anon_sym_fallback] = ACTIONS(833),
    [anon_sym_receive] = ACTIONS(833),
    [anon_sym_mapping] = ACTIONS(833),
    [anon_sym_bool] = ACTIONS(833),
    [anon_sym_string] = ACTIONS(833),
    [anon_sym_int] = ACTIONS(833),
    [anon_sym_int8] = ACTIONS(833),
    [anon_sym_int16] = ACTIONS(833),
    [anon_sym_int24] = ACTIONS(833),
    [anon_sym_int32] = ACTIONS(833),
    [anon_sym_int40] = ACTIONS(833),
    [anon_sym_int48] = ACTIONS(833),
    [anon_sym_int56] = ACTIONS(833),
    [anon_sym_int64] = ACTIONS(833),
    [anon_sym_int72] = ACTIONS(833),
    [anon_sym_int80] = ACTIONS(833),
    [anon_sym_int88] = ACTIONS(833),
    [anon_sym_int96] = ACTIONS(833),
    [anon_sym_int104] = ACTIONS(833),
    [anon_sym_int112] = ACTIONS(833),
    [anon_sym_int120] = ACTIONS(833),
    [anon_sym_int128] = ACTIONS(833),
    [anon_sym_int136] = ACTIONS(833),
    [anon_sym_int144] = ACTIONS(833),
    [anon_sym_int152] = ACTIONS(833),
    [anon_sym_int160] = ACTIONS(833),
    [anon_sym_int168] = ACTIONS(833),
    [anon_sym_int176] = ACTIONS(833),
    [anon_sym_int184] = ACTIONS(833),
    [anon_sym_int192] = ACTIONS(833),
    [anon_sym_int200] = ACTIONS(833),
    [anon_sym_int208] = ACTIONS(833),
    [anon_sym_int216] = ACTIONS(833),
    [anon_sym_int224] = ACTIONS(833),
    [anon_sym_int232] = ACTIONS(833),
    [anon_sym_int240] = ACTIONS(833),
    [anon_sym_int248] = ACTIONS(833),
    [anon_sym_int256] = ACTIONS(833),
    [anon_sym_uint] = ACTIONS(833),
    [anon_sym_uint8] = ACTIONS(833),
    [anon_sym_uint16] = ACTIONS(833),
    [anon_sym_uint24] = ACTIONS(833),
    [anon_sym_uint32] = ACTIONS(833),
    [anon_sym_uint40] = ACTIONS(833),
    [anon_sym_uint48] = ACTIONS(833),
    [anon_sym_uint56] = ACTIONS(833),
    [anon_sym_uint64] = ACTIONS(833),
    [anon_sym_uint72] = ACTIONS(833),
    [anon_sym_uint80] = ACTIONS(833),
    [anon_sym_uint88] = ACTIONS(833),
    [anon_sym_uint96] = ACTIONS(833),
    [anon_sym_uint104] = ACTIONS(833),
    [anon_sym_uint112] = ACTIONS(833),
    [anon_sym_uint120] = ACTIONS(833),
    [anon_sym_uint128] = ACTIONS(833),
    [anon_sym_uint136] = ACTIONS(833),
    [anon_sym_uint144] = ACTIONS(833),
    [anon_sym_uint152] = ACTIONS(833),
    [anon_sym_uint160] = ACTIONS(833),
    [anon_sym_uint168] = ACTIONS(833),
    [anon_sym_uint176] = ACTIONS(833),
    [anon_sym_uint184] = ACTIONS(833),
    [anon_sym_uint192] = ACTIONS(833),
    [anon_sym_uint200] = ACTIONS(833),
    [anon_sym_uint208] = ACTIONS(833),
    [anon_sym_uint216] = ACTIONS(833),
    [anon_sym_uint224] = ACTIONS(833),
    [anon_sym_uint232] = ACTIONS(833),
    [anon_sym_uint240] = ACTIONS(833),
    [anon_sym_uint248] = ACTIONS(833),
    [anon_sym_uint256] = ACTIONS(833),
    [anon_sym_bytes] = ACTIONS(833),
    [anon_sym_bytes1] = ACTIONS(833),
    [anon_sym_bytes2] = ACTIONS(833),
    [anon_sym_bytes3] = ACTIONS(833),
    [anon_sym_bytes4] = ACTIONS(833),
    [anon_sym_bytes5] = ACTIONS(833),
    [anon_sym_bytes6] = ACTIONS(833),
    [anon_sym_bytes7] = ACTIONS(833),
    [anon_sym_bytes8] = ACTIONS(833),
    [anon_sym_bytes9] = ACTIONS(833),
    [anon_sym_bytes10] = ACTIONS(833),
    [anon_sym_bytes11] = ACTIONS(833),
    [anon_sym_bytes12] = ACTIONS(833),
    [anon_sym_bytes13] = ACTIONS(833),
    [anon_sym_bytes14] = ACTIONS(833),
    [anon_sym_bytes15] = ACTIONS(833),
    [anon_sym_bytes16] = ACTIONS(833),
    [anon_sym_bytes17] = ACTIONS(833),
    [anon_sym_bytes18] = ACTIONS(833),
    [anon_sym_bytes19] = ACTIONS(833),
    [anon_sym_bytes20] = ACTIONS(833),
    [anon_sym_bytes21] = ACTIONS(833),
    [anon_sym_bytes22] = ACTIONS(833),
    [anon_sym_bytes23] = ACTIONS(833),
    [anon_sym_bytes24] = ACTIONS(833),
    [anon_sym_bytes25] = ACTIONS(833),
    [anon_sym_bytes26] = ACTIONS(833),
    [anon_sym_bytes27] = ACTIONS(833),
    [anon_sym_bytes28] = ACTIONS(833),
    [anon_sym_bytes29] = ACTIONS(833),
    [anon_sym_bytes30] = ACTIONS(833),
    [anon_sym_bytes31] = ACTIONS(833),
    [anon_sym_bytes32] = ACTIONS(833),
    [anon_sym_fixed] = ACTIONS(833),
    [aux_sym__fixed_token1] = ACTIONS(833),
    [anon_sym_ufixed] = ACTIONS(833),
    [aux_sym__ufixed_token1] = ACTIONS(833),
    [sym_comment] = ACTIONS(3),
  },
  [223] = {
    [sym_identifier] = ACTIONS(837),
    [anon_sym_RBRACE] = ACTIONS(839),
    [anon_sym_type] = ACTIONS(837),
    [anon_sym_error] = ACTIONS(837),
    [anon_sym_struct] = ACTIONS(837),
    [anon_sym_enum] = ACTIONS(837),
    [anon_sym_event] = ACTIONS(837),
    [anon_sym_using] = ACTIONS(837),
    [anon_sym_function] = ACTIONS(837),
    [anon_sym_byte] = ACTIONS(837),
    [anon_sym_address] = ACTIONS(837),
    [anon_sym_var] = ACTIONS(837),
    [anon_sym_modifier] = ACTIONS(837),
    [anon_sym_constructor] = ACTIONS(837),
    [anon_sym_fallback] = ACTIONS(837),
    [anon_sym_receive] = ACTIONS(837),
    [anon_sym_mapping] = ACTIONS(837),
    [anon_sym_bool] = ACTIONS(837),
    [anon_sym_string] = ACTIONS(837),
    [anon_sym_int] = ACTIONS(837),
    [anon_sym_int8] = ACTIONS(837),
    [anon_sym_int16] = ACTIONS(837),
    [anon_sym_int24] = ACTIONS(837),
    [anon_sym_int32] = ACTIONS(837),
    [anon_sym_int40] = ACTIONS(837),
    [anon_sym_int48] = ACTIONS(837),
    [anon_sym_int56] = ACTIONS(837),
    [anon_sym_int64] = ACTIONS(837),
    [anon_sym_int72] = ACTIONS(837),
    [anon_sym_int80] = ACTIONS(837),
    [anon_sym_int88] = ACTIONS(837),
    [anon_sym_int96] = ACTIONS(837),
    [anon_sym_int104] = ACTIONS(837),
    [anon_sym_int112] = ACTIONS(837),
    [anon_sym_int120] = ACTIONS(837),
    [anon_sym_int128] = ACTIONS(837),
    [anon_sym_int136] = ACTIONS(837),
    [anon_sym_int144] = ACTIONS(837),
    [anon_sym_int152] = ACTIONS(837),
    [anon_sym_int160] = ACTIONS(837),
    [anon_sym_int168] = ACTIONS(837),
    [anon_sym_int176] = ACTIONS(837),
    [anon_sym_int184] = ACTIONS(837),
    [anon_sym_int192] = ACTIONS(837),
    [anon_sym_int200] = ACTIONS(837),
    [anon_sym_int208] = ACTIONS(837),
    [anon_sym_int216] = ACTIONS(837),
    [anon_sym_int224] = ACTIONS(837),
    [anon_sym_int232] = ACTIONS(837),
    [anon_sym_int240] = ACTIONS(837),
    [anon_sym_int248] = ACTIONS(837),
    [anon_sym_int256] = ACTIONS(837),
    [anon_sym_uint] = ACTIONS(837),
    [anon_sym_uint8] = ACTIONS(837),
    [anon_sym_uint16] = ACTIONS(837),
    [anon_sym_uint24] = ACTIONS(837),
    [anon_sym_uint32] = ACTIONS(837),
    [anon_sym_uint40] = ACTIONS(837),
    [anon_sym_uint48] = ACTIONS(837),
    [anon_sym_uint56] = ACTIONS(837),
    [anon_sym_uint64] = ACTIONS(837),
    [anon_sym_uint72] = ACTIONS(837),
    [anon_sym_uint80] = ACTIONS(837),
    [anon_sym_uint88] = ACTIONS(837),
    [anon_sym_uint96] = ACTIONS(837),
    [anon_sym_uint104] = ACTIONS(837),
    [anon_sym_uint112] = ACTIONS(837),
    [anon_sym_uint120] = ACTIONS(837),
    [anon_sym_uint128] = ACTIONS(837),
    [anon_sym_uint136] = ACTIONS(837),
    [anon_sym_uint144] = ACTIONS(837),
    [anon_sym_uint152] = ACTIONS(837),
    [anon_sym_uint160] = ACTIONS(837),
    [anon_sym_uint168] = ACTIONS(837),
    [anon_sym_uint176] = ACTIONS(837),
    [anon_sym_uint184] = ACTIONS(837),
    [anon_sym_uint192] = ACTIONS(837),
    [anon_sym_uint200] = ACTIONS(837),
    [anon_sym_uint208] = ACTIONS(837),
    [anon_sym_uint216] = ACTIONS(837),
    [anon_sym_uint224] = ACTIONS(837),
    [anon_sym_uint232] = ACTIONS(837),
    [anon_sym_uint240] = ACTIONS(837),
    [anon_sym_uint248] = ACTIONS(837),
    [anon_sym_uint256] = ACTIONS(837),
    [anon_sym_bytes] = ACTIONS(837),
    [anon_sym_bytes1] = ACTIONS(837),
    [anon_sym_bytes2] = ACTIONS(837),
    [anon_sym_bytes3] = ACTIONS(837),
    [anon_sym_bytes4] = ACTIONS(837),
    [anon_sym_bytes5] = ACTIONS(837),
    [anon_sym_bytes6] = ACTIONS(837),
    [anon_sym_bytes7] = ACTIONS(837),
    [anon_sym_bytes8] = ACTIONS(837),
    [anon_sym_bytes9] = ACTIONS(837),
    [anon_sym_bytes10] = ACTIONS(837),
    [anon_sym_bytes11] = ACTIONS(837),
    [anon_sym_bytes12] = ACTIONS(837),
    [anon_sym_bytes13] = ACTIONS(837),
    [anon_sym_bytes14] = ACTIONS(837),
    [anon_sym_bytes15] = ACTIONS(837),
    [anon_sym_bytes16] = ACTIONS(837),
    [anon_sym_bytes17] = ACTIONS(837),
    [anon_sym_bytes18] = ACTIONS(837),
    [anon_sym_bytes19] = ACTIONS(837),
    [anon_sym_bytes20] = ACTIONS(837),
    [anon_sym_bytes21] = ACTIONS(837),
    [anon_sym_bytes22] = ACTIONS(837),
    [anon_sym_bytes23] = ACTIONS(837),
    [anon_sym_bytes24] = ACTIONS(837),
    [anon_sym_bytes25] = ACTIONS(837),
    [anon_sym_bytes26] = ACTIONS(837),
    [anon_sym_bytes27] = ACTIONS(837),
    [anon_sym_bytes28] = ACTIONS(837),
    [anon_sym_bytes29] = ACTIONS(837),
    [anon_sym_bytes30] = ACTIONS(837),
    [anon_sym_bytes31] = ACTIONS(837),
    [anon_sym_bytes32] = ACTIONS(837),
    [anon_sym_fixed] = ACTIONS(837),
    [aux_sym__fixed_token1] = ACTIONS(837),
    [anon_sym_ufixed] = ACTIONS(837),
    [aux_sym__ufixed_token1] = ACTIONS(837),
    [sym_comment] = ACTIONS(3),
  },
  [224] = {
    [sym_identifier] = ACTIONS(841),
    [anon_sym_RBRACE] = ACTIONS(843),
    [anon_sym_type] = ACTIONS(841),
    [anon_sym_error] = ACTIONS(841),
    [anon_sym_struct] = ACTIONS(841),
    [anon_sym_enum] = ACTIONS(841),
    [anon_sym_event] = ACTIONS(841),
    [anon_sym_using] = ACTIONS(841),
    [anon_sym_function] = ACTIONS(841),
    [anon_sym_byte] = ACTIONS(841),
    [anon_sym_address] = ACTIONS(841),
    [anon_sym_var] = ACTIONS(841),
    [anon_sym_modifier] = ACTIONS(841),
    [anon_sym_constructor] = ACTIONS(841),
    [anon_sym_fallback] = ACTIONS(841),
    [anon_sym_receive] = ACTIONS(841),
    [anon_sym_mapping] = ACTIONS(841),
    [anon_sym_bool] = ACTIONS(841),
    [anon_sym_string] = ACTIONS(841),
    [anon_sym_int] = ACTIONS(841),
    [anon_sym_int8] = ACTIONS(841),
    [anon_sym_int16] = ACTIONS(841),
    [anon_sym_int24] = ACTIONS(841),
    [anon_sym_int32] = ACTIONS(841),
    [anon_sym_int40] = ACTIONS(841),
    [anon_sym_int48] = ACTIONS(841),
    [anon_sym_int56] = ACTIONS(841),
    [anon_sym_int64] = ACTIONS(841),
    [anon_sym_int72] = ACTIONS(841),
    [anon_sym_int80] = ACTIONS(841),
    [anon_sym_int88] = ACTIONS(841),
    [anon_sym_int96] = ACTIONS(841),
    [anon_sym_int104] = ACTIONS(841),
    [anon_sym_int112] = ACTIONS(841),
    [anon_sym_int120] = ACTIONS(841),
    [anon_sym_int128] = ACTIONS(841),
    [anon_sym_int136] = ACTIONS(841),
    [anon_sym_int144] = ACTIONS(841),
    [anon_sym_int152] = ACTIONS(841),
    [anon_sym_int160] = ACTIONS(841),
    [anon_sym_int168] = ACTIONS(841),
    [anon_sym_int176] = ACTIONS(841),
    [anon_sym_int184] = ACTIONS(841),
    [anon_sym_int192] = ACTIONS(841),
    [anon_sym_int200] = ACTIONS(841),
    [anon_sym_int208] = ACTIONS(841),
    [anon_sym_int216] = ACTIONS(841),
    [anon_sym_int224] = ACTIONS(841),
    [anon_sym_int232] = ACTIONS(841),
    [anon_sym_int240] = ACTIONS(841),
    [anon_sym_int248] = ACTIONS(841),
    [anon_sym_int256] = ACTIONS(841),
    [anon_sym_uint] = ACTIONS(841),
    [anon_sym_uint8] = ACTIONS(841),
    [anon_sym_uint16] = ACTIONS(841),
    [anon_sym_uint24] = ACTIONS(841),
    [anon_sym_uint32] = ACTIONS(841),
    [anon_sym_uint40] = ACTIONS(841),
    [anon_sym_uint48] = ACTIONS(841),
    [anon_sym_uint56] = ACTIONS(841),
    [anon_sym_uint64] = ACTIONS(841),
    [anon_sym_uint72] = ACTIONS(841),
    [anon_sym_uint80] = ACTIONS(841),
    [anon_sym_uint88] = ACTIONS(841),
    [anon_sym_uint96] = ACTIONS(841),
    [anon_sym_uint104] = ACTIONS(841),
    [anon_sym_uint112] = ACTIONS(841),
    [anon_sym_uint120] = ACTIONS(841),
    [anon_sym_uint128] = ACTIONS(841),
    [anon_sym_uint136] = ACTIONS(841),
    [anon_sym_uint144] = ACTIONS(841),
    [anon_sym_uint152] = ACTIONS(841),
    [anon_sym_uint160] = ACTIONS(841),
    [anon_sym_uint168] = ACTIONS(841),
    [anon_sym_uint176] = ACTIONS(841),
    [anon_sym_uint184] = ACTIONS(841),
    [anon_sym_uint192] = ACTIONS(841),
    [anon_sym_uint200] = ACTIONS(841),
    [anon_sym_uint208] = ACTIONS(841),
    [anon_sym_uint216] = ACTIONS(841),
    [anon_sym_uint224] = ACTIONS(841),
    [anon_sym_uint232] = ACTIONS(841),
    [anon_sym_uint240] = ACTIONS(841),
    [anon_sym_uint248] = ACTIONS(841),
    [anon_sym_uint256] = ACTIONS(841),
    [anon_sym_bytes] = ACTIONS(841),
    [anon_sym_bytes1] = ACTIONS(841),
    [anon_sym_bytes2] = ACTIONS(841),
    [anon_sym_bytes3] = ACTIONS(841),
    [anon_sym_bytes4] = ACTIONS(841),
    [anon_sym_bytes5] = ACTIONS(841),
    [anon_sym_bytes6] = ACTIONS(841),
    [anon_sym_bytes7] = ACTIONS(841),
    [anon_sym_bytes8] = ACTIONS(841),
    [anon_sym_bytes9] = ACTIONS(841),
    [anon_sym_bytes10] = ACTIONS(841),
    [anon_sym_bytes11] = ACTIONS(841),
    [anon_sym_bytes12] = ACTIONS(841),
    [anon_sym_bytes13] = ACTIONS(841),
    [anon_sym_bytes14] = ACTIONS(841),
    [anon_sym_bytes15] = ACTIONS(841),
    [anon_sym_bytes16] = ACTIONS(841),
    [anon_sym_bytes17] = ACTIONS(841),
    [anon_sym_bytes18] = ACTIONS(841),
    [anon_sym_bytes19] = ACTIONS(841),
    [anon_sym_bytes20] = ACTIONS(841),
    [anon_sym_bytes21] = ACTIONS(841),
    [anon_sym_bytes22] = ACTIONS(841),
    [anon_sym_bytes23] = ACTIONS(841),
    [anon_sym_bytes24] = ACTIONS(841),
    [anon_sym_bytes25] = ACTIONS(841),
    [anon_sym_bytes26] = ACTIONS(841),
    [anon_sym_bytes27] = ACTIONS(841),
    [anon_sym_bytes28] = ACTIONS(841),
    [anon_sym_bytes29] = ACTIONS(841),
    [anon_sym_bytes30] = ACTIONS(841),
    [anon_sym_bytes31] = ACTIONS(841),
    [anon_sym_bytes32] = ACTIONS(841),
    [anon_sym_fixed] = ACTIONS(841),
    [aux_sym__fixed_token1] = ACTIONS(841),
    [anon_sym_ufixed] = ACTIONS(841),
    [aux_sym__ufixed_token1] = ACTIONS(841),
    [sym_comment] = ACTIONS(3),
  },
  [225] = {
    [sym_identifier] = ACTIONS(845),
    [anon_sym_RBRACE] = ACTIONS(847),
    [anon_sym_type] = ACTIONS(845),
    [anon_sym_error] = ACTIONS(845),
    [anon_sym_struct] = ACTIONS(845),
    [anon_sym_enum] = ACTIONS(845),
    [anon_sym_event] = ACTIONS(845),
    [anon_sym_using] = ACTIONS(845),
    [anon_sym_function] = ACTIONS(845),
    [anon_sym_byte] = ACTIONS(845),
    [anon_sym_address] = ACTIONS(845),
    [anon_sym_var] = ACTIONS(845),
    [anon_sym_modifier] = ACTIONS(845),
    [anon_sym_constructor] = ACTIONS(845),
    [anon_sym_fallback] = ACTIONS(845),
    [anon_sym_receive] = ACTIONS(845),
    [anon_sym_mapping] = ACTIONS(845),
    [anon_sym_bool] = ACTIONS(845),
    [anon_sym_string] = ACTIONS(845),
    [anon_sym_int] = ACTIONS(845),
    [anon_sym_int8] = ACTIONS(845),
    [anon_sym_int16] = ACTIONS(845),
    [anon_sym_int24] = ACTIONS(845),
    [anon_sym_int32] = ACTIONS(845),
    [anon_sym_int40] = ACTIONS(845),
    [anon_sym_int48] = ACTIONS(845),
    [anon_sym_int56] = ACTIONS(845),
    [anon_sym_int64] = ACTIONS(845),
    [anon_sym_int72] = ACTIONS(845),
    [anon_sym_int80] = ACTIONS(845),
    [anon_sym_int88] = ACTIONS(845),
    [anon_sym_int96] = ACTIONS(845),
    [anon_sym_int104] = ACTIONS(845),
    [anon_sym_int112] = ACTIONS(845),
    [anon_sym_int120] = ACTIONS(845),
    [anon_sym_int128] = ACTIONS(845),
    [anon_sym_int136] = ACTIONS(845),
    [anon_sym_int144] = ACTIONS(845),
    [anon_sym_int152] = ACTIONS(845),
    [anon_sym_int160] = ACTIONS(845),
    [anon_sym_int168] = ACTIONS(845),
    [anon_sym_int176] = ACTIONS(845),
    [anon_sym_int184] = ACTIONS(845),
    [anon_sym_int192] = ACTIONS(845),
    [anon_sym_int200] = ACTIONS(845),
    [anon_sym_int208] = ACTIONS(845),
    [anon_sym_int216] = ACTIONS(845),
    [anon_sym_int224] = ACTIONS(845),
    [anon_sym_int232] = ACTIONS(845),
    [anon_sym_int240] = ACTIONS(845),
    [anon_sym_int248] = ACTIONS(845),
    [anon_sym_int256] = ACTIONS(845),
    [anon_sym_uint] = ACTIONS(845),
    [anon_sym_uint8] = ACTIONS(845),
    [anon_sym_uint16] = ACTIONS(845),
    [anon_sym_uint24] = ACTIONS(845),
    [anon_sym_uint32] = ACTIONS(845),
    [anon_sym_uint40] = ACTIONS(845),
    [anon_sym_uint48] = ACTIONS(845),
    [anon_sym_uint56] = ACTIONS(845),
    [anon_sym_uint64] = ACTIONS(845),
    [anon_sym_uint72] = ACTIONS(845),
    [anon_sym_uint80] = ACTIONS(845),
    [anon_sym_uint88] = ACTIONS(845),
    [anon_sym_uint96] = ACTIONS(845),
    [anon_sym_uint104] = ACTIONS(845),
    [anon_sym_uint112] = ACTIONS(845),
    [anon_sym_uint120] = ACTIONS(845),
    [anon_sym_uint128] = ACTIONS(845),
    [anon_sym_uint136] = ACTIONS(845),
    [anon_sym_uint144] = ACTIONS(845),
    [anon_sym_uint152] = ACTIONS(845),
    [anon_sym_uint160] = ACTIONS(845),
    [anon_sym_uint168] = ACTIONS(845),
    [anon_sym_uint176] = ACTIONS(845),
    [anon_sym_uint184] = ACTIONS(845),
    [anon_sym_uint192] = ACTIONS(845),
    [anon_sym_uint200] = ACTIONS(845),
    [anon_sym_uint208] = ACTIONS(845),
    [anon_sym_uint216] = ACTIONS(845),
    [anon_sym_uint224] = ACTIONS(845),
    [anon_sym_uint232] = ACTIONS(845),
    [anon_sym_uint240] = ACTIONS(845),
    [anon_sym_uint248] = ACTIONS(845),
    [anon_sym_uint256] = ACTIONS(845),
    [anon_sym_bytes] = ACTIONS(845),
    [anon_sym_bytes1] = ACTIONS(845),
    [anon_sym_bytes2] = ACTIONS(845),
    [anon_sym_bytes3] = ACTIONS(845),
    [anon_sym_bytes4] = ACTIONS(845),
    [anon_sym_bytes5] = ACTIONS(845),
    [anon_sym_bytes6] = ACTIONS(845),
    [anon_sym_bytes7] = ACTIONS(845),
    [anon_sym_bytes8] = ACTIONS(845),
    [anon_sym_bytes9] = ACTIONS(845),
    [anon_sym_bytes10] = ACTIONS(845),
    [anon_sym_bytes11] = ACTIONS(845),
    [anon_sym_bytes12] = ACTIONS(845),
    [anon_sym_bytes13] = ACTIONS(845),
    [anon_sym_bytes14] = ACTIONS(845),
    [anon_sym_bytes15] = ACTIONS(845),
    [anon_sym_bytes16] = ACTIONS(845),
    [anon_sym_bytes17] = ACTIONS(845),
    [anon_sym_bytes18] = ACTIONS(845),
    [anon_sym_bytes19] = ACTIONS(845),
    [anon_sym_bytes20] = ACTIONS(845),
    [anon_sym_bytes21] = ACTIONS(845),
    [anon_sym_bytes22] = ACTIONS(845),
    [anon_sym_bytes23] = ACTIONS(845),
    [anon_sym_bytes24] = ACTIONS(845),
    [anon_sym_bytes25] = ACTIONS(845),
    [anon_sym_bytes26] = ACTIONS(845),
    [anon_sym_bytes27] = ACTIONS(845),
    [anon_sym_bytes28] = ACTIONS(845),
    [anon_sym_bytes29] = ACTIONS(845),
    [anon_sym_bytes30] = ACTIONS(845),
    [anon_sym_bytes31] = ACTIONS(845),
    [anon_sym_bytes32] = ACTIONS(845),
    [anon_sym_fixed] = ACTIONS(845),
    [aux_sym__fixed_token1] = ACTIONS(845),
    [anon_sym_ufixed] = ACTIONS(845),
    [aux_sym__ufixed_token1] = ACTIONS(845),
    [sym_comment] = ACTIONS(3),
  },
  [226] = {
    [sym_identifier] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_type] = ACTIONS(769),
    [anon_sym_error] = ACTIONS(769),
    [anon_sym_struct] = ACTIONS(769),
    [anon_sym_enum] = ACTIONS(769),
    [anon_sym_event] = ACTIONS(769),
    [anon_sym_using] = ACTIONS(769),
    [anon_sym_function] = ACTIONS(769),
    [anon_sym_byte] = ACTIONS(769),
    [anon_sym_address] = ACTIONS(769),
    [anon_sym_var] = ACTIONS(769),
    [anon_sym_modifier] = ACTIONS(769),
    [anon_sym_constructor] = ACTIONS(769),
    [anon_sym_fallback] = ACTIONS(769),
    [anon_sym_receive] = ACTIONS(769),
    [anon_sym_mapping] = ACTIONS(769),
    [anon_sym_bool] = ACTIONS(769),
    [anon_sym_string] = ACTIONS(769),
    [anon_sym_int] = ACTIONS(769),
    [anon_sym_int8] = ACTIONS(769),
    [anon_sym_int16] = ACTIONS(769),
    [anon_sym_int24] = ACTIONS(769),
    [anon_sym_int32] = ACTIONS(769),
    [anon_sym_int40] = ACTIONS(769),
    [anon_sym_int48] = ACTIONS(769),
    [anon_sym_int56] = ACTIONS(769),
    [anon_sym_int64] = ACTIONS(769),
    [anon_sym_int72] = ACTIONS(769),
    [anon_sym_int80] = ACTIONS(769),
    [anon_sym_int88] = ACTIONS(769),
    [anon_sym_int96] = ACTIONS(769),
    [anon_sym_int104] = ACTIONS(769),
    [anon_sym_int112] = ACTIONS(769),
    [anon_sym_int120] = ACTIONS(769),
    [anon_sym_int128] = ACTIONS(769),
    [anon_sym_int136] = ACTIONS(769),
    [anon_sym_int144] = ACTIONS(769),
    [anon_sym_int152] = ACTIONS(769),
    [anon_sym_int160] = ACTIONS(769),
    [anon_sym_int168] = ACTIONS(769),
    [anon_sym_int176] = ACTIONS(769),
    [anon_sym_int184] = ACTIONS(769),
    [anon_sym_int192] = ACTIONS(769),
    [anon_sym_int200] = ACTIONS(769),
    [anon_sym_int208] = ACTIONS(769),
    [anon_sym_int216] = ACTIONS(769),
    [anon_sym_int224] = ACTIONS(769),
    [anon_sym_int232] = ACTIONS(769),
    [anon_sym_int240] = ACTIONS(769),
    [anon_sym_int248] = ACTIONS(769),
    [anon_sym_int256] = ACTIONS(769),
    [anon_sym_uint] = ACTIONS(769),
    [anon_sym_uint8] = ACTIONS(769),
    [anon_sym_uint16] = ACTIONS(769),
    [anon_sym_uint24] = ACTIONS(769),
    [anon_sym_uint32] = ACTIONS(769),
    [anon_sym_uint40] = ACTIONS(769),
    [anon_sym_uint48] = ACTIONS(769),
    [anon_sym_uint56] = ACTIONS(769),
    [anon_sym_uint64] = ACTIONS(769),
    [anon_sym_uint72] = ACTIONS(769),
    [anon_sym_uint80] = ACTIONS(769),
    [anon_sym_uint88] = ACTIONS(769),
    [anon_sym_uint96] = ACTIONS(769),
    [anon_sym_uint104] = ACTIONS(769),
    [anon_sym_uint112] = ACTIONS(769),
    [anon_sym_uint120] = ACTIONS(769),
    [anon_sym_uint128] = ACTIONS(769),
    [anon_sym_uint136] = ACTIONS(769),
    [anon_sym_uint144] = ACTIONS(769),
    [anon_sym_uint152] = ACTIONS(769),
    [anon_sym_uint160] = ACTIONS(769),
    [anon_sym_uint168] = ACTIONS(769),
    [anon_sym_uint176] = ACTIONS(769),
    [anon_sym_uint184] = ACTIONS(769),
    [anon_sym_uint192] = ACTIONS(769),
    [anon_sym_uint200] = ACTIONS(769),
    [anon_sym_uint208] = ACTIONS(769),
    [anon_sym_uint216] = ACTIONS(769),
    [anon_sym_uint224] = ACTIONS(769),
    [anon_sym_uint232] = ACTIONS(769),
    [anon_sym_uint240] = ACTIONS(769),
    [anon_sym_uint248] = ACTIONS(769),
    [anon_sym_uint256] = ACTIONS(769),
    [anon_sym_bytes] = ACTIONS(769),
    [anon_sym_bytes1] = ACTIONS(769),
    [anon_sym_bytes2] = ACTIONS(769),
    [anon_sym_bytes3] = ACTIONS(769),
    [anon_sym_bytes4] = ACTIONS(769),
    [anon_sym_bytes5] = ACTIONS(769),
    [anon_sym_bytes6] = ACTIONS(769),
    [anon_sym_bytes7] = ACTIONS(769),
    [anon_sym_bytes8] = ACTIONS(769),
    [anon_sym_bytes9] = ACTIONS(769),
    [anon_sym_bytes10] = ACTIONS(769),
    [anon_sym_bytes11] = ACTIONS(769),
    [anon_sym_bytes12] = ACTIONS(769),
    [anon_sym_bytes13] = ACTIONS(769),
    [anon_sym_bytes14] = ACTIONS(769),
    [anon_sym_bytes15] = ACTIONS(769),
    [anon_sym_bytes16] = ACTIONS(769),
    [anon_sym_bytes17] = ACTIONS(769),
    [anon_sym_bytes18] = ACTIONS(769),
    [anon_sym_bytes19] = ACTIONS(769),
    [anon_sym_bytes20] = ACTIONS(769),
    [anon_sym_bytes21] = ACTIONS(769),
    [anon_sym_bytes22] = ACTIONS(769),
    [anon_sym_bytes23] = ACTIONS(769),
    [anon_sym_bytes24] = ACTIONS(769),
    [anon_sym_bytes25] = ACTIONS(769),
    [anon_sym_bytes26] = ACTIONS(769),
    [anon_sym_bytes27] = ACTIONS(769),
    [anon_sym_bytes28] = ACTIONS(769),
    [anon_sym_bytes29] = ACTIONS(769),
    [anon_sym_bytes30] = ACTIONS(769),
    [anon_sym_bytes31] = ACTIONS(769),
    [anon_sym_bytes32] = ACTIONS(769),
    [anon_sym_fixed] = ACTIONS(769),
    [aux_sym__fixed_token1] = ACTIONS(769),
    [anon_sym_ufixed] = ACTIONS(769),
    [aux_sym__ufixed_token1] = ACTIONS(769),
    [sym_comment] = ACTIONS(3),
  },
  [227] = {
    [sym_identifier] = ACTIONS(765),
    [anon_sym_RBRACE] = ACTIONS(763),
    [anon_sym_type] = ACTIONS(765),
    [anon_sym_error] = ACTIONS(765),
    [anon_sym_struct] = ACTIONS(765),
    [anon_sym_enum] = ACTIONS(765),
    [anon_sym_event] = ACTIONS(765),
    [anon_sym_using] = ACTIONS(765),
    [anon_sym_function] = ACTIONS(765),
    [anon_sym_byte] = ACTIONS(765),
    [anon_sym_address] = ACTIONS(765),
    [anon_sym_var] = ACTIONS(765),
    [anon_sym_modifier] = ACTIONS(765),
    [anon_sym_constructor] = ACTIONS(765),
    [anon_sym_fallback] = ACTIONS(765),
    [anon_sym_receive] = ACTIONS(765),
    [anon_sym_mapping] = ACTIONS(765),
    [anon_sym_bool] = ACTIONS(765),
    [anon_sym_string] = ACTIONS(765),
    [anon_sym_int] = ACTIONS(765),
    [anon_sym_int8] = ACTIONS(765),
    [anon_sym_int16] = ACTIONS(765),
    [anon_sym_int24] = ACTIONS(765),
    [anon_sym_int32] = ACTIONS(765),
    [anon_sym_int40] = ACTIONS(765),
    [anon_sym_int48] = ACTIONS(765),
    [anon_sym_int56] = ACTIONS(765),
    [anon_sym_int64] = ACTIONS(765),
    [anon_sym_int72] = ACTIONS(765),
    [anon_sym_int80] = ACTIONS(765),
    [anon_sym_int88] = ACTIONS(765),
    [anon_sym_int96] = ACTIONS(765),
    [anon_sym_int104] = ACTIONS(765),
    [anon_sym_int112] = ACTIONS(765),
    [anon_sym_int120] = ACTIONS(765),
    [anon_sym_int128] = ACTIONS(765),
    [anon_sym_int136] = ACTIONS(765),
    [anon_sym_int144] = ACTIONS(765),
    [anon_sym_int152] = ACTIONS(765),
    [anon_sym_int160] = ACTIONS(765),
    [anon_sym_int168] = ACTIONS(765),
    [anon_sym_int176] = ACTIONS(765),
    [anon_sym_int184] = ACTIONS(765),
    [anon_sym_int192] = ACTIONS(765),
    [anon_sym_int200] = ACTIONS(765),
    [anon_sym_int208] = ACTIONS(765),
    [anon_sym_int216] = ACTIONS(765),
    [anon_sym_int224] = ACTIONS(765),
    [anon_sym_int232] = ACTIONS(765),
    [anon_sym_int240] = ACTIONS(765),
    [anon_sym_int248] = ACTIONS(765),
    [anon_sym_int256] = ACTIONS(765),
    [anon_sym_uint] = ACTIONS(765),
    [anon_sym_uint8] = ACTIONS(765),
    [anon_sym_uint16] = ACTIONS(765),
    [anon_sym_uint24] = ACTIONS(765),
    [anon_sym_uint32] = ACTIONS(765),
    [anon_sym_uint40] = ACTIONS(765),
    [anon_sym_uint48] = ACTIONS(765),
    [anon_sym_uint56] = ACTIONS(765),
    [anon_sym_uint64] = ACTIONS(765),
    [anon_sym_uint72] = ACTIONS(765),
    [anon_sym_uint80] = ACTIONS(765),
    [anon_sym_uint88] = ACTIONS(765),
    [anon_sym_uint96] = ACTIONS(765),
    [anon_sym_uint104] = ACTIONS(765),
    [anon_sym_uint112] = ACTIONS(765),
    [anon_sym_uint120] = ACTIONS(765),
    [anon_sym_uint128] = ACTIONS(765),
    [anon_sym_uint136] = ACTIONS(765),
    [anon_sym_uint144] = ACTIONS(765),
    [anon_sym_uint152] = ACTIONS(765),
    [anon_sym_uint160] = ACTIONS(765),
    [anon_sym_uint168] = ACTIONS(765),
    [anon_sym_uint176] = ACTIONS(765),
    [anon_sym_uint184] = ACTIONS(765),
    [anon_sym_uint192] = ACTIONS(765),
    [anon_sym_uint200] = ACTIONS(765),
    [anon_sym_uint208] = ACTIONS(765),
    [anon_sym_uint216] = ACTIONS(765),
    [anon_sym_uint224] = ACTIONS(765),
    [anon_sym_uint232] = ACTIONS(765),
    [anon_sym_uint240] = ACTIONS(765),
    [anon_sym_uint248] = ACTIONS(765),
    [anon_sym_uint256] = ACTIONS(765),
    [anon_sym_bytes] = ACTIONS(765),
    [anon_sym_bytes1] = ACTIONS(765),
    [anon_sym_bytes2] = ACTIONS(765),
    [anon_sym_bytes3] = ACTIONS(765),
    [anon_sym_bytes4] = ACTIONS(765),
    [anon_sym_bytes5] = ACTIONS(765),
    [anon_sym_bytes6] = ACTIONS(765),
    [anon_sym_bytes7] = ACTIONS(765),
    [anon_sym_bytes8] = ACTIONS(765),
    [anon_sym_bytes9] = ACTIONS(765),
    [anon_sym_bytes10] = ACTIONS(765),
    [anon_sym_bytes11] = ACTIONS(765),
    [anon_sym_bytes12] = ACTIONS(765),
    [anon_sym_bytes13] = ACTIONS(765),
    [anon_sym_bytes14] = ACTIONS(765),
    [anon_sym_bytes15] = ACTIONS(765),
    [anon_sym_bytes16] = ACTIONS(765),
    [anon_sym_bytes17] = ACTIONS(765),
    [anon_sym_bytes18] = ACTIONS(765),
    [anon_sym_bytes19] = ACTIONS(765),
    [anon_sym_bytes20] = ACTIONS(765),
    [anon_sym_bytes21] = ACTIONS(765),
    [anon_sym_bytes22] = ACTIONS(765),
    [anon_sym_bytes23] = ACTIONS(765),
    [anon_sym_bytes24] = ACTIONS(765),
    [anon_sym_bytes25] = ACTIONS(765),
    [anon_sym_bytes26] = ACTIONS(765),
    [anon_sym_bytes27] = ACTIONS(765),
    [anon_sym_bytes28] = ACTIONS(765),
    [anon_sym_bytes29] = ACTIONS(765),
    [anon_sym_bytes30] = ACTIONS(765),
    [anon_sym_bytes31] = ACTIONS(765),
    [anon_sym_bytes32] = ACTIONS(765),
    [anon_sym_fixed] = ACTIONS(765),
    [aux_sym__fixed_token1] = ACTIONS(765),
    [anon_sym_ufixed] = ACTIONS(765),
    [aux_sym__ufixed_token1] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
  },
  [228] = {
    [sym_identifier] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(851),
    [anon_sym_type] = ACTIONS(849),
    [anon_sym_error] = ACTIONS(849),
    [anon_sym_struct] = ACTIONS(849),
    [anon_sym_enum] = ACTIONS(849),
    [anon_sym_event] = ACTIONS(849),
    [anon_sym_using] = ACTIONS(849),
    [anon_sym_function] = ACTIONS(849),
    [anon_sym_byte] = ACTIONS(849),
    [anon_sym_address] = ACTIONS(849),
    [anon_sym_var] = ACTIONS(849),
    [anon_sym_modifier] = ACTIONS(849),
    [anon_sym_constructor] = ACTIONS(849),
    [anon_sym_fallback] = ACTIONS(849),
    [anon_sym_receive] = ACTIONS(849),
    [anon_sym_mapping] = ACTIONS(849),
    [anon_sym_bool] = ACTIONS(849),
    [anon_sym_string] = ACTIONS(849),
    [anon_sym_int] = ACTIONS(849),
    [anon_sym_int8] = ACTIONS(849),
    [anon_sym_int16] = ACTIONS(849),
    [anon_sym_int24] = ACTIONS(849),
    [anon_sym_int32] = ACTIONS(849),
    [anon_sym_int40] = ACTIONS(849),
    [anon_sym_int48] = ACTIONS(849),
    [anon_sym_int56] = ACTIONS(849),
    [anon_sym_int64] = ACTIONS(849),
    [anon_sym_int72] = ACTIONS(849),
    [anon_sym_int80] = ACTIONS(849),
    [anon_sym_int88] = ACTIONS(849),
    [anon_sym_int96] = ACTIONS(849),
    [anon_sym_int104] = ACTIONS(849),
    [anon_sym_int112] = ACTIONS(849),
    [anon_sym_int120] = ACTIONS(849),
    [anon_sym_int128] = ACTIONS(849),
    [anon_sym_int136] = ACTIONS(849),
    [anon_sym_int144] = ACTIONS(849),
    [anon_sym_int152] = ACTIONS(849),
    [anon_sym_int160] = ACTIONS(849),
    [anon_sym_int168] = ACTIONS(849),
    [anon_sym_int176] = ACTIONS(849),
    [anon_sym_int184] = ACTIONS(849),
    [anon_sym_int192] = ACTIONS(849),
    [anon_sym_int200] = ACTIONS(849),
    [anon_sym_int208] = ACTIONS(849),
    [anon_sym_int216] = ACTIONS(849),
    [anon_sym_int224] = ACTIONS(849),
    [anon_sym_int232] = ACTIONS(849),
    [anon_sym_int240] = ACTIONS(849),
    [anon_sym_int248] = ACTIONS(849),
    [anon_sym_int256] = ACTIONS(849),
    [anon_sym_uint] = ACTIONS(849),
    [anon_sym_uint8] = ACTIONS(849),
    [anon_sym_uint16] = ACTIONS(849),
    [anon_sym_uint24] = ACTIONS(849),
    [anon_sym_uint32] = ACTIONS(849),
    [anon_sym_uint40] = ACTIONS(849),
    [anon_sym_uint48] = ACTIONS(849),
    [anon_sym_uint56] = ACTIONS(849),
    [anon_sym_uint64] = ACTIONS(849),
    [anon_sym_uint72] = ACTIONS(849),
    [anon_sym_uint80] = ACTIONS(849),
    [anon_sym_uint88] = ACTIONS(849),
    [anon_sym_uint96] = ACTIONS(849),
    [anon_sym_uint104] = ACTIONS(849),
    [anon_sym_uint112] = ACTIONS(849),
    [anon_sym_uint120] = ACTIONS(849),
    [anon_sym_uint128] = ACTIONS(849),
    [anon_sym_uint136] = ACTIONS(849),
    [anon_sym_uint144] = ACTIONS(849),
    [anon_sym_uint152] = ACTIONS(849),
    [anon_sym_uint160] = ACTIONS(849),
    [anon_sym_uint168] = ACTIONS(849),
    [anon_sym_uint176] = ACTIONS(849),
    [anon_sym_uint184] = ACTIONS(849),
    [anon_sym_uint192] = ACTIONS(849),
    [anon_sym_uint200] = ACTIONS(849),
    [anon_sym_uint208] = ACTIONS(849),
    [anon_sym_uint216] = ACTIONS(849),
    [anon_sym_uint224] = ACTIONS(849),
    [anon_sym_uint232] = ACTIONS(849),
    [anon_sym_uint240] = ACTIONS(849),
    [anon_sym_uint248] = ACTIONS(849),
    [anon_sym_uint256] = ACTIONS(849),
    [anon_sym_bytes] = ACTIONS(849),
    [anon_sym_bytes1] = ACTIONS(849),
    [anon_sym_bytes2] = ACTIONS(849),
    [anon_sym_bytes3] = ACTIONS(849),
    [anon_sym_bytes4] = ACTIONS(849),
    [anon_sym_bytes5] = ACTIONS(849),
    [anon_sym_bytes6] = ACTIONS(849),
    [anon_sym_bytes7] = ACTIONS(849),
    [anon_sym_bytes8] = ACTIONS(849),
    [anon_sym_bytes9] = ACTIONS(849),
    [anon_sym_bytes10] = ACTIONS(849),
    [anon_sym_bytes11] = ACTIONS(849),
    [anon_sym_bytes12] = ACTIONS(849),
    [anon_sym_bytes13] = ACTIONS(849),
    [anon_sym_bytes14] = ACTIONS(849),
    [anon_sym_bytes15] = ACTIONS(849),
    [anon_sym_bytes16] = ACTIONS(849),
    [anon_sym_bytes17] = ACTIONS(849),
    [anon_sym_bytes18] = ACTIONS(849),
    [anon_sym_bytes19] = ACTIONS(849),
    [anon_sym_bytes20] = ACTIONS(849),
    [anon_sym_bytes21] = ACTIONS(849),
    [anon_sym_bytes22] = ACTIONS(849),
    [anon_sym_bytes23] = ACTIONS(849),
    [anon_sym_bytes24] = ACTIONS(849),
    [anon_sym_bytes25] = ACTIONS(849),
    [anon_sym_bytes26] = ACTIONS(849),
    [anon_sym_bytes27] = ACTIONS(849),
    [anon_sym_bytes28] = ACTIONS(849),
    [anon_sym_bytes29] = ACTIONS(849),
    [anon_sym_bytes30] = ACTIONS(849),
    [anon_sym_bytes31] = ACTIONS(849),
    [anon_sym_bytes32] = ACTIONS(849),
    [anon_sym_fixed] = ACTIONS(849),
    [aux_sym__fixed_token1] = ACTIONS(849),
    [anon_sym_ufixed] = ACTIONS(849),
    [aux_sym__ufixed_token1] = ACTIONS(849),
    [sym_comment] = ACTIONS(3),
  },
  [229] = {
    [sym_identifier] = ACTIONS(853),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_type] = ACTIONS(853),
    [anon_sym_error] = ACTIONS(853),
    [anon_sym_struct] = ACTIONS(853),
    [anon_sym_enum] = ACTIONS(853),
    [anon_sym_event] = ACTIONS(853),
    [anon_sym_using] = ACTIONS(853),
    [anon_sym_function] = ACTIONS(853),
    [anon_sym_byte] = ACTIONS(853),
    [anon_sym_address] = ACTIONS(853),
    [anon_sym_var] = ACTIONS(853),
    [anon_sym_modifier] = ACTIONS(853),
    [anon_sym_constructor] = ACTIONS(853),
    [anon_sym_fallback] = ACTIONS(853),
    [anon_sym_receive] = ACTIONS(853),
    [anon_sym_mapping] = ACTIONS(853),
    [anon_sym_bool] = ACTIONS(853),
    [anon_sym_string] = ACTIONS(853),
    [anon_sym_int] = ACTIONS(853),
    [anon_sym_int8] = ACTIONS(853),
    [anon_sym_int16] = ACTIONS(853),
    [anon_sym_int24] = ACTIONS(853),
    [anon_sym_int32] = ACTIONS(853),
    [anon_sym_int40] = ACTIONS(853),
    [anon_sym_int48] = ACTIONS(853),
    [anon_sym_int56] = ACTIONS(853),
    [anon_sym_int64] = ACTIONS(853),
    [anon_sym_int72] = ACTIONS(853),
    [anon_sym_int80] = ACTIONS(853),
    [anon_sym_int88] = ACTIONS(853),
    [anon_sym_int96] = ACTIONS(853),
    [anon_sym_int104] = ACTIONS(853),
    [anon_sym_int112] = ACTIONS(853),
    [anon_sym_int120] = ACTIONS(853),
    [anon_sym_int128] = ACTIONS(853),
    [anon_sym_int136] = ACTIONS(853),
    [anon_sym_int144] = ACTIONS(853),
    [anon_sym_int152] = ACTIONS(853),
    [anon_sym_int160] = ACTIONS(853),
    [anon_sym_int168] = ACTIONS(853),
    [anon_sym_int176] = ACTIONS(853),
    [anon_sym_int184] = ACTIONS(853),
    [anon_sym_int192] = ACTIONS(853),
    [anon_sym_int200] = ACTIONS(853),
    [anon_sym_int208] = ACTIONS(853),
    [anon_sym_int216] = ACTIONS(853),
    [anon_sym_int224] = ACTIONS(853),
    [anon_sym_int232] = ACTIONS(853),
    [anon_sym_int240] = ACTIONS(853),
    [anon_sym_int248] = ACTIONS(853),
    [anon_sym_int256] = ACTIONS(853),
    [anon_sym_uint] = ACTIONS(853),
    [anon_sym_uint8] = ACTIONS(853),
    [anon_sym_uint16] = ACTIONS(853),
    [anon_sym_uint24] = ACTIONS(853),
    [anon_sym_uint32] = ACTIONS(853),
    [anon_sym_uint40] = ACTIONS(853),
    [anon_sym_uint48] = ACTIONS(853),
    [anon_sym_uint56] = ACTIONS(853),
    [anon_sym_uint64] = ACTIONS(853),
    [anon_sym_uint72] = ACTIONS(853),
    [anon_sym_uint80] = ACTIONS(853),
    [anon_sym_uint88] = ACTIONS(853),
    [anon_sym_uint96] = ACTIONS(853),
    [anon_sym_uint104] = ACTIONS(853),
    [anon_sym_uint112] = ACTIONS(853),
    [anon_sym_uint120] = ACTIONS(853),
    [anon_sym_uint128] = ACTIONS(853),
    [anon_sym_uint136] = ACTIONS(853),
    [anon_sym_uint144] = ACTIONS(853),
    [anon_sym_uint152] = ACTIONS(853),
    [anon_sym_uint160] = ACTIONS(853),
    [anon_sym_uint168] = ACTIONS(853),
    [anon_sym_uint176] = ACTIONS(853),
    [anon_sym_uint184] = ACTIONS(853),
    [anon_sym_uint192] = ACTIONS(853),
    [anon_sym_uint200] = ACTIONS(853),
    [anon_sym_uint208] = ACTIONS(853),
    [anon_sym_uint216] = ACTIONS(853),
    [anon_sym_uint224] = ACTIONS(853),
    [anon_sym_uint232] = ACTIONS(853),
    [anon_sym_uint240] = ACTIONS(853),
    [anon_sym_uint248] = ACTIONS(853),
    [anon_sym_uint256] = ACTIONS(853),
    [anon_sym_bytes] = ACTIONS(853),
    [anon_sym_bytes1] = ACTIONS(853),
    [anon_sym_bytes2] = ACTIONS(853),
    [anon_sym_bytes3] = ACTIONS(853),
    [anon_sym_bytes4] = ACTIONS(853),
    [anon_sym_bytes5] = ACTIONS(853),
    [anon_sym_bytes6] = ACTIONS(853),
    [anon_sym_bytes7] = ACTIONS(853),
    [anon_sym_bytes8] = ACTIONS(853),
    [anon_sym_bytes9] = ACTIONS(853),
    [anon_sym_bytes10] = ACTIONS(853),
    [anon_sym_bytes11] = ACTIONS(853),
    [anon_sym_bytes12] = ACTIONS(853),
    [anon_sym_bytes13] = ACTIONS(853),
    [anon_sym_bytes14] = ACTIONS(853),
    [anon_sym_bytes15] = ACTIONS(853),
    [anon_sym_bytes16] = ACTIONS(853),
    [anon_sym_bytes17] = ACTIONS(853),
    [anon_sym_bytes18] = ACTIONS(853),
    [anon_sym_bytes19] = ACTIONS(853),
    [anon_sym_bytes20] = ACTIONS(853),
    [anon_sym_bytes21] = ACTIONS(853),
    [anon_sym_bytes22] = ACTIONS(853),
    [anon_sym_bytes23] = ACTIONS(853),
    [anon_sym_bytes24] = ACTIONS(853),
    [anon_sym_bytes25] = ACTIONS(853),
    [anon_sym_bytes26] = ACTIONS(853),
    [anon_sym_bytes27] = ACTIONS(853),
    [anon_sym_bytes28] = ACTIONS(853),
    [anon_sym_bytes29] = ACTIONS(853),
    [anon_sym_bytes30] = ACTIONS(853),
    [anon_sym_bytes31] = ACTIONS(853),
    [anon_sym_bytes32] = ACTIONS(853),
    [anon_sym_fixed] = ACTIONS(853),
    [aux_sym__fixed_token1] = ACTIONS(853),
    [anon_sym_ufixed] = ACTIONS(853),
    [aux_sym__ufixed_token1] = ACTIONS(853),
    [sym_comment] = ACTIONS(3),
  },
  [230] = {
    [sym_identifier] = ACTIONS(857),
    [anon_sym_RBRACE] = ACTIONS(859),
    [anon_sym_type] = ACTIONS(857),
    [anon_sym_error] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(857),
    [anon_sym_enum] = ACTIONS(857),
    [anon_sym_event] = ACTIONS(857),
    [anon_sym_using] = ACTIONS(857),
    [anon_sym_function] = ACTIONS(857),
    [anon_sym_byte] = ACTIONS(857),
    [anon_sym_address] = ACTIONS(857),
    [anon_sym_var] = ACTIONS(857),
    [anon_sym_modifier] = ACTIONS(857),
    [anon_sym_constructor] = ACTIONS(857),
    [anon_sym_fallback] = ACTIONS(857),
    [anon_sym_receive] = ACTIONS(857),
    [anon_sym_mapping] = ACTIONS(857),
    [anon_sym_bool] = ACTIONS(857),
    [anon_sym_string] = ACTIONS(857),
    [anon_sym_int] = ACTIONS(857),
    [anon_sym_int8] = ACTIONS(857),
    [anon_sym_int16] = ACTIONS(857),
    [anon_sym_int24] = ACTIONS(857),
    [anon_sym_int32] = ACTIONS(857),
    [anon_sym_int40] = ACTIONS(857),
    [anon_sym_int48] = ACTIONS(857),
    [anon_sym_int56] = ACTIONS(857),
    [anon_sym_int64] = ACTIONS(857),
    [anon_sym_int72] = ACTIONS(857),
    [anon_sym_int80] = ACTIONS(857),
    [anon_sym_int88] = ACTIONS(857),
    [anon_sym_int96] = ACTIONS(857),
    [anon_sym_int104] = ACTIONS(857),
    [anon_sym_int112] = ACTIONS(857),
    [anon_sym_int120] = ACTIONS(857),
    [anon_sym_int128] = ACTIONS(857),
    [anon_sym_int136] = ACTIONS(857),
    [anon_sym_int144] = ACTIONS(857),
    [anon_sym_int152] = ACTIONS(857),
    [anon_sym_int160] = ACTIONS(857),
    [anon_sym_int168] = ACTIONS(857),
    [anon_sym_int176] = ACTIONS(857),
    [anon_sym_int184] = ACTIONS(857),
    [anon_sym_int192] = ACTIONS(857),
    [anon_sym_int200] = ACTIONS(857),
    [anon_sym_int208] = ACTIONS(857),
    [anon_sym_int216] = ACTIONS(857),
    [anon_sym_int224] = ACTIONS(857),
    [anon_sym_int232] = ACTIONS(857),
    [anon_sym_int240] = ACTIONS(857),
    [anon_sym_int248] = ACTIONS(857),
    [anon_sym_int256] = ACTIONS(857),
    [anon_sym_uint] = ACTIONS(857),
    [anon_sym_uint8] = ACTIONS(857),
    [anon_sym_uint16] = ACTIONS(857),
    [anon_sym_uint24] = ACTIONS(857),
    [anon_sym_uint32] = ACTIONS(857),
    [anon_sym_uint40] = ACTIONS(857),
    [anon_sym_uint48] = ACTIONS(857),
    [anon_sym_uint56] = ACTIONS(857),
    [anon_sym_uint64] = ACTIONS(857),
    [anon_sym_uint72] = ACTIONS(857),
    [anon_sym_uint80] = ACTIONS(857),
    [anon_sym_uint88] = ACTIONS(857),
    [anon_sym_uint96] = ACTIONS(857),
    [anon_sym_uint104] = ACTIONS(857),
    [anon_sym_uint112] = ACTIONS(857),
    [anon_sym_uint120] = ACTIONS(857),
    [anon_sym_uint128] = ACTIONS(857),
    [anon_sym_uint136] = ACTIONS(857),
    [anon_sym_uint144] = ACTIONS(857),
    [anon_sym_uint152] = ACTIONS(857),
    [anon_sym_uint160] = ACTIONS(857),
    [anon_sym_uint168] = ACTIONS(857),
    [anon_sym_uint176] = ACTIONS(857),
    [anon_sym_uint184] = ACTIONS(857),
    [anon_sym_uint192] = ACTIONS(857),
    [anon_sym_uint200] = ACTIONS(857),
    [anon_sym_uint208] = ACTIONS(857),
    [anon_sym_uint216] = ACTIONS(857),
    [anon_sym_uint224] = ACTIONS(857),
    [anon_sym_uint232] = ACTIONS(857),
    [anon_sym_uint240] = ACTIONS(857),
    [anon_sym_uint248] = ACTIONS(857),
    [anon_sym_uint256] = ACTIONS(857),
    [anon_sym_bytes] = ACTIONS(857),
    [anon_sym_bytes1] = ACTIONS(857),
    [anon_sym_bytes2] = ACTIONS(857),
    [anon_sym_bytes3] = ACTIONS(857),
    [anon_sym_bytes4] = ACTIONS(857),
    [anon_sym_bytes5] = ACTIONS(857),
    [anon_sym_bytes6] = ACTIONS(857),
    [anon_sym_bytes7] = ACTIONS(857),
    [anon_sym_bytes8] = ACTIONS(857),
    [anon_sym_bytes9] = ACTIONS(857),
    [anon_sym_bytes10] = ACTIONS(857),
    [anon_sym_bytes11] = ACTIONS(857),
    [anon_sym_bytes12] = ACTIONS(857),
    [anon_sym_bytes13] = ACTIONS(857),
    [anon_sym_bytes14] = ACTIONS(857),
    [anon_sym_bytes15] = ACTIONS(857),
    [anon_sym_bytes16] = ACTIONS(857),
    [anon_sym_bytes17] = ACTIONS(857),
    [anon_sym_bytes18] = ACTIONS(857),
    [anon_sym_bytes19] = ACTIONS(857),
    [anon_sym_bytes20] = ACTIONS(857),
    [anon_sym_bytes21] = ACTIONS(857),
    [anon_sym_bytes22] = ACTIONS(857),
    [anon_sym_bytes23] = ACTIONS(857),
    [anon_sym_bytes24] = ACTIONS(857),
    [anon_sym_bytes25] = ACTIONS(857),
    [anon_sym_bytes26] = ACTIONS(857),
    [anon_sym_bytes27] = ACTIONS(857),
    [anon_sym_bytes28] = ACTIONS(857),
    [anon_sym_bytes29] = ACTIONS(857),
    [anon_sym_bytes30] = ACTIONS(857),
    [anon_sym_bytes31] = ACTIONS(857),
    [anon_sym_bytes32] = ACTIONS(857),
    [anon_sym_fixed] = ACTIONS(857),
    [aux_sym__fixed_token1] = ACTIONS(857),
    [anon_sym_ufixed] = ACTIONS(857),
    [aux_sym__ufixed_token1] = ACTIONS(857),
    [sym_comment] = ACTIONS(3),
  },
  [231] = {
    [sym_identifier] = ACTIONS(861),
    [anon_sym_RBRACE] = ACTIONS(863),
    [anon_sym_type] = ACTIONS(861),
    [anon_sym_error] = ACTIONS(861),
    [anon_sym_struct] = ACTIONS(861),
    [anon_sym_enum] = ACTIONS(861),
    [anon_sym_event] = ACTIONS(861),
    [anon_sym_using] = ACTIONS(861),
    [anon_sym_function] = ACTIONS(861),
    [anon_sym_byte] = ACTIONS(861),
    [anon_sym_address] = ACTIONS(861),
    [anon_sym_var] = ACTIONS(861),
    [anon_sym_modifier] = ACTIONS(861),
    [anon_sym_constructor] = ACTIONS(861),
    [anon_sym_fallback] = ACTIONS(861),
    [anon_sym_receive] = ACTIONS(861),
    [anon_sym_mapping] = ACTIONS(861),
    [anon_sym_bool] = ACTIONS(861),
    [anon_sym_string] = ACTIONS(861),
    [anon_sym_int] = ACTIONS(861),
    [anon_sym_int8] = ACTIONS(861),
    [anon_sym_int16] = ACTIONS(861),
    [anon_sym_int24] = ACTIONS(861),
    [anon_sym_int32] = ACTIONS(861),
    [anon_sym_int40] = ACTIONS(861),
    [anon_sym_int48] = ACTIONS(861),
    [anon_sym_int56] = ACTIONS(861),
    [anon_sym_int64] = ACTIONS(861),
    [anon_sym_int72] = ACTIONS(861),
    [anon_sym_int80] = ACTIONS(861),
    [anon_sym_int88] = ACTIONS(861),
    [anon_sym_int96] = ACTIONS(861),
    [anon_sym_int104] = ACTIONS(861),
    [anon_sym_int112] = ACTIONS(861),
    [anon_sym_int120] = ACTIONS(861),
    [anon_sym_int128] = ACTIONS(861),
    [anon_sym_int136] = ACTIONS(861),
    [anon_sym_int144] = ACTIONS(861),
    [anon_sym_int152] = ACTIONS(861),
    [anon_sym_int160] = ACTIONS(861),
    [anon_sym_int168] = ACTIONS(861),
    [anon_sym_int176] = ACTIONS(861),
    [anon_sym_int184] = ACTIONS(861),
    [anon_sym_int192] = ACTIONS(861),
    [anon_sym_int200] = ACTIONS(861),
    [anon_sym_int208] = ACTIONS(861),
    [anon_sym_int216] = ACTIONS(861),
    [anon_sym_int224] = ACTIONS(861),
    [anon_sym_int232] = ACTIONS(861),
    [anon_sym_int240] = ACTIONS(861),
    [anon_sym_int248] = ACTIONS(861),
    [anon_sym_int256] = ACTIONS(861),
    [anon_sym_uint] = ACTIONS(861),
    [anon_sym_uint8] = ACTIONS(861),
    [anon_sym_uint16] = ACTIONS(861),
    [anon_sym_uint24] = ACTIONS(861),
    [anon_sym_uint32] = ACTIONS(861),
    [anon_sym_uint40] = ACTIONS(861),
    [anon_sym_uint48] = ACTIONS(861),
    [anon_sym_uint56] = ACTIONS(861),
    [anon_sym_uint64] = ACTIONS(861),
    [anon_sym_uint72] = ACTIONS(861),
    [anon_sym_uint80] = ACTIONS(861),
    [anon_sym_uint88] = ACTIONS(861),
    [anon_sym_uint96] = ACTIONS(861),
    [anon_sym_uint104] = ACTIONS(861),
    [anon_sym_uint112] = ACTIONS(861),
    [anon_sym_uint120] = ACTIONS(861),
    [anon_sym_uint128] = ACTIONS(861),
    [anon_sym_uint136] = ACTIONS(861),
    [anon_sym_uint144] = ACTIONS(861),
    [anon_sym_uint152] = ACTIONS(861),
    [anon_sym_uint160] = ACTIONS(861),
    [anon_sym_uint168] = ACTIONS(861),
    [anon_sym_uint176] = ACTIONS(861),
    [anon_sym_uint184] = ACTIONS(861),
    [anon_sym_uint192] = ACTIONS(861),
    [anon_sym_uint200] = ACTIONS(861),
    [anon_sym_uint208] = ACTIONS(861),
    [anon_sym_uint216] = ACTIONS(861),
    [anon_sym_uint224] = ACTIONS(861),
    [anon_sym_uint232] = ACTIONS(861),
    [anon_sym_uint240] = ACTIONS(861),
    [anon_sym_uint248] = ACTIONS(861),
    [anon_sym_uint256] = ACTIONS(861),
    [anon_sym_bytes] = ACTIONS(861),
    [anon_sym_bytes1] = ACTIONS(861),
    [anon_sym_bytes2] = ACTIONS(861),
    [anon_sym_bytes3] = ACTIONS(861),
    [anon_sym_bytes4] = ACTIONS(861),
    [anon_sym_bytes5] = ACTIONS(861),
    [anon_sym_bytes6] = ACTIONS(861),
    [anon_sym_bytes7] = ACTIONS(861),
    [anon_sym_bytes8] = ACTIONS(861),
    [anon_sym_bytes9] = ACTIONS(861),
    [anon_sym_bytes10] = ACTIONS(861),
    [anon_sym_bytes11] = ACTIONS(861),
    [anon_sym_bytes12] = ACTIONS(861),
    [anon_sym_bytes13] = ACTIONS(861),
    [anon_sym_bytes14] = ACTIONS(861),
    [anon_sym_bytes15] = ACTIONS(861),
    [anon_sym_bytes16] = ACTIONS(861),
    [anon_sym_bytes17] = ACTIONS(861),
    [anon_sym_bytes18] = ACTIONS(861),
    [anon_sym_bytes19] = ACTIONS(861),
    [anon_sym_bytes20] = ACTIONS(861),
    [anon_sym_bytes21] = ACTIONS(861),
    [anon_sym_bytes22] = ACTIONS(861),
    [anon_sym_bytes23] = ACTIONS(861),
    [anon_sym_bytes24] = ACTIONS(861),
    [anon_sym_bytes25] = ACTIONS(861),
    [anon_sym_bytes26] = ACTIONS(861),
    [anon_sym_bytes27] = ACTIONS(861),
    [anon_sym_bytes28] = ACTIONS(861),
    [anon_sym_bytes29] = ACTIONS(861),
    [anon_sym_bytes30] = ACTIONS(861),
    [anon_sym_bytes31] = ACTIONS(861),
    [anon_sym_bytes32] = ACTIONS(861),
    [anon_sym_fixed] = ACTIONS(861),
    [aux_sym__fixed_token1] = ACTIONS(861),
    [anon_sym_ufixed] = ACTIONS(861),
    [aux_sym__ufixed_token1] = ACTIONS(861),
    [sym_comment] = ACTIONS(3),
  },
  [232] = {
    [sym_identifier] = ACTIONS(865),
    [anon_sym_RBRACE] = ACTIONS(867),
    [anon_sym_type] = ACTIONS(865),
    [anon_sym_error] = ACTIONS(865),
    [anon_sym_struct] = ACTIONS(865),
    [anon_sym_enum] = ACTIONS(865),
    [anon_sym_event] = ACTIONS(865),
    [anon_sym_using] = ACTIONS(865),
    [anon_sym_function] = ACTIONS(865),
    [anon_sym_byte] = ACTIONS(865),
    [anon_sym_address] = ACTIONS(865),
    [anon_sym_var] = ACTIONS(865),
    [anon_sym_modifier] = ACTIONS(865),
    [anon_sym_constructor] = ACTIONS(865),
    [anon_sym_fallback] = ACTIONS(865),
    [anon_sym_receive] = ACTIONS(865),
    [anon_sym_mapping] = ACTIONS(865),
    [anon_sym_bool] = ACTIONS(865),
    [anon_sym_string] = ACTIONS(865),
    [anon_sym_int] = ACTIONS(865),
    [anon_sym_int8] = ACTIONS(865),
    [anon_sym_int16] = ACTIONS(865),
    [anon_sym_int24] = ACTIONS(865),
    [anon_sym_int32] = ACTIONS(865),
    [anon_sym_int40] = ACTIONS(865),
    [anon_sym_int48] = ACTIONS(865),
    [anon_sym_int56] = ACTIONS(865),
    [anon_sym_int64] = ACTIONS(865),
    [anon_sym_int72] = ACTIONS(865),
    [anon_sym_int80] = ACTIONS(865),
    [anon_sym_int88] = ACTIONS(865),
    [anon_sym_int96] = ACTIONS(865),
    [anon_sym_int104] = ACTIONS(865),
    [anon_sym_int112] = ACTIONS(865),
    [anon_sym_int120] = ACTIONS(865),
    [anon_sym_int128] = ACTIONS(865),
    [anon_sym_int136] = ACTIONS(865),
    [anon_sym_int144] = ACTIONS(865),
    [anon_sym_int152] = ACTIONS(865),
    [anon_sym_int160] = ACTIONS(865),
    [anon_sym_int168] = ACTIONS(865),
    [anon_sym_int176] = ACTIONS(865),
    [anon_sym_int184] = ACTIONS(865),
    [anon_sym_int192] = ACTIONS(865),
    [anon_sym_int200] = ACTIONS(865),
    [anon_sym_int208] = ACTIONS(865),
    [anon_sym_int216] = ACTIONS(865),
    [anon_sym_int224] = ACTIONS(865),
    [anon_sym_int232] = ACTIONS(865),
    [anon_sym_int240] = ACTIONS(865),
    [anon_sym_int248] = ACTIONS(865),
    [anon_sym_int256] = ACTIONS(865),
    [anon_sym_uint] = ACTIONS(865),
    [anon_sym_uint8] = ACTIONS(865),
    [anon_sym_uint16] = ACTIONS(865),
    [anon_sym_uint24] = ACTIONS(865),
    [anon_sym_uint32] = ACTIONS(865),
    [anon_sym_uint40] = ACTIONS(865),
    [anon_sym_uint48] = ACTIONS(865),
    [anon_sym_uint56] = ACTIONS(865),
    [anon_sym_uint64] = ACTIONS(865),
    [anon_sym_uint72] = ACTIONS(865),
    [anon_sym_uint80] = ACTIONS(865),
    [anon_sym_uint88] = ACTIONS(865),
    [anon_sym_uint96] = ACTIONS(865),
    [anon_sym_uint104] = ACTIONS(865),
    [anon_sym_uint112] = ACTIONS(865),
    [anon_sym_uint120] = ACTIONS(865),
    [anon_sym_uint128] = ACTIONS(865),
    [anon_sym_uint136] = ACTIONS(865),
    [anon_sym_uint144] = ACTIONS(865),
    [anon_sym_uint152] = ACTIONS(865),
    [anon_sym_uint160] = ACTIONS(865),
    [anon_sym_uint168] = ACTIONS(865),
    [anon_sym_uint176] = ACTIONS(865),
    [anon_sym_uint184] = ACTIONS(865),
    [anon_sym_uint192] = ACTIONS(865),
    [anon_sym_uint200] = ACTIONS(865),
    [anon_sym_uint208] = ACTIONS(865),
    [anon_sym_uint216] = ACTIONS(865),
    [anon_sym_uint224] = ACTIONS(865),
    [anon_sym_uint232] = ACTIONS(865),
    [anon_sym_uint240] = ACTIONS(865),
    [anon_sym_uint248] = ACTIONS(865),
    [anon_sym_uint256] = ACTIONS(865),
    [anon_sym_bytes] = ACTIONS(865),
    [anon_sym_bytes1] = ACTIONS(865),
    [anon_sym_bytes2] = ACTIONS(865),
    [anon_sym_bytes3] = ACTIONS(865),
    [anon_sym_bytes4] = ACTIONS(865),
    [anon_sym_bytes5] = ACTIONS(865),
    [anon_sym_bytes6] = ACTIONS(865),
    [anon_sym_bytes7] = ACTIONS(865),
    [anon_sym_bytes8] = ACTIONS(865),
    [anon_sym_bytes9] = ACTIONS(865),
    [anon_sym_bytes10] = ACTIONS(865),
    [anon_sym_bytes11] = ACTIONS(865),
    [anon_sym_bytes12] = ACTIONS(865),
    [anon_sym_bytes13] = ACTIONS(865),
    [anon_sym_bytes14] = ACTIONS(865),
    [anon_sym_bytes15] = ACTIONS(865),
    [anon_sym_bytes16] = ACTIONS(865),
    [anon_sym_bytes17] = ACTIONS(865),
    [anon_sym_bytes18] = ACTIONS(865),
    [anon_sym_bytes19] = ACTIONS(865),
    [anon_sym_bytes20] = ACTIONS(865),
    [anon_sym_bytes21] = ACTIONS(865),
    [anon_sym_bytes22] = ACTIONS(865),
    [anon_sym_bytes23] = ACTIONS(865),
    [anon_sym_bytes24] = ACTIONS(865),
    [anon_sym_bytes25] = ACTIONS(865),
    [anon_sym_bytes26] = ACTIONS(865),
    [anon_sym_bytes27] = ACTIONS(865),
    [anon_sym_bytes28] = ACTIONS(865),
    [anon_sym_bytes29] = ACTIONS(865),
    [anon_sym_bytes30] = ACTIONS(865),
    [anon_sym_bytes31] = ACTIONS(865),
    [anon_sym_bytes32] = ACTIONS(865),
    [anon_sym_fixed] = ACTIONS(865),
    [aux_sym__fixed_token1] = ACTIONS(865),
    [anon_sym_ufixed] = ACTIONS(865),
    [aux_sym__ufixed_token1] = ACTIONS(865),
    [sym_comment] = ACTIONS(3),
  },
  [233] = {
    [sym_identifier] = ACTIONS(753),
    [anon_sym_RBRACE] = ACTIONS(751),
    [anon_sym_type] = ACTIONS(753),
    [anon_sym_error] = ACTIONS(753),
    [anon_sym_struct] = ACTIONS(753),
    [anon_sym_enum] = ACTIONS(753),
    [anon_sym_event] = ACTIONS(753),
    [anon_sym_using] = ACTIONS(753),
    [anon_sym_function] = ACTIONS(753),
    [anon_sym_byte] = ACTIONS(753),
    [anon_sym_address] = ACTIONS(753),
    [anon_sym_var] = ACTIONS(753),
    [anon_sym_modifier] = ACTIONS(753),
    [anon_sym_constructor] = ACTIONS(753),
    [anon_sym_fallback] = ACTIONS(753),
    [anon_sym_receive] = ACTIONS(753),
    [anon_sym_mapping] = ACTIONS(753),
    [anon_sym_bool] = ACTIONS(753),
    [anon_sym_string] = ACTIONS(753),
    [anon_sym_int] = ACTIONS(753),
    [anon_sym_int8] = ACTIONS(753),
    [anon_sym_int16] = ACTIONS(753),
    [anon_sym_int24] = ACTIONS(753),
    [anon_sym_int32] = ACTIONS(753),
    [anon_sym_int40] = ACTIONS(753),
    [anon_sym_int48] = ACTIONS(753),
    [anon_sym_int56] = ACTIONS(753),
    [anon_sym_int64] = ACTIONS(753),
    [anon_sym_int72] = ACTIONS(753),
    [anon_sym_int80] = ACTIONS(753),
    [anon_sym_int88] = ACTIONS(753),
    [anon_sym_int96] = ACTIONS(753),
    [anon_sym_int104] = ACTIONS(753),
    [anon_sym_int112] = ACTIONS(753),
    [anon_sym_int120] = ACTIONS(753),
    [anon_sym_int128] = ACTIONS(753),
    [anon_sym_int136] = ACTIONS(753),
    [anon_sym_int144] = ACTIONS(753),
    [anon_sym_int152] = ACTIONS(753),
    [anon_sym_int160] = ACTIONS(753),
    [anon_sym_int168] = ACTIONS(753),
    [anon_sym_int176] = ACTIONS(753),
    [anon_sym_int184] = ACTIONS(753),
    [anon_sym_int192] = ACTIONS(753),
    [anon_sym_int200] = ACTIONS(753),
    [anon_sym_int208] = ACTIONS(753),
    [anon_sym_int216] = ACTIONS(753),
    [anon_sym_int224] = ACTIONS(753),
    [anon_sym_int232] = ACTIONS(753),
    [anon_sym_int240] = ACTIONS(753),
    [anon_sym_int248] = ACTIONS(753),
    [anon_sym_int256] = ACTIONS(753),
    [anon_sym_uint] = ACTIONS(753),
    [anon_sym_uint8] = ACTIONS(753),
    [anon_sym_uint16] = ACTIONS(753),
    [anon_sym_uint24] = ACTIONS(753),
    [anon_sym_uint32] = ACTIONS(753),
    [anon_sym_uint40] = ACTIONS(753),
    [anon_sym_uint48] = ACTIONS(753),
    [anon_sym_uint56] = ACTIONS(753),
    [anon_sym_uint64] = ACTIONS(753),
    [anon_sym_uint72] = ACTIONS(753),
    [anon_sym_uint80] = ACTIONS(753),
    [anon_sym_uint88] = ACTIONS(753),
    [anon_sym_uint96] = ACTIONS(753),
    [anon_sym_uint104] = ACTIONS(753),
    [anon_sym_uint112] = ACTIONS(753),
    [anon_sym_uint120] = ACTIONS(753),
    [anon_sym_uint128] = ACTIONS(753),
    [anon_sym_uint136] = ACTIONS(753),
    [anon_sym_uint144] = ACTIONS(753),
    [anon_sym_uint152] = ACTIONS(753),
    [anon_sym_uint160] = ACTIONS(753),
    [anon_sym_uint168] = ACTIONS(753),
    [anon_sym_uint176] = ACTIONS(753),
    [anon_sym_uint184] = ACTIONS(753),
    [anon_sym_uint192] = ACTIONS(753),
    [anon_sym_uint200] = ACTIONS(753),
    [anon_sym_uint208] = ACTIONS(753),
    [anon_sym_uint216] = ACTIONS(753),
    [anon_sym_uint224] = ACTIONS(753),
    [anon_sym_uint232] = ACTIONS(753),
    [anon_sym_uint240] = ACTIONS(753),
    [anon_sym_uint248] = ACTIONS(753),
    [anon_sym_uint256] = ACTIONS(753),
    [anon_sym_bytes] = ACTIONS(753),
    [anon_sym_bytes1] = ACTIONS(753),
    [anon_sym_bytes2] = ACTIONS(753),
    [anon_sym_bytes3] = ACTIONS(753),
    [anon_sym_bytes4] = ACTIONS(753),
    [anon_sym_bytes5] = ACTIONS(753),
    [anon_sym_bytes6] = ACTIONS(753),
    [anon_sym_bytes7] = ACTIONS(753),
    [anon_sym_bytes8] = ACTIONS(753),
    [anon_sym_bytes9] = ACTIONS(753),
    [anon_sym_bytes10] = ACTIONS(753),
    [anon_sym_bytes11] = ACTIONS(753),
    [anon_sym_bytes12] = ACTIONS(753),
    [anon_sym_bytes13] = ACTIONS(753),
    [anon_sym_bytes14] = ACTIONS(753),
    [anon_sym_bytes15] = ACTIONS(753),
    [anon_sym_bytes16] = ACTIONS(753),
    [anon_sym_bytes17] = ACTIONS(753),
    [anon_sym_bytes18] = ACTIONS(753),
    [anon_sym_bytes19] = ACTIONS(753),
    [anon_sym_bytes20] = ACTIONS(753),
    [anon_sym_bytes21] = ACTIONS(753),
    [anon_sym_bytes22] = ACTIONS(753),
    [anon_sym_bytes23] = ACTIONS(753),
    [anon_sym_bytes24] = ACTIONS(753),
    [anon_sym_bytes25] = ACTIONS(753),
    [anon_sym_bytes26] = ACTIONS(753),
    [anon_sym_bytes27] = ACTIONS(753),
    [anon_sym_bytes28] = ACTIONS(753),
    [anon_sym_bytes29] = ACTIONS(753),
    [anon_sym_bytes30] = ACTIONS(753),
    [anon_sym_bytes31] = ACTIONS(753),
    [anon_sym_bytes32] = ACTIONS(753),
    [anon_sym_fixed] = ACTIONS(753),
    [aux_sym__fixed_token1] = ACTIONS(753),
    [anon_sym_ufixed] = ACTIONS(753),
    [aux_sym__ufixed_token1] = ACTIONS(753),
    [sym_comment] = ACTIONS(3),
  },
  [234] = {
    [sym_identifier] = ACTIONS(773),
    [anon_sym_RBRACE] = ACTIONS(771),
    [anon_sym_type] = ACTIONS(773),
    [anon_sym_error] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(773),
    [anon_sym_enum] = ACTIONS(773),
    [anon_sym_event] = ACTIONS(773),
    [anon_sym_using] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(773),
    [anon_sym_byte] = ACTIONS(773),
    [anon_sym_address] = ACTIONS(773),
    [anon_sym_var] = ACTIONS(773),
    [anon_sym_modifier] = ACTIONS(773),
    [anon_sym_constructor] = ACTIONS(773),
    [anon_sym_fallback] = ACTIONS(773),
    [anon_sym_receive] = ACTIONS(773),
    [anon_sym_mapping] = ACTIONS(773),
    [anon_sym_bool] = ACTIONS(773),
    [anon_sym_string] = ACTIONS(773),
    [anon_sym_int] = ACTIONS(773),
    [anon_sym_int8] = ACTIONS(773),
    [anon_sym_int16] = ACTIONS(773),
    [anon_sym_int24] = ACTIONS(773),
    [anon_sym_int32] = ACTIONS(773),
    [anon_sym_int40] = ACTIONS(773),
    [anon_sym_int48] = ACTIONS(773),
    [anon_sym_int56] = ACTIONS(773),
    [anon_sym_int64] = ACTIONS(773),
    [anon_sym_int72] = ACTIONS(773),
    [anon_sym_int80] = ACTIONS(773),
    [anon_sym_int88] = ACTIONS(773),
    [anon_sym_int96] = ACTIONS(773),
    [anon_sym_int104] = ACTIONS(773),
    [anon_sym_int112] = ACTIONS(773),
    [anon_sym_int120] = ACTIONS(773),
    [anon_sym_int128] = ACTIONS(773),
    [anon_sym_int136] = ACTIONS(773),
    [anon_sym_int144] = ACTIONS(773),
    [anon_sym_int152] = ACTIONS(773),
    [anon_sym_int160] = ACTIONS(773),
    [anon_sym_int168] = ACTIONS(773),
    [anon_sym_int176] = ACTIONS(773),
    [anon_sym_int184] = ACTIONS(773),
    [anon_sym_int192] = ACTIONS(773),
    [anon_sym_int200] = ACTIONS(773),
    [anon_sym_int208] = ACTIONS(773),
    [anon_sym_int216] = ACTIONS(773),
    [anon_sym_int224] = ACTIONS(773),
    [anon_sym_int232] = ACTIONS(773),
    [anon_sym_int240] = ACTIONS(773),
    [anon_sym_int248] = ACTIONS(773),
    [anon_sym_int256] = ACTIONS(773),
    [anon_sym_uint] = ACTIONS(773),
    [anon_sym_uint8] = ACTIONS(773),
    [anon_sym_uint16] = ACTIONS(773),
    [anon_sym_uint24] = ACTIONS(773),
    [anon_sym_uint32] = ACTIONS(773),
    [anon_sym_uint40] = ACTIONS(773),
    [anon_sym_uint48] = ACTIONS(773),
    [anon_sym_uint56] = ACTIONS(773),
    [anon_sym_uint64] = ACTIONS(773),
    [anon_sym_uint72] = ACTIONS(773),
    [anon_sym_uint80] = ACTIONS(773),
    [anon_sym_uint88] = ACTIONS(773),
    [anon_sym_uint96] = ACTIONS(773),
    [anon_sym_uint104] = ACTIONS(773),
    [anon_sym_uint112] = ACTIONS(773),
    [anon_sym_uint120] = ACTIONS(773),
    [anon_sym_uint128] = ACTIONS(773),
    [anon_sym_uint136] = ACTIONS(773),
    [anon_sym_uint144] = ACTIONS(773),
    [anon_sym_uint152] = ACTIONS(773),
    [anon_sym_uint160] = ACTIONS(773),
    [anon_sym_uint168] = ACTIONS(773),
    [anon_sym_uint176] = ACTIONS(773),
    [anon_sym_uint184] = ACTIONS(773),
    [anon_sym_uint192] = ACTIONS(773),
    [anon_sym_uint200] = ACTIONS(773),
    [anon_sym_uint208] = ACTIONS(773),
    [anon_sym_uint216] = ACTIONS(773),
    [anon_sym_uint224] = ACTIONS(773),
    [anon_sym_uint232] = ACTIONS(773),
    [anon_sym_uint240] = ACTIONS(773),
    [anon_sym_uint248] = ACTIONS(773),
    [anon_sym_uint256] = ACTIONS(773),
    [anon_sym_bytes] = ACTIONS(773),
    [anon_sym_bytes1] = ACTIONS(773),
    [anon_sym_bytes2] = ACTIONS(773),
    [anon_sym_bytes3] = ACTIONS(773),
    [anon_sym_bytes4] = ACTIONS(773),
    [anon_sym_bytes5] = ACTIONS(773),
    [anon_sym_bytes6] = ACTIONS(773),
    [anon_sym_bytes7] = ACTIONS(773),
    [anon_sym_bytes8] = ACTIONS(773),
    [anon_sym_bytes9] = ACTIONS(773),
    [anon_sym_bytes10] = ACTIONS(773),
    [anon_sym_bytes11] = ACTIONS(773),
    [anon_sym_bytes12] = ACTIONS(773),
    [anon_sym_bytes13] = ACTIONS(773),
    [anon_sym_bytes14] = ACTIONS(773),
    [anon_sym_bytes15] = ACTIONS(773),
    [anon_sym_bytes16] = ACTIONS(773),
    [anon_sym_bytes17] = ACTIONS(773),
    [anon_sym_bytes18] = ACTIONS(773),
    [anon_sym_bytes19] = ACTIONS(773),
    [anon_sym_bytes20] = ACTIONS(773),
    [anon_sym_bytes21] = ACTIONS(773),
    [anon_sym_bytes22] = ACTIONS(773),
    [anon_sym_bytes23] = ACTIONS(773),
    [anon_sym_bytes24] = ACTIONS(773),
    [anon_sym_bytes25] = ACTIONS(773),
    [anon_sym_bytes26] = ACTIONS(773),
    [anon_sym_bytes27] = ACTIONS(773),
    [anon_sym_bytes28] = ACTIONS(773),
    [anon_sym_bytes29] = ACTIONS(773),
    [anon_sym_bytes30] = ACTIONS(773),
    [anon_sym_bytes31] = ACTIONS(773),
    [anon_sym_bytes32] = ACTIONS(773),
    [anon_sym_fixed] = ACTIONS(773),
    [aux_sym__fixed_token1] = ACTIONS(773),
    [anon_sym_ufixed] = ACTIONS(773),
    [aux_sym__ufixed_token1] = ACTIONS(773),
    [sym_comment] = ACTIONS(3),
  },
  [235] = {
    [sym_identifier] = ACTIONS(869),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_type] = ACTIONS(869),
    [anon_sym_error] = ACTIONS(869),
    [anon_sym_struct] = ACTIONS(869),
    [anon_sym_enum] = ACTIONS(869),
    [anon_sym_event] = ACTIONS(869),
    [anon_sym_using] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(869),
    [anon_sym_byte] = ACTIONS(869),
    [anon_sym_address] = ACTIONS(869),
    [anon_sym_var] = ACTIONS(869),
    [anon_sym_modifier] = ACTIONS(869),
    [anon_sym_constructor] = ACTIONS(869),
    [anon_sym_fallback] = ACTIONS(869),
    [anon_sym_receive] = ACTIONS(869),
    [anon_sym_mapping] = ACTIONS(869),
    [anon_sym_bool] = ACTIONS(869),
    [anon_sym_string] = ACTIONS(869),
    [anon_sym_int] = ACTIONS(869),
    [anon_sym_int8] = ACTIONS(869),
    [anon_sym_int16] = ACTIONS(869),
    [anon_sym_int24] = ACTIONS(869),
    [anon_sym_int32] = ACTIONS(869),
    [anon_sym_int40] = ACTIONS(869),
    [anon_sym_int48] = ACTIONS(869),
    [anon_sym_int56] = ACTIONS(869),
    [anon_sym_int64] = ACTIONS(869),
    [anon_sym_int72] = ACTIONS(869),
    [anon_sym_int80] = ACTIONS(869),
    [anon_sym_int88] = ACTIONS(869),
    [anon_sym_int96] = ACTIONS(869),
    [anon_sym_int104] = ACTIONS(869),
    [anon_sym_int112] = ACTIONS(869),
    [anon_sym_int120] = ACTIONS(869),
    [anon_sym_int128] = ACTIONS(869),
    [anon_sym_int136] = ACTIONS(869),
    [anon_sym_int144] = ACTIONS(869),
    [anon_sym_int152] = ACTIONS(869),
    [anon_sym_int160] = ACTIONS(869),
    [anon_sym_int168] = ACTIONS(869),
    [anon_sym_int176] = ACTIONS(869),
    [anon_sym_int184] = ACTIONS(869),
    [anon_sym_int192] = ACTIONS(869),
    [anon_sym_int200] = ACTIONS(869),
    [anon_sym_int208] = ACTIONS(869),
    [anon_sym_int216] = ACTIONS(869),
    [anon_sym_int224] = ACTIONS(869),
    [anon_sym_int232] = ACTIONS(869),
    [anon_sym_int240] = ACTIONS(869),
    [anon_sym_int248] = ACTIONS(869),
    [anon_sym_int256] = ACTIONS(869),
    [anon_sym_uint] = ACTIONS(869),
    [anon_sym_uint8] = ACTIONS(869),
    [anon_sym_uint16] = ACTIONS(869),
    [anon_sym_uint24] = ACTIONS(869),
    [anon_sym_uint32] = ACTIONS(869),
    [anon_sym_uint40] = ACTIONS(869),
    [anon_sym_uint48] = ACTIONS(869),
    [anon_sym_uint56] = ACTIONS(869),
    [anon_sym_uint64] = ACTIONS(869),
    [anon_sym_uint72] = ACTIONS(869),
    [anon_sym_uint80] = ACTIONS(869),
    [anon_sym_uint88] = ACTIONS(869),
    [anon_sym_uint96] = ACTIONS(869),
    [anon_sym_uint104] = ACTIONS(869),
    [anon_sym_uint112] = ACTIONS(869),
    [anon_sym_uint120] = ACTIONS(869),
    [anon_sym_uint128] = ACTIONS(869),
    [anon_sym_uint136] = ACTIONS(869),
    [anon_sym_uint144] = ACTIONS(869),
    [anon_sym_uint152] = ACTIONS(869),
    [anon_sym_uint160] = ACTIONS(869),
    [anon_sym_uint168] = ACTIONS(869),
    [anon_sym_uint176] = ACTIONS(869),
    [anon_sym_uint184] = ACTIONS(869),
    [anon_sym_uint192] = ACTIONS(869),
    [anon_sym_uint200] = ACTIONS(869),
    [anon_sym_uint208] = ACTIONS(869),
    [anon_sym_uint216] = ACTIONS(869),
    [anon_sym_uint224] = ACTIONS(869),
    [anon_sym_uint232] = ACTIONS(869),
    [anon_sym_uint240] = ACTIONS(869),
    [anon_sym_uint248] = ACTIONS(869),
    [anon_sym_uint256] = ACTIONS(869),
    [anon_sym_bytes] = ACTIONS(869),
    [anon_sym_bytes1] = ACTIONS(869),
    [anon_sym_bytes2] = ACTIONS(869),
    [anon_sym_bytes3] = ACTIONS(869),
    [anon_sym_bytes4] = ACTIONS(869),
    [anon_sym_bytes5] = ACTIONS(869),
    [anon_sym_bytes6] = ACTIONS(869),
    [anon_sym_bytes7] = ACTIONS(869),
    [anon_sym_bytes8] = ACTIONS(869),
    [anon_sym_bytes9] = ACTIONS(869),
    [anon_sym_bytes10] = ACTIONS(869),
    [anon_sym_bytes11] = ACTIONS(869),
    [anon_sym_bytes12] = ACTIONS(869),
    [anon_sym_bytes13] = ACTIONS(869),
    [anon_sym_bytes14] = ACTIONS(869),
    [anon_sym_bytes15] = ACTIONS(869),
    [anon_sym_bytes16] = ACTIONS(869),
    [anon_sym_bytes17] = ACTIONS(869),
    [anon_sym_bytes18] = ACTIONS(869),
    [anon_sym_bytes19] = ACTIONS(869),
    [anon_sym_bytes20] = ACTIONS(869),
    [anon_sym_bytes21] = ACTIONS(869),
    [anon_sym_bytes22] = ACTIONS(869),
    [anon_sym_bytes23] = ACTIONS(869),
    [anon_sym_bytes24] = ACTIONS(869),
    [anon_sym_bytes25] = ACTIONS(869),
    [anon_sym_bytes26] = ACTIONS(869),
    [anon_sym_bytes27] = ACTIONS(869),
    [anon_sym_bytes28] = ACTIONS(869),
    [anon_sym_bytes29] = ACTIONS(869),
    [anon_sym_bytes30] = ACTIONS(869),
    [anon_sym_bytes31] = ACTIONS(869),
    [anon_sym_bytes32] = ACTIONS(869),
    [anon_sym_fixed] = ACTIONS(869),
    [aux_sym__fixed_token1] = ACTIONS(869),
    [anon_sym_ufixed] = ACTIONS(869),
    [aux_sym__ufixed_token1] = ACTIONS(869),
    [sym_comment] = ACTIONS(3),
  },
  [236] = {
    [sym_identifier] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(619),
    [anon_sym_type] = ACTIONS(621),
    [anon_sym_error] = ACTIONS(621),
    [anon_sym_struct] = ACTIONS(621),
    [anon_sym_enum] = ACTIONS(621),
    [anon_sym_event] = ACTIONS(621),
    [anon_sym_using] = ACTIONS(621),
    [anon_sym_function] = ACTIONS(621),
    [anon_sym_byte] = ACTIONS(621),
    [anon_sym_address] = ACTIONS(621),
    [anon_sym_var] = ACTIONS(621),
    [anon_sym_modifier] = ACTIONS(621),
    [anon_sym_constructor] = ACTIONS(621),
    [anon_sym_fallback] = ACTIONS(621),
    [anon_sym_receive] = ACTIONS(621),
    [anon_sym_mapping] = ACTIONS(621),
    [anon_sym_bool] = ACTIONS(621),
    [anon_sym_string] = ACTIONS(621),
    [anon_sym_int] = ACTIONS(621),
    [anon_sym_int8] = ACTIONS(621),
    [anon_sym_int16] = ACTIONS(621),
    [anon_sym_int24] = ACTIONS(621),
    [anon_sym_int32] = ACTIONS(621),
    [anon_sym_int40] = ACTIONS(621),
    [anon_sym_int48] = ACTIONS(621),
    [anon_sym_int56] = ACTIONS(621),
    [anon_sym_int64] = ACTIONS(621),
    [anon_sym_int72] = ACTIONS(621),
    [anon_sym_int80] = ACTIONS(621),
    [anon_sym_int88] = ACTIONS(621),
    [anon_sym_int96] = ACTIONS(621),
    [anon_sym_int104] = ACTIONS(621),
    [anon_sym_int112] = ACTIONS(621),
    [anon_sym_int120] = ACTIONS(621),
    [anon_sym_int128] = ACTIONS(621),
    [anon_sym_int136] = ACTIONS(621),
    [anon_sym_int144] = ACTIONS(621),
    [anon_sym_int152] = ACTIONS(621),
    [anon_sym_int160] = ACTIONS(621),
    [anon_sym_int168] = ACTIONS(621),
    [anon_sym_int176] = ACTIONS(621),
    [anon_sym_int184] = ACTIONS(621),
    [anon_sym_int192] = ACTIONS(621),
    [anon_sym_int200] = ACTIONS(621),
    [anon_sym_int208] = ACTIONS(621),
    [anon_sym_int216] = ACTIONS(621),
    [anon_sym_int224] = ACTIONS(621),
    [anon_sym_int232] = ACTIONS(621),
    [anon_sym_int240] = ACTIONS(621),
    [anon_sym_int248] = ACTIONS(621),
    [anon_sym_int256] = ACTIONS(621),
    [anon_sym_uint] = ACTIONS(621),
    [anon_sym_uint8] = ACTIONS(621),
    [anon_sym_uint16] = ACTIONS(621),
    [anon_sym_uint24] = ACTIONS(621),
    [anon_sym_uint32] = ACTIONS(621),
    [anon_sym_uint40] = ACTIONS(621),
    [anon_sym_uint48] = ACTIONS(621),
    [anon_sym_uint56] = ACTIONS(621),
    [anon_sym_uint64] = ACTIONS(621),
    [anon_sym_uint72] = ACTIONS(621),
    [anon_sym_uint80] = ACTIONS(621),
    [anon_sym_uint88] = ACTIONS(621),
    [anon_sym_uint96] = ACTIONS(621),
    [anon_sym_uint104] = ACTIONS(621),
    [anon_sym_uint112] = ACTIONS(621),
    [anon_sym_uint120] = ACTIONS(621),
    [anon_sym_uint128] = ACTIONS(621),
    [anon_sym_uint136] = ACTIONS(621),
    [anon_sym_uint144] = ACTIONS(621),
    [anon_sym_uint152] = ACTIONS(621),
    [anon_sym_uint160] = ACTIONS(621),
    [anon_sym_uint168] = ACTIONS(621),
    [anon_sym_uint176] = ACTIONS(621),
    [anon_sym_uint184] = ACTIONS(621),
    [anon_sym_uint192] = ACTIONS(621),
    [anon_sym_uint200] = ACTIONS(621),
    [anon_sym_uint208] = ACTIONS(621),
    [anon_sym_uint216] = ACTIONS(621),
    [anon_sym_uint224] = ACTIONS(621),
    [anon_sym_uint232] = ACTIONS(621),
    [anon_sym_uint240] = ACTIONS(621),
    [anon_sym_uint248] = ACTIONS(621),
    [anon_sym_uint256] = ACTIONS(621),
    [anon_sym_bytes] = ACTIONS(621),
    [anon_sym_bytes1] = ACTIONS(621),
    [anon_sym_bytes2] = ACTIONS(621),
    [anon_sym_bytes3] = ACTIONS(621),
    [anon_sym_bytes4] = ACTIONS(621),
    [anon_sym_bytes5] = ACTIONS(621),
    [anon_sym_bytes6] = ACTIONS(621),
    [anon_sym_bytes7] = ACTIONS(621),
    [anon_sym_bytes8] = ACTIONS(621),
    [anon_sym_bytes9] = ACTIONS(621),
    [anon_sym_bytes10] = ACTIONS(621),
    [anon_sym_bytes11] = ACTIONS(621),
    [anon_sym_bytes12] = ACTIONS(621),
    [anon_sym_bytes13] = ACTIONS(621),
    [anon_sym_bytes14] = ACTIONS(621),
    [anon_sym_bytes15] = ACTIONS(621),
    [anon_sym_bytes16] = ACTIONS(621),
    [anon_sym_bytes17] = ACTIONS(621),
    [anon_sym_bytes18] = ACTIONS(621),
    [anon_sym_bytes19] = ACTIONS(621),
    [anon_sym_bytes20] = ACTIONS(621),
    [anon_sym_bytes21] = ACTIONS(621),
    [anon_sym_bytes22] = ACTIONS(621),
    [anon_sym_bytes23] = ACTIONS(621),
    [anon_sym_bytes24] = ACTIONS(621),
    [anon_sym_bytes25] = ACTIONS(621),
    [anon_sym_bytes26] = ACTIONS(621),
    [anon_sym_bytes27] = ACTIONS(621),
    [anon_sym_bytes28] = ACTIONS(621),
    [anon_sym_bytes29] = ACTIONS(621),
    [anon_sym_bytes30] = ACTIONS(621),
    [anon_sym_bytes31] = ACTIONS(621),
    [anon_sym_bytes32] = ACTIONS(621),
    [anon_sym_fixed] = ACTIONS(621),
    [aux_sym__fixed_token1] = ACTIONS(621),
    [anon_sym_ufixed] = ACTIONS(621),
    [aux_sym__ufixed_token1] = ACTIONS(621),
    [sym_comment] = ACTIONS(3),
  },
  [237] = {
    [sym_identifier] = ACTIONS(873),
    [anon_sym_RBRACE] = ACTIONS(875),
    [anon_sym_type] = ACTIONS(873),
    [anon_sym_error] = ACTIONS(873),
    [anon_sym_struct] = ACTIONS(873),
    [anon_sym_enum] = ACTIONS(873),
    [anon_sym_event] = ACTIONS(873),
    [anon_sym_using] = ACTIONS(873),
    [anon_sym_function] = ACTIONS(873),
    [anon_sym_byte] = ACTIONS(873),
    [anon_sym_address] = ACTIONS(873),
    [anon_sym_var] = ACTIONS(873),
    [anon_sym_modifier] = ACTIONS(873),
    [anon_sym_constructor] = ACTIONS(873),
    [anon_sym_fallback] = ACTIONS(873),
    [anon_sym_receive] = ACTIONS(873),
    [anon_sym_mapping] = ACTIONS(873),
    [anon_sym_bool] = ACTIONS(873),
    [anon_sym_string] = ACTIONS(873),
    [anon_sym_int] = ACTIONS(873),
    [anon_sym_int8] = ACTIONS(873),
    [anon_sym_int16] = ACTIONS(873),
    [anon_sym_int24] = ACTIONS(873),
    [anon_sym_int32] = ACTIONS(873),
    [anon_sym_int40] = ACTIONS(873),
    [anon_sym_int48] = ACTIONS(873),
    [anon_sym_int56] = ACTIONS(873),
    [anon_sym_int64] = ACTIONS(873),
    [anon_sym_int72] = ACTIONS(873),
    [anon_sym_int80] = ACTIONS(873),
    [anon_sym_int88] = ACTIONS(873),
    [anon_sym_int96] = ACTIONS(873),
    [anon_sym_int104] = ACTIONS(873),
    [anon_sym_int112] = ACTIONS(873),
    [anon_sym_int120] = ACTIONS(873),
    [anon_sym_int128] = ACTIONS(873),
    [anon_sym_int136] = ACTIONS(873),
    [anon_sym_int144] = ACTIONS(873),
    [anon_sym_int152] = ACTIONS(873),
    [anon_sym_int160] = ACTIONS(873),
    [anon_sym_int168] = ACTIONS(873),
    [anon_sym_int176] = ACTIONS(873),
    [anon_sym_int184] = ACTIONS(873),
    [anon_sym_int192] = ACTIONS(873),
    [anon_sym_int200] = ACTIONS(873),
    [anon_sym_int208] = ACTIONS(873),
    [anon_sym_int216] = ACTIONS(873),
    [anon_sym_int224] = ACTIONS(873),
    [anon_sym_int232] = ACTIONS(873),
    [anon_sym_int240] = ACTIONS(873),
    [anon_sym_int248] = ACTIONS(873),
    [anon_sym_int256] = ACTIONS(873),
    [anon_sym_uint] = ACTIONS(873),
    [anon_sym_uint8] = ACTIONS(873),
    [anon_sym_uint16] = ACTIONS(873),
    [anon_sym_uint24] = ACTIONS(873),
    [anon_sym_uint32] = ACTIONS(873),
    [anon_sym_uint40] = ACTIONS(873),
    [anon_sym_uint48] = ACTIONS(873),
    [anon_sym_uint56] = ACTIONS(873),
    [anon_sym_uint64] = ACTIONS(873),
    [anon_sym_uint72] = ACTIONS(873),
    [anon_sym_uint80] = ACTIONS(873),
    [anon_sym_uint88] = ACTIONS(873),
    [anon_sym_uint96] = ACTIONS(873),
    [anon_sym_uint104] = ACTIONS(873),
    [anon_sym_uint112] = ACTIONS(873),
    [anon_sym_uint120] = ACTIONS(873),
    [anon_sym_uint128] = ACTIONS(873),
    [anon_sym_uint136] = ACTIONS(873),
    [anon_sym_uint144] = ACTIONS(873),
    [anon_sym_uint152] = ACTIONS(873),
    [anon_sym_uint160] = ACTIONS(873),
    [anon_sym_uint168] = ACTIONS(873),
    [anon_sym_uint176] = ACTIONS(873),
    [anon_sym_uint184] = ACTIONS(873),
    [anon_sym_uint192] = ACTIONS(873),
    [anon_sym_uint200] = ACTIONS(873),
    [anon_sym_uint208] = ACTIONS(873),
    [anon_sym_uint216] = ACTIONS(873),
    [anon_sym_uint224] = ACTIONS(873),
    [anon_sym_uint232] = ACTIONS(873),
    [anon_sym_uint240] = ACTIONS(873),
    [anon_sym_uint248] = ACTIONS(873),
    [anon_sym_uint256] = ACTIONS(873),
    [anon_sym_bytes] = ACTIONS(873),
    [anon_sym_bytes1] = ACTIONS(873),
    [anon_sym_bytes2] = ACTIONS(873),
    [anon_sym_bytes3] = ACTIONS(873),
    [anon_sym_bytes4] = ACTIONS(873),
    [anon_sym_bytes5] = ACTIONS(873),
    [anon_sym_bytes6] = ACTIONS(873),
    [anon_sym_bytes7] = ACTIONS(873),
    [anon_sym_bytes8] = ACTIONS(873),
    [anon_sym_bytes9] = ACTIONS(873),
    [anon_sym_bytes10] = ACTIONS(873),
    [anon_sym_bytes11] = ACTIONS(873),
    [anon_sym_bytes12] = ACTIONS(873),
    [anon_sym_bytes13] = ACTIONS(873),
    [anon_sym_bytes14] = ACTIONS(873),
    [anon_sym_bytes15] = ACTIONS(873),
    [anon_sym_bytes16] = ACTIONS(873),
    [anon_sym_bytes17] = ACTIONS(873),
    [anon_sym_bytes18] = ACTIONS(873),
    [anon_sym_bytes19] = ACTIONS(873),
    [anon_sym_bytes20] = ACTIONS(873),
    [anon_sym_bytes21] = ACTIONS(873),
    [anon_sym_bytes22] = ACTIONS(873),
    [anon_sym_bytes23] = ACTIONS(873),
    [anon_sym_bytes24] = ACTIONS(873),
    [anon_sym_bytes25] = ACTIONS(873),
    [anon_sym_bytes26] = ACTIONS(873),
    [anon_sym_bytes27] = ACTIONS(873),
    [anon_sym_bytes28] = ACTIONS(873),
    [anon_sym_bytes29] = ACTIONS(873),
    [anon_sym_bytes30] = ACTIONS(873),
    [anon_sym_bytes31] = ACTIONS(873),
    [anon_sym_bytes32] = ACTIONS(873),
    [anon_sym_fixed] = ACTIONS(873),
    [aux_sym__fixed_token1] = ACTIONS(873),
    [anon_sym_ufixed] = ACTIONS(873),
    [aux_sym__ufixed_token1] = ACTIONS(873),
    [sym_comment] = ACTIONS(3),
  },
  [238] = {
    [sym_identifier] = ACTIONS(733),
    [anon_sym_RBRACE] = ACTIONS(731),
    [anon_sym_type] = ACTIONS(733),
    [anon_sym_error] = ACTIONS(733),
    [anon_sym_struct] = ACTIONS(733),
    [anon_sym_enum] = ACTIONS(733),
    [anon_sym_event] = ACTIONS(733),
    [anon_sym_using] = ACTIONS(733),
    [anon_sym_function] = ACTIONS(733),
    [anon_sym_byte] = ACTIONS(733),
    [anon_sym_address] = ACTIONS(733),
    [anon_sym_var] = ACTIONS(733),
    [anon_sym_modifier] = ACTIONS(733),
    [anon_sym_constructor] = ACTIONS(733),
    [anon_sym_fallback] = ACTIONS(733),
    [anon_sym_receive] = ACTIONS(733),
    [anon_sym_mapping] = ACTIONS(733),
    [anon_sym_bool] = ACTIONS(733),
    [anon_sym_string] = ACTIONS(733),
    [anon_sym_int] = ACTIONS(733),
    [anon_sym_int8] = ACTIONS(733),
    [anon_sym_int16] = ACTIONS(733),
    [anon_sym_int24] = ACTIONS(733),
    [anon_sym_int32] = ACTIONS(733),
    [anon_sym_int40] = ACTIONS(733),
    [anon_sym_int48] = ACTIONS(733),
    [anon_sym_int56] = ACTIONS(733),
    [anon_sym_int64] = ACTIONS(733),
    [anon_sym_int72] = ACTIONS(733),
    [anon_sym_int80] = ACTIONS(733),
    [anon_sym_int88] = ACTIONS(733),
    [anon_sym_int96] = ACTIONS(733),
    [anon_sym_int104] = ACTIONS(733),
    [anon_sym_int112] = ACTIONS(733),
    [anon_sym_int120] = ACTIONS(733),
    [anon_sym_int128] = ACTIONS(733),
    [anon_sym_int136] = ACTIONS(733),
    [anon_sym_int144] = ACTIONS(733),
    [anon_sym_int152] = ACTIONS(733),
    [anon_sym_int160] = ACTIONS(733),
    [anon_sym_int168] = ACTIONS(733),
    [anon_sym_int176] = ACTIONS(733),
    [anon_sym_int184] = ACTIONS(733),
    [anon_sym_int192] = ACTIONS(733),
    [anon_sym_int200] = ACTIONS(733),
    [anon_sym_int208] = ACTIONS(733),
    [anon_sym_int216] = ACTIONS(733),
    [anon_sym_int224] = ACTIONS(733),
    [anon_sym_int232] = ACTIONS(733),
    [anon_sym_int240] = ACTIONS(733),
    [anon_sym_int248] = ACTIONS(733),
    [anon_sym_int256] = ACTIONS(733),
    [anon_sym_uint] = ACTIONS(733),
    [anon_sym_uint8] = ACTIONS(733),
    [anon_sym_uint16] = ACTIONS(733),
    [anon_sym_uint24] = ACTIONS(733),
    [anon_sym_uint32] = ACTIONS(733),
    [anon_sym_uint40] = ACTIONS(733),
    [anon_sym_uint48] = ACTIONS(733),
    [anon_sym_uint56] = ACTIONS(733),
    [anon_sym_uint64] = ACTIONS(733),
    [anon_sym_uint72] = ACTIONS(733),
    [anon_sym_uint80] = ACTIONS(733),
    [anon_sym_uint88] = ACTIONS(733),
    [anon_sym_uint96] = ACTIONS(733),
    [anon_sym_uint104] = ACTIONS(733),
    [anon_sym_uint112] = ACTIONS(733),
    [anon_sym_uint120] = ACTIONS(733),
    [anon_sym_uint128] = ACTIONS(733),
    [anon_sym_uint136] = ACTIONS(733),
    [anon_sym_uint144] = ACTIONS(733),
    [anon_sym_uint152] = ACTIONS(733),
    [anon_sym_uint160] = ACTIONS(733),
    [anon_sym_uint168] = ACTIONS(733),
    [anon_sym_uint176] = ACTIONS(733),
    [anon_sym_uint184] = ACTIONS(733),
    [anon_sym_uint192] = ACTIONS(733),
    [anon_sym_uint200] = ACTIONS(733),
    [anon_sym_uint208] = ACTIONS(733),
    [anon_sym_uint216] = ACTIONS(733),
    [anon_sym_uint224] = ACTIONS(733),
    [anon_sym_uint232] = ACTIONS(733),
    [anon_sym_uint240] = ACTIONS(733),
    [anon_sym_uint248] = ACTIONS(733),
    [anon_sym_uint256] = ACTIONS(733),
    [anon_sym_bytes] = ACTIONS(733),
    [anon_sym_bytes1] = ACTIONS(733),
    [anon_sym_bytes2] = ACTIONS(733),
    [anon_sym_bytes3] = ACTIONS(733),
    [anon_sym_bytes4] = ACTIONS(733),
    [anon_sym_bytes5] = ACTIONS(733),
    [anon_sym_bytes6] = ACTIONS(733),
    [anon_sym_bytes7] = ACTIONS(733),
    [anon_sym_bytes8] = ACTIONS(733),
    [anon_sym_bytes9] = ACTIONS(733),
    [anon_sym_bytes10] = ACTIONS(733),
    [anon_sym_bytes11] = ACTIONS(733),
    [anon_sym_bytes12] = ACTIONS(733),
    [anon_sym_bytes13] = ACTIONS(733),
    [anon_sym_bytes14] = ACTIONS(733),
    [anon_sym_bytes15] = ACTIONS(733),
    [anon_sym_bytes16] = ACTIONS(733),
    [anon_sym_bytes17] = ACTIONS(733),
    [anon_sym_bytes18] = ACTIONS(733),
    [anon_sym_bytes19] = ACTIONS(733),
    [anon_sym_bytes20] = ACTIONS(733),
    [anon_sym_bytes21] = ACTIONS(733),
    [anon_sym_bytes22] = ACTIONS(733),
    [anon_sym_bytes23] = ACTIONS(733),
    [anon_sym_bytes24] = ACTIONS(733),
    [anon_sym_bytes25] = ACTIONS(733),
    [anon_sym_bytes26] = ACTIONS(733),
    [anon_sym_bytes27] = ACTIONS(733),
    [anon_sym_bytes28] = ACTIONS(733),
    [anon_sym_bytes29] = ACTIONS(733),
    [anon_sym_bytes30] = ACTIONS(733),
    [anon_sym_bytes31] = ACTIONS(733),
    [anon_sym_bytes32] = ACTIONS(733),
    [anon_sym_fixed] = ACTIONS(733),
    [aux_sym__fixed_token1] = ACTIONS(733),
    [anon_sym_ufixed] = ACTIONS(733),
    [aux_sym__ufixed_token1] = ACTIONS(733),
    [sym_comment] = ACTIONS(3),
  },
  [239] = {
    [sym_identifier] = ACTIONS(733),
    [anon_sym_RBRACE] = ACTIONS(731),
    [anon_sym_type] = ACTIONS(733),
    [anon_sym_error] = ACTIONS(733),
    [anon_sym_struct] = ACTIONS(733),
    [anon_sym_enum] = ACTIONS(733),
    [anon_sym_event] = ACTIONS(733),
    [anon_sym_using] = ACTIONS(733),
    [anon_sym_function] = ACTIONS(733),
    [anon_sym_byte] = ACTIONS(733),
    [anon_sym_address] = ACTIONS(733),
    [anon_sym_var] = ACTIONS(733),
    [anon_sym_modifier] = ACTIONS(733),
    [anon_sym_constructor] = ACTIONS(733),
    [anon_sym_fallback] = ACTIONS(733),
    [anon_sym_receive] = ACTIONS(733),
    [anon_sym_mapping] = ACTIONS(733),
    [anon_sym_bool] = ACTIONS(733),
    [anon_sym_string] = ACTIONS(733),
    [anon_sym_int] = ACTIONS(733),
    [anon_sym_int8] = ACTIONS(733),
    [anon_sym_int16] = ACTIONS(733),
    [anon_sym_int24] = ACTIONS(733),
    [anon_sym_int32] = ACTIONS(733),
    [anon_sym_int40] = ACTIONS(733),
    [anon_sym_int48] = ACTIONS(733),
    [anon_sym_int56] = ACTIONS(733),
    [anon_sym_int64] = ACTIONS(733),
    [anon_sym_int72] = ACTIONS(733),
    [anon_sym_int80] = ACTIONS(733),
    [anon_sym_int88] = ACTIONS(733),
    [anon_sym_int96] = ACTIONS(733),
    [anon_sym_int104] = ACTIONS(733),
    [anon_sym_int112] = ACTIONS(733),
    [anon_sym_int120] = ACTIONS(733),
    [anon_sym_int128] = ACTIONS(733),
    [anon_sym_int136] = ACTIONS(733),
    [anon_sym_int144] = ACTIONS(733),
    [anon_sym_int152] = ACTIONS(733),
    [anon_sym_int160] = ACTIONS(733),
    [anon_sym_int168] = ACTIONS(733),
    [anon_sym_int176] = ACTIONS(733),
    [anon_sym_int184] = ACTIONS(733),
    [anon_sym_int192] = ACTIONS(733),
    [anon_sym_int200] = ACTIONS(733),
    [anon_sym_int208] = ACTIONS(733),
    [anon_sym_int216] = ACTIONS(733),
    [anon_sym_int224] = ACTIONS(733),
    [anon_sym_int232] = ACTIONS(733),
    [anon_sym_int240] = ACTIONS(733),
    [anon_sym_int248] = ACTIONS(733),
    [anon_sym_int256] = ACTIONS(733),
    [anon_sym_uint] = ACTIONS(733),
    [anon_sym_uint8] = ACTIONS(733),
    [anon_sym_uint16] = ACTIONS(733),
    [anon_sym_uint24] = ACTIONS(733),
    [anon_sym_uint32] = ACTIONS(733),
    [anon_sym_uint40] = ACTIONS(733),
    [anon_sym_uint48] = ACTIONS(733),
    [anon_sym_uint56] = ACTIONS(733),
    [anon_sym_uint64] = ACTIONS(733),
    [anon_sym_uint72] = ACTIONS(733),
    [anon_sym_uint80] = ACTIONS(733),
    [anon_sym_uint88] = ACTIONS(733),
    [anon_sym_uint96] = ACTIONS(733),
    [anon_sym_uint104] = ACTIONS(733),
    [anon_sym_uint112] = ACTIONS(733),
    [anon_sym_uint120] = ACTIONS(733),
    [anon_sym_uint128] = ACTIONS(733),
    [anon_sym_uint136] = ACTIONS(733),
    [anon_sym_uint144] = ACTIONS(733),
    [anon_sym_uint152] = ACTIONS(733),
    [anon_sym_uint160] = ACTIONS(733),
    [anon_sym_uint168] = ACTIONS(733),
    [anon_sym_uint176] = ACTIONS(733),
    [anon_sym_uint184] = ACTIONS(733),
    [anon_sym_uint192] = ACTIONS(733),
    [anon_sym_uint200] = ACTIONS(733),
    [anon_sym_uint208] = ACTIONS(733),
    [anon_sym_uint216] = ACTIONS(733),
    [anon_sym_uint224] = ACTIONS(733),
    [anon_sym_uint232] = ACTIONS(733),
    [anon_sym_uint240] = ACTIONS(733),
    [anon_sym_uint248] = ACTIONS(733),
    [anon_sym_uint256] = ACTIONS(733),
    [anon_sym_bytes] = ACTIONS(733),
    [anon_sym_bytes1] = ACTIONS(733),
    [anon_sym_bytes2] = ACTIONS(733),
    [anon_sym_bytes3] = ACTIONS(733),
    [anon_sym_bytes4] = ACTIONS(733),
    [anon_sym_bytes5] = ACTIONS(733),
    [anon_sym_bytes6] = ACTIONS(733),
    [anon_sym_bytes7] = ACTIONS(733),
    [anon_sym_bytes8] = ACTIONS(733),
    [anon_sym_bytes9] = ACTIONS(733),
    [anon_sym_bytes10] = ACTIONS(733),
    [anon_sym_bytes11] = ACTIONS(733),
    [anon_sym_bytes12] = ACTIONS(733),
    [anon_sym_bytes13] = ACTIONS(733),
    [anon_sym_bytes14] = ACTIONS(733),
    [anon_sym_bytes15] = ACTIONS(733),
    [anon_sym_bytes16] = ACTIONS(733),
    [anon_sym_bytes17] = ACTIONS(733),
    [anon_sym_bytes18] = ACTIONS(733),
    [anon_sym_bytes19] = ACTIONS(733),
    [anon_sym_bytes20] = ACTIONS(733),
    [anon_sym_bytes21] = ACTIONS(733),
    [anon_sym_bytes22] = ACTIONS(733),
    [anon_sym_bytes23] = ACTIONS(733),
    [anon_sym_bytes24] = ACTIONS(733),
    [anon_sym_bytes25] = ACTIONS(733),
    [anon_sym_bytes26] = ACTIONS(733),
    [anon_sym_bytes27] = ACTIONS(733),
    [anon_sym_bytes28] = ACTIONS(733),
    [anon_sym_bytes29] = ACTIONS(733),
    [anon_sym_bytes30] = ACTIONS(733),
    [anon_sym_bytes31] = ACTIONS(733),
    [anon_sym_bytes32] = ACTIONS(733),
    [anon_sym_fixed] = ACTIONS(733),
    [aux_sym__fixed_token1] = ACTIONS(733),
    [anon_sym_ufixed] = ACTIONS(733),
    [aux_sym__ufixed_token1] = ACTIONS(733),
    [sym_comment] = ACTIONS(3),
  },
  [240] = {
    [sym_identifier] = ACTIONS(817),
    [anon_sym_RBRACE] = ACTIONS(815),
    [anon_sym_type] = ACTIONS(817),
    [anon_sym_error] = ACTIONS(817),
    [anon_sym_struct] = ACTIONS(817),
    [anon_sym_enum] = ACTIONS(817),
    [anon_sym_event] = ACTIONS(817),
    [anon_sym_using] = ACTIONS(817),
    [anon_sym_function] = ACTIONS(817),
    [anon_sym_byte] = ACTIONS(817),
    [anon_sym_address] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_modifier] = ACTIONS(817),
    [anon_sym_constructor] = ACTIONS(817),
    [anon_sym_fallback] = ACTIONS(817),
    [anon_sym_receive] = ACTIONS(817),
    [anon_sym_mapping] = ACTIONS(817),
    [anon_sym_bool] = ACTIONS(817),
    [anon_sym_string] = ACTIONS(817),
    [anon_sym_int] = ACTIONS(817),
    [anon_sym_int8] = ACTIONS(817),
    [anon_sym_int16] = ACTIONS(817),
    [anon_sym_int24] = ACTIONS(817),
    [anon_sym_int32] = ACTIONS(817),
    [anon_sym_int40] = ACTIONS(817),
    [anon_sym_int48] = ACTIONS(817),
    [anon_sym_int56] = ACTIONS(817),
    [anon_sym_int64] = ACTIONS(817),
    [anon_sym_int72] = ACTIONS(817),
    [anon_sym_int80] = ACTIONS(817),
    [anon_sym_int88] = ACTIONS(817),
    [anon_sym_int96] = ACTIONS(817),
    [anon_sym_int104] = ACTIONS(817),
    [anon_sym_int112] = ACTIONS(817),
    [anon_sym_int120] = ACTIONS(817),
    [anon_sym_int128] = ACTIONS(817),
    [anon_sym_int136] = ACTIONS(817),
    [anon_sym_int144] = ACTIONS(817),
    [anon_sym_int152] = ACTIONS(817),
    [anon_sym_int160] = ACTIONS(817),
    [anon_sym_int168] = ACTIONS(817),
    [anon_sym_int176] = ACTIONS(817),
    [anon_sym_int184] = ACTIONS(817),
    [anon_sym_int192] = ACTIONS(817),
    [anon_sym_int200] = ACTIONS(817),
    [anon_sym_int208] = ACTIONS(817),
    [anon_sym_int216] = ACTIONS(817),
    [anon_sym_int224] = ACTIONS(817),
    [anon_sym_int232] = ACTIONS(817),
    [anon_sym_int240] = ACTIONS(817),
    [anon_sym_int248] = ACTIONS(817),
    [anon_sym_int256] = ACTIONS(817),
    [anon_sym_uint] = ACTIONS(817),
    [anon_sym_uint8] = ACTIONS(817),
    [anon_sym_uint16] = ACTIONS(817),
    [anon_sym_uint24] = ACTIONS(817),
    [anon_sym_uint32] = ACTIONS(817),
    [anon_sym_uint40] = ACTIONS(817),
    [anon_sym_uint48] = ACTIONS(817),
    [anon_sym_uint56] = ACTIONS(817),
    [anon_sym_uint64] = ACTIONS(817),
    [anon_sym_uint72] = ACTIONS(817),
    [anon_sym_uint80] = ACTIONS(817),
    [anon_sym_uint88] = ACTIONS(817),
    [anon_sym_uint96] = ACTIONS(817),
    [anon_sym_uint104] = ACTIONS(817),
    [anon_sym_uint112] = ACTIONS(817),
    [anon_sym_uint120] = ACTIONS(817),
    [anon_sym_uint128] = ACTIONS(817),
    [anon_sym_uint136] = ACTIONS(817),
    [anon_sym_uint144] = ACTIONS(817),
    [anon_sym_uint152] = ACTIONS(817),
    [anon_sym_uint160] = ACTIONS(817),
    [anon_sym_uint168] = ACTIONS(817),
    [anon_sym_uint176] = ACTIONS(817),
    [anon_sym_uint184] = ACTIONS(817),
    [anon_sym_uint192] = ACTIONS(817),
    [anon_sym_uint200] = ACTIONS(817),
    [anon_sym_uint208] = ACTIONS(817),
    [anon_sym_uint216] = ACTIONS(817),
    [anon_sym_uint224] = ACTIONS(817),
    [anon_sym_uint232] = ACTIONS(817),
    [anon_sym_uint240] = ACTIONS(817),
    [anon_sym_uint248] = ACTIONS(817),
    [anon_sym_uint256] = ACTIONS(817),
    [anon_sym_bytes] = ACTIONS(817),
    [anon_sym_bytes1] = ACTIONS(817),
    [anon_sym_bytes2] = ACTIONS(817),
    [anon_sym_bytes3] = ACTIONS(817),
    [anon_sym_bytes4] = ACTIONS(817),
    [anon_sym_bytes5] = ACTIONS(817),
    [anon_sym_bytes6] = ACTIONS(817),
    [anon_sym_bytes7] = ACTIONS(817),
    [anon_sym_bytes8] = ACTIONS(817),
    [anon_sym_bytes9] = ACTIONS(817),
    [anon_sym_bytes10] = ACTIONS(817),
    [anon_sym_bytes11] = ACTIONS(817),
    [anon_sym_bytes12] = ACTIONS(817),
    [anon_sym_bytes13] = ACTIONS(817),
    [anon_sym_bytes14] = ACTIONS(817),
    [anon_sym_bytes15] = ACTIONS(817),
    [anon_sym_bytes16] = ACTIONS(817),
    [anon_sym_bytes17] = ACTIONS(817),
    [anon_sym_bytes18] = ACTIONS(817),
    [anon_sym_bytes19] = ACTIONS(817),
    [anon_sym_bytes20] = ACTIONS(817),
    [anon_sym_bytes21] = ACTIONS(817),
    [anon_sym_bytes22] = ACTIONS(817),
    [anon_sym_bytes23] = ACTIONS(817),
    [anon_sym_bytes24] = ACTIONS(817),
    [anon_sym_bytes25] = ACTIONS(817),
    [anon_sym_bytes26] = ACTIONS(817),
    [anon_sym_bytes27] = ACTIONS(817),
    [anon_sym_bytes28] = ACTIONS(817),
    [anon_sym_bytes29] = ACTIONS(817),
    [anon_sym_bytes30] = ACTIONS(817),
    [anon_sym_bytes31] = ACTIONS(817),
    [anon_sym_bytes32] = ACTIONS(817),
    [anon_sym_fixed] = ACTIONS(817),
    [aux_sym__fixed_token1] = ACTIONS(817),
    [anon_sym_ufixed] = ACTIONS(817),
    [aux_sym__ufixed_token1] = ACTIONS(817),
    [sym_comment] = ACTIONS(3),
  },
  [241] = {
    [sym_identifier] = ACTIONS(813),
    [anon_sym_RBRACE] = ACTIONS(811),
    [anon_sym_type] = ACTIONS(813),
    [anon_sym_error] = ACTIONS(813),
    [anon_sym_struct] = ACTIONS(813),
    [anon_sym_enum] = ACTIONS(813),
    [anon_sym_event] = ACTIONS(813),
    [anon_sym_using] = ACTIONS(813),
    [anon_sym_function] = ACTIONS(813),
    [anon_sym_byte] = ACTIONS(813),
    [anon_sym_address] = ACTIONS(813),
    [anon_sym_var] = ACTIONS(813),
    [anon_sym_modifier] = ACTIONS(813),
    [anon_sym_constructor] = ACTIONS(813),
    [anon_sym_fallback] = ACTIONS(813),
    [anon_sym_receive] = ACTIONS(813),
    [anon_sym_mapping] = ACTIONS(813),
    [anon_sym_bool] = ACTIONS(813),
    [anon_sym_string] = ACTIONS(813),
    [anon_sym_int] = ACTIONS(813),
    [anon_sym_int8] = ACTIONS(813),
    [anon_sym_int16] = ACTIONS(813),
    [anon_sym_int24] = ACTIONS(813),
    [anon_sym_int32] = ACTIONS(813),
    [anon_sym_int40] = ACTIONS(813),
    [anon_sym_int48] = ACTIONS(813),
    [anon_sym_int56] = ACTIONS(813),
    [anon_sym_int64] = ACTIONS(813),
    [anon_sym_int72] = ACTIONS(813),
    [anon_sym_int80] = ACTIONS(813),
    [anon_sym_int88] = ACTIONS(813),
    [anon_sym_int96] = ACTIONS(813),
    [anon_sym_int104] = ACTIONS(813),
    [anon_sym_int112] = ACTIONS(813),
    [anon_sym_int120] = ACTIONS(813),
    [anon_sym_int128] = ACTIONS(813),
    [anon_sym_int136] = ACTIONS(813),
    [anon_sym_int144] = ACTIONS(813),
    [anon_sym_int152] = ACTIONS(813),
    [anon_sym_int160] = ACTIONS(813),
    [anon_sym_int168] = ACTIONS(813),
    [anon_sym_int176] = ACTIONS(813),
    [anon_sym_int184] = ACTIONS(813),
    [anon_sym_int192] = ACTIONS(813),
    [anon_sym_int200] = ACTIONS(813),
    [anon_sym_int208] = ACTIONS(813),
    [anon_sym_int216] = ACTIONS(813),
    [anon_sym_int224] = ACTIONS(813),
    [anon_sym_int232] = ACTIONS(813),
    [anon_sym_int240] = ACTIONS(813),
    [anon_sym_int248] = ACTIONS(813),
    [anon_sym_int256] = ACTIONS(813),
    [anon_sym_uint] = ACTIONS(813),
    [anon_sym_uint8] = ACTIONS(813),
    [anon_sym_uint16] = ACTIONS(813),
    [anon_sym_uint24] = ACTIONS(813),
    [anon_sym_uint32] = ACTIONS(813),
    [anon_sym_uint40] = ACTIONS(813),
    [anon_sym_uint48] = ACTIONS(813),
    [anon_sym_uint56] = ACTIONS(813),
    [anon_sym_uint64] = ACTIONS(813),
    [anon_sym_uint72] = ACTIONS(813),
    [anon_sym_uint80] = ACTIONS(813),
    [anon_sym_uint88] = ACTIONS(813),
    [anon_sym_uint96] = ACTIONS(813),
    [anon_sym_uint104] = ACTIONS(813),
    [anon_sym_uint112] = ACTIONS(813),
    [anon_sym_uint120] = ACTIONS(813),
    [anon_sym_uint128] = ACTIONS(813),
    [anon_sym_uint136] = ACTIONS(813),
    [anon_sym_uint144] = ACTIONS(813),
    [anon_sym_uint152] = ACTIONS(813),
    [anon_sym_uint160] = ACTIONS(813),
    [anon_sym_uint168] = ACTIONS(813),
    [anon_sym_uint176] = ACTIONS(813),
    [anon_sym_uint184] = ACTIONS(813),
    [anon_sym_uint192] = ACTIONS(813),
    [anon_sym_uint200] = ACTIONS(813),
    [anon_sym_uint208] = ACTIONS(813),
    [anon_sym_uint216] = ACTIONS(813),
    [anon_sym_uint224] = ACTIONS(813),
    [anon_sym_uint232] = ACTIONS(813),
    [anon_sym_uint240] = ACTIONS(813),
    [anon_sym_uint248] = ACTIONS(813),
    [anon_sym_uint256] = ACTIONS(813),
    [anon_sym_bytes] = ACTIONS(813),
    [anon_sym_bytes1] = ACTIONS(813),
    [anon_sym_bytes2] = ACTIONS(813),
    [anon_sym_bytes3] = ACTIONS(813),
    [anon_sym_bytes4] = ACTIONS(813),
    [anon_sym_bytes5] = ACTIONS(813),
    [anon_sym_bytes6] = ACTIONS(813),
    [anon_sym_bytes7] = ACTIONS(813),
    [anon_sym_bytes8] = ACTIONS(813),
    [anon_sym_bytes9] = ACTIONS(813),
    [anon_sym_bytes10] = ACTIONS(813),
    [anon_sym_bytes11] = ACTIONS(813),
    [anon_sym_bytes12] = ACTIONS(813),
    [anon_sym_bytes13] = ACTIONS(813),
    [anon_sym_bytes14] = ACTIONS(813),
    [anon_sym_bytes15] = ACTIONS(813),
    [anon_sym_bytes16] = ACTIONS(813),
    [anon_sym_bytes17] = ACTIONS(813),
    [anon_sym_bytes18] = ACTIONS(813),
    [anon_sym_bytes19] = ACTIONS(813),
    [anon_sym_bytes20] = ACTIONS(813),
    [anon_sym_bytes21] = ACTIONS(813),
    [anon_sym_bytes22] = ACTIONS(813),
    [anon_sym_bytes23] = ACTIONS(813),
    [anon_sym_bytes24] = ACTIONS(813),
    [anon_sym_bytes25] = ACTIONS(813),
    [anon_sym_bytes26] = ACTIONS(813),
    [anon_sym_bytes27] = ACTIONS(813),
    [anon_sym_bytes28] = ACTIONS(813),
    [anon_sym_bytes29] = ACTIONS(813),
    [anon_sym_bytes30] = ACTIONS(813),
    [anon_sym_bytes31] = ACTIONS(813),
    [anon_sym_bytes32] = ACTIONS(813),
    [anon_sym_fixed] = ACTIONS(813),
    [aux_sym__fixed_token1] = ACTIONS(813),
    [anon_sym_ufixed] = ACTIONS(813),
    [aux_sym__ufixed_token1] = ACTIONS(813),
    [sym_comment] = ACTIONS(3),
  },
  [242] = {
    [sym_identifier] = ACTIONS(877),
    [anon_sym_RBRACE] = ACTIONS(879),
    [anon_sym_type] = ACTIONS(877),
    [anon_sym_error] = ACTIONS(877),
    [anon_sym_struct] = ACTIONS(877),
    [anon_sym_enum] = ACTIONS(877),
    [anon_sym_event] = ACTIONS(877),
    [anon_sym_using] = ACTIONS(877),
    [anon_sym_function] = ACTIONS(877),
    [anon_sym_byte] = ACTIONS(877),
    [anon_sym_address] = ACTIONS(877),
    [anon_sym_var] = ACTIONS(877),
    [anon_sym_modifier] = ACTIONS(877),
    [anon_sym_constructor] = ACTIONS(877),
    [anon_sym_fallback] = ACTIONS(877),
    [anon_sym_receive] = ACTIONS(877),
    [anon_sym_mapping] = ACTIONS(877),
    [anon_sym_bool] = ACTIONS(877),
    [anon_sym_string] = ACTIONS(877),
    [anon_sym_int] = ACTIONS(877),
    [anon_sym_int8] = ACTIONS(877),
    [anon_sym_int16] = ACTIONS(877),
    [anon_sym_int24] = ACTIONS(877),
    [anon_sym_int32] = ACTIONS(877),
    [anon_sym_int40] = ACTIONS(877),
    [anon_sym_int48] = ACTIONS(877),
    [anon_sym_int56] = ACTIONS(877),
    [anon_sym_int64] = ACTIONS(877),
    [anon_sym_int72] = ACTIONS(877),
    [anon_sym_int80] = ACTIONS(877),
    [anon_sym_int88] = ACTIONS(877),
    [anon_sym_int96] = ACTIONS(877),
    [anon_sym_int104] = ACTIONS(877),
    [anon_sym_int112] = ACTIONS(877),
    [anon_sym_int120] = ACTIONS(877),
    [anon_sym_int128] = ACTIONS(877),
    [anon_sym_int136] = ACTIONS(877),
    [anon_sym_int144] = ACTIONS(877),
    [anon_sym_int152] = ACTIONS(877),
    [anon_sym_int160] = ACTIONS(877),
    [anon_sym_int168] = ACTIONS(877),
    [anon_sym_int176] = ACTIONS(877),
    [anon_sym_int184] = ACTIONS(877),
    [anon_sym_int192] = ACTIONS(877),
    [anon_sym_int200] = ACTIONS(877),
    [anon_sym_int208] = ACTIONS(877),
    [anon_sym_int216] = ACTIONS(877),
    [anon_sym_int224] = ACTIONS(877),
    [anon_sym_int232] = ACTIONS(877),
    [anon_sym_int240] = ACTIONS(877),
    [anon_sym_int248] = ACTIONS(877),
    [anon_sym_int256] = ACTIONS(877),
    [anon_sym_uint] = ACTIONS(877),
    [anon_sym_uint8] = ACTIONS(877),
    [anon_sym_uint16] = ACTIONS(877),
    [anon_sym_uint24] = ACTIONS(877),
    [anon_sym_uint32] = ACTIONS(877),
    [anon_sym_uint40] = ACTIONS(877),
    [anon_sym_uint48] = ACTIONS(877),
    [anon_sym_uint56] = ACTIONS(877),
    [anon_sym_uint64] = ACTIONS(877),
    [anon_sym_uint72] = ACTIONS(877),
    [anon_sym_uint80] = ACTIONS(877),
    [anon_sym_uint88] = ACTIONS(877),
    [anon_sym_uint96] = ACTIONS(877),
    [anon_sym_uint104] = ACTIONS(877),
    [anon_sym_uint112] = ACTIONS(877),
    [anon_sym_uint120] = ACTIONS(877),
    [anon_sym_uint128] = ACTIONS(877),
    [anon_sym_uint136] = ACTIONS(877),
    [anon_sym_uint144] = ACTIONS(877),
    [anon_sym_uint152] = ACTIONS(877),
    [anon_sym_uint160] = ACTIONS(877),
    [anon_sym_uint168] = ACTIONS(877),
    [anon_sym_uint176] = ACTIONS(877),
    [anon_sym_uint184] = ACTIONS(877),
    [anon_sym_uint192] = ACTIONS(877),
    [anon_sym_uint200] = ACTIONS(877),
    [anon_sym_uint208] = ACTIONS(877),
    [anon_sym_uint216] = ACTIONS(877),
    [anon_sym_uint224] = ACTIONS(877),
    [anon_sym_uint232] = ACTIONS(877),
    [anon_sym_uint240] = ACTIONS(877),
    [anon_sym_uint248] = ACTIONS(877),
    [anon_sym_uint256] = ACTIONS(877),
    [anon_sym_bytes] = ACTIONS(877),
    [anon_sym_bytes1] = ACTIONS(877),
    [anon_sym_bytes2] = ACTIONS(877),
    [anon_sym_bytes3] = ACTIONS(877),
    [anon_sym_bytes4] = ACTIONS(877),
    [anon_sym_bytes5] = ACTIONS(877),
    [anon_sym_bytes6] = ACTIONS(877),
    [anon_sym_bytes7] = ACTIONS(877),
    [anon_sym_bytes8] = ACTIONS(877),
    [anon_sym_bytes9] = ACTIONS(877),
    [anon_sym_bytes10] = ACTIONS(877),
    [anon_sym_bytes11] = ACTIONS(877),
    [anon_sym_bytes12] = ACTIONS(877),
    [anon_sym_bytes13] = ACTIONS(877),
    [anon_sym_bytes14] = ACTIONS(877),
    [anon_sym_bytes15] = ACTIONS(877),
    [anon_sym_bytes16] = ACTIONS(877),
    [anon_sym_bytes17] = ACTIONS(877),
    [anon_sym_bytes18] = ACTIONS(877),
    [anon_sym_bytes19] = ACTIONS(877),
    [anon_sym_bytes20] = ACTIONS(877),
    [anon_sym_bytes21] = ACTIONS(877),
    [anon_sym_bytes22] = ACTIONS(877),
    [anon_sym_bytes23] = ACTIONS(877),
    [anon_sym_bytes24] = ACTIONS(877),
    [anon_sym_bytes25] = ACTIONS(877),
    [anon_sym_bytes26] = ACTIONS(877),
    [anon_sym_bytes27] = ACTIONS(877),
    [anon_sym_bytes28] = ACTIONS(877),
    [anon_sym_bytes29] = ACTIONS(877),
    [anon_sym_bytes30] = ACTIONS(877),
    [anon_sym_bytes31] = ACTIONS(877),
    [anon_sym_bytes32] = ACTIONS(877),
    [anon_sym_fixed] = ACTIONS(877),
    [aux_sym__fixed_token1] = ACTIONS(877),
    [anon_sym_ufixed] = ACTIONS(877),
    [aux_sym__ufixed_token1] = ACTIONS(877),
    [sym_comment] = ACTIONS(3),
  },
  [243] = {
    [sym_identifier] = ACTIONS(881),
    [anon_sym_RBRACE] = ACTIONS(883),
    [anon_sym_type] = ACTIONS(881),
    [anon_sym_error] = ACTIONS(881),
    [anon_sym_struct] = ACTIONS(881),
    [anon_sym_enum] = ACTIONS(881),
    [anon_sym_event] = ACTIONS(881),
    [anon_sym_using] = ACTIONS(881),
    [anon_sym_function] = ACTIONS(881),
    [anon_sym_byte] = ACTIONS(881),
    [anon_sym_address] = ACTIONS(881),
    [anon_sym_var] = ACTIONS(881),
    [anon_sym_modifier] = ACTIONS(881),
    [anon_sym_constructor] = ACTIONS(881),
    [anon_sym_fallback] = ACTIONS(881),
    [anon_sym_receive] = ACTIONS(881),
    [anon_sym_mapping] = ACTIONS(881),
    [anon_sym_bool] = ACTIONS(881),
    [anon_sym_string] = ACTIONS(881),
    [anon_sym_int] = ACTIONS(881),
    [anon_sym_int8] = ACTIONS(881),
    [anon_sym_int16] = ACTIONS(881),
    [anon_sym_int24] = ACTIONS(881),
    [anon_sym_int32] = ACTIONS(881),
    [anon_sym_int40] = ACTIONS(881),
    [anon_sym_int48] = ACTIONS(881),
    [anon_sym_int56] = ACTIONS(881),
    [anon_sym_int64] = ACTIONS(881),
    [anon_sym_int72] = ACTIONS(881),
    [anon_sym_int80] = ACTIONS(881),
    [anon_sym_int88] = ACTIONS(881),
    [anon_sym_int96] = ACTIONS(881),
    [anon_sym_int104] = ACTIONS(881),
    [anon_sym_int112] = ACTIONS(881),
    [anon_sym_int120] = ACTIONS(881),
    [anon_sym_int128] = ACTIONS(881),
    [anon_sym_int136] = ACTIONS(881),
    [anon_sym_int144] = ACTIONS(881),
    [anon_sym_int152] = ACTIONS(881),
    [anon_sym_int160] = ACTIONS(881),
    [anon_sym_int168] = ACTIONS(881),
    [anon_sym_int176] = ACTIONS(881),
    [anon_sym_int184] = ACTIONS(881),
    [anon_sym_int192] = ACTIONS(881),
    [anon_sym_int200] = ACTIONS(881),
    [anon_sym_int208] = ACTIONS(881),
    [anon_sym_int216] = ACTIONS(881),
    [anon_sym_int224] = ACTIONS(881),
    [anon_sym_int232] = ACTIONS(881),
    [anon_sym_int240] = ACTIONS(881),
    [anon_sym_int248] = ACTIONS(881),
    [anon_sym_int256] = ACTIONS(881),
    [anon_sym_uint] = ACTIONS(881),
    [anon_sym_uint8] = ACTIONS(881),
    [anon_sym_uint16] = ACTIONS(881),
    [anon_sym_uint24] = ACTIONS(881),
    [anon_sym_uint32] = ACTIONS(881),
    [anon_sym_uint40] = ACTIONS(881),
    [anon_sym_uint48] = ACTIONS(881),
    [anon_sym_uint56] = ACTIONS(881),
    [anon_sym_uint64] = ACTIONS(881),
    [anon_sym_uint72] = ACTIONS(881),
    [anon_sym_uint80] = ACTIONS(881),
    [anon_sym_uint88] = ACTIONS(881),
    [anon_sym_uint96] = ACTIONS(881),
    [anon_sym_uint104] = ACTIONS(881),
    [anon_sym_uint112] = ACTIONS(881),
    [anon_sym_uint120] = ACTIONS(881),
    [anon_sym_uint128] = ACTIONS(881),
    [anon_sym_uint136] = ACTIONS(881),
    [anon_sym_uint144] = ACTIONS(881),
    [anon_sym_uint152] = ACTIONS(881),
    [anon_sym_uint160] = ACTIONS(881),
    [anon_sym_uint168] = ACTIONS(881),
    [anon_sym_uint176] = ACTIONS(881),
    [anon_sym_uint184] = ACTIONS(881),
    [anon_sym_uint192] = ACTIONS(881),
    [anon_sym_uint200] = ACTIONS(881),
    [anon_sym_uint208] = ACTIONS(881),
    [anon_sym_uint216] = ACTIONS(881),
    [anon_sym_uint224] = ACTIONS(881),
    [anon_sym_uint232] = ACTIONS(881),
    [anon_sym_uint240] = ACTIONS(881),
    [anon_sym_uint248] = ACTIONS(881),
    [anon_sym_uint256] = ACTIONS(881),
    [anon_sym_bytes] = ACTIONS(881),
    [anon_sym_bytes1] = ACTIONS(881),
    [anon_sym_bytes2] = ACTIONS(881),
    [anon_sym_bytes3] = ACTIONS(881),
    [anon_sym_bytes4] = ACTIONS(881),
    [anon_sym_bytes5] = ACTIONS(881),
    [anon_sym_bytes6] = ACTIONS(881),
    [anon_sym_bytes7] = ACTIONS(881),
    [anon_sym_bytes8] = ACTIONS(881),
    [anon_sym_bytes9] = ACTIONS(881),
    [anon_sym_bytes10] = ACTIONS(881),
    [anon_sym_bytes11] = ACTIONS(881),
    [anon_sym_bytes12] = ACTIONS(881),
    [anon_sym_bytes13] = ACTIONS(881),
    [anon_sym_bytes14] = ACTIONS(881),
    [anon_sym_bytes15] = ACTIONS(881),
    [anon_sym_bytes16] = ACTIONS(881),
    [anon_sym_bytes17] = ACTIONS(881),
    [anon_sym_bytes18] = ACTIONS(881),
    [anon_sym_bytes19] = ACTIONS(881),
    [anon_sym_bytes20] = ACTIONS(881),
    [anon_sym_bytes21] = ACTIONS(881),
    [anon_sym_bytes22] = ACTIONS(881),
    [anon_sym_bytes23] = ACTIONS(881),
    [anon_sym_bytes24] = ACTIONS(881),
    [anon_sym_bytes25] = ACTIONS(881),
    [anon_sym_bytes26] = ACTIONS(881),
    [anon_sym_bytes27] = ACTIONS(881),
    [anon_sym_bytes28] = ACTIONS(881),
    [anon_sym_bytes29] = ACTIONS(881),
    [anon_sym_bytes30] = ACTIONS(881),
    [anon_sym_bytes31] = ACTIONS(881),
    [anon_sym_bytes32] = ACTIONS(881),
    [anon_sym_fixed] = ACTIONS(881),
    [aux_sym__fixed_token1] = ACTIONS(881),
    [anon_sym_ufixed] = ACTIONS(881),
    [aux_sym__ufixed_token1] = ACTIONS(881),
    [sym_comment] = ACTIONS(3),
  },
  [244] = {
    [sym_identifier] = ACTIONS(817),
    [anon_sym_RBRACE] = ACTIONS(815),
    [anon_sym_type] = ACTIONS(817),
    [anon_sym_error] = ACTIONS(817),
    [anon_sym_struct] = ACTIONS(817),
    [anon_sym_enum] = ACTIONS(817),
    [anon_sym_event] = ACTIONS(817),
    [anon_sym_using] = ACTIONS(817),
    [anon_sym_function] = ACTIONS(817),
    [anon_sym_byte] = ACTIONS(817),
    [anon_sym_address] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_modifier] = ACTIONS(817),
    [anon_sym_constructor] = ACTIONS(817),
    [anon_sym_fallback] = ACTIONS(817),
    [anon_sym_receive] = ACTIONS(817),
    [anon_sym_mapping] = ACTIONS(817),
    [anon_sym_bool] = ACTIONS(817),
    [anon_sym_string] = ACTIONS(817),
    [anon_sym_int] = ACTIONS(817),
    [anon_sym_int8] = ACTIONS(817),
    [anon_sym_int16] = ACTIONS(817),
    [anon_sym_int24] = ACTIONS(817),
    [anon_sym_int32] = ACTIONS(817),
    [anon_sym_int40] = ACTIONS(817),
    [anon_sym_int48] = ACTIONS(817),
    [anon_sym_int56] = ACTIONS(817),
    [anon_sym_int64] = ACTIONS(817),
    [anon_sym_int72] = ACTIONS(817),
    [anon_sym_int80] = ACTIONS(817),
    [anon_sym_int88] = ACTIONS(817),
    [anon_sym_int96] = ACTIONS(817),
    [anon_sym_int104] = ACTIONS(817),
    [anon_sym_int112] = ACTIONS(817),
    [anon_sym_int120] = ACTIONS(817),
    [anon_sym_int128] = ACTIONS(817),
    [anon_sym_int136] = ACTIONS(817),
    [anon_sym_int144] = ACTIONS(817),
    [anon_sym_int152] = ACTIONS(817),
    [anon_sym_int160] = ACTIONS(817),
    [anon_sym_int168] = ACTIONS(817),
    [anon_sym_int176] = ACTIONS(817),
    [anon_sym_int184] = ACTIONS(817),
    [anon_sym_int192] = ACTIONS(817),
    [anon_sym_int200] = ACTIONS(817),
    [anon_sym_int208] = ACTIONS(817),
    [anon_sym_int216] = ACTIONS(817),
    [anon_sym_int224] = ACTIONS(817),
    [anon_sym_int232] = ACTIONS(817),
    [anon_sym_int240] = ACTIONS(817),
    [anon_sym_int248] = ACTIONS(817),
    [anon_sym_int256] = ACTIONS(817),
    [anon_sym_uint] = ACTIONS(817),
    [anon_sym_uint8] = ACTIONS(817),
    [anon_sym_uint16] = ACTIONS(817),
    [anon_sym_uint24] = ACTIONS(817),
    [anon_sym_uint32] = ACTIONS(817),
    [anon_sym_uint40] = ACTIONS(817),
    [anon_sym_uint48] = ACTIONS(817),
    [anon_sym_uint56] = ACTIONS(817),
    [anon_sym_uint64] = ACTIONS(817),
    [anon_sym_uint72] = ACTIONS(817),
    [anon_sym_uint80] = ACTIONS(817),
    [anon_sym_uint88] = ACTIONS(817),
    [anon_sym_uint96] = ACTIONS(817),
    [anon_sym_uint104] = ACTIONS(817),
    [anon_sym_uint112] = ACTIONS(817),
    [anon_sym_uint120] = ACTIONS(817),
    [anon_sym_uint128] = ACTIONS(817),
    [anon_sym_uint136] = ACTIONS(817),
    [anon_sym_uint144] = ACTIONS(817),
    [anon_sym_uint152] = ACTIONS(817),
    [anon_sym_uint160] = ACTIONS(817),
    [anon_sym_uint168] = ACTIONS(817),
    [anon_sym_uint176] = ACTIONS(817),
    [anon_sym_uint184] = ACTIONS(817),
    [anon_sym_uint192] = ACTIONS(817),
    [anon_sym_uint200] = ACTIONS(817),
    [anon_sym_uint208] = ACTIONS(817),
    [anon_sym_uint216] = ACTIONS(817),
    [anon_sym_uint224] = ACTIONS(817),
    [anon_sym_uint232] = ACTIONS(817),
    [anon_sym_uint240] = ACTIONS(817),
    [anon_sym_uint248] = ACTIONS(817),
    [anon_sym_uint256] = ACTIONS(817),
    [anon_sym_bytes] = ACTIONS(817),
    [anon_sym_bytes1] = ACTIONS(817),
    [anon_sym_bytes2] = ACTIONS(817),
    [anon_sym_bytes3] = ACTIONS(817),
    [anon_sym_bytes4] = ACTIONS(817),
    [anon_sym_bytes5] = ACTIONS(817),
    [anon_sym_bytes6] = ACTIONS(817),
    [anon_sym_bytes7] = ACTIONS(817),
    [anon_sym_bytes8] = ACTIONS(817),
    [anon_sym_bytes9] = ACTIONS(817),
    [anon_sym_bytes10] = ACTIONS(817),
    [anon_sym_bytes11] = ACTIONS(817),
    [anon_sym_bytes12] = ACTIONS(817),
    [anon_sym_bytes13] = ACTIONS(817),
    [anon_sym_bytes14] = ACTIONS(817),
    [anon_sym_bytes15] = ACTIONS(817),
    [anon_sym_bytes16] = ACTIONS(817),
    [anon_sym_bytes17] = ACTIONS(817),
    [anon_sym_bytes18] = ACTIONS(817),
    [anon_sym_bytes19] = ACTIONS(817),
    [anon_sym_bytes20] = ACTIONS(817),
    [anon_sym_bytes21] = ACTIONS(817),
    [anon_sym_bytes22] = ACTIONS(817),
    [anon_sym_bytes23] = ACTIONS(817),
    [anon_sym_bytes24] = ACTIONS(817),
    [anon_sym_bytes25] = ACTIONS(817),
    [anon_sym_bytes26] = ACTIONS(817),
    [anon_sym_bytes27] = ACTIONS(817),
    [anon_sym_bytes28] = ACTIONS(817),
    [anon_sym_bytes29] = ACTIONS(817),
    [anon_sym_bytes30] = ACTIONS(817),
    [anon_sym_bytes31] = ACTIONS(817),
    [anon_sym_bytes32] = ACTIONS(817),
    [anon_sym_fixed] = ACTIONS(817),
    [aux_sym__fixed_token1] = ACTIONS(817),
    [anon_sym_ufixed] = ACTIONS(817),
    [aux_sym__ufixed_token1] = ACTIONS(817),
    [sym_comment] = ACTIONS(3),
  },
  [245] = {
    [sym_identifier] = ACTIONS(797),
    [anon_sym_RBRACE] = ACTIONS(795),
    [anon_sym_type] = ACTIONS(797),
    [anon_sym_error] = ACTIONS(797),
    [anon_sym_struct] = ACTIONS(797),
    [anon_sym_enum] = ACTIONS(797),
    [anon_sym_event] = ACTIONS(797),
    [anon_sym_using] = ACTIONS(797),
    [anon_sym_function] = ACTIONS(797),
    [anon_sym_byte] = ACTIONS(797),
    [anon_sym_address] = ACTIONS(797),
    [anon_sym_var] = ACTIONS(797),
    [anon_sym_modifier] = ACTIONS(797),
    [anon_sym_constructor] = ACTIONS(797),
    [anon_sym_fallback] = ACTIONS(797),
    [anon_sym_receive] = ACTIONS(797),
    [anon_sym_mapping] = ACTIONS(797),
    [anon_sym_bool] = ACTIONS(797),
    [anon_sym_string] = ACTIONS(797),
    [anon_sym_int] = ACTIONS(797),
    [anon_sym_int8] = ACTIONS(797),
    [anon_sym_int16] = ACTIONS(797),
    [anon_sym_int24] = ACTIONS(797),
    [anon_sym_int32] = ACTIONS(797),
    [anon_sym_int40] = ACTIONS(797),
    [anon_sym_int48] = ACTIONS(797),
    [anon_sym_int56] = ACTIONS(797),
    [anon_sym_int64] = ACTIONS(797),
    [anon_sym_int72] = ACTIONS(797),
    [anon_sym_int80] = ACTIONS(797),
    [anon_sym_int88] = ACTIONS(797),
    [anon_sym_int96] = ACTIONS(797),
    [anon_sym_int104] = ACTIONS(797),
    [anon_sym_int112] = ACTIONS(797),
    [anon_sym_int120] = ACTIONS(797),
    [anon_sym_int128] = ACTIONS(797),
    [anon_sym_int136] = ACTIONS(797),
    [anon_sym_int144] = ACTIONS(797),
    [anon_sym_int152] = ACTIONS(797),
    [anon_sym_int160] = ACTIONS(797),
    [anon_sym_int168] = ACTIONS(797),
    [anon_sym_int176] = ACTIONS(797),
    [anon_sym_int184] = ACTIONS(797),
    [anon_sym_int192] = ACTIONS(797),
    [anon_sym_int200] = ACTIONS(797),
    [anon_sym_int208] = ACTIONS(797),
    [anon_sym_int216] = ACTIONS(797),
    [anon_sym_int224] = ACTIONS(797),
    [anon_sym_int232] = ACTIONS(797),
    [anon_sym_int240] = ACTIONS(797),
    [anon_sym_int248] = ACTIONS(797),
    [anon_sym_int256] = ACTIONS(797),
    [anon_sym_uint] = ACTIONS(797),
    [anon_sym_uint8] = ACTIONS(797),
    [anon_sym_uint16] = ACTIONS(797),
    [anon_sym_uint24] = ACTIONS(797),
    [anon_sym_uint32] = ACTIONS(797),
    [anon_sym_uint40] = ACTIONS(797),
    [anon_sym_uint48] = ACTIONS(797),
    [anon_sym_uint56] = ACTIONS(797),
    [anon_sym_uint64] = ACTIONS(797),
    [anon_sym_uint72] = ACTIONS(797),
    [anon_sym_uint80] = ACTIONS(797),
    [anon_sym_uint88] = ACTIONS(797),
    [anon_sym_uint96] = ACTIONS(797),
    [anon_sym_uint104] = ACTIONS(797),
    [anon_sym_uint112] = ACTIONS(797),
    [anon_sym_uint120] = ACTIONS(797),
    [anon_sym_uint128] = ACTIONS(797),
    [anon_sym_uint136] = ACTIONS(797),
    [anon_sym_uint144] = ACTIONS(797),
    [anon_sym_uint152] = ACTIONS(797),
    [anon_sym_uint160] = ACTIONS(797),
    [anon_sym_uint168] = ACTIONS(797),
    [anon_sym_uint176] = ACTIONS(797),
    [anon_sym_uint184] = ACTIONS(797),
    [anon_sym_uint192] = ACTIONS(797),
    [anon_sym_uint200] = ACTIONS(797),
    [anon_sym_uint208] = ACTIONS(797),
    [anon_sym_uint216] = ACTIONS(797),
    [anon_sym_uint224] = ACTIONS(797),
    [anon_sym_uint232] = ACTIONS(797),
    [anon_sym_uint240] = ACTIONS(797),
    [anon_sym_uint248] = ACTIONS(797),
    [anon_sym_uint256] = ACTIONS(797),
    [anon_sym_bytes] = ACTIONS(797),
    [anon_sym_bytes1] = ACTIONS(797),
    [anon_sym_bytes2] = ACTIONS(797),
    [anon_sym_bytes3] = ACTIONS(797),
    [anon_sym_bytes4] = ACTIONS(797),
    [anon_sym_bytes5] = ACTIONS(797),
    [anon_sym_bytes6] = ACTIONS(797),
    [anon_sym_bytes7] = ACTIONS(797),
    [anon_sym_bytes8] = ACTIONS(797),
    [anon_sym_bytes9] = ACTIONS(797),
    [anon_sym_bytes10] = ACTIONS(797),
    [anon_sym_bytes11] = ACTIONS(797),
    [anon_sym_bytes12] = ACTIONS(797),
    [anon_sym_bytes13] = ACTIONS(797),
    [anon_sym_bytes14] = ACTIONS(797),
    [anon_sym_bytes15] = ACTIONS(797),
    [anon_sym_bytes16] = ACTIONS(797),
    [anon_sym_bytes17] = ACTIONS(797),
    [anon_sym_bytes18] = ACTIONS(797),
    [anon_sym_bytes19] = ACTIONS(797),
    [anon_sym_bytes20] = ACTIONS(797),
    [anon_sym_bytes21] = ACTIONS(797),
    [anon_sym_bytes22] = ACTIONS(797),
    [anon_sym_bytes23] = ACTIONS(797),
    [anon_sym_bytes24] = ACTIONS(797),
    [anon_sym_bytes25] = ACTIONS(797),
    [anon_sym_bytes26] = ACTIONS(797),
    [anon_sym_bytes27] = ACTIONS(797),
    [anon_sym_bytes28] = ACTIONS(797),
    [anon_sym_bytes29] = ACTIONS(797),
    [anon_sym_bytes30] = ACTIONS(797),
    [anon_sym_bytes31] = ACTIONS(797),
    [anon_sym_bytes32] = ACTIONS(797),
    [anon_sym_fixed] = ACTIONS(797),
    [aux_sym__fixed_token1] = ACTIONS(797),
    [anon_sym_ufixed] = ACTIONS(797),
    [aux_sym__ufixed_token1] = ACTIONS(797),
    [sym_comment] = ACTIONS(3),
  },
  [246] = {
    [sym_identifier] = ACTIONS(649),
    [anon_sym_RBRACE] = ACTIONS(647),
    [anon_sym_type] = ACTIONS(649),
    [anon_sym_error] = ACTIONS(649),
    [anon_sym_struct] = ACTIONS(649),
    [anon_sym_enum] = ACTIONS(649),
    [anon_sym_event] = ACTIONS(649),
    [anon_sym_using] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(649),
    [anon_sym_byte] = ACTIONS(649),
    [anon_sym_address] = ACTIONS(649),
    [anon_sym_var] = ACTIONS(649),
    [anon_sym_modifier] = ACTIONS(649),
    [anon_sym_constructor] = ACTIONS(649),
    [anon_sym_fallback] = ACTIONS(649),
    [anon_sym_receive] = ACTIONS(649),
    [anon_sym_mapping] = ACTIONS(649),
    [anon_sym_bool] = ACTIONS(649),
    [anon_sym_string] = ACTIONS(649),
    [anon_sym_int] = ACTIONS(649),
    [anon_sym_int8] = ACTIONS(649),
    [anon_sym_int16] = ACTIONS(649),
    [anon_sym_int24] = ACTIONS(649),
    [anon_sym_int32] = ACTIONS(649),
    [anon_sym_int40] = ACTIONS(649),
    [anon_sym_int48] = ACTIONS(649),
    [anon_sym_int56] = ACTIONS(649),
    [anon_sym_int64] = ACTIONS(649),
    [anon_sym_int72] = ACTIONS(649),
    [anon_sym_int80] = ACTIONS(649),
    [anon_sym_int88] = ACTIONS(649),
    [anon_sym_int96] = ACTIONS(649),
    [anon_sym_int104] = ACTIONS(649),
    [anon_sym_int112] = ACTIONS(649),
    [anon_sym_int120] = ACTIONS(649),
    [anon_sym_int128] = ACTIONS(649),
    [anon_sym_int136] = ACTIONS(649),
    [anon_sym_int144] = ACTIONS(649),
    [anon_sym_int152] = ACTIONS(649),
    [anon_sym_int160] = ACTIONS(649),
    [anon_sym_int168] = ACTIONS(649),
    [anon_sym_int176] = ACTIONS(649),
    [anon_sym_int184] = ACTIONS(649),
    [anon_sym_int192] = ACTIONS(649),
    [anon_sym_int200] = ACTIONS(649),
    [anon_sym_int208] = ACTIONS(649),
    [anon_sym_int216] = ACTIONS(649),
    [anon_sym_int224] = ACTIONS(649),
    [anon_sym_int232] = ACTIONS(649),
    [anon_sym_int240] = ACTIONS(649),
    [anon_sym_int248] = ACTIONS(649),
    [anon_sym_int256] = ACTIONS(649),
    [anon_sym_uint] = ACTIONS(649),
    [anon_sym_uint8] = ACTIONS(649),
    [anon_sym_uint16] = ACTIONS(649),
    [anon_sym_uint24] = ACTIONS(649),
    [anon_sym_uint32] = ACTIONS(649),
    [anon_sym_uint40] = ACTIONS(649),
    [anon_sym_uint48] = ACTIONS(649),
    [anon_sym_uint56] = ACTIONS(649),
    [anon_sym_uint64] = ACTIONS(649),
    [anon_sym_uint72] = ACTIONS(649),
    [anon_sym_uint80] = ACTIONS(649),
    [anon_sym_uint88] = ACTIONS(649),
    [anon_sym_uint96] = ACTIONS(649),
    [anon_sym_uint104] = ACTIONS(649),
    [anon_sym_uint112] = ACTIONS(649),
    [anon_sym_uint120] = ACTIONS(649),
    [anon_sym_uint128] = ACTIONS(649),
    [anon_sym_uint136] = ACTIONS(649),
    [anon_sym_uint144] = ACTIONS(649),
    [anon_sym_uint152] = ACTIONS(649),
    [anon_sym_uint160] = ACTIONS(649),
    [anon_sym_uint168] = ACTIONS(649),
    [anon_sym_uint176] = ACTIONS(649),
    [anon_sym_uint184] = ACTIONS(649),
    [anon_sym_uint192] = ACTIONS(649),
    [anon_sym_uint200] = ACTIONS(649),
    [anon_sym_uint208] = ACTIONS(649),
    [anon_sym_uint216] = ACTIONS(649),
    [anon_sym_uint224] = ACTIONS(649),
    [anon_sym_uint232] = ACTIONS(649),
    [anon_sym_uint240] = ACTIONS(649),
    [anon_sym_uint248] = ACTIONS(649),
    [anon_sym_uint256] = ACTIONS(649),
    [anon_sym_bytes] = ACTIONS(649),
    [anon_sym_bytes1] = ACTIONS(649),
    [anon_sym_bytes2] = ACTIONS(649),
    [anon_sym_bytes3] = ACTIONS(649),
    [anon_sym_bytes4] = ACTIONS(649),
    [anon_sym_bytes5] = ACTIONS(649),
    [anon_sym_bytes6] = ACTIONS(649),
    [anon_sym_bytes7] = ACTIONS(649),
    [anon_sym_bytes8] = ACTIONS(649),
    [anon_sym_bytes9] = ACTIONS(649),
    [anon_sym_bytes10] = ACTIONS(649),
    [anon_sym_bytes11] = ACTIONS(649),
    [anon_sym_bytes12] = ACTIONS(649),
    [anon_sym_bytes13] = ACTIONS(649),
    [anon_sym_bytes14] = ACTIONS(649),
    [anon_sym_bytes15] = ACTIONS(649),
    [anon_sym_bytes16] = ACTIONS(649),
    [anon_sym_bytes17] = ACTIONS(649),
    [anon_sym_bytes18] = ACTIONS(649),
    [anon_sym_bytes19] = ACTIONS(649),
    [anon_sym_bytes20] = ACTIONS(649),
    [anon_sym_bytes21] = ACTIONS(649),
    [anon_sym_bytes22] = ACTIONS(649),
    [anon_sym_bytes23] = ACTIONS(649),
    [anon_sym_bytes24] = ACTIONS(649),
    [anon_sym_bytes25] = ACTIONS(649),
    [anon_sym_bytes26] = ACTIONS(649),
    [anon_sym_bytes27] = ACTIONS(649),
    [anon_sym_bytes28] = ACTIONS(649),
    [anon_sym_bytes29] = ACTIONS(649),
    [anon_sym_bytes30] = ACTIONS(649),
    [anon_sym_bytes31] = ACTIONS(649),
    [anon_sym_bytes32] = ACTIONS(649),
    [anon_sym_fixed] = ACTIONS(649),
    [aux_sym__fixed_token1] = ACTIONS(649),
    [anon_sym_ufixed] = ACTIONS(649),
    [aux_sym__ufixed_token1] = ACTIONS(649),
    [sym_comment] = ACTIONS(3),
  },
  [247] = {
    [sym_identifier] = ACTIONS(885),
    [anon_sym_RBRACE] = ACTIONS(887),
    [anon_sym_type] = ACTIONS(885),
    [anon_sym_error] = ACTIONS(885),
    [anon_sym_struct] = ACTIONS(885),
    [anon_sym_enum] = ACTIONS(885),
    [anon_sym_event] = ACTIONS(885),
    [anon_sym_using] = ACTIONS(885),
    [anon_sym_function] = ACTIONS(885),
    [anon_sym_byte] = ACTIONS(885),
    [anon_sym_address] = ACTIONS(885),
    [anon_sym_var] = ACTIONS(885),
    [anon_sym_modifier] = ACTIONS(885),
    [anon_sym_constructor] = ACTIONS(885),
    [anon_sym_fallback] = ACTIONS(885),
    [anon_sym_receive] = ACTIONS(885),
    [anon_sym_mapping] = ACTIONS(885),
    [anon_sym_bool] = ACTIONS(885),
    [anon_sym_string] = ACTIONS(885),
    [anon_sym_int] = ACTIONS(885),
    [anon_sym_int8] = ACTIONS(885),
    [anon_sym_int16] = ACTIONS(885),
    [anon_sym_int24] = ACTIONS(885),
    [anon_sym_int32] = ACTIONS(885),
    [anon_sym_int40] = ACTIONS(885),
    [anon_sym_int48] = ACTIONS(885),
    [anon_sym_int56] = ACTIONS(885),
    [anon_sym_int64] = ACTIONS(885),
    [anon_sym_int72] = ACTIONS(885),
    [anon_sym_int80] = ACTIONS(885),
    [anon_sym_int88] = ACTIONS(885),
    [anon_sym_int96] = ACTIONS(885),
    [anon_sym_int104] = ACTIONS(885),
    [anon_sym_int112] = ACTIONS(885),
    [anon_sym_int120] = ACTIONS(885),
    [anon_sym_int128] = ACTIONS(885),
    [anon_sym_int136] = ACTIONS(885),
    [anon_sym_int144] = ACTIONS(885),
    [anon_sym_int152] = ACTIONS(885),
    [anon_sym_int160] = ACTIONS(885),
    [anon_sym_int168] = ACTIONS(885),
    [anon_sym_int176] = ACTIONS(885),
    [anon_sym_int184] = ACTIONS(885),
    [anon_sym_int192] = ACTIONS(885),
    [anon_sym_int200] = ACTIONS(885),
    [anon_sym_int208] = ACTIONS(885),
    [anon_sym_int216] = ACTIONS(885),
    [anon_sym_int224] = ACTIONS(885),
    [anon_sym_int232] = ACTIONS(885),
    [anon_sym_int240] = ACTIONS(885),
    [anon_sym_int248] = ACTIONS(885),
    [anon_sym_int256] = ACTIONS(885),
    [anon_sym_uint] = ACTIONS(885),
    [anon_sym_uint8] = ACTIONS(885),
    [anon_sym_uint16] = ACTIONS(885),
    [anon_sym_uint24] = ACTIONS(885),
    [anon_sym_uint32] = ACTIONS(885),
    [anon_sym_uint40] = ACTIONS(885),
    [anon_sym_uint48] = ACTIONS(885),
    [anon_sym_uint56] = ACTIONS(885),
    [anon_sym_uint64] = ACTIONS(885),
    [anon_sym_uint72] = ACTIONS(885),
    [anon_sym_uint80] = ACTIONS(885),
    [anon_sym_uint88] = ACTIONS(885),
    [anon_sym_uint96] = ACTIONS(885),
    [anon_sym_uint104] = ACTIONS(885),
    [anon_sym_uint112] = ACTIONS(885),
    [anon_sym_uint120] = ACTIONS(885),
    [anon_sym_uint128] = ACTIONS(885),
    [anon_sym_uint136] = ACTIONS(885),
    [anon_sym_uint144] = ACTIONS(885),
    [anon_sym_uint152] = ACTIONS(885),
    [anon_sym_uint160] = ACTIONS(885),
    [anon_sym_uint168] = ACTIONS(885),
    [anon_sym_uint176] = ACTIONS(885),
    [anon_sym_uint184] = ACTIONS(885),
    [anon_sym_uint192] = ACTIONS(885),
    [anon_sym_uint200] = ACTIONS(885),
    [anon_sym_uint208] = ACTIONS(885),
    [anon_sym_uint216] = ACTIONS(885),
    [anon_sym_uint224] = ACTIONS(885),
    [anon_sym_uint232] = ACTIONS(885),
    [anon_sym_uint240] = ACTIONS(885),
    [anon_sym_uint248] = ACTIONS(885),
    [anon_sym_uint256] = ACTIONS(885),
    [anon_sym_bytes] = ACTIONS(885),
    [anon_sym_bytes1] = ACTIONS(885),
    [anon_sym_bytes2] = ACTIONS(885),
    [anon_sym_bytes3] = ACTIONS(885),
    [anon_sym_bytes4] = ACTIONS(885),
    [anon_sym_bytes5] = ACTIONS(885),
    [anon_sym_bytes6] = ACTIONS(885),
    [anon_sym_bytes7] = ACTIONS(885),
    [anon_sym_bytes8] = ACTIONS(885),
    [anon_sym_bytes9] = ACTIONS(885),
    [anon_sym_bytes10] = ACTIONS(885),
    [anon_sym_bytes11] = ACTIONS(885),
    [anon_sym_bytes12] = ACTIONS(885),
    [anon_sym_bytes13] = ACTIONS(885),
    [anon_sym_bytes14] = ACTIONS(885),
    [anon_sym_bytes15] = ACTIONS(885),
    [anon_sym_bytes16] = ACTIONS(885),
    [anon_sym_bytes17] = ACTIONS(885),
    [anon_sym_bytes18] = ACTIONS(885),
    [anon_sym_bytes19] = ACTIONS(885),
    [anon_sym_bytes20] = ACTIONS(885),
    [anon_sym_bytes21] = ACTIONS(885),
    [anon_sym_bytes22] = ACTIONS(885),
    [anon_sym_bytes23] = ACTIONS(885),
    [anon_sym_bytes24] = ACTIONS(885),
    [anon_sym_bytes25] = ACTIONS(885),
    [anon_sym_bytes26] = ACTIONS(885),
    [anon_sym_bytes27] = ACTIONS(885),
    [anon_sym_bytes28] = ACTIONS(885),
    [anon_sym_bytes29] = ACTIONS(885),
    [anon_sym_bytes30] = ACTIONS(885),
    [anon_sym_bytes31] = ACTIONS(885),
    [anon_sym_bytes32] = ACTIONS(885),
    [anon_sym_fixed] = ACTIONS(885),
    [aux_sym__fixed_token1] = ACTIONS(885),
    [anon_sym_ufixed] = ACTIONS(885),
    [aux_sym__ufixed_token1] = ACTIONS(885),
    [sym_comment] = ACTIONS(3),
  },
  [248] = {
    [sym_identifier] = ACTIONS(737),
    [anon_sym_RBRACE] = ACTIONS(735),
    [anon_sym_type] = ACTIONS(737),
    [anon_sym_error] = ACTIONS(737),
    [anon_sym_struct] = ACTIONS(737),
    [anon_sym_enum] = ACTIONS(737),
    [anon_sym_event] = ACTIONS(737),
    [anon_sym_using] = ACTIONS(737),
    [anon_sym_function] = ACTIONS(737),
    [anon_sym_byte] = ACTIONS(737),
    [anon_sym_address] = ACTIONS(737),
    [anon_sym_var] = ACTIONS(737),
    [anon_sym_modifier] = ACTIONS(737),
    [anon_sym_constructor] = ACTIONS(737),
    [anon_sym_fallback] = ACTIONS(737),
    [anon_sym_receive] = ACTIONS(737),
    [anon_sym_mapping] = ACTIONS(737),
    [anon_sym_bool] = ACTIONS(737),
    [anon_sym_string] = ACTIONS(737),
    [anon_sym_int] = ACTIONS(737),
    [anon_sym_int8] = ACTIONS(737),
    [anon_sym_int16] = ACTIONS(737),
    [anon_sym_int24] = ACTIONS(737),
    [anon_sym_int32] = ACTIONS(737),
    [anon_sym_int40] = ACTIONS(737),
    [anon_sym_int48] = ACTIONS(737),
    [anon_sym_int56] = ACTIONS(737),
    [anon_sym_int64] = ACTIONS(737),
    [anon_sym_int72] = ACTIONS(737),
    [anon_sym_int80] = ACTIONS(737),
    [anon_sym_int88] = ACTIONS(737),
    [anon_sym_int96] = ACTIONS(737),
    [anon_sym_int104] = ACTIONS(737),
    [anon_sym_int112] = ACTIONS(737),
    [anon_sym_int120] = ACTIONS(737),
    [anon_sym_int128] = ACTIONS(737),
    [anon_sym_int136] = ACTIONS(737),
    [anon_sym_int144] = ACTIONS(737),
    [anon_sym_int152] = ACTIONS(737),
    [anon_sym_int160] = ACTIONS(737),
    [anon_sym_int168] = ACTIONS(737),
    [anon_sym_int176] = ACTIONS(737),
    [anon_sym_int184] = ACTIONS(737),
    [anon_sym_int192] = ACTIONS(737),
    [anon_sym_int200] = ACTIONS(737),
    [anon_sym_int208] = ACTIONS(737),
    [anon_sym_int216] = ACTIONS(737),
    [anon_sym_int224] = ACTIONS(737),
    [anon_sym_int232] = ACTIONS(737),
    [anon_sym_int240] = ACTIONS(737),
    [anon_sym_int248] = ACTIONS(737),
    [anon_sym_int256] = ACTIONS(737),
    [anon_sym_uint] = ACTIONS(737),
    [anon_sym_uint8] = ACTIONS(737),
    [anon_sym_uint16] = ACTIONS(737),
    [anon_sym_uint24] = ACTIONS(737),
    [anon_sym_uint32] = ACTIONS(737),
    [anon_sym_uint40] = ACTIONS(737),
    [anon_sym_uint48] = ACTIONS(737),
    [anon_sym_uint56] = ACTIONS(737),
    [anon_sym_uint64] = ACTIONS(737),
    [anon_sym_uint72] = ACTIONS(737),
    [anon_sym_uint80] = ACTIONS(737),
    [anon_sym_uint88] = ACTIONS(737),
    [anon_sym_uint96] = ACTIONS(737),
    [anon_sym_uint104] = ACTIONS(737),
    [anon_sym_uint112] = ACTIONS(737),
    [anon_sym_uint120] = ACTIONS(737),
    [anon_sym_uint128] = ACTIONS(737),
    [anon_sym_uint136] = ACTIONS(737),
    [anon_sym_uint144] = ACTIONS(737),
    [anon_sym_uint152] = ACTIONS(737),
    [anon_sym_uint160] = ACTIONS(737),
    [anon_sym_uint168] = ACTIONS(737),
    [anon_sym_uint176] = ACTIONS(737),
    [anon_sym_uint184] = ACTIONS(737),
    [anon_sym_uint192] = ACTIONS(737),
    [anon_sym_uint200] = ACTIONS(737),
    [anon_sym_uint208] = ACTIONS(737),
    [anon_sym_uint216] = ACTIONS(737),
    [anon_sym_uint224] = ACTIONS(737),
    [anon_sym_uint232] = ACTIONS(737),
    [anon_sym_uint240] = ACTIONS(737),
    [anon_sym_uint248] = ACTIONS(737),
    [anon_sym_uint256] = ACTIONS(737),
    [anon_sym_bytes] = ACTIONS(737),
    [anon_sym_bytes1] = ACTIONS(737),
    [anon_sym_bytes2] = ACTIONS(737),
    [anon_sym_bytes3] = ACTIONS(737),
    [anon_sym_bytes4] = ACTIONS(737),
    [anon_sym_bytes5] = ACTIONS(737),
    [anon_sym_bytes6] = ACTIONS(737),
    [anon_sym_bytes7] = ACTIONS(737),
    [anon_sym_bytes8] = ACTIONS(737),
    [anon_sym_bytes9] = ACTIONS(737),
    [anon_sym_bytes10] = ACTIONS(737),
    [anon_sym_bytes11] = ACTIONS(737),
    [anon_sym_bytes12] = ACTIONS(737),
    [anon_sym_bytes13] = ACTIONS(737),
    [anon_sym_bytes14] = ACTIONS(737),
    [anon_sym_bytes15] = ACTIONS(737),
    [anon_sym_bytes16] = ACTIONS(737),
    [anon_sym_bytes17] = ACTIONS(737),
    [anon_sym_bytes18] = ACTIONS(737),
    [anon_sym_bytes19] = ACTIONS(737),
    [anon_sym_bytes20] = ACTIONS(737),
    [anon_sym_bytes21] = ACTIONS(737),
    [anon_sym_bytes22] = ACTIONS(737),
    [anon_sym_bytes23] = ACTIONS(737),
    [anon_sym_bytes24] = ACTIONS(737),
    [anon_sym_bytes25] = ACTIONS(737),
    [anon_sym_bytes26] = ACTIONS(737),
    [anon_sym_bytes27] = ACTIONS(737),
    [anon_sym_bytes28] = ACTIONS(737),
    [anon_sym_bytes29] = ACTIONS(737),
    [anon_sym_bytes30] = ACTIONS(737),
    [anon_sym_bytes31] = ACTIONS(737),
    [anon_sym_bytes32] = ACTIONS(737),
    [anon_sym_fixed] = ACTIONS(737),
    [aux_sym__fixed_token1] = ACTIONS(737),
    [anon_sym_ufixed] = ACTIONS(737),
    [aux_sym__ufixed_token1] = ACTIONS(737),
    [sym_comment] = ACTIONS(3),
  },
  [249] = {
    [sym_identifier] = ACTIONS(823),
    [anon_sym_RBRACE] = ACTIONS(821),
    [anon_sym_type] = ACTIONS(823),
    [anon_sym_error] = ACTIONS(823),
    [anon_sym_struct] = ACTIONS(823),
    [anon_sym_enum] = ACTIONS(823),
    [anon_sym_event] = ACTIONS(823),
    [anon_sym_using] = ACTIONS(823),
    [anon_sym_function] = ACTIONS(823),
    [anon_sym_byte] = ACTIONS(823),
    [anon_sym_address] = ACTIONS(823),
    [anon_sym_var] = ACTIONS(823),
    [anon_sym_modifier] = ACTIONS(823),
    [anon_sym_constructor] = ACTIONS(823),
    [anon_sym_fallback] = ACTIONS(823),
    [anon_sym_receive] = ACTIONS(823),
    [anon_sym_mapping] = ACTIONS(823),
    [anon_sym_bool] = ACTIONS(823),
    [anon_sym_string] = ACTIONS(823),
    [anon_sym_int] = ACTIONS(823),
    [anon_sym_int8] = ACTIONS(823),
    [anon_sym_int16] = ACTIONS(823),
    [anon_sym_int24] = ACTIONS(823),
    [anon_sym_int32] = ACTIONS(823),
    [anon_sym_int40] = ACTIONS(823),
    [anon_sym_int48] = ACTIONS(823),
    [anon_sym_int56] = ACTIONS(823),
    [anon_sym_int64] = ACTIONS(823),
    [anon_sym_int72] = ACTIONS(823),
    [anon_sym_int80] = ACTIONS(823),
    [anon_sym_int88] = ACTIONS(823),
    [anon_sym_int96] = ACTIONS(823),
    [anon_sym_int104] = ACTIONS(823),
    [anon_sym_int112] = ACTIONS(823),
    [anon_sym_int120] = ACTIONS(823),
    [anon_sym_int128] = ACTIONS(823),
    [anon_sym_int136] = ACTIONS(823),
    [anon_sym_int144] = ACTIONS(823),
    [anon_sym_int152] = ACTIONS(823),
    [anon_sym_int160] = ACTIONS(823),
    [anon_sym_int168] = ACTIONS(823),
    [anon_sym_int176] = ACTIONS(823),
    [anon_sym_int184] = ACTIONS(823),
    [anon_sym_int192] = ACTIONS(823),
    [anon_sym_int200] = ACTIONS(823),
    [anon_sym_int208] = ACTIONS(823),
    [anon_sym_int216] = ACTIONS(823),
    [anon_sym_int224] = ACTIONS(823),
    [anon_sym_int232] = ACTIONS(823),
    [anon_sym_int240] = ACTIONS(823),
    [anon_sym_int248] = ACTIONS(823),
    [anon_sym_int256] = ACTIONS(823),
    [anon_sym_uint] = ACTIONS(823),
    [anon_sym_uint8] = ACTIONS(823),
    [anon_sym_uint16] = ACTIONS(823),
    [anon_sym_uint24] = ACTIONS(823),
    [anon_sym_uint32] = ACTIONS(823),
    [anon_sym_uint40] = ACTIONS(823),
    [anon_sym_uint48] = ACTIONS(823),
    [anon_sym_uint56] = ACTIONS(823),
    [anon_sym_uint64] = ACTIONS(823),
    [anon_sym_uint72] = ACTIONS(823),
    [anon_sym_uint80] = ACTIONS(823),
    [anon_sym_uint88] = ACTIONS(823),
    [anon_sym_uint96] = ACTIONS(823),
    [anon_sym_uint104] = ACTIONS(823),
    [anon_sym_uint112] = ACTIONS(823),
    [anon_sym_uint120] = ACTIONS(823),
    [anon_sym_uint128] = ACTIONS(823),
    [anon_sym_uint136] = ACTIONS(823),
    [anon_sym_uint144] = ACTIONS(823),
    [anon_sym_uint152] = ACTIONS(823),
    [anon_sym_uint160] = ACTIONS(823),
    [anon_sym_uint168] = ACTIONS(823),
    [anon_sym_uint176] = ACTIONS(823),
    [anon_sym_uint184] = ACTIONS(823),
    [anon_sym_uint192] = ACTIONS(823),
    [anon_sym_uint200] = ACTIONS(823),
    [anon_sym_uint208] = ACTIONS(823),
    [anon_sym_uint216] = ACTIONS(823),
    [anon_sym_uint224] = ACTIONS(823),
    [anon_sym_uint232] = ACTIONS(823),
    [anon_sym_uint240] = ACTIONS(823),
    [anon_sym_uint248] = ACTIONS(823),
    [anon_sym_uint256] = ACTIONS(823),
    [anon_sym_bytes] = ACTIONS(823),
    [anon_sym_bytes1] = ACTIONS(823),
    [anon_sym_bytes2] = ACTIONS(823),
    [anon_sym_bytes3] = ACTIONS(823),
    [anon_sym_bytes4] = ACTIONS(823),
    [anon_sym_bytes5] = ACTIONS(823),
    [anon_sym_bytes6] = ACTIONS(823),
    [anon_sym_bytes7] = ACTIONS(823),
    [anon_sym_bytes8] = ACTIONS(823),
    [anon_sym_bytes9] = ACTIONS(823),
    [anon_sym_bytes10] = ACTIONS(823),
    [anon_sym_bytes11] = ACTIONS(823),
    [anon_sym_bytes12] = ACTIONS(823),
    [anon_sym_bytes13] = ACTIONS(823),
    [anon_sym_bytes14] = ACTIONS(823),
    [anon_sym_bytes15] = ACTIONS(823),
    [anon_sym_bytes16] = ACTIONS(823),
    [anon_sym_bytes17] = ACTIONS(823),
    [anon_sym_bytes18] = ACTIONS(823),
    [anon_sym_bytes19] = ACTIONS(823),
    [anon_sym_bytes20] = ACTIONS(823),
    [anon_sym_bytes21] = ACTIONS(823),
    [anon_sym_bytes22] = ACTIONS(823),
    [anon_sym_bytes23] = ACTIONS(823),
    [anon_sym_bytes24] = ACTIONS(823),
    [anon_sym_bytes25] = ACTIONS(823),
    [anon_sym_bytes26] = ACTIONS(823),
    [anon_sym_bytes27] = ACTIONS(823),
    [anon_sym_bytes28] = ACTIONS(823),
    [anon_sym_bytes29] = ACTIONS(823),
    [anon_sym_bytes30] = ACTIONS(823),
    [anon_sym_bytes31] = ACTIONS(823),
    [anon_sym_bytes32] = ACTIONS(823),
    [anon_sym_fixed] = ACTIONS(823),
    [aux_sym__fixed_token1] = ACTIONS(823),
    [anon_sym_ufixed] = ACTIONS(823),
    [aux_sym__ufixed_token1] = ACTIONS(823),
    [sym_comment] = ACTIONS(3),
  },
  [250] = {
    [sym_identifier] = ACTIONS(761),
    [anon_sym_RBRACE] = ACTIONS(759),
    [anon_sym_type] = ACTIONS(761),
    [anon_sym_error] = ACTIONS(761),
    [anon_sym_struct] = ACTIONS(761),
    [anon_sym_enum] = ACTIONS(761),
    [anon_sym_event] = ACTIONS(761),
    [anon_sym_using] = ACTIONS(761),
    [anon_sym_function] = ACTIONS(761),
    [anon_sym_byte] = ACTIONS(761),
    [anon_sym_address] = ACTIONS(761),
    [anon_sym_var] = ACTIONS(761),
    [anon_sym_modifier] = ACTIONS(761),
    [anon_sym_constructor] = ACTIONS(761),
    [anon_sym_fallback] = ACTIONS(761),
    [anon_sym_receive] = ACTIONS(761),
    [anon_sym_mapping] = ACTIONS(761),
    [anon_sym_bool] = ACTIONS(761),
    [anon_sym_string] = ACTIONS(761),
    [anon_sym_int] = ACTIONS(761),
    [anon_sym_int8] = ACTIONS(761),
    [anon_sym_int16] = ACTIONS(761),
    [anon_sym_int24] = ACTIONS(761),
    [anon_sym_int32] = ACTIONS(761),
    [anon_sym_int40] = ACTIONS(761),
    [anon_sym_int48] = ACTIONS(761),
    [anon_sym_int56] = ACTIONS(761),
    [anon_sym_int64] = ACTIONS(761),
    [anon_sym_int72] = ACTIONS(761),
    [anon_sym_int80] = ACTIONS(761),
    [anon_sym_int88] = ACTIONS(761),
    [anon_sym_int96] = ACTIONS(761),
    [anon_sym_int104] = ACTIONS(761),
    [anon_sym_int112] = ACTIONS(761),
    [anon_sym_int120] = ACTIONS(761),
    [anon_sym_int128] = ACTIONS(761),
    [anon_sym_int136] = ACTIONS(761),
    [anon_sym_int144] = ACTIONS(761),
    [anon_sym_int152] = ACTIONS(761),
    [anon_sym_int160] = ACTIONS(761),
    [anon_sym_int168] = ACTIONS(761),
    [anon_sym_int176] = ACTIONS(761),
    [anon_sym_int184] = ACTIONS(761),
    [anon_sym_int192] = ACTIONS(761),
    [anon_sym_int200] = ACTIONS(761),
    [anon_sym_int208] = ACTIONS(761),
    [anon_sym_int216] = ACTIONS(761),
    [anon_sym_int224] = ACTIONS(761),
    [anon_sym_int232] = ACTIONS(761),
    [anon_sym_int240] = ACTIONS(761),
    [anon_sym_int248] = ACTIONS(761),
    [anon_sym_int256] = ACTIONS(761),
    [anon_sym_uint] = ACTIONS(761),
    [anon_sym_uint8] = ACTIONS(761),
    [anon_sym_uint16] = ACTIONS(761),
    [anon_sym_uint24] = ACTIONS(761),
    [anon_sym_uint32] = ACTIONS(761),
    [anon_sym_uint40] = ACTIONS(761),
    [anon_sym_uint48] = ACTIONS(761),
    [anon_sym_uint56] = ACTIONS(761),
    [anon_sym_uint64] = ACTIONS(761),
    [anon_sym_uint72] = ACTIONS(761),
    [anon_sym_uint80] = ACTIONS(761),
    [anon_sym_uint88] = ACTIONS(761),
    [anon_sym_uint96] = ACTIONS(761),
    [anon_sym_uint104] = ACTIONS(761),
    [anon_sym_uint112] = ACTIONS(761),
    [anon_sym_uint120] = ACTIONS(761),
    [anon_sym_uint128] = ACTIONS(761),
    [anon_sym_uint136] = ACTIONS(761),
    [anon_sym_uint144] = ACTIONS(761),
    [anon_sym_uint152] = ACTIONS(761),
    [anon_sym_uint160] = ACTIONS(761),
    [anon_sym_uint168] = ACTIONS(761),
    [anon_sym_uint176] = ACTIONS(761),
    [anon_sym_uint184] = ACTIONS(761),
    [anon_sym_uint192] = ACTIONS(761),
    [anon_sym_uint200] = ACTIONS(761),
    [anon_sym_uint208] = ACTIONS(761),
    [anon_sym_uint216] = ACTIONS(761),
    [anon_sym_uint224] = ACTIONS(761),
    [anon_sym_uint232] = ACTIONS(761),
    [anon_sym_uint240] = ACTIONS(761),
    [anon_sym_uint248] = ACTIONS(761),
    [anon_sym_uint256] = ACTIONS(761),
    [anon_sym_bytes] = ACTIONS(761),
    [anon_sym_bytes1] = ACTIONS(761),
    [anon_sym_bytes2] = ACTIONS(761),
    [anon_sym_bytes3] = ACTIONS(761),
    [anon_sym_bytes4] = ACTIONS(761),
    [anon_sym_bytes5] = ACTIONS(761),
    [anon_sym_bytes6] = ACTIONS(761),
    [anon_sym_bytes7] = ACTIONS(761),
    [anon_sym_bytes8] = ACTIONS(761),
    [anon_sym_bytes9] = ACTIONS(761),
    [anon_sym_bytes10] = ACTIONS(761),
    [anon_sym_bytes11] = ACTIONS(761),
    [anon_sym_bytes12] = ACTIONS(761),
    [anon_sym_bytes13] = ACTIONS(761),
    [anon_sym_bytes14] = ACTIONS(761),
    [anon_sym_bytes15] = ACTIONS(761),
    [anon_sym_bytes16] = ACTIONS(761),
    [anon_sym_bytes17] = ACTIONS(761),
    [anon_sym_bytes18] = ACTIONS(761),
    [anon_sym_bytes19] = ACTIONS(761),
    [anon_sym_bytes20] = ACTIONS(761),
    [anon_sym_bytes21] = ACTIONS(761),
    [anon_sym_bytes22] = ACTIONS(761),
    [anon_sym_bytes23] = ACTIONS(761),
    [anon_sym_bytes24] = ACTIONS(761),
    [anon_sym_bytes25] = ACTIONS(761),
    [anon_sym_bytes26] = ACTIONS(761),
    [anon_sym_bytes27] = ACTIONS(761),
    [anon_sym_bytes28] = ACTIONS(761),
    [anon_sym_bytes29] = ACTIONS(761),
    [anon_sym_bytes30] = ACTIONS(761),
    [anon_sym_bytes31] = ACTIONS(761),
    [anon_sym_bytes32] = ACTIONS(761),
    [anon_sym_fixed] = ACTIONS(761),
    [aux_sym__fixed_token1] = ACTIONS(761),
    [anon_sym_ufixed] = ACTIONS(761),
    [aux_sym__ufixed_token1] = ACTIONS(761),
    [sym_comment] = ACTIONS(3),
  },
  [251] = {
    [sym_identifier] = ACTIONS(889),
    [anon_sym_RBRACE] = ACTIONS(891),
    [anon_sym_type] = ACTIONS(889),
    [anon_sym_error] = ACTIONS(889),
    [anon_sym_struct] = ACTIONS(889),
    [anon_sym_enum] = ACTIONS(889),
    [anon_sym_event] = ACTIONS(889),
    [anon_sym_using] = ACTIONS(889),
    [anon_sym_function] = ACTIONS(889),
    [anon_sym_byte] = ACTIONS(889),
    [anon_sym_address] = ACTIONS(889),
    [anon_sym_var] = ACTIONS(889),
    [anon_sym_modifier] = ACTIONS(889),
    [anon_sym_constructor] = ACTIONS(889),
    [anon_sym_fallback] = ACTIONS(889),
    [anon_sym_receive] = ACTIONS(889),
    [anon_sym_mapping] = ACTIONS(889),
    [anon_sym_bool] = ACTIONS(889),
    [anon_sym_string] = ACTIONS(889),
    [anon_sym_int] = ACTIONS(889),
    [anon_sym_int8] = ACTIONS(889),
    [anon_sym_int16] = ACTIONS(889),
    [anon_sym_int24] = ACTIONS(889),
    [anon_sym_int32] = ACTIONS(889),
    [anon_sym_int40] = ACTIONS(889),
    [anon_sym_int48] = ACTIONS(889),
    [anon_sym_int56] = ACTIONS(889),
    [anon_sym_int64] = ACTIONS(889),
    [anon_sym_int72] = ACTIONS(889),
    [anon_sym_int80] = ACTIONS(889),
    [anon_sym_int88] = ACTIONS(889),
    [anon_sym_int96] = ACTIONS(889),
    [anon_sym_int104] = ACTIONS(889),
    [anon_sym_int112] = ACTIONS(889),
    [anon_sym_int120] = ACTIONS(889),
    [anon_sym_int128] = ACTIONS(889),
    [anon_sym_int136] = ACTIONS(889),
    [anon_sym_int144] = ACTIONS(889),
    [anon_sym_int152] = ACTIONS(889),
    [anon_sym_int160] = ACTIONS(889),
    [anon_sym_int168] = ACTIONS(889),
    [anon_sym_int176] = ACTIONS(889),
    [anon_sym_int184] = ACTIONS(889),
    [anon_sym_int192] = ACTIONS(889),
    [anon_sym_int200] = ACTIONS(889),
    [anon_sym_int208] = ACTIONS(889),
    [anon_sym_int216] = ACTIONS(889),
    [anon_sym_int224] = ACTIONS(889),
    [anon_sym_int232] = ACTIONS(889),
    [anon_sym_int240] = ACTIONS(889),
    [anon_sym_int248] = ACTIONS(889),
    [anon_sym_int256] = ACTIONS(889),
    [anon_sym_uint] = ACTIONS(889),
    [anon_sym_uint8] = ACTIONS(889),
    [anon_sym_uint16] = ACTIONS(889),
    [anon_sym_uint24] = ACTIONS(889),
    [anon_sym_uint32] = ACTIONS(889),
    [anon_sym_uint40] = ACTIONS(889),
    [anon_sym_uint48] = ACTIONS(889),
    [anon_sym_uint56] = ACTIONS(889),
    [anon_sym_uint64] = ACTIONS(889),
    [anon_sym_uint72] = ACTIONS(889),
    [anon_sym_uint80] = ACTIONS(889),
    [anon_sym_uint88] = ACTIONS(889),
    [anon_sym_uint96] = ACTIONS(889),
    [anon_sym_uint104] = ACTIONS(889),
    [anon_sym_uint112] = ACTIONS(889),
    [anon_sym_uint120] = ACTIONS(889),
    [anon_sym_uint128] = ACTIONS(889),
    [anon_sym_uint136] = ACTIONS(889),
    [anon_sym_uint144] = ACTIONS(889),
    [anon_sym_uint152] = ACTIONS(889),
    [anon_sym_uint160] = ACTIONS(889),
    [anon_sym_uint168] = ACTIONS(889),
    [anon_sym_uint176] = ACTIONS(889),
    [anon_sym_uint184] = ACTIONS(889),
    [anon_sym_uint192] = ACTIONS(889),
    [anon_sym_uint200] = ACTIONS(889),
    [anon_sym_uint208] = ACTIONS(889),
    [anon_sym_uint216] = ACTIONS(889),
    [anon_sym_uint224] = ACTIONS(889),
    [anon_sym_uint232] = ACTIONS(889),
    [anon_sym_uint240] = ACTIONS(889),
    [anon_sym_uint248] = ACTIONS(889),
    [anon_sym_uint256] = ACTIONS(889),
    [anon_sym_bytes] = ACTIONS(889),
    [anon_sym_bytes1] = ACTIONS(889),
    [anon_sym_bytes2] = ACTIONS(889),
    [anon_sym_bytes3] = ACTIONS(889),
    [anon_sym_bytes4] = ACTIONS(889),
    [anon_sym_bytes5] = ACTIONS(889),
    [anon_sym_bytes6] = ACTIONS(889),
    [anon_sym_bytes7] = ACTIONS(889),
    [anon_sym_bytes8] = ACTIONS(889),
    [anon_sym_bytes9] = ACTIONS(889),
    [anon_sym_bytes10] = ACTIONS(889),
    [anon_sym_bytes11] = ACTIONS(889),
    [anon_sym_bytes12] = ACTIONS(889),
    [anon_sym_bytes13] = ACTIONS(889),
    [anon_sym_bytes14] = ACTIONS(889),
    [anon_sym_bytes15] = ACTIONS(889),
    [anon_sym_bytes16] = ACTIONS(889),
    [anon_sym_bytes17] = ACTIONS(889),
    [anon_sym_bytes18] = ACTIONS(889),
    [anon_sym_bytes19] = ACTIONS(889),
    [anon_sym_bytes20] = ACTIONS(889),
    [anon_sym_bytes21] = ACTIONS(889),
    [anon_sym_bytes22] = ACTIONS(889),
    [anon_sym_bytes23] = ACTIONS(889),
    [anon_sym_bytes24] = ACTIONS(889),
    [anon_sym_bytes25] = ACTIONS(889),
    [anon_sym_bytes26] = ACTIONS(889),
    [anon_sym_bytes27] = ACTIONS(889),
    [anon_sym_bytes28] = ACTIONS(889),
    [anon_sym_bytes29] = ACTIONS(889),
    [anon_sym_bytes30] = ACTIONS(889),
    [anon_sym_bytes31] = ACTIONS(889),
    [anon_sym_bytes32] = ACTIONS(889),
    [anon_sym_fixed] = ACTIONS(889),
    [aux_sym__fixed_token1] = ACTIONS(889),
    [anon_sym_ufixed] = ACTIONS(889),
    [aux_sym__ufixed_token1] = ACTIONS(889),
    [sym_comment] = ACTIONS(3),
  },
  [252] = {
    [sym_identifier] = ACTIONS(793),
    [anon_sym_RBRACE] = ACTIONS(791),
    [anon_sym_type] = ACTIONS(793),
    [anon_sym_error] = ACTIONS(793),
    [anon_sym_struct] = ACTIONS(793),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_event] = ACTIONS(793),
    [anon_sym_using] = ACTIONS(793),
    [anon_sym_function] = ACTIONS(793),
    [anon_sym_byte] = ACTIONS(793),
    [anon_sym_address] = ACTIONS(793),
    [anon_sym_var] = ACTIONS(793),
    [anon_sym_modifier] = ACTIONS(793),
    [anon_sym_constructor] = ACTIONS(793),
    [anon_sym_fallback] = ACTIONS(793),
    [anon_sym_receive] = ACTIONS(793),
    [anon_sym_mapping] = ACTIONS(793),
    [anon_sym_bool] = ACTIONS(793),
    [anon_sym_string] = ACTIONS(793),
    [anon_sym_int] = ACTIONS(793),
    [anon_sym_int8] = ACTIONS(793),
    [anon_sym_int16] = ACTIONS(793),
    [anon_sym_int24] = ACTIONS(793),
    [anon_sym_int32] = ACTIONS(793),
    [anon_sym_int40] = ACTIONS(793),
    [anon_sym_int48] = ACTIONS(793),
    [anon_sym_int56] = ACTIONS(793),
    [anon_sym_int64] = ACTIONS(793),
    [anon_sym_int72] = ACTIONS(793),
    [anon_sym_int80] = ACTIONS(793),
    [anon_sym_int88] = ACTIONS(793),
    [anon_sym_int96] = ACTIONS(793),
    [anon_sym_int104] = ACTIONS(793),
    [anon_sym_int112] = ACTIONS(793),
    [anon_sym_int120] = ACTIONS(793),
    [anon_sym_int128] = ACTIONS(793),
    [anon_sym_int136] = ACTIONS(793),
    [anon_sym_int144] = ACTIONS(793),
    [anon_sym_int152] = ACTIONS(793),
    [anon_sym_int160] = ACTIONS(793),
    [anon_sym_int168] = ACTIONS(793),
    [anon_sym_int176] = ACTIONS(793),
    [anon_sym_int184] = ACTIONS(793),
    [anon_sym_int192] = ACTIONS(793),
    [anon_sym_int200] = ACTIONS(793),
    [anon_sym_int208] = ACTIONS(793),
    [anon_sym_int216] = ACTIONS(793),
    [anon_sym_int224] = ACTIONS(793),
    [anon_sym_int232] = ACTIONS(793),
    [anon_sym_int240] = ACTIONS(793),
    [anon_sym_int248] = ACTIONS(793),
    [anon_sym_int256] = ACTIONS(793),
    [anon_sym_uint] = ACTIONS(793),
    [anon_sym_uint8] = ACTIONS(793),
    [anon_sym_uint16] = ACTIONS(793),
    [anon_sym_uint24] = ACTIONS(793),
    [anon_sym_uint32] = ACTIONS(793),
    [anon_sym_uint40] = ACTIONS(793),
    [anon_sym_uint48] = ACTIONS(793),
    [anon_sym_uint56] = ACTIONS(793),
    [anon_sym_uint64] = ACTIONS(793),
    [anon_sym_uint72] = ACTIONS(793),
    [anon_sym_uint80] = ACTIONS(793),
    [anon_sym_uint88] = ACTIONS(793),
    [anon_sym_uint96] = ACTIONS(793),
    [anon_sym_uint104] = ACTIONS(793),
    [anon_sym_uint112] = ACTIONS(793),
    [anon_sym_uint120] = ACTIONS(793),
    [anon_sym_uint128] = ACTIONS(793),
    [anon_sym_uint136] = ACTIONS(793),
    [anon_sym_uint144] = ACTIONS(793),
    [anon_sym_uint152] = ACTIONS(793),
    [anon_sym_uint160] = ACTIONS(793),
    [anon_sym_uint168] = ACTIONS(793),
    [anon_sym_uint176] = ACTIONS(793),
    [anon_sym_uint184] = ACTIONS(793),
    [anon_sym_uint192] = ACTIONS(793),
    [anon_sym_uint200] = ACTIONS(793),
    [anon_sym_uint208] = ACTIONS(793),
    [anon_sym_uint216] = ACTIONS(793),
    [anon_sym_uint224] = ACTIONS(793),
    [anon_sym_uint232] = ACTIONS(793),
    [anon_sym_uint240] = ACTIONS(793),
    [anon_sym_uint248] = ACTIONS(793),
    [anon_sym_uint256] = ACTIONS(793),
    [anon_sym_bytes] = ACTIONS(793),
    [anon_sym_bytes1] = ACTIONS(793),
    [anon_sym_bytes2] = ACTIONS(793),
    [anon_sym_bytes3] = ACTIONS(793),
    [anon_sym_bytes4] = ACTIONS(793),
    [anon_sym_bytes5] = ACTIONS(793),
    [anon_sym_bytes6] = ACTIONS(793),
    [anon_sym_bytes7] = ACTIONS(793),
    [anon_sym_bytes8] = ACTIONS(793),
    [anon_sym_bytes9] = ACTIONS(793),
    [anon_sym_bytes10] = ACTIONS(793),
    [anon_sym_bytes11] = ACTIONS(793),
    [anon_sym_bytes12] = ACTIONS(793),
    [anon_sym_bytes13] = ACTIONS(793),
    [anon_sym_bytes14] = ACTIONS(793),
    [anon_sym_bytes15] = ACTIONS(793),
    [anon_sym_bytes16] = ACTIONS(793),
    [anon_sym_bytes17] = ACTIONS(793),
    [anon_sym_bytes18] = ACTIONS(793),
    [anon_sym_bytes19] = ACTIONS(793),
    [anon_sym_bytes20] = ACTIONS(793),
    [anon_sym_bytes21] = ACTIONS(793),
    [anon_sym_bytes22] = ACTIONS(793),
    [anon_sym_bytes23] = ACTIONS(793),
    [anon_sym_bytes24] = ACTIONS(793),
    [anon_sym_bytes25] = ACTIONS(793),
    [anon_sym_bytes26] = ACTIONS(793),
    [anon_sym_bytes27] = ACTIONS(793),
    [anon_sym_bytes28] = ACTIONS(793),
    [anon_sym_bytes29] = ACTIONS(793),
    [anon_sym_bytes30] = ACTIONS(793),
    [anon_sym_bytes31] = ACTIONS(793),
    [anon_sym_bytes32] = ACTIONS(793),
    [anon_sym_fixed] = ACTIONS(793),
    [aux_sym__fixed_token1] = ACTIONS(793),
    [anon_sym_ufixed] = ACTIONS(793),
    [aux_sym__ufixed_token1] = ACTIONS(793),
    [sym_comment] = ACTIONS(3),
  },
  [253] = {
    [sym_identifier] = ACTIONS(823),
    [anon_sym_RBRACE] = ACTIONS(821),
    [anon_sym_type] = ACTIONS(823),
    [anon_sym_error] = ACTIONS(823),
    [anon_sym_struct] = ACTIONS(823),
    [anon_sym_enum] = ACTIONS(823),
    [anon_sym_event] = ACTIONS(823),
    [anon_sym_using] = ACTIONS(823),
    [anon_sym_function] = ACTIONS(823),
    [anon_sym_byte] = ACTIONS(823),
    [anon_sym_address] = ACTIONS(823),
    [anon_sym_var] = ACTIONS(823),
    [anon_sym_modifier] = ACTIONS(823),
    [anon_sym_constructor] = ACTIONS(823),
    [anon_sym_fallback] = ACTIONS(823),
    [anon_sym_receive] = ACTIONS(823),
    [anon_sym_mapping] = ACTIONS(823),
    [anon_sym_bool] = ACTIONS(823),
    [anon_sym_string] = ACTIONS(823),
    [anon_sym_int] = ACTIONS(823),
    [anon_sym_int8] = ACTIONS(823),
    [anon_sym_int16] = ACTIONS(823),
    [anon_sym_int24] = ACTIONS(823),
    [anon_sym_int32] = ACTIONS(823),
    [anon_sym_int40] = ACTIONS(823),
    [anon_sym_int48] = ACTIONS(823),
    [anon_sym_int56] = ACTIONS(823),
    [anon_sym_int64] = ACTIONS(823),
    [anon_sym_int72] = ACTIONS(823),
    [anon_sym_int80] = ACTIONS(823),
    [anon_sym_int88] = ACTIONS(823),
    [anon_sym_int96] = ACTIONS(823),
    [anon_sym_int104] = ACTIONS(823),
    [anon_sym_int112] = ACTIONS(823),
    [anon_sym_int120] = ACTIONS(823),
    [anon_sym_int128] = ACTIONS(823),
    [anon_sym_int136] = ACTIONS(823),
    [anon_sym_int144] = ACTIONS(823),
    [anon_sym_int152] = ACTIONS(823),
    [anon_sym_int160] = ACTIONS(823),
    [anon_sym_int168] = ACTIONS(823),
    [anon_sym_int176] = ACTIONS(823),
    [anon_sym_int184] = ACTIONS(823),
    [anon_sym_int192] = ACTIONS(823),
    [anon_sym_int200] = ACTIONS(823),
    [anon_sym_int208] = ACTIONS(823),
    [anon_sym_int216] = ACTIONS(823),
    [anon_sym_int224] = ACTIONS(823),
    [anon_sym_int232] = ACTIONS(823),
    [anon_sym_int240] = ACTIONS(823),
    [anon_sym_int248] = ACTIONS(823),
    [anon_sym_int256] = ACTIONS(823),
    [anon_sym_uint] = ACTIONS(823),
    [anon_sym_uint8] = ACTIONS(823),
    [anon_sym_uint16] = ACTIONS(823),
    [anon_sym_uint24] = ACTIONS(823),
    [anon_sym_uint32] = ACTIONS(823),
    [anon_sym_uint40] = ACTIONS(823),
    [anon_sym_uint48] = ACTIONS(823),
    [anon_sym_uint56] = ACTIONS(823),
    [anon_sym_uint64] = ACTIONS(823),
    [anon_sym_uint72] = ACTIONS(823),
    [anon_sym_uint80] = ACTIONS(823),
    [anon_sym_uint88] = ACTIONS(823),
    [anon_sym_uint96] = ACTIONS(823),
    [anon_sym_uint104] = ACTIONS(823),
    [anon_sym_uint112] = ACTIONS(823),
    [anon_sym_uint120] = ACTIONS(823),
    [anon_sym_uint128] = ACTIONS(823),
    [anon_sym_uint136] = ACTIONS(823),
    [anon_sym_uint144] = ACTIONS(823),
    [anon_sym_uint152] = ACTIONS(823),
    [anon_sym_uint160] = ACTIONS(823),
    [anon_sym_uint168] = ACTIONS(823),
    [anon_sym_uint176] = ACTIONS(823),
    [anon_sym_uint184] = ACTIONS(823),
    [anon_sym_uint192] = ACTIONS(823),
    [anon_sym_uint200] = ACTIONS(823),
    [anon_sym_uint208] = ACTIONS(823),
    [anon_sym_uint216] = ACTIONS(823),
    [anon_sym_uint224] = ACTIONS(823),
    [anon_sym_uint232] = ACTIONS(823),
    [anon_sym_uint240] = ACTIONS(823),
    [anon_sym_uint248] = ACTIONS(823),
    [anon_sym_uint256] = ACTIONS(823),
    [anon_sym_bytes] = ACTIONS(823),
    [anon_sym_bytes1] = ACTIONS(823),
    [anon_sym_bytes2] = ACTIONS(823),
    [anon_sym_bytes3] = ACTIONS(823),
    [anon_sym_bytes4] = ACTIONS(823),
    [anon_sym_bytes5] = ACTIONS(823),
    [anon_sym_bytes6] = ACTIONS(823),
    [anon_sym_bytes7] = ACTIONS(823),
    [anon_sym_bytes8] = ACTIONS(823),
    [anon_sym_bytes9] = ACTIONS(823),
    [anon_sym_bytes10] = ACTIONS(823),
    [anon_sym_bytes11] = ACTIONS(823),
    [anon_sym_bytes12] = ACTIONS(823),
    [anon_sym_bytes13] = ACTIONS(823),
    [anon_sym_bytes14] = ACTIONS(823),
    [anon_sym_bytes15] = ACTIONS(823),
    [anon_sym_bytes16] = ACTIONS(823),
    [anon_sym_bytes17] = ACTIONS(823),
    [anon_sym_bytes18] = ACTIONS(823),
    [anon_sym_bytes19] = ACTIONS(823),
    [anon_sym_bytes20] = ACTIONS(823),
    [anon_sym_bytes21] = ACTIONS(823),
    [anon_sym_bytes22] = ACTIONS(823),
    [anon_sym_bytes23] = ACTIONS(823),
    [anon_sym_bytes24] = ACTIONS(823),
    [anon_sym_bytes25] = ACTIONS(823),
    [anon_sym_bytes26] = ACTIONS(823),
    [anon_sym_bytes27] = ACTIONS(823),
    [anon_sym_bytes28] = ACTIONS(823),
    [anon_sym_bytes29] = ACTIONS(823),
    [anon_sym_bytes30] = ACTIONS(823),
    [anon_sym_bytes31] = ACTIONS(823),
    [anon_sym_bytes32] = ACTIONS(823),
    [anon_sym_fixed] = ACTIONS(823),
    [aux_sym__fixed_token1] = ACTIONS(823),
    [anon_sym_ufixed] = ACTIONS(823),
    [aux_sym__ufixed_token1] = ACTIONS(823),
    [sym_comment] = ACTIONS(3),
  },
  [254] = {
    [sym_identifier] = ACTIONS(801),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_type] = ACTIONS(801),
    [anon_sym_error] = ACTIONS(801),
    [anon_sym_struct] = ACTIONS(801),
    [anon_sym_enum] = ACTIONS(801),
    [anon_sym_event] = ACTIONS(801),
    [anon_sym_using] = ACTIONS(801),
    [anon_sym_function] = ACTIONS(801),
    [anon_sym_byte] = ACTIONS(801),
    [anon_sym_address] = ACTIONS(801),
    [anon_sym_var] = ACTIONS(801),
    [anon_sym_modifier] = ACTIONS(801),
    [anon_sym_constructor] = ACTIONS(801),
    [anon_sym_fallback] = ACTIONS(801),
    [anon_sym_receive] = ACTIONS(801),
    [anon_sym_mapping] = ACTIONS(801),
    [anon_sym_bool] = ACTIONS(801),
    [anon_sym_string] = ACTIONS(801),
    [anon_sym_int] = ACTIONS(801),
    [anon_sym_int8] = ACTIONS(801),
    [anon_sym_int16] = ACTIONS(801),
    [anon_sym_int24] = ACTIONS(801),
    [anon_sym_int32] = ACTIONS(801),
    [anon_sym_int40] = ACTIONS(801),
    [anon_sym_int48] = ACTIONS(801),
    [anon_sym_int56] = ACTIONS(801),
    [anon_sym_int64] = ACTIONS(801),
    [anon_sym_int72] = ACTIONS(801),
    [anon_sym_int80] = ACTIONS(801),
    [anon_sym_int88] = ACTIONS(801),
    [anon_sym_int96] = ACTIONS(801),
    [anon_sym_int104] = ACTIONS(801),
    [anon_sym_int112] = ACTIONS(801),
    [anon_sym_int120] = ACTIONS(801),
    [anon_sym_int128] = ACTIONS(801),
    [anon_sym_int136] = ACTIONS(801),
    [anon_sym_int144] = ACTIONS(801),
    [anon_sym_int152] = ACTIONS(801),
    [anon_sym_int160] = ACTIONS(801),
    [anon_sym_int168] = ACTIONS(801),
    [anon_sym_int176] = ACTIONS(801),
    [anon_sym_int184] = ACTIONS(801),
    [anon_sym_int192] = ACTIONS(801),
    [anon_sym_int200] = ACTIONS(801),
    [anon_sym_int208] = ACTIONS(801),
    [anon_sym_int216] = ACTIONS(801),
    [anon_sym_int224] = ACTIONS(801),
    [anon_sym_int232] = ACTIONS(801),
    [anon_sym_int240] = ACTIONS(801),
    [anon_sym_int248] = ACTIONS(801),
    [anon_sym_int256] = ACTIONS(801),
    [anon_sym_uint] = ACTIONS(801),
    [anon_sym_uint8] = ACTIONS(801),
    [anon_sym_uint16] = ACTIONS(801),
    [anon_sym_uint24] = ACTIONS(801),
    [anon_sym_uint32] = ACTIONS(801),
    [anon_sym_uint40] = ACTIONS(801),
    [anon_sym_uint48] = ACTIONS(801),
    [anon_sym_uint56] = ACTIONS(801),
    [anon_sym_uint64] = ACTIONS(801),
    [anon_sym_uint72] = ACTIONS(801),
    [anon_sym_uint80] = ACTIONS(801),
    [anon_sym_uint88] = ACTIONS(801),
    [anon_sym_uint96] = ACTIONS(801),
    [anon_sym_uint104] = ACTIONS(801),
    [anon_sym_uint112] = ACTIONS(801),
    [anon_sym_uint120] = ACTIONS(801),
    [anon_sym_uint128] = ACTIONS(801),
    [anon_sym_uint136] = ACTIONS(801),
    [anon_sym_uint144] = ACTIONS(801),
    [anon_sym_uint152] = ACTIONS(801),
    [anon_sym_uint160] = ACTIONS(801),
    [anon_sym_uint168] = ACTIONS(801),
    [anon_sym_uint176] = ACTIONS(801),
    [anon_sym_uint184] = ACTIONS(801),
    [anon_sym_uint192] = ACTIONS(801),
    [anon_sym_uint200] = ACTIONS(801),
    [anon_sym_uint208] = ACTIONS(801),
    [anon_sym_uint216] = ACTIONS(801),
    [anon_sym_uint224] = ACTIONS(801),
    [anon_sym_uint232] = ACTIONS(801),
    [anon_sym_uint240] = ACTIONS(801),
    [anon_sym_uint248] = ACTIONS(801),
    [anon_sym_uint256] = ACTIONS(801),
    [anon_sym_bytes] = ACTIONS(801),
    [anon_sym_bytes1] = ACTIONS(801),
    [anon_sym_bytes2] = ACTIONS(801),
    [anon_sym_bytes3] = ACTIONS(801),
    [anon_sym_bytes4] = ACTIONS(801),
    [anon_sym_bytes5] = ACTIONS(801),
    [anon_sym_bytes6] = ACTIONS(801),
    [anon_sym_bytes7] = ACTIONS(801),
    [anon_sym_bytes8] = ACTIONS(801),
    [anon_sym_bytes9] = ACTIONS(801),
    [anon_sym_bytes10] = ACTIONS(801),
    [anon_sym_bytes11] = ACTIONS(801),
    [anon_sym_bytes12] = ACTIONS(801),
    [anon_sym_bytes13] = ACTIONS(801),
    [anon_sym_bytes14] = ACTIONS(801),
    [anon_sym_bytes15] = ACTIONS(801),
    [anon_sym_bytes16] = ACTIONS(801),
    [anon_sym_bytes17] = ACTIONS(801),
    [anon_sym_bytes18] = ACTIONS(801),
    [anon_sym_bytes19] = ACTIONS(801),
    [anon_sym_bytes20] = ACTIONS(801),
    [anon_sym_bytes21] = ACTIONS(801),
    [anon_sym_bytes22] = ACTIONS(801),
    [anon_sym_bytes23] = ACTIONS(801),
    [anon_sym_bytes24] = ACTIONS(801),
    [anon_sym_bytes25] = ACTIONS(801),
    [anon_sym_bytes26] = ACTIONS(801),
    [anon_sym_bytes27] = ACTIONS(801),
    [anon_sym_bytes28] = ACTIONS(801),
    [anon_sym_bytes29] = ACTIONS(801),
    [anon_sym_bytes30] = ACTIONS(801),
    [anon_sym_bytes31] = ACTIONS(801),
    [anon_sym_bytes32] = ACTIONS(801),
    [anon_sym_fixed] = ACTIONS(801),
    [aux_sym__fixed_token1] = ACTIONS(801),
    [anon_sym_ufixed] = ACTIONS(801),
    [aux_sym__ufixed_token1] = ACTIONS(801),
    [sym_comment] = ACTIONS(3),
  },
  [255] = {
    [sym_identifier] = ACTIONS(781),
    [anon_sym_RBRACE] = ACTIONS(779),
    [anon_sym_type] = ACTIONS(781),
    [anon_sym_error] = ACTIONS(781),
    [anon_sym_struct] = ACTIONS(781),
    [anon_sym_enum] = ACTIONS(781),
    [anon_sym_event] = ACTIONS(781),
    [anon_sym_using] = ACTIONS(781),
    [anon_sym_function] = ACTIONS(781),
    [anon_sym_byte] = ACTIONS(781),
    [anon_sym_address] = ACTIONS(781),
    [anon_sym_var] = ACTIONS(781),
    [anon_sym_modifier] = ACTIONS(781),
    [anon_sym_constructor] = ACTIONS(781),
    [anon_sym_fallback] = ACTIONS(781),
    [anon_sym_receive] = ACTIONS(781),
    [anon_sym_mapping] = ACTIONS(781),
    [anon_sym_bool] = ACTIONS(781),
    [anon_sym_string] = ACTIONS(781),
    [anon_sym_int] = ACTIONS(781),
    [anon_sym_int8] = ACTIONS(781),
    [anon_sym_int16] = ACTIONS(781),
    [anon_sym_int24] = ACTIONS(781),
    [anon_sym_int32] = ACTIONS(781),
    [anon_sym_int40] = ACTIONS(781),
    [anon_sym_int48] = ACTIONS(781),
    [anon_sym_int56] = ACTIONS(781),
    [anon_sym_int64] = ACTIONS(781),
    [anon_sym_int72] = ACTIONS(781),
    [anon_sym_int80] = ACTIONS(781),
    [anon_sym_int88] = ACTIONS(781),
    [anon_sym_int96] = ACTIONS(781),
    [anon_sym_int104] = ACTIONS(781),
    [anon_sym_int112] = ACTIONS(781),
    [anon_sym_int120] = ACTIONS(781),
    [anon_sym_int128] = ACTIONS(781),
    [anon_sym_int136] = ACTIONS(781),
    [anon_sym_int144] = ACTIONS(781),
    [anon_sym_int152] = ACTIONS(781),
    [anon_sym_int160] = ACTIONS(781),
    [anon_sym_int168] = ACTIONS(781),
    [anon_sym_int176] = ACTIONS(781),
    [anon_sym_int184] = ACTIONS(781),
    [anon_sym_int192] = ACTIONS(781),
    [anon_sym_int200] = ACTIONS(781),
    [anon_sym_int208] = ACTIONS(781),
    [anon_sym_int216] = ACTIONS(781),
    [anon_sym_int224] = ACTIONS(781),
    [anon_sym_int232] = ACTIONS(781),
    [anon_sym_int240] = ACTIONS(781),
    [anon_sym_int248] = ACTIONS(781),
    [anon_sym_int256] = ACTIONS(781),
    [anon_sym_uint] = ACTIONS(781),
    [anon_sym_uint8] = ACTIONS(781),
    [anon_sym_uint16] = ACTIONS(781),
    [anon_sym_uint24] = ACTIONS(781),
    [anon_sym_uint32] = ACTIONS(781),
    [anon_sym_uint40] = ACTIONS(781),
    [anon_sym_uint48] = ACTIONS(781),
    [anon_sym_uint56] = ACTIONS(781),
    [anon_sym_uint64] = ACTIONS(781),
    [anon_sym_uint72] = ACTIONS(781),
    [anon_sym_uint80] = ACTIONS(781),
    [anon_sym_uint88] = ACTIONS(781),
    [anon_sym_uint96] = ACTIONS(781),
    [anon_sym_uint104] = ACTIONS(781),
    [anon_sym_uint112] = ACTIONS(781),
    [anon_sym_uint120] = ACTIONS(781),
    [anon_sym_uint128] = ACTIONS(781),
    [anon_sym_uint136] = ACTIONS(781),
    [anon_sym_uint144] = ACTIONS(781),
    [anon_sym_uint152] = ACTIONS(781),
    [anon_sym_uint160] = ACTIONS(781),
    [anon_sym_uint168] = ACTIONS(781),
    [anon_sym_uint176] = ACTIONS(781),
    [anon_sym_uint184] = ACTIONS(781),
    [anon_sym_uint192] = ACTIONS(781),
    [anon_sym_uint200] = ACTIONS(781),
    [anon_sym_uint208] = ACTIONS(781),
    [anon_sym_uint216] = ACTIONS(781),
    [anon_sym_uint224] = ACTIONS(781),
    [anon_sym_uint232] = ACTIONS(781),
    [anon_sym_uint240] = ACTIONS(781),
    [anon_sym_uint248] = ACTIONS(781),
    [anon_sym_uint256] = ACTIONS(781),
    [anon_sym_bytes] = ACTIONS(781),
    [anon_sym_bytes1] = ACTIONS(781),
    [anon_sym_bytes2] = ACTIONS(781),
    [anon_sym_bytes3] = ACTIONS(781),
    [anon_sym_bytes4] = ACTIONS(781),
    [anon_sym_bytes5] = ACTIONS(781),
    [anon_sym_bytes6] = ACTIONS(781),
    [anon_sym_bytes7] = ACTIONS(781),
    [anon_sym_bytes8] = ACTIONS(781),
    [anon_sym_bytes9] = ACTIONS(781),
    [anon_sym_bytes10] = ACTIONS(781),
    [anon_sym_bytes11] = ACTIONS(781),
    [anon_sym_bytes12] = ACTIONS(781),
    [anon_sym_bytes13] = ACTIONS(781),
    [anon_sym_bytes14] = ACTIONS(781),
    [anon_sym_bytes15] = ACTIONS(781),
    [anon_sym_bytes16] = ACTIONS(781),
    [anon_sym_bytes17] = ACTIONS(781),
    [anon_sym_bytes18] = ACTIONS(781),
    [anon_sym_bytes19] = ACTIONS(781),
    [anon_sym_bytes20] = ACTIONS(781),
    [anon_sym_bytes21] = ACTIONS(781),
    [anon_sym_bytes22] = ACTIONS(781),
    [anon_sym_bytes23] = ACTIONS(781),
    [anon_sym_bytes24] = ACTIONS(781),
    [anon_sym_bytes25] = ACTIONS(781),
    [anon_sym_bytes26] = ACTIONS(781),
    [anon_sym_bytes27] = ACTIONS(781),
    [anon_sym_bytes28] = ACTIONS(781),
    [anon_sym_bytes29] = ACTIONS(781),
    [anon_sym_bytes30] = ACTIONS(781),
    [anon_sym_bytes31] = ACTIONS(781),
    [anon_sym_bytes32] = ACTIONS(781),
    [anon_sym_fixed] = ACTIONS(781),
    [aux_sym__fixed_token1] = ACTIONS(781),
    [anon_sym_ufixed] = ACTIONS(781),
    [aux_sym__ufixed_token1] = ACTIONS(781),
    [sym_comment] = ACTIONS(3),
  },
  [256] = {
    [sym_identifier] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(895),
    [anon_sym_type] = ACTIONS(893),
    [anon_sym_error] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(893),
    [anon_sym_enum] = ACTIONS(893),
    [anon_sym_event] = ACTIONS(893),
    [anon_sym_using] = ACTIONS(893),
    [anon_sym_function] = ACTIONS(893),
    [anon_sym_byte] = ACTIONS(893),
    [anon_sym_address] = ACTIONS(893),
    [anon_sym_var] = ACTIONS(893),
    [anon_sym_modifier] = ACTIONS(893),
    [anon_sym_constructor] = ACTIONS(893),
    [anon_sym_fallback] = ACTIONS(893),
    [anon_sym_receive] = ACTIONS(893),
    [anon_sym_mapping] = ACTIONS(893),
    [anon_sym_bool] = ACTIONS(893),
    [anon_sym_string] = ACTIONS(893),
    [anon_sym_int] = ACTIONS(893),
    [anon_sym_int8] = ACTIONS(893),
    [anon_sym_int16] = ACTIONS(893),
    [anon_sym_int24] = ACTIONS(893),
    [anon_sym_int32] = ACTIONS(893),
    [anon_sym_int40] = ACTIONS(893),
    [anon_sym_int48] = ACTIONS(893),
    [anon_sym_int56] = ACTIONS(893),
    [anon_sym_int64] = ACTIONS(893),
    [anon_sym_int72] = ACTIONS(893),
    [anon_sym_int80] = ACTIONS(893),
    [anon_sym_int88] = ACTIONS(893),
    [anon_sym_int96] = ACTIONS(893),
    [anon_sym_int104] = ACTIONS(893),
    [anon_sym_int112] = ACTIONS(893),
    [anon_sym_int120] = ACTIONS(893),
    [anon_sym_int128] = ACTIONS(893),
    [anon_sym_int136] = ACTIONS(893),
    [anon_sym_int144] = ACTIONS(893),
    [anon_sym_int152] = ACTIONS(893),
    [anon_sym_int160] = ACTIONS(893),
    [anon_sym_int168] = ACTIONS(893),
    [anon_sym_int176] = ACTIONS(893),
    [anon_sym_int184] = ACTIONS(893),
    [anon_sym_int192] = ACTIONS(893),
    [anon_sym_int200] = ACTIONS(893),
    [anon_sym_int208] = ACTIONS(893),
    [anon_sym_int216] = ACTIONS(893),
    [anon_sym_int224] = ACTIONS(893),
    [anon_sym_int232] = ACTIONS(893),
    [anon_sym_int240] = ACTIONS(893),
    [anon_sym_int248] = ACTIONS(893),
    [anon_sym_int256] = ACTIONS(893),
    [anon_sym_uint] = ACTIONS(893),
    [anon_sym_uint8] = ACTIONS(893),
    [anon_sym_uint16] = ACTIONS(893),
    [anon_sym_uint24] = ACTIONS(893),
    [anon_sym_uint32] = ACTIONS(893),
    [anon_sym_uint40] = ACTIONS(893),
    [anon_sym_uint48] = ACTIONS(893),
    [anon_sym_uint56] = ACTIONS(893),
    [anon_sym_uint64] = ACTIONS(893),
    [anon_sym_uint72] = ACTIONS(893),
    [anon_sym_uint80] = ACTIONS(893),
    [anon_sym_uint88] = ACTIONS(893),
    [anon_sym_uint96] = ACTIONS(893),
    [anon_sym_uint104] = ACTIONS(893),
    [anon_sym_uint112] = ACTIONS(893),
    [anon_sym_uint120] = ACTIONS(893),
    [anon_sym_uint128] = ACTIONS(893),
    [anon_sym_uint136] = ACTIONS(893),
    [anon_sym_uint144] = ACTIONS(893),
    [anon_sym_uint152] = ACTIONS(893),
    [anon_sym_uint160] = ACTIONS(893),
    [anon_sym_uint168] = ACTIONS(893),
    [anon_sym_uint176] = ACTIONS(893),
    [anon_sym_uint184] = ACTIONS(893),
    [anon_sym_uint192] = ACTIONS(893),
    [anon_sym_uint200] = ACTIONS(893),
    [anon_sym_uint208] = ACTIONS(893),
    [anon_sym_uint216] = ACTIONS(893),
    [anon_sym_uint224] = ACTIONS(893),
    [anon_sym_uint232] = ACTIONS(893),
    [anon_sym_uint240] = ACTIONS(893),
    [anon_sym_uint248] = ACTIONS(893),
    [anon_sym_uint256] = ACTIONS(893),
    [anon_sym_bytes] = ACTIONS(893),
    [anon_sym_bytes1] = ACTIONS(893),
    [anon_sym_bytes2] = ACTIONS(893),
    [anon_sym_bytes3] = ACTIONS(893),
    [anon_sym_bytes4] = ACTIONS(893),
    [anon_sym_bytes5] = ACTIONS(893),
    [anon_sym_bytes6] = ACTIONS(893),
    [anon_sym_bytes7] = ACTIONS(893),
    [anon_sym_bytes8] = ACTIONS(893),
    [anon_sym_bytes9] = ACTIONS(893),
    [anon_sym_bytes10] = ACTIONS(893),
    [anon_sym_bytes11] = ACTIONS(893),
    [anon_sym_bytes12] = ACTIONS(893),
    [anon_sym_bytes13] = ACTIONS(893),
    [anon_sym_bytes14] = ACTIONS(893),
    [anon_sym_bytes15] = ACTIONS(893),
    [anon_sym_bytes16] = ACTIONS(893),
    [anon_sym_bytes17] = ACTIONS(893),
    [anon_sym_bytes18] = ACTIONS(893),
    [anon_sym_bytes19] = ACTIONS(893),
    [anon_sym_bytes20] = ACTIONS(893),
    [anon_sym_bytes21] = ACTIONS(893),
    [anon_sym_bytes22] = ACTIONS(893),
    [anon_sym_bytes23] = ACTIONS(893),
    [anon_sym_bytes24] = ACTIONS(893),
    [anon_sym_bytes25] = ACTIONS(893),
    [anon_sym_bytes26] = ACTIONS(893),
    [anon_sym_bytes27] = ACTIONS(893),
    [anon_sym_bytes28] = ACTIONS(893),
    [anon_sym_bytes29] = ACTIONS(893),
    [anon_sym_bytes30] = ACTIONS(893),
    [anon_sym_bytes31] = ACTIONS(893),
    [anon_sym_bytes32] = ACTIONS(893),
    [anon_sym_fixed] = ACTIONS(893),
    [aux_sym__fixed_token1] = ACTIONS(893),
    [anon_sym_ufixed] = ACTIONS(893),
    [aux_sym__ufixed_token1] = ACTIONS(893),
    [sym_comment] = ACTIONS(3),
  },
  [257] = {
    [sym_identifier] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(899),
    [anon_sym_type] = ACTIONS(897),
    [anon_sym_error] = ACTIONS(897),
    [anon_sym_struct] = ACTIONS(897),
    [anon_sym_enum] = ACTIONS(897),
    [anon_sym_event] = ACTIONS(897),
    [anon_sym_using] = ACTIONS(897),
    [anon_sym_function] = ACTIONS(897),
    [anon_sym_byte] = ACTIONS(897),
    [anon_sym_address] = ACTIONS(897),
    [anon_sym_var] = ACTIONS(897),
    [anon_sym_modifier] = ACTIONS(897),
    [anon_sym_constructor] = ACTIONS(897),
    [anon_sym_fallback] = ACTIONS(897),
    [anon_sym_receive] = ACTIONS(897),
    [anon_sym_mapping] = ACTIONS(897),
    [anon_sym_bool] = ACTIONS(897),
    [anon_sym_string] = ACTIONS(897),
    [anon_sym_int] = ACTIONS(897),
    [anon_sym_int8] = ACTIONS(897),
    [anon_sym_int16] = ACTIONS(897),
    [anon_sym_int24] = ACTIONS(897),
    [anon_sym_int32] = ACTIONS(897),
    [anon_sym_int40] = ACTIONS(897),
    [anon_sym_int48] = ACTIONS(897),
    [anon_sym_int56] = ACTIONS(897),
    [anon_sym_int64] = ACTIONS(897),
    [anon_sym_int72] = ACTIONS(897),
    [anon_sym_int80] = ACTIONS(897),
    [anon_sym_int88] = ACTIONS(897),
    [anon_sym_int96] = ACTIONS(897),
    [anon_sym_int104] = ACTIONS(897),
    [anon_sym_int112] = ACTIONS(897),
    [anon_sym_int120] = ACTIONS(897),
    [anon_sym_int128] = ACTIONS(897),
    [anon_sym_int136] = ACTIONS(897),
    [anon_sym_int144] = ACTIONS(897),
    [anon_sym_int152] = ACTIONS(897),
    [anon_sym_int160] = ACTIONS(897),
    [anon_sym_int168] = ACTIONS(897),
    [anon_sym_int176] = ACTIONS(897),
    [anon_sym_int184] = ACTIONS(897),
    [anon_sym_int192] = ACTIONS(897),
    [anon_sym_int200] = ACTIONS(897),
    [anon_sym_int208] = ACTIONS(897),
    [anon_sym_int216] = ACTIONS(897),
    [anon_sym_int224] = ACTIONS(897),
    [anon_sym_int232] = ACTIONS(897),
    [anon_sym_int240] = ACTIONS(897),
    [anon_sym_int248] = ACTIONS(897),
    [anon_sym_int256] = ACTIONS(897),
    [anon_sym_uint] = ACTIONS(897),
    [anon_sym_uint8] = ACTIONS(897),
    [anon_sym_uint16] = ACTIONS(897),
    [anon_sym_uint24] = ACTIONS(897),
    [anon_sym_uint32] = ACTIONS(897),
    [anon_sym_uint40] = ACTIONS(897),
    [anon_sym_uint48] = ACTIONS(897),
    [anon_sym_uint56] = ACTIONS(897),
    [anon_sym_uint64] = ACTIONS(897),
    [anon_sym_uint72] = ACTIONS(897),
    [anon_sym_uint80] = ACTIONS(897),
    [anon_sym_uint88] = ACTIONS(897),
    [anon_sym_uint96] = ACTIONS(897),
    [anon_sym_uint104] = ACTIONS(897),
    [anon_sym_uint112] = ACTIONS(897),
    [anon_sym_uint120] = ACTIONS(897),
    [anon_sym_uint128] = ACTIONS(897),
    [anon_sym_uint136] = ACTIONS(897),
    [anon_sym_uint144] = ACTIONS(897),
    [anon_sym_uint152] = ACTIONS(897),
    [anon_sym_uint160] = ACTIONS(897),
    [anon_sym_uint168] = ACTIONS(897),
    [anon_sym_uint176] = ACTIONS(897),
    [anon_sym_uint184] = ACTIONS(897),
    [anon_sym_uint192] = ACTIONS(897),
    [anon_sym_uint200] = ACTIONS(897),
    [anon_sym_uint208] = ACTIONS(897),
    [anon_sym_uint216] = ACTIONS(897),
    [anon_sym_uint224] = ACTIONS(897),
    [anon_sym_uint232] = ACTIONS(897),
    [anon_sym_uint240] = ACTIONS(897),
    [anon_sym_uint248] = ACTIONS(897),
    [anon_sym_uint256] = ACTIONS(897),
    [anon_sym_bytes] = ACTIONS(897),
    [anon_sym_bytes1] = ACTIONS(897),
    [anon_sym_bytes2] = ACTIONS(897),
    [anon_sym_bytes3] = ACTIONS(897),
    [anon_sym_bytes4] = ACTIONS(897),
    [anon_sym_bytes5] = ACTIONS(897),
    [anon_sym_bytes6] = ACTIONS(897),
    [anon_sym_bytes7] = ACTIONS(897),
    [anon_sym_bytes8] = ACTIONS(897),
    [anon_sym_bytes9] = ACTIONS(897),
    [anon_sym_bytes10] = ACTIONS(897),
    [anon_sym_bytes11] = ACTIONS(897),
    [anon_sym_bytes12] = ACTIONS(897),
    [anon_sym_bytes13] = ACTIONS(897),
    [anon_sym_bytes14] = ACTIONS(897),
    [anon_sym_bytes15] = ACTIONS(897),
    [anon_sym_bytes16] = ACTIONS(897),
    [anon_sym_bytes17] = ACTIONS(897),
    [anon_sym_bytes18] = ACTIONS(897),
    [anon_sym_bytes19] = ACTIONS(897),
    [anon_sym_bytes20] = ACTIONS(897),
    [anon_sym_bytes21] = ACTIONS(897),
    [anon_sym_bytes22] = ACTIONS(897),
    [anon_sym_bytes23] = ACTIONS(897),
    [anon_sym_bytes24] = ACTIONS(897),
    [anon_sym_bytes25] = ACTIONS(897),
    [anon_sym_bytes26] = ACTIONS(897),
    [anon_sym_bytes27] = ACTIONS(897),
    [anon_sym_bytes28] = ACTIONS(897),
    [anon_sym_bytes29] = ACTIONS(897),
    [anon_sym_bytes30] = ACTIONS(897),
    [anon_sym_bytes31] = ACTIONS(897),
    [anon_sym_bytes32] = ACTIONS(897),
    [anon_sym_fixed] = ACTIONS(897),
    [aux_sym__fixed_token1] = ACTIONS(897),
    [anon_sym_ufixed] = ACTIONS(897),
    [aux_sym__ufixed_token1] = ACTIONS(897),
    [sym_comment] = ACTIONS(3),
  },
  [258] = {
    [sym_identifier] = ACTIONS(745),
    [anon_sym_RBRACE] = ACTIONS(743),
    [anon_sym_type] = ACTIONS(745),
    [anon_sym_error] = ACTIONS(745),
    [anon_sym_struct] = ACTIONS(745),
    [anon_sym_enum] = ACTIONS(745),
    [anon_sym_event] = ACTIONS(745),
    [anon_sym_using] = ACTIONS(745),
    [anon_sym_function] = ACTIONS(745),
    [anon_sym_byte] = ACTIONS(745),
    [anon_sym_address] = ACTIONS(745),
    [anon_sym_var] = ACTIONS(745),
    [anon_sym_modifier] = ACTIONS(745),
    [anon_sym_constructor] = ACTIONS(745),
    [anon_sym_fallback] = ACTIONS(745),
    [anon_sym_receive] = ACTIONS(745),
    [anon_sym_mapping] = ACTIONS(745),
    [anon_sym_bool] = ACTIONS(745),
    [anon_sym_string] = ACTIONS(745),
    [anon_sym_int] = ACTIONS(745),
    [anon_sym_int8] = ACTIONS(745),
    [anon_sym_int16] = ACTIONS(745),
    [anon_sym_int24] = ACTIONS(745),
    [anon_sym_int32] = ACTIONS(745),
    [anon_sym_int40] = ACTIONS(745),
    [anon_sym_int48] = ACTIONS(745),
    [anon_sym_int56] = ACTIONS(745),
    [anon_sym_int64] = ACTIONS(745),
    [anon_sym_int72] = ACTIONS(745),
    [anon_sym_int80] = ACTIONS(745),
    [anon_sym_int88] = ACTIONS(745),
    [anon_sym_int96] = ACTIONS(745),
    [anon_sym_int104] = ACTIONS(745),
    [anon_sym_int112] = ACTIONS(745),
    [anon_sym_int120] = ACTIONS(745),
    [anon_sym_int128] = ACTIONS(745),
    [anon_sym_int136] = ACTIONS(745),
    [anon_sym_int144] = ACTIONS(745),
    [anon_sym_int152] = ACTIONS(745),
    [anon_sym_int160] = ACTIONS(745),
    [anon_sym_int168] = ACTIONS(745),
    [anon_sym_int176] = ACTIONS(745),
    [anon_sym_int184] = ACTIONS(745),
    [anon_sym_int192] = ACTIONS(745),
    [anon_sym_int200] = ACTIONS(745),
    [anon_sym_int208] = ACTIONS(745),
    [anon_sym_int216] = ACTIONS(745),
    [anon_sym_int224] = ACTIONS(745),
    [anon_sym_int232] = ACTIONS(745),
    [anon_sym_int240] = ACTIONS(745),
    [anon_sym_int248] = ACTIONS(745),
    [anon_sym_int256] = ACTIONS(745),
    [anon_sym_uint] = ACTIONS(745),
    [anon_sym_uint8] = ACTIONS(745),
    [anon_sym_uint16] = ACTIONS(745),
    [anon_sym_uint24] = ACTIONS(745),
    [anon_sym_uint32] = ACTIONS(745),
    [anon_sym_uint40] = ACTIONS(745),
    [anon_sym_uint48] = ACTIONS(745),
    [anon_sym_uint56] = ACTIONS(745),
    [anon_sym_uint64] = ACTIONS(745),
    [anon_sym_uint72] = ACTIONS(745),
    [anon_sym_uint80] = ACTIONS(745),
    [anon_sym_uint88] = ACTIONS(745),
    [anon_sym_uint96] = ACTIONS(745),
    [anon_sym_uint104] = ACTIONS(745),
    [anon_sym_uint112] = ACTIONS(745),
    [anon_sym_uint120] = ACTIONS(745),
    [anon_sym_uint128] = ACTIONS(745),
    [anon_sym_uint136] = ACTIONS(745),
    [anon_sym_uint144] = ACTIONS(745),
    [anon_sym_uint152] = ACTIONS(745),
    [anon_sym_uint160] = ACTIONS(745),
    [anon_sym_uint168] = ACTIONS(745),
    [anon_sym_uint176] = ACTIONS(745),
    [anon_sym_uint184] = ACTIONS(745),
    [anon_sym_uint192] = ACTIONS(745),
    [anon_sym_uint200] = ACTIONS(745),
    [anon_sym_uint208] = ACTIONS(745),
    [anon_sym_uint216] = ACTIONS(745),
    [anon_sym_uint224] = ACTIONS(745),
    [anon_sym_uint232] = ACTIONS(745),
    [anon_sym_uint240] = ACTIONS(745),
    [anon_sym_uint248] = ACTIONS(745),
    [anon_sym_uint256] = ACTIONS(745),
    [anon_sym_bytes] = ACTIONS(745),
    [anon_sym_bytes1] = ACTIONS(745),
    [anon_sym_bytes2] = ACTIONS(745),
    [anon_sym_bytes3] = ACTIONS(745),
    [anon_sym_bytes4] = ACTIONS(745),
    [anon_sym_bytes5] = ACTIONS(745),
    [anon_sym_bytes6] = ACTIONS(745),
    [anon_sym_bytes7] = ACTIONS(745),
    [anon_sym_bytes8] = ACTIONS(745),
    [anon_sym_bytes9] = ACTIONS(745),
    [anon_sym_bytes10] = ACTIONS(745),
    [anon_sym_bytes11] = ACTIONS(745),
    [anon_sym_bytes12] = ACTIONS(745),
    [anon_sym_bytes13] = ACTIONS(745),
    [anon_sym_bytes14] = ACTIONS(745),
    [anon_sym_bytes15] = ACTIONS(745),
    [anon_sym_bytes16] = ACTIONS(745),
    [anon_sym_bytes17] = ACTIONS(745),
    [anon_sym_bytes18] = ACTIONS(745),
    [anon_sym_bytes19] = ACTIONS(745),
    [anon_sym_bytes20] = ACTIONS(745),
    [anon_sym_bytes21] = ACTIONS(745),
    [anon_sym_bytes22] = ACTIONS(745),
    [anon_sym_bytes23] = ACTIONS(745),
    [anon_sym_bytes24] = ACTIONS(745),
    [anon_sym_bytes25] = ACTIONS(745),
    [anon_sym_bytes26] = ACTIONS(745),
    [anon_sym_bytes27] = ACTIONS(745),
    [anon_sym_bytes28] = ACTIONS(745),
    [anon_sym_bytes29] = ACTIONS(745),
    [anon_sym_bytes30] = ACTIONS(745),
    [anon_sym_bytes31] = ACTIONS(745),
    [anon_sym_bytes32] = ACTIONS(745),
    [anon_sym_fixed] = ACTIONS(745),
    [aux_sym__fixed_token1] = ACTIONS(745),
    [anon_sym_ufixed] = ACTIONS(745),
    [aux_sym__ufixed_token1] = ACTIONS(745),
    [sym_comment] = ACTIONS(3),
  },
  [259] = {
    [sym_identifier] = ACTIONS(649),
    [anon_sym_RBRACE] = ACTIONS(647),
    [anon_sym_type] = ACTIONS(649),
    [anon_sym_error] = ACTIONS(649),
    [anon_sym_struct] = ACTIONS(649),
    [anon_sym_enum] = ACTIONS(649),
    [anon_sym_event] = ACTIONS(649),
    [anon_sym_using] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(649),
    [anon_sym_byte] = ACTIONS(649),
    [anon_sym_address] = ACTIONS(649),
    [anon_sym_var] = ACTIONS(649),
    [anon_sym_modifier] = ACTIONS(649),
    [anon_sym_constructor] = ACTIONS(649),
    [anon_sym_fallback] = ACTIONS(649),
    [anon_sym_receive] = ACTIONS(649),
    [anon_sym_mapping] = ACTIONS(649),
    [anon_sym_bool] = ACTIONS(649),
    [anon_sym_string] = ACTIONS(649),
    [anon_sym_int] = ACTIONS(649),
    [anon_sym_int8] = ACTIONS(649),
    [anon_sym_int16] = ACTIONS(649),
    [anon_sym_int24] = ACTIONS(649),
    [anon_sym_int32] = ACTIONS(649),
    [anon_sym_int40] = ACTIONS(649),
    [anon_sym_int48] = ACTIONS(649),
    [anon_sym_int56] = ACTIONS(649),
    [anon_sym_int64] = ACTIONS(649),
    [anon_sym_int72] = ACTIONS(649),
    [anon_sym_int80] = ACTIONS(649),
    [anon_sym_int88] = ACTIONS(649),
    [anon_sym_int96] = ACTIONS(649),
    [anon_sym_int104] = ACTIONS(649),
    [anon_sym_int112] = ACTIONS(649),
    [anon_sym_int120] = ACTIONS(649),
    [anon_sym_int128] = ACTIONS(649),
    [anon_sym_int136] = ACTIONS(649),
    [anon_sym_int144] = ACTIONS(649),
    [anon_sym_int152] = ACTIONS(649),
    [anon_sym_int160] = ACTIONS(649),
    [anon_sym_int168] = ACTIONS(649),
    [anon_sym_int176] = ACTIONS(649),
    [anon_sym_int184] = ACTIONS(649),
    [anon_sym_int192] = ACTIONS(649),
    [anon_sym_int200] = ACTIONS(649),
    [anon_sym_int208] = ACTIONS(649),
    [anon_sym_int216] = ACTIONS(649),
    [anon_sym_int224] = ACTIONS(649),
    [anon_sym_int232] = ACTIONS(649),
    [anon_sym_int240] = ACTIONS(649),
    [anon_sym_int248] = ACTIONS(649),
    [anon_sym_int256] = ACTIONS(649),
    [anon_sym_uint] = ACTIONS(649),
    [anon_sym_uint8] = ACTIONS(649),
    [anon_sym_uint16] = ACTIONS(649),
    [anon_sym_uint24] = ACTIONS(649),
    [anon_sym_uint32] = ACTIONS(649),
    [anon_sym_uint40] = ACTIONS(649),
    [anon_sym_uint48] = ACTIONS(649),
    [anon_sym_uint56] = ACTIONS(649),
    [anon_sym_uint64] = ACTIONS(649),
    [anon_sym_uint72] = ACTIONS(649),
    [anon_sym_uint80] = ACTIONS(649),
    [anon_sym_uint88] = ACTIONS(649),
    [anon_sym_uint96] = ACTIONS(649),
    [anon_sym_uint104] = ACTIONS(649),
    [anon_sym_uint112] = ACTIONS(649),
    [anon_sym_uint120] = ACTIONS(649),
    [anon_sym_uint128] = ACTIONS(649),
    [anon_sym_uint136] = ACTIONS(649),
    [anon_sym_uint144] = ACTIONS(649),
    [anon_sym_uint152] = ACTIONS(649),
    [anon_sym_uint160] = ACTIONS(649),
    [anon_sym_uint168] = ACTIONS(649),
    [anon_sym_uint176] = ACTIONS(649),
    [anon_sym_uint184] = ACTIONS(649),
    [anon_sym_uint192] = ACTIONS(649),
    [anon_sym_uint200] = ACTIONS(649),
    [anon_sym_uint208] = ACTIONS(649),
    [anon_sym_uint216] = ACTIONS(649),
    [anon_sym_uint224] = ACTIONS(649),
    [anon_sym_uint232] = ACTIONS(649),
    [anon_sym_uint240] = ACTIONS(649),
    [anon_sym_uint248] = ACTIONS(649),
    [anon_sym_uint256] = ACTIONS(649),
    [anon_sym_bytes] = ACTIONS(649),
    [anon_sym_bytes1] = ACTIONS(649),
    [anon_sym_bytes2] = ACTIONS(649),
    [anon_sym_bytes3] = ACTIONS(649),
    [anon_sym_bytes4] = ACTIONS(649),
    [anon_sym_bytes5] = ACTIONS(649),
    [anon_sym_bytes6] = ACTIONS(649),
    [anon_sym_bytes7] = ACTIONS(649),
    [anon_sym_bytes8] = ACTIONS(649),
    [anon_sym_bytes9] = ACTIONS(649),
    [anon_sym_bytes10] = ACTIONS(649),
    [anon_sym_bytes11] = ACTIONS(649),
    [anon_sym_bytes12] = ACTIONS(649),
    [anon_sym_bytes13] = ACTIONS(649),
    [anon_sym_bytes14] = ACTIONS(649),
    [anon_sym_bytes15] = ACTIONS(649),
    [anon_sym_bytes16] = ACTIONS(649),
    [anon_sym_bytes17] = ACTIONS(649),
    [anon_sym_bytes18] = ACTIONS(649),
    [anon_sym_bytes19] = ACTIONS(649),
    [anon_sym_bytes20] = ACTIONS(649),
    [anon_sym_bytes21] = ACTIONS(649),
    [anon_sym_bytes22] = ACTIONS(649),
    [anon_sym_bytes23] = ACTIONS(649),
    [anon_sym_bytes24] = ACTIONS(649),
    [anon_sym_bytes25] = ACTIONS(649),
    [anon_sym_bytes26] = ACTIONS(649),
    [anon_sym_bytes27] = ACTIONS(649),
    [anon_sym_bytes28] = ACTIONS(649),
    [anon_sym_bytes29] = ACTIONS(649),
    [anon_sym_bytes30] = ACTIONS(649),
    [anon_sym_bytes31] = ACTIONS(649),
    [anon_sym_bytes32] = ACTIONS(649),
    [anon_sym_fixed] = ACTIONS(649),
    [aux_sym__fixed_token1] = ACTIONS(649),
    [anon_sym_ufixed] = ACTIONS(649),
    [aux_sym__ufixed_token1] = ACTIONS(649),
    [sym_comment] = ACTIONS(3),
  },
  [260] = {
    [sym_identifier] = ACTIONS(801),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_type] = ACTIONS(801),
    [anon_sym_error] = ACTIONS(801),
    [anon_sym_struct] = ACTIONS(801),
    [anon_sym_enum] = ACTIONS(801),
    [anon_sym_event] = ACTIONS(801),
    [anon_sym_using] = ACTIONS(801),
    [anon_sym_function] = ACTIONS(801),
    [anon_sym_byte] = ACTIONS(801),
    [anon_sym_address] = ACTIONS(801),
    [anon_sym_var] = ACTIONS(801),
    [anon_sym_modifier] = ACTIONS(801),
    [anon_sym_constructor] = ACTIONS(801),
    [anon_sym_fallback] = ACTIONS(801),
    [anon_sym_receive] = ACTIONS(801),
    [anon_sym_mapping] = ACTIONS(801),
    [anon_sym_bool] = ACTIONS(801),
    [anon_sym_string] = ACTIONS(801),
    [anon_sym_int] = ACTIONS(801),
    [anon_sym_int8] = ACTIONS(801),
    [anon_sym_int16] = ACTIONS(801),
    [anon_sym_int24] = ACTIONS(801),
    [anon_sym_int32] = ACTIONS(801),
    [anon_sym_int40] = ACTIONS(801),
    [anon_sym_int48] = ACTIONS(801),
    [anon_sym_int56] = ACTIONS(801),
    [anon_sym_int64] = ACTIONS(801),
    [anon_sym_int72] = ACTIONS(801),
    [anon_sym_int80] = ACTIONS(801),
    [anon_sym_int88] = ACTIONS(801),
    [anon_sym_int96] = ACTIONS(801),
    [anon_sym_int104] = ACTIONS(801),
    [anon_sym_int112] = ACTIONS(801),
    [anon_sym_int120] = ACTIONS(801),
    [anon_sym_int128] = ACTIONS(801),
    [anon_sym_int136] = ACTIONS(801),
    [anon_sym_int144] = ACTIONS(801),
    [anon_sym_int152] = ACTIONS(801),
    [anon_sym_int160] = ACTIONS(801),
    [anon_sym_int168] = ACTIONS(801),
    [anon_sym_int176] = ACTIONS(801),
    [anon_sym_int184] = ACTIONS(801),
    [anon_sym_int192] = ACTIONS(801),
    [anon_sym_int200] = ACTIONS(801),
    [anon_sym_int208] = ACTIONS(801),
    [anon_sym_int216] = ACTIONS(801),
    [anon_sym_int224] = ACTIONS(801),
    [anon_sym_int232] = ACTIONS(801),
    [anon_sym_int240] = ACTIONS(801),
    [anon_sym_int248] = ACTIONS(801),
    [anon_sym_int256] = ACTIONS(801),
    [anon_sym_uint] = ACTIONS(801),
    [anon_sym_uint8] = ACTIONS(801),
    [anon_sym_uint16] = ACTIONS(801),
    [anon_sym_uint24] = ACTIONS(801),
    [anon_sym_uint32] = ACTIONS(801),
    [anon_sym_uint40] = ACTIONS(801),
    [anon_sym_uint48] = ACTIONS(801),
    [anon_sym_uint56] = ACTIONS(801),
    [anon_sym_uint64] = ACTIONS(801),
    [anon_sym_uint72] = ACTIONS(801),
    [anon_sym_uint80] = ACTIONS(801),
    [anon_sym_uint88] = ACTIONS(801),
    [anon_sym_uint96] = ACTIONS(801),
    [anon_sym_uint104] = ACTIONS(801),
    [anon_sym_uint112] = ACTIONS(801),
    [anon_sym_uint120] = ACTIONS(801),
    [anon_sym_uint128] = ACTIONS(801),
    [anon_sym_uint136] = ACTIONS(801),
    [anon_sym_uint144] = ACTIONS(801),
    [anon_sym_uint152] = ACTIONS(801),
    [anon_sym_uint160] = ACTIONS(801),
    [anon_sym_uint168] = ACTIONS(801),
    [anon_sym_uint176] = ACTIONS(801),
    [anon_sym_uint184] = ACTIONS(801),
    [anon_sym_uint192] = ACTIONS(801),
    [anon_sym_uint200] = ACTIONS(801),
    [anon_sym_uint208] = ACTIONS(801),
    [anon_sym_uint216] = ACTIONS(801),
    [anon_sym_uint224] = ACTIONS(801),
    [anon_sym_uint232] = ACTIONS(801),
    [anon_sym_uint240] = ACTIONS(801),
    [anon_sym_uint248] = ACTIONS(801),
    [anon_sym_uint256] = ACTIONS(801),
    [anon_sym_bytes] = ACTIONS(801),
    [anon_sym_bytes1] = ACTIONS(801),
    [anon_sym_bytes2] = ACTIONS(801),
    [anon_sym_bytes3] = ACTIONS(801),
    [anon_sym_bytes4] = ACTIONS(801),
    [anon_sym_bytes5] = ACTIONS(801),
    [anon_sym_bytes6] = ACTIONS(801),
    [anon_sym_bytes7] = ACTIONS(801),
    [anon_sym_bytes8] = ACTIONS(801),
    [anon_sym_bytes9] = ACTIONS(801),
    [anon_sym_bytes10] = ACTIONS(801),
    [anon_sym_bytes11] = ACTIONS(801),
    [anon_sym_bytes12] = ACTIONS(801),
    [anon_sym_bytes13] = ACTIONS(801),
    [anon_sym_bytes14] = ACTIONS(801),
    [anon_sym_bytes15] = ACTIONS(801),
    [anon_sym_bytes16] = ACTIONS(801),
    [anon_sym_bytes17] = ACTIONS(801),
    [anon_sym_bytes18] = ACTIONS(801),
    [anon_sym_bytes19] = ACTIONS(801),
    [anon_sym_bytes20] = ACTIONS(801),
    [anon_sym_bytes21] = ACTIONS(801),
    [anon_sym_bytes22] = ACTIONS(801),
    [anon_sym_bytes23] = ACTIONS(801),
    [anon_sym_bytes24] = ACTIONS(801),
    [anon_sym_bytes25] = ACTIONS(801),
    [anon_sym_bytes26] = ACTIONS(801),
    [anon_sym_bytes27] = ACTIONS(801),
    [anon_sym_bytes28] = ACTIONS(801),
    [anon_sym_bytes29] = ACTIONS(801),
    [anon_sym_bytes30] = ACTIONS(801),
    [anon_sym_bytes31] = ACTIONS(801),
    [anon_sym_bytes32] = ACTIONS(801),
    [anon_sym_fixed] = ACTIONS(801),
    [aux_sym__fixed_token1] = ACTIONS(801),
    [anon_sym_ufixed] = ACTIONS(801),
    [aux_sym__ufixed_token1] = ACTIONS(801),
    [sym_comment] = ACTIONS(3),
  },
  [261] = {
    [sym_identifier] = ACTIONS(693),
    [anon_sym_RBRACE] = ACTIONS(691),
    [anon_sym_type] = ACTIONS(693),
    [anon_sym_error] = ACTIONS(693),
    [anon_sym_struct] = ACTIONS(693),
    [anon_sym_enum] = ACTIONS(693),
    [anon_sym_event] = ACTIONS(693),
    [anon_sym_using] = ACTIONS(693),
    [anon_sym_function] = ACTIONS(693),
    [anon_sym_byte] = ACTIONS(693),
    [anon_sym_address] = ACTIONS(693),
    [anon_sym_var] = ACTIONS(693),
    [anon_sym_modifier] = ACTIONS(693),
    [anon_sym_constructor] = ACTIONS(693),
    [anon_sym_fallback] = ACTIONS(693),
    [anon_sym_receive] = ACTIONS(693),
    [anon_sym_mapping] = ACTIONS(693),
    [anon_sym_bool] = ACTIONS(693),
    [anon_sym_string] = ACTIONS(693),
    [anon_sym_int] = ACTIONS(693),
    [anon_sym_int8] = ACTIONS(693),
    [anon_sym_int16] = ACTIONS(693),
    [anon_sym_int24] = ACTIONS(693),
    [anon_sym_int32] = ACTIONS(693),
    [anon_sym_int40] = ACTIONS(693),
    [anon_sym_int48] = ACTIONS(693),
    [anon_sym_int56] = ACTIONS(693),
    [anon_sym_int64] = ACTIONS(693),
    [anon_sym_int72] = ACTIONS(693),
    [anon_sym_int80] = ACTIONS(693),
    [anon_sym_int88] = ACTIONS(693),
    [anon_sym_int96] = ACTIONS(693),
    [anon_sym_int104] = ACTIONS(693),
    [anon_sym_int112] = ACTIONS(693),
    [anon_sym_int120] = ACTIONS(693),
    [anon_sym_int128] = ACTIONS(693),
    [anon_sym_int136] = ACTIONS(693),
    [anon_sym_int144] = ACTIONS(693),
    [anon_sym_int152] = ACTIONS(693),
    [anon_sym_int160] = ACTIONS(693),
    [anon_sym_int168] = ACTIONS(693),
    [anon_sym_int176] = ACTIONS(693),
    [anon_sym_int184] = ACTIONS(693),
    [anon_sym_int192] = ACTIONS(693),
    [anon_sym_int200] = ACTIONS(693),
    [anon_sym_int208] = ACTIONS(693),
    [anon_sym_int216] = ACTIONS(693),
    [anon_sym_int224] = ACTIONS(693),
    [anon_sym_int232] = ACTIONS(693),
    [anon_sym_int240] = ACTIONS(693),
    [anon_sym_int248] = ACTIONS(693),
    [anon_sym_int256] = ACTIONS(693),
    [anon_sym_uint] = ACTIONS(693),
    [anon_sym_uint8] = ACTIONS(693),
    [anon_sym_uint16] = ACTIONS(693),
    [anon_sym_uint24] = ACTIONS(693),
    [anon_sym_uint32] = ACTIONS(693),
    [anon_sym_uint40] = ACTIONS(693),
    [anon_sym_uint48] = ACTIONS(693),
    [anon_sym_uint56] = ACTIONS(693),
    [anon_sym_uint64] = ACTIONS(693),
    [anon_sym_uint72] = ACTIONS(693),
    [anon_sym_uint80] = ACTIONS(693),
    [anon_sym_uint88] = ACTIONS(693),
    [anon_sym_uint96] = ACTIONS(693),
    [anon_sym_uint104] = ACTIONS(693),
    [anon_sym_uint112] = ACTIONS(693),
    [anon_sym_uint120] = ACTIONS(693),
    [anon_sym_uint128] = ACTIONS(693),
    [anon_sym_uint136] = ACTIONS(693),
    [anon_sym_uint144] = ACTIONS(693),
    [anon_sym_uint152] = ACTIONS(693),
    [anon_sym_uint160] = ACTIONS(693),
    [anon_sym_uint168] = ACTIONS(693),
    [anon_sym_uint176] = ACTIONS(693),
    [anon_sym_uint184] = ACTIONS(693),
    [anon_sym_uint192] = ACTIONS(693),
    [anon_sym_uint200] = ACTIONS(693),
    [anon_sym_uint208] = ACTIONS(693),
    [anon_sym_uint216] = ACTIONS(693),
    [anon_sym_uint224] = ACTIONS(693),
    [anon_sym_uint232] = ACTIONS(693),
    [anon_sym_uint240] = ACTIONS(693),
    [anon_sym_uint248] = ACTIONS(693),
    [anon_sym_uint256] = ACTIONS(693),
    [anon_sym_bytes] = ACTIONS(693),
    [anon_sym_bytes1] = ACTIONS(693),
    [anon_sym_bytes2] = ACTIONS(693),
    [anon_sym_bytes3] = ACTIONS(693),
    [anon_sym_bytes4] = ACTIONS(693),
    [anon_sym_bytes5] = ACTIONS(693),
    [anon_sym_bytes6] = ACTIONS(693),
    [anon_sym_bytes7] = ACTIONS(693),
    [anon_sym_bytes8] = ACTIONS(693),
    [anon_sym_bytes9] = ACTIONS(693),
    [anon_sym_bytes10] = ACTIONS(693),
    [anon_sym_bytes11] = ACTIONS(693),
    [anon_sym_bytes12] = ACTIONS(693),
    [anon_sym_bytes13] = ACTIONS(693),
    [anon_sym_bytes14] = ACTIONS(693),
    [anon_sym_bytes15] = ACTIONS(693),
    [anon_sym_bytes16] = ACTIONS(693),
    [anon_sym_bytes17] = ACTIONS(693),
    [anon_sym_bytes18] = ACTIONS(693),
    [anon_sym_bytes19] = ACTIONS(693),
    [anon_sym_bytes20] = ACTIONS(693),
    [anon_sym_bytes21] = ACTIONS(693),
    [anon_sym_bytes22] = ACTIONS(693),
    [anon_sym_bytes23] = ACTIONS(693),
    [anon_sym_bytes24] = ACTIONS(693),
    [anon_sym_bytes25] = ACTIONS(693),
    [anon_sym_bytes26] = ACTIONS(693),
    [anon_sym_bytes27] = ACTIONS(693),
    [anon_sym_bytes28] = ACTIONS(693),
    [anon_sym_bytes29] = ACTIONS(693),
    [anon_sym_bytes30] = ACTIONS(693),
    [anon_sym_bytes31] = ACTIONS(693),
    [anon_sym_bytes32] = ACTIONS(693),
    [anon_sym_fixed] = ACTIONS(693),
    [aux_sym__fixed_token1] = ACTIONS(693),
    [anon_sym_ufixed] = ACTIONS(693),
    [aux_sym__ufixed_token1] = ACTIONS(693),
    [sym_comment] = ACTIONS(3),
  },
  [262] = {
    [sym_identifier] = ACTIONS(729),
    [anon_sym_RBRACE] = ACTIONS(727),
    [anon_sym_type] = ACTIONS(729),
    [anon_sym_error] = ACTIONS(729),
    [anon_sym_struct] = ACTIONS(729),
    [anon_sym_enum] = ACTIONS(729),
    [anon_sym_event] = ACTIONS(729),
    [anon_sym_using] = ACTIONS(729),
    [anon_sym_function] = ACTIONS(729),
    [anon_sym_byte] = ACTIONS(729),
    [anon_sym_address] = ACTIONS(729),
    [anon_sym_var] = ACTIONS(729),
    [anon_sym_modifier] = ACTIONS(729),
    [anon_sym_constructor] = ACTIONS(729),
    [anon_sym_fallback] = ACTIONS(729),
    [anon_sym_receive] = ACTIONS(729),
    [anon_sym_mapping] = ACTIONS(729),
    [anon_sym_bool] = ACTIONS(729),
    [anon_sym_string] = ACTIONS(729),
    [anon_sym_int] = ACTIONS(729),
    [anon_sym_int8] = ACTIONS(729),
    [anon_sym_int16] = ACTIONS(729),
    [anon_sym_int24] = ACTIONS(729),
    [anon_sym_int32] = ACTIONS(729),
    [anon_sym_int40] = ACTIONS(729),
    [anon_sym_int48] = ACTIONS(729),
    [anon_sym_int56] = ACTIONS(729),
    [anon_sym_int64] = ACTIONS(729),
    [anon_sym_int72] = ACTIONS(729),
    [anon_sym_int80] = ACTIONS(729),
    [anon_sym_int88] = ACTIONS(729),
    [anon_sym_int96] = ACTIONS(729),
    [anon_sym_int104] = ACTIONS(729),
    [anon_sym_int112] = ACTIONS(729),
    [anon_sym_int120] = ACTIONS(729),
    [anon_sym_int128] = ACTIONS(729),
    [anon_sym_int136] = ACTIONS(729),
    [anon_sym_int144] = ACTIONS(729),
    [anon_sym_int152] = ACTIONS(729),
    [anon_sym_int160] = ACTIONS(729),
    [anon_sym_int168] = ACTIONS(729),
    [anon_sym_int176] = ACTIONS(729),
    [anon_sym_int184] = ACTIONS(729),
    [anon_sym_int192] = ACTIONS(729),
    [anon_sym_int200] = ACTIONS(729),
    [anon_sym_int208] = ACTIONS(729),
    [anon_sym_int216] = ACTIONS(729),
    [anon_sym_int224] = ACTIONS(729),
    [anon_sym_int232] = ACTIONS(729),
    [anon_sym_int240] = ACTIONS(729),
    [anon_sym_int248] = ACTIONS(729),
    [anon_sym_int256] = ACTIONS(729),
    [anon_sym_uint] = ACTIONS(729),
    [anon_sym_uint8] = ACTIONS(729),
    [anon_sym_uint16] = ACTIONS(729),
    [anon_sym_uint24] = ACTIONS(729),
    [anon_sym_uint32] = ACTIONS(729),
    [anon_sym_uint40] = ACTIONS(729),
    [anon_sym_uint48] = ACTIONS(729),
    [anon_sym_uint56] = ACTIONS(729),
    [anon_sym_uint64] = ACTIONS(729),
    [anon_sym_uint72] = ACTIONS(729),
    [anon_sym_uint80] = ACTIONS(729),
    [anon_sym_uint88] = ACTIONS(729),
    [anon_sym_uint96] = ACTIONS(729),
    [anon_sym_uint104] = ACTIONS(729),
    [anon_sym_uint112] = ACTIONS(729),
    [anon_sym_uint120] = ACTIONS(729),
    [anon_sym_uint128] = ACTIONS(729),
    [anon_sym_uint136] = ACTIONS(729),
    [anon_sym_uint144] = ACTIONS(729),
    [anon_sym_uint152] = ACTIONS(729),
    [anon_sym_uint160] = ACTIONS(729),
    [anon_sym_uint168] = ACTIONS(729),
    [anon_sym_uint176] = ACTIONS(729),
    [anon_sym_uint184] = ACTIONS(729),
    [anon_sym_uint192] = ACTIONS(729),
    [anon_sym_uint200] = ACTIONS(729),
    [anon_sym_uint208] = ACTIONS(729),
    [anon_sym_uint216] = ACTIONS(729),
    [anon_sym_uint224] = ACTIONS(729),
    [anon_sym_uint232] = ACTIONS(729),
    [anon_sym_uint240] = ACTIONS(729),
    [anon_sym_uint248] = ACTIONS(729),
    [anon_sym_uint256] = ACTIONS(729),
    [anon_sym_bytes] = ACTIONS(729),
    [anon_sym_bytes1] = ACTIONS(729),
    [anon_sym_bytes2] = ACTIONS(729),
    [anon_sym_bytes3] = ACTIONS(729),
    [anon_sym_bytes4] = ACTIONS(729),
    [anon_sym_bytes5] = ACTIONS(729),
    [anon_sym_bytes6] = ACTIONS(729),
    [anon_sym_bytes7] = ACTIONS(729),
    [anon_sym_bytes8] = ACTIONS(729),
    [anon_sym_bytes9] = ACTIONS(729),
    [anon_sym_bytes10] = ACTIONS(729),
    [anon_sym_bytes11] = ACTIONS(729),
    [anon_sym_bytes12] = ACTIONS(729),
    [anon_sym_bytes13] = ACTIONS(729),
    [anon_sym_bytes14] = ACTIONS(729),
    [anon_sym_bytes15] = ACTIONS(729),
    [anon_sym_bytes16] = ACTIONS(729),
    [anon_sym_bytes17] = ACTIONS(729),
    [anon_sym_bytes18] = ACTIONS(729),
    [anon_sym_bytes19] = ACTIONS(729),
    [anon_sym_bytes20] = ACTIONS(729),
    [anon_sym_bytes21] = ACTIONS(729),
    [anon_sym_bytes22] = ACTIONS(729),
    [anon_sym_bytes23] = ACTIONS(729),
    [anon_sym_bytes24] = ACTIONS(729),
    [anon_sym_bytes25] = ACTIONS(729),
    [anon_sym_bytes26] = ACTIONS(729),
    [anon_sym_bytes27] = ACTIONS(729),
    [anon_sym_bytes28] = ACTIONS(729),
    [anon_sym_bytes29] = ACTIONS(729),
    [anon_sym_bytes30] = ACTIONS(729),
    [anon_sym_bytes31] = ACTIONS(729),
    [anon_sym_bytes32] = ACTIONS(729),
    [anon_sym_fixed] = ACTIONS(729),
    [aux_sym__fixed_token1] = ACTIONS(729),
    [anon_sym_ufixed] = ACTIONS(729),
    [aux_sym__ufixed_token1] = ACTIONS(729),
    [sym_comment] = ACTIONS(3),
  },
  [263] = {
    [sym_identifier] = ACTIONS(901),
    [anon_sym_RBRACE] = ACTIONS(903),
    [anon_sym_type] = ACTIONS(901),
    [anon_sym_error] = ACTIONS(901),
    [anon_sym_struct] = ACTIONS(901),
    [anon_sym_enum] = ACTIONS(901),
    [anon_sym_event] = ACTIONS(901),
    [anon_sym_using] = ACTIONS(901),
    [anon_sym_function] = ACTIONS(901),
    [anon_sym_byte] = ACTIONS(901),
    [anon_sym_address] = ACTIONS(901),
    [anon_sym_var] = ACTIONS(901),
    [anon_sym_modifier] = ACTIONS(901),
    [anon_sym_constructor] = ACTIONS(901),
    [anon_sym_fallback] = ACTIONS(901),
    [anon_sym_receive] = ACTIONS(901),
    [anon_sym_mapping] = ACTIONS(901),
    [anon_sym_bool] = ACTIONS(901),
    [anon_sym_string] = ACTIONS(901),
    [anon_sym_int] = ACTIONS(901),
    [anon_sym_int8] = ACTIONS(901),
    [anon_sym_int16] = ACTIONS(901),
    [anon_sym_int24] = ACTIONS(901),
    [anon_sym_int32] = ACTIONS(901),
    [anon_sym_int40] = ACTIONS(901),
    [anon_sym_int48] = ACTIONS(901),
    [anon_sym_int56] = ACTIONS(901),
    [anon_sym_int64] = ACTIONS(901),
    [anon_sym_int72] = ACTIONS(901),
    [anon_sym_int80] = ACTIONS(901),
    [anon_sym_int88] = ACTIONS(901),
    [anon_sym_int96] = ACTIONS(901),
    [anon_sym_int104] = ACTIONS(901),
    [anon_sym_int112] = ACTIONS(901),
    [anon_sym_int120] = ACTIONS(901),
    [anon_sym_int128] = ACTIONS(901),
    [anon_sym_int136] = ACTIONS(901),
    [anon_sym_int144] = ACTIONS(901),
    [anon_sym_int152] = ACTIONS(901),
    [anon_sym_int160] = ACTIONS(901),
    [anon_sym_int168] = ACTIONS(901),
    [anon_sym_int176] = ACTIONS(901),
    [anon_sym_int184] = ACTIONS(901),
    [anon_sym_int192] = ACTIONS(901),
    [anon_sym_int200] = ACTIONS(901),
    [anon_sym_int208] = ACTIONS(901),
    [anon_sym_int216] = ACTIONS(901),
    [anon_sym_int224] = ACTIONS(901),
    [anon_sym_int232] = ACTIONS(901),
    [anon_sym_int240] = ACTIONS(901),
    [anon_sym_int248] = ACTIONS(901),
    [anon_sym_int256] = ACTIONS(901),
    [anon_sym_uint] = ACTIONS(901),
    [anon_sym_uint8] = ACTIONS(901),
    [anon_sym_uint16] = ACTIONS(901),
    [anon_sym_uint24] = ACTIONS(901),
    [anon_sym_uint32] = ACTIONS(901),
    [anon_sym_uint40] = ACTIONS(901),
    [anon_sym_uint48] = ACTIONS(901),
    [anon_sym_uint56] = ACTIONS(901),
    [anon_sym_uint64] = ACTIONS(901),
    [anon_sym_uint72] = ACTIONS(901),
    [anon_sym_uint80] = ACTIONS(901),
    [anon_sym_uint88] = ACTIONS(901),
    [anon_sym_uint96] = ACTIONS(901),
    [anon_sym_uint104] = ACTIONS(901),
    [anon_sym_uint112] = ACTIONS(901),
    [anon_sym_uint120] = ACTIONS(901),
    [anon_sym_uint128] = ACTIONS(901),
    [anon_sym_uint136] = ACTIONS(901),
    [anon_sym_uint144] = ACTIONS(901),
    [anon_sym_uint152] = ACTIONS(901),
    [anon_sym_uint160] = ACTIONS(901),
    [anon_sym_uint168] = ACTIONS(901),
    [anon_sym_uint176] = ACTIONS(901),
    [anon_sym_uint184] = ACTIONS(901),
    [anon_sym_uint192] = ACTIONS(901),
    [anon_sym_uint200] = ACTIONS(901),
    [anon_sym_uint208] = ACTIONS(901),
    [anon_sym_uint216] = ACTIONS(901),
    [anon_sym_uint224] = ACTIONS(901),
    [anon_sym_uint232] = ACTIONS(901),
    [anon_sym_uint240] = ACTIONS(901),
    [anon_sym_uint248] = ACTIONS(901),
    [anon_sym_uint256] = ACTIONS(901),
    [anon_sym_bytes] = ACTIONS(901),
    [anon_sym_bytes1] = ACTIONS(901),
    [anon_sym_bytes2] = ACTIONS(901),
    [anon_sym_bytes3] = ACTIONS(901),
    [anon_sym_bytes4] = ACTIONS(901),
    [anon_sym_bytes5] = ACTIONS(901),
    [anon_sym_bytes6] = ACTIONS(901),
    [anon_sym_bytes7] = ACTIONS(901),
    [anon_sym_bytes8] = ACTIONS(901),
    [anon_sym_bytes9] = ACTIONS(901),
    [anon_sym_bytes10] = ACTIONS(901),
    [anon_sym_bytes11] = ACTIONS(901),
    [anon_sym_bytes12] = ACTIONS(901),
    [anon_sym_bytes13] = ACTIONS(901),
    [anon_sym_bytes14] = ACTIONS(901),
    [anon_sym_bytes15] = ACTIONS(901),
    [anon_sym_bytes16] = ACTIONS(901),
    [anon_sym_bytes17] = ACTIONS(901),
    [anon_sym_bytes18] = ACTIONS(901),
    [anon_sym_bytes19] = ACTIONS(901),
    [anon_sym_bytes20] = ACTIONS(901),
    [anon_sym_bytes21] = ACTIONS(901),
    [anon_sym_bytes22] = ACTIONS(901),
    [anon_sym_bytes23] = ACTIONS(901),
    [anon_sym_bytes24] = ACTIONS(901),
    [anon_sym_bytes25] = ACTIONS(901),
    [anon_sym_bytes26] = ACTIONS(901),
    [anon_sym_bytes27] = ACTIONS(901),
    [anon_sym_bytes28] = ACTIONS(901),
    [anon_sym_bytes29] = ACTIONS(901),
    [anon_sym_bytes30] = ACTIONS(901),
    [anon_sym_bytes31] = ACTIONS(901),
    [anon_sym_bytes32] = ACTIONS(901),
    [anon_sym_fixed] = ACTIONS(901),
    [aux_sym__fixed_token1] = ACTIONS(901),
    [anon_sym_ufixed] = ACTIONS(901),
    [aux_sym__ufixed_token1] = ACTIONS(901),
    [sym_comment] = ACTIONS(3),
  },
  [264] = {
    [sym_identifier] = ACTIONS(805),
    [anon_sym_RBRACE] = ACTIONS(803),
    [anon_sym_type] = ACTIONS(805),
    [anon_sym_error] = ACTIONS(805),
    [anon_sym_struct] = ACTIONS(805),
    [anon_sym_enum] = ACTIONS(805),
    [anon_sym_event] = ACTIONS(805),
    [anon_sym_using] = ACTIONS(805),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_byte] = ACTIONS(805),
    [anon_sym_address] = ACTIONS(805),
    [anon_sym_var] = ACTIONS(805),
    [anon_sym_modifier] = ACTIONS(805),
    [anon_sym_constructor] = ACTIONS(805),
    [anon_sym_fallback] = ACTIONS(805),
    [anon_sym_receive] = ACTIONS(805),
    [anon_sym_mapping] = ACTIONS(805),
    [anon_sym_bool] = ACTIONS(805),
    [anon_sym_string] = ACTIONS(805),
    [anon_sym_int] = ACTIONS(805),
    [anon_sym_int8] = ACTIONS(805),
    [anon_sym_int16] = ACTIONS(805),
    [anon_sym_int24] = ACTIONS(805),
    [anon_sym_int32] = ACTIONS(805),
    [anon_sym_int40] = ACTIONS(805),
    [anon_sym_int48] = ACTIONS(805),
    [anon_sym_int56] = ACTIONS(805),
    [anon_sym_int64] = ACTIONS(805),
    [anon_sym_int72] = ACTIONS(805),
    [anon_sym_int80] = ACTIONS(805),
    [anon_sym_int88] = ACTIONS(805),
    [anon_sym_int96] = ACTIONS(805),
    [anon_sym_int104] = ACTIONS(805),
    [anon_sym_int112] = ACTIONS(805),
    [anon_sym_int120] = ACTIONS(805),
    [anon_sym_int128] = ACTIONS(805),
    [anon_sym_int136] = ACTIONS(805),
    [anon_sym_int144] = ACTIONS(805),
    [anon_sym_int152] = ACTIONS(805),
    [anon_sym_int160] = ACTIONS(805),
    [anon_sym_int168] = ACTIONS(805),
    [anon_sym_int176] = ACTIONS(805),
    [anon_sym_int184] = ACTIONS(805),
    [anon_sym_int192] = ACTIONS(805),
    [anon_sym_int200] = ACTIONS(805),
    [anon_sym_int208] = ACTIONS(805),
    [anon_sym_int216] = ACTIONS(805),
    [anon_sym_int224] = ACTIONS(805),
    [anon_sym_int232] = ACTIONS(805),
    [anon_sym_int240] = ACTIONS(805),
    [anon_sym_int248] = ACTIONS(805),
    [anon_sym_int256] = ACTIONS(805),
    [anon_sym_uint] = ACTIONS(805),
    [anon_sym_uint8] = ACTIONS(805),
    [anon_sym_uint16] = ACTIONS(805),
    [anon_sym_uint24] = ACTIONS(805),
    [anon_sym_uint32] = ACTIONS(805),
    [anon_sym_uint40] = ACTIONS(805),
    [anon_sym_uint48] = ACTIONS(805),
    [anon_sym_uint56] = ACTIONS(805),
    [anon_sym_uint64] = ACTIONS(805),
    [anon_sym_uint72] = ACTIONS(805),
    [anon_sym_uint80] = ACTIONS(805),
    [anon_sym_uint88] = ACTIONS(805),
    [anon_sym_uint96] = ACTIONS(805),
    [anon_sym_uint104] = ACTIONS(805),
    [anon_sym_uint112] = ACTIONS(805),
    [anon_sym_uint120] = ACTIONS(805),
    [anon_sym_uint128] = ACTIONS(805),
    [anon_sym_uint136] = ACTIONS(805),
    [anon_sym_uint144] = ACTIONS(805),
    [anon_sym_uint152] = ACTIONS(805),
    [anon_sym_uint160] = ACTIONS(805),
    [anon_sym_uint168] = ACTIONS(805),
    [anon_sym_uint176] = ACTIONS(805),
    [anon_sym_uint184] = ACTIONS(805),
    [anon_sym_uint192] = ACTIONS(805),
    [anon_sym_uint200] = ACTIONS(805),
    [anon_sym_uint208] = ACTIONS(805),
    [anon_sym_uint216] = ACTIONS(805),
    [anon_sym_uint224] = ACTIONS(805),
    [anon_sym_uint232] = ACTIONS(805),
    [anon_sym_uint240] = ACTIONS(805),
    [anon_sym_uint248] = ACTIONS(805),
    [anon_sym_uint256] = ACTIONS(805),
    [anon_sym_bytes] = ACTIONS(805),
    [anon_sym_bytes1] = ACTIONS(805),
    [anon_sym_bytes2] = ACTIONS(805),
    [anon_sym_bytes3] = ACTIONS(805),
    [anon_sym_bytes4] = ACTIONS(805),
    [anon_sym_bytes5] = ACTIONS(805),
    [anon_sym_bytes6] = ACTIONS(805),
    [anon_sym_bytes7] = ACTIONS(805),
    [anon_sym_bytes8] = ACTIONS(805),
    [anon_sym_bytes9] = ACTIONS(805),
    [anon_sym_bytes10] = ACTIONS(805),
    [anon_sym_bytes11] = ACTIONS(805),
    [anon_sym_bytes12] = ACTIONS(805),
    [anon_sym_bytes13] = ACTIONS(805),
    [anon_sym_bytes14] = ACTIONS(805),
    [anon_sym_bytes15] = ACTIONS(805),
    [anon_sym_bytes16] = ACTIONS(805),
    [anon_sym_bytes17] = ACTIONS(805),
    [anon_sym_bytes18] = ACTIONS(805),
    [anon_sym_bytes19] = ACTIONS(805),
    [anon_sym_bytes20] = ACTIONS(805),
    [anon_sym_bytes21] = ACTIONS(805),
    [anon_sym_bytes22] = ACTIONS(805),
    [anon_sym_bytes23] = ACTIONS(805),
    [anon_sym_bytes24] = ACTIONS(805),
    [anon_sym_bytes25] = ACTIONS(805),
    [anon_sym_bytes26] = ACTIONS(805),
    [anon_sym_bytes27] = ACTIONS(805),
    [anon_sym_bytes28] = ACTIONS(805),
    [anon_sym_bytes29] = ACTIONS(805),
    [anon_sym_bytes30] = ACTIONS(805),
    [anon_sym_bytes31] = ACTIONS(805),
    [anon_sym_bytes32] = ACTIONS(805),
    [anon_sym_fixed] = ACTIONS(805),
    [aux_sym__fixed_token1] = ACTIONS(805),
    [anon_sym_ufixed] = ACTIONS(805),
    [aux_sym__ufixed_token1] = ACTIONS(805),
    [sym_comment] = ACTIONS(3),
  },
  [265] = {
    [sym_identifier] = ACTIONS(905),
    [anon_sym_RBRACE] = ACTIONS(907),
    [anon_sym_type] = ACTIONS(905),
    [anon_sym_error] = ACTIONS(905),
    [anon_sym_struct] = ACTIONS(905),
    [anon_sym_enum] = ACTIONS(905),
    [anon_sym_event] = ACTIONS(905),
    [anon_sym_using] = ACTIONS(905),
    [anon_sym_function] = ACTIONS(905),
    [anon_sym_byte] = ACTIONS(905),
    [anon_sym_address] = ACTIONS(905),
    [anon_sym_var] = ACTIONS(905),
    [anon_sym_modifier] = ACTIONS(905),
    [anon_sym_constructor] = ACTIONS(905),
    [anon_sym_fallback] = ACTIONS(905),
    [anon_sym_receive] = ACTIONS(905),
    [anon_sym_mapping] = ACTIONS(905),
    [anon_sym_bool] = ACTIONS(905),
    [anon_sym_string] = ACTIONS(905),
    [anon_sym_int] = ACTIONS(905),
    [anon_sym_int8] = ACTIONS(905),
    [anon_sym_int16] = ACTIONS(905),
    [anon_sym_int24] = ACTIONS(905),
    [anon_sym_int32] = ACTIONS(905),
    [anon_sym_int40] = ACTIONS(905),
    [anon_sym_int48] = ACTIONS(905),
    [anon_sym_int56] = ACTIONS(905),
    [anon_sym_int64] = ACTIONS(905),
    [anon_sym_int72] = ACTIONS(905),
    [anon_sym_int80] = ACTIONS(905),
    [anon_sym_int88] = ACTIONS(905),
    [anon_sym_int96] = ACTIONS(905),
    [anon_sym_int104] = ACTIONS(905),
    [anon_sym_int112] = ACTIONS(905),
    [anon_sym_int120] = ACTIONS(905),
    [anon_sym_int128] = ACTIONS(905),
    [anon_sym_int136] = ACTIONS(905),
    [anon_sym_int144] = ACTIONS(905),
    [anon_sym_int152] = ACTIONS(905),
    [anon_sym_int160] = ACTIONS(905),
    [anon_sym_int168] = ACTIONS(905),
    [anon_sym_int176] = ACTIONS(905),
    [anon_sym_int184] = ACTIONS(905),
    [anon_sym_int192] = ACTIONS(905),
    [anon_sym_int200] = ACTIONS(905),
    [anon_sym_int208] = ACTIONS(905),
    [anon_sym_int216] = ACTIONS(905),
    [anon_sym_int224] = ACTIONS(905),
    [anon_sym_int232] = ACTIONS(905),
    [anon_sym_int240] = ACTIONS(905),
    [anon_sym_int248] = ACTIONS(905),
    [anon_sym_int256] = ACTIONS(905),
    [anon_sym_uint] = ACTIONS(905),
    [anon_sym_uint8] = ACTIONS(905),
    [anon_sym_uint16] = ACTIONS(905),
    [anon_sym_uint24] = ACTIONS(905),
    [anon_sym_uint32] = ACTIONS(905),
    [anon_sym_uint40] = ACTIONS(905),
    [anon_sym_uint48] = ACTIONS(905),
    [anon_sym_uint56] = ACTIONS(905),
    [anon_sym_uint64] = ACTIONS(905),
    [anon_sym_uint72] = ACTIONS(905),
    [anon_sym_uint80] = ACTIONS(905),
    [anon_sym_uint88] = ACTIONS(905),
    [anon_sym_uint96] = ACTIONS(905),
    [anon_sym_uint104] = ACTIONS(905),
    [anon_sym_uint112] = ACTIONS(905),
    [anon_sym_uint120] = ACTIONS(905),
    [anon_sym_uint128] = ACTIONS(905),
    [anon_sym_uint136] = ACTIONS(905),
    [anon_sym_uint144] = ACTIONS(905),
    [anon_sym_uint152] = ACTIONS(905),
    [anon_sym_uint160] = ACTIONS(905),
    [anon_sym_uint168] = ACTIONS(905),
    [anon_sym_uint176] = ACTIONS(905),
    [anon_sym_uint184] = ACTIONS(905),
    [anon_sym_uint192] = ACTIONS(905),
    [anon_sym_uint200] = ACTIONS(905),
    [anon_sym_uint208] = ACTIONS(905),
    [anon_sym_uint216] = ACTIONS(905),
    [anon_sym_uint224] = ACTIONS(905),
    [anon_sym_uint232] = ACTIONS(905),
    [anon_sym_uint240] = ACTIONS(905),
    [anon_sym_uint248] = ACTIONS(905),
    [anon_sym_uint256] = ACTIONS(905),
    [anon_sym_bytes] = ACTIONS(905),
    [anon_sym_bytes1] = ACTIONS(905),
    [anon_sym_bytes2] = ACTIONS(905),
    [anon_sym_bytes3] = ACTIONS(905),
    [anon_sym_bytes4] = ACTIONS(905),
    [anon_sym_bytes5] = ACTIONS(905),
    [anon_sym_bytes6] = ACTIONS(905),
    [anon_sym_bytes7] = ACTIONS(905),
    [anon_sym_bytes8] = ACTIONS(905),
    [anon_sym_bytes9] = ACTIONS(905),
    [anon_sym_bytes10] = ACTIONS(905),
    [anon_sym_bytes11] = ACTIONS(905),
    [anon_sym_bytes12] = ACTIONS(905),
    [anon_sym_bytes13] = ACTIONS(905),
    [anon_sym_bytes14] = ACTIONS(905),
    [anon_sym_bytes15] = ACTIONS(905),
    [anon_sym_bytes16] = ACTIONS(905),
    [anon_sym_bytes17] = ACTIONS(905),
    [anon_sym_bytes18] = ACTIONS(905),
    [anon_sym_bytes19] = ACTIONS(905),
    [anon_sym_bytes20] = ACTIONS(905),
    [anon_sym_bytes21] = ACTIONS(905),
    [anon_sym_bytes22] = ACTIONS(905),
    [anon_sym_bytes23] = ACTIONS(905),
    [anon_sym_bytes24] = ACTIONS(905),
    [anon_sym_bytes25] = ACTIONS(905),
    [anon_sym_bytes26] = ACTIONS(905),
    [anon_sym_bytes27] = ACTIONS(905),
    [anon_sym_bytes28] = ACTIONS(905),
    [anon_sym_bytes29] = ACTIONS(905),
    [anon_sym_bytes30] = ACTIONS(905),
    [anon_sym_bytes31] = ACTIONS(905),
    [anon_sym_bytes32] = ACTIONS(905),
    [anon_sym_fixed] = ACTIONS(905),
    [aux_sym__fixed_token1] = ACTIONS(905),
    [anon_sym_ufixed] = ACTIONS(905),
    [aux_sym__ufixed_token1] = ACTIONS(905),
    [sym_comment] = ACTIONS(3),
  },
  [266] = {
    [sym_identifier] = ACTIONS(757),
    [anon_sym_RBRACE] = ACTIONS(755),
    [anon_sym_type] = ACTIONS(757),
    [anon_sym_error] = ACTIONS(757),
    [anon_sym_struct] = ACTIONS(757),
    [anon_sym_enum] = ACTIONS(757),
    [anon_sym_event] = ACTIONS(757),
    [anon_sym_using] = ACTIONS(757),
    [anon_sym_function] = ACTIONS(757),
    [anon_sym_byte] = ACTIONS(757),
    [anon_sym_address] = ACTIONS(757),
    [anon_sym_var] = ACTIONS(757),
    [anon_sym_modifier] = ACTIONS(757),
    [anon_sym_constructor] = ACTIONS(757),
    [anon_sym_fallback] = ACTIONS(757),
    [anon_sym_receive] = ACTIONS(757),
    [anon_sym_mapping] = ACTIONS(757),
    [anon_sym_bool] = ACTIONS(757),
    [anon_sym_string] = ACTIONS(757),
    [anon_sym_int] = ACTIONS(757),
    [anon_sym_int8] = ACTIONS(757),
    [anon_sym_int16] = ACTIONS(757),
    [anon_sym_int24] = ACTIONS(757),
    [anon_sym_int32] = ACTIONS(757),
    [anon_sym_int40] = ACTIONS(757),
    [anon_sym_int48] = ACTIONS(757),
    [anon_sym_int56] = ACTIONS(757),
    [anon_sym_int64] = ACTIONS(757),
    [anon_sym_int72] = ACTIONS(757),
    [anon_sym_int80] = ACTIONS(757),
    [anon_sym_int88] = ACTIONS(757),
    [anon_sym_int96] = ACTIONS(757),
    [anon_sym_int104] = ACTIONS(757),
    [anon_sym_int112] = ACTIONS(757),
    [anon_sym_int120] = ACTIONS(757),
    [anon_sym_int128] = ACTIONS(757),
    [anon_sym_int136] = ACTIONS(757),
    [anon_sym_int144] = ACTIONS(757),
    [anon_sym_int152] = ACTIONS(757),
    [anon_sym_int160] = ACTIONS(757),
    [anon_sym_int168] = ACTIONS(757),
    [anon_sym_int176] = ACTIONS(757),
    [anon_sym_int184] = ACTIONS(757),
    [anon_sym_int192] = ACTIONS(757),
    [anon_sym_int200] = ACTIONS(757),
    [anon_sym_int208] = ACTIONS(757),
    [anon_sym_int216] = ACTIONS(757),
    [anon_sym_int224] = ACTIONS(757),
    [anon_sym_int232] = ACTIONS(757),
    [anon_sym_int240] = ACTIONS(757),
    [anon_sym_int248] = ACTIONS(757),
    [anon_sym_int256] = ACTIONS(757),
    [anon_sym_uint] = ACTIONS(757),
    [anon_sym_uint8] = ACTIONS(757),
    [anon_sym_uint16] = ACTIONS(757),
    [anon_sym_uint24] = ACTIONS(757),
    [anon_sym_uint32] = ACTIONS(757),
    [anon_sym_uint40] = ACTIONS(757),
    [anon_sym_uint48] = ACTIONS(757),
    [anon_sym_uint56] = ACTIONS(757),
    [anon_sym_uint64] = ACTIONS(757),
    [anon_sym_uint72] = ACTIONS(757),
    [anon_sym_uint80] = ACTIONS(757),
    [anon_sym_uint88] = ACTIONS(757),
    [anon_sym_uint96] = ACTIONS(757),
    [anon_sym_uint104] = ACTIONS(757),
    [anon_sym_uint112] = ACTIONS(757),
    [anon_sym_uint120] = ACTIONS(757),
    [anon_sym_uint128] = ACTIONS(757),
    [anon_sym_uint136] = ACTIONS(757),
    [anon_sym_uint144] = ACTIONS(757),
    [anon_sym_uint152] = ACTIONS(757),
    [anon_sym_uint160] = ACTIONS(757),
    [anon_sym_uint168] = ACTIONS(757),
    [anon_sym_uint176] = ACTIONS(757),
    [anon_sym_uint184] = ACTIONS(757),
    [anon_sym_uint192] = ACTIONS(757),
    [anon_sym_uint200] = ACTIONS(757),
    [anon_sym_uint208] = ACTIONS(757),
    [anon_sym_uint216] = ACTIONS(757),
    [anon_sym_uint224] = ACTIONS(757),
    [anon_sym_uint232] = ACTIONS(757),
    [anon_sym_uint240] = ACTIONS(757),
    [anon_sym_uint248] = ACTIONS(757),
    [anon_sym_uint256] = ACTIONS(757),
    [anon_sym_bytes] = ACTIONS(757),
    [anon_sym_bytes1] = ACTIONS(757),
    [anon_sym_bytes2] = ACTIONS(757),
    [anon_sym_bytes3] = ACTIONS(757),
    [anon_sym_bytes4] = ACTIONS(757),
    [anon_sym_bytes5] = ACTIONS(757),
    [anon_sym_bytes6] = ACTIONS(757),
    [anon_sym_bytes7] = ACTIONS(757),
    [anon_sym_bytes8] = ACTIONS(757),
    [anon_sym_bytes9] = ACTIONS(757),
    [anon_sym_bytes10] = ACTIONS(757),
    [anon_sym_bytes11] = ACTIONS(757),
    [anon_sym_bytes12] = ACTIONS(757),
    [anon_sym_bytes13] = ACTIONS(757),
    [anon_sym_bytes14] = ACTIONS(757),
    [anon_sym_bytes15] = ACTIONS(757),
    [anon_sym_bytes16] = ACTIONS(757),
    [anon_sym_bytes17] = ACTIONS(757),
    [anon_sym_bytes18] = ACTIONS(757),
    [anon_sym_bytes19] = ACTIONS(757),
    [anon_sym_bytes20] = ACTIONS(757),
    [anon_sym_bytes21] = ACTIONS(757),
    [anon_sym_bytes22] = ACTIONS(757),
    [anon_sym_bytes23] = ACTIONS(757),
    [anon_sym_bytes24] = ACTIONS(757),
    [anon_sym_bytes25] = ACTIONS(757),
    [anon_sym_bytes26] = ACTIONS(757),
    [anon_sym_bytes27] = ACTIONS(757),
    [anon_sym_bytes28] = ACTIONS(757),
    [anon_sym_bytes29] = ACTIONS(757),
    [anon_sym_bytes30] = ACTIONS(757),
    [anon_sym_bytes31] = ACTIONS(757),
    [anon_sym_bytes32] = ACTIONS(757),
    [anon_sym_fixed] = ACTIONS(757),
    [aux_sym__fixed_token1] = ACTIONS(757),
    [anon_sym_ufixed] = ACTIONS(757),
    [aux_sym__ufixed_token1] = ACTIONS(757),
    [sym_comment] = ACTIONS(3),
  },
  [267] = {
    [sym_identifier] = ACTIONS(629),
    [anon_sym_RBRACE] = ACTIONS(627),
    [anon_sym_type] = ACTIONS(629),
    [anon_sym_error] = ACTIONS(629),
    [anon_sym_struct] = ACTIONS(629),
    [anon_sym_enum] = ACTIONS(629),
    [anon_sym_event] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(629),
    [anon_sym_function] = ACTIONS(629),
    [anon_sym_byte] = ACTIONS(629),
    [anon_sym_address] = ACTIONS(629),
    [anon_sym_var] = ACTIONS(629),
    [anon_sym_modifier] = ACTIONS(629),
    [anon_sym_constructor] = ACTIONS(629),
    [anon_sym_fallback] = ACTIONS(629),
    [anon_sym_receive] = ACTIONS(629),
    [anon_sym_mapping] = ACTIONS(629),
    [anon_sym_bool] = ACTIONS(629),
    [anon_sym_string] = ACTIONS(629),
    [anon_sym_int] = ACTIONS(629),
    [anon_sym_int8] = ACTIONS(629),
    [anon_sym_int16] = ACTIONS(629),
    [anon_sym_int24] = ACTIONS(629),
    [anon_sym_int32] = ACTIONS(629),
    [anon_sym_int40] = ACTIONS(629),
    [anon_sym_int48] = ACTIONS(629),
    [anon_sym_int56] = ACTIONS(629),
    [anon_sym_int64] = ACTIONS(629),
    [anon_sym_int72] = ACTIONS(629),
    [anon_sym_int80] = ACTIONS(629),
    [anon_sym_int88] = ACTIONS(629),
    [anon_sym_int96] = ACTIONS(629),
    [anon_sym_int104] = ACTIONS(629),
    [anon_sym_int112] = ACTIONS(629),
    [anon_sym_int120] = ACTIONS(629),
    [anon_sym_int128] = ACTIONS(629),
    [anon_sym_int136] = ACTIONS(629),
    [anon_sym_int144] = ACTIONS(629),
    [anon_sym_int152] = ACTIONS(629),
    [anon_sym_int160] = ACTIONS(629),
    [anon_sym_int168] = ACTIONS(629),
    [anon_sym_int176] = ACTIONS(629),
    [anon_sym_int184] = ACTIONS(629),
    [anon_sym_int192] = ACTIONS(629),
    [anon_sym_int200] = ACTIONS(629),
    [anon_sym_int208] = ACTIONS(629),
    [anon_sym_int216] = ACTIONS(629),
    [anon_sym_int224] = ACTIONS(629),
    [anon_sym_int232] = ACTIONS(629),
    [anon_sym_int240] = ACTIONS(629),
    [anon_sym_int248] = ACTIONS(629),
    [anon_sym_int256] = ACTIONS(629),
    [anon_sym_uint] = ACTIONS(629),
    [anon_sym_uint8] = ACTIONS(629),
    [anon_sym_uint16] = ACTIONS(629),
    [anon_sym_uint24] = ACTIONS(629),
    [anon_sym_uint32] = ACTIONS(629),
    [anon_sym_uint40] = ACTIONS(629),
    [anon_sym_uint48] = ACTIONS(629),
    [anon_sym_uint56] = ACTIONS(629),
    [anon_sym_uint64] = ACTIONS(629),
    [anon_sym_uint72] = ACTIONS(629),
    [anon_sym_uint80] = ACTIONS(629),
    [anon_sym_uint88] = ACTIONS(629),
    [anon_sym_uint96] = ACTIONS(629),
    [anon_sym_uint104] = ACTIONS(629),
    [anon_sym_uint112] = ACTIONS(629),
    [anon_sym_uint120] = ACTIONS(629),
    [anon_sym_uint128] = ACTIONS(629),
    [anon_sym_uint136] = ACTIONS(629),
    [anon_sym_uint144] = ACTIONS(629),
    [anon_sym_uint152] = ACTIONS(629),
    [anon_sym_uint160] = ACTIONS(629),
    [anon_sym_uint168] = ACTIONS(629),
    [anon_sym_uint176] = ACTIONS(629),
    [anon_sym_uint184] = ACTIONS(629),
    [anon_sym_uint192] = ACTIONS(629),
    [anon_sym_uint200] = ACTIONS(629),
    [anon_sym_uint208] = ACTIONS(629),
    [anon_sym_uint216] = ACTIONS(629),
    [anon_sym_uint224] = ACTIONS(629),
    [anon_sym_uint232] = ACTIONS(629),
    [anon_sym_uint240] = ACTIONS(629),
    [anon_sym_uint248] = ACTIONS(629),
    [anon_sym_uint256] = ACTIONS(629),
    [anon_sym_bytes] = ACTIONS(629),
    [anon_sym_bytes1] = ACTIONS(629),
    [anon_sym_bytes2] = ACTIONS(629),
    [anon_sym_bytes3] = ACTIONS(629),
    [anon_sym_bytes4] = ACTIONS(629),
    [anon_sym_bytes5] = ACTIONS(629),
    [anon_sym_bytes6] = ACTIONS(629),
    [anon_sym_bytes7] = ACTIONS(629),
    [anon_sym_bytes8] = ACTIONS(629),
    [anon_sym_bytes9] = ACTIONS(629),
    [anon_sym_bytes10] = ACTIONS(629),
    [anon_sym_bytes11] = ACTIONS(629),
    [anon_sym_bytes12] = ACTIONS(629),
    [anon_sym_bytes13] = ACTIONS(629),
    [anon_sym_bytes14] = ACTIONS(629),
    [anon_sym_bytes15] = ACTIONS(629),
    [anon_sym_bytes16] = ACTIONS(629),
    [anon_sym_bytes17] = ACTIONS(629),
    [anon_sym_bytes18] = ACTIONS(629),
    [anon_sym_bytes19] = ACTIONS(629),
    [anon_sym_bytes20] = ACTIONS(629),
    [anon_sym_bytes21] = ACTIONS(629),
    [anon_sym_bytes22] = ACTIONS(629),
    [anon_sym_bytes23] = ACTIONS(629),
    [anon_sym_bytes24] = ACTIONS(629),
    [anon_sym_bytes25] = ACTIONS(629),
    [anon_sym_bytes26] = ACTIONS(629),
    [anon_sym_bytes27] = ACTIONS(629),
    [anon_sym_bytes28] = ACTIONS(629),
    [anon_sym_bytes29] = ACTIONS(629),
    [anon_sym_bytes30] = ACTIONS(629),
    [anon_sym_bytes31] = ACTIONS(629),
    [anon_sym_bytes32] = ACTIONS(629),
    [anon_sym_fixed] = ACTIONS(629),
    [aux_sym__fixed_token1] = ACTIONS(629),
    [anon_sym_ufixed] = ACTIONS(629),
    [aux_sym__ufixed_token1] = ACTIONS(629),
    [sym_comment] = ACTIONS(3),
  },
  [268] = {
    [sym_identifier] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(911),
    [anon_sym_type] = ACTIONS(909),
    [anon_sym_error] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(909),
    [anon_sym_enum] = ACTIONS(909),
    [anon_sym_event] = ACTIONS(909),
    [anon_sym_using] = ACTIONS(909),
    [anon_sym_function] = ACTIONS(909),
    [anon_sym_byte] = ACTIONS(909),
    [anon_sym_address] = ACTIONS(909),
    [anon_sym_var] = ACTIONS(909),
    [anon_sym_modifier] = ACTIONS(909),
    [anon_sym_constructor] = ACTIONS(909),
    [anon_sym_fallback] = ACTIONS(909),
    [anon_sym_receive] = ACTIONS(909),
    [anon_sym_mapping] = ACTIONS(909),
    [anon_sym_bool] = ACTIONS(909),
    [anon_sym_string] = ACTIONS(909),
    [anon_sym_int] = ACTIONS(909),
    [anon_sym_int8] = ACTIONS(909),
    [anon_sym_int16] = ACTIONS(909),
    [anon_sym_int24] = ACTIONS(909),
    [anon_sym_int32] = ACTIONS(909),
    [anon_sym_int40] = ACTIONS(909),
    [anon_sym_int48] = ACTIONS(909),
    [anon_sym_int56] = ACTIONS(909),
    [anon_sym_int64] = ACTIONS(909),
    [anon_sym_int72] = ACTIONS(909),
    [anon_sym_int80] = ACTIONS(909),
    [anon_sym_int88] = ACTIONS(909),
    [anon_sym_int96] = ACTIONS(909),
    [anon_sym_int104] = ACTIONS(909),
    [anon_sym_int112] = ACTIONS(909),
    [anon_sym_int120] = ACTIONS(909),
    [anon_sym_int128] = ACTIONS(909),
    [anon_sym_int136] = ACTIONS(909),
    [anon_sym_int144] = ACTIONS(909),
    [anon_sym_int152] = ACTIONS(909),
    [anon_sym_int160] = ACTIONS(909),
    [anon_sym_int168] = ACTIONS(909),
    [anon_sym_int176] = ACTIONS(909),
    [anon_sym_int184] = ACTIONS(909),
    [anon_sym_int192] = ACTIONS(909),
    [anon_sym_int200] = ACTIONS(909),
    [anon_sym_int208] = ACTIONS(909),
    [anon_sym_int216] = ACTIONS(909),
    [anon_sym_int224] = ACTIONS(909),
    [anon_sym_int232] = ACTIONS(909),
    [anon_sym_int240] = ACTIONS(909),
    [anon_sym_int248] = ACTIONS(909),
    [anon_sym_int256] = ACTIONS(909),
    [anon_sym_uint] = ACTIONS(909),
    [anon_sym_uint8] = ACTIONS(909),
    [anon_sym_uint16] = ACTIONS(909),
    [anon_sym_uint24] = ACTIONS(909),
    [anon_sym_uint32] = ACTIONS(909),
    [anon_sym_uint40] = ACTIONS(909),
    [anon_sym_uint48] = ACTIONS(909),
    [anon_sym_uint56] = ACTIONS(909),
    [anon_sym_uint64] = ACTIONS(909),
    [anon_sym_uint72] = ACTIONS(909),
    [anon_sym_uint80] = ACTIONS(909),
    [anon_sym_uint88] = ACTIONS(909),
    [anon_sym_uint96] = ACTIONS(909),
    [anon_sym_uint104] = ACTIONS(909),
    [anon_sym_uint112] = ACTIONS(909),
    [anon_sym_uint120] = ACTIONS(909),
    [anon_sym_uint128] = ACTIONS(909),
    [anon_sym_uint136] = ACTIONS(909),
    [anon_sym_uint144] = ACTIONS(909),
    [anon_sym_uint152] = ACTIONS(909),
    [anon_sym_uint160] = ACTIONS(909),
    [anon_sym_uint168] = ACTIONS(909),
    [anon_sym_uint176] = ACTIONS(909),
    [anon_sym_uint184] = ACTIONS(909),
    [anon_sym_uint192] = ACTIONS(909),
    [anon_sym_uint200] = ACTIONS(909),
    [anon_sym_uint208] = ACTIONS(909),
    [anon_sym_uint216] = ACTIONS(909),
    [anon_sym_uint224] = ACTIONS(909),
    [anon_sym_uint232] = ACTIONS(909),
    [anon_sym_uint240] = ACTIONS(909),
    [anon_sym_uint248] = ACTIONS(909),
    [anon_sym_uint256] = ACTIONS(909),
    [anon_sym_bytes] = ACTIONS(909),
    [anon_sym_bytes1] = ACTIONS(909),
    [anon_sym_bytes2] = ACTIONS(909),
    [anon_sym_bytes3] = ACTIONS(909),
    [anon_sym_bytes4] = ACTIONS(909),
    [anon_sym_bytes5] = ACTIONS(909),
    [anon_sym_bytes6] = ACTIONS(909),
    [anon_sym_bytes7] = ACTIONS(909),
    [anon_sym_bytes8] = ACTIONS(909),
    [anon_sym_bytes9] = ACTIONS(909),
    [anon_sym_bytes10] = ACTIONS(909),
    [anon_sym_bytes11] = ACTIONS(909),
    [anon_sym_bytes12] = ACTIONS(909),
    [anon_sym_bytes13] = ACTIONS(909),
    [anon_sym_bytes14] = ACTIONS(909),
    [anon_sym_bytes15] = ACTIONS(909),
    [anon_sym_bytes16] = ACTIONS(909),
    [anon_sym_bytes17] = ACTIONS(909),
    [anon_sym_bytes18] = ACTIONS(909),
    [anon_sym_bytes19] = ACTIONS(909),
    [anon_sym_bytes20] = ACTIONS(909),
    [anon_sym_bytes21] = ACTIONS(909),
    [anon_sym_bytes22] = ACTIONS(909),
    [anon_sym_bytes23] = ACTIONS(909),
    [anon_sym_bytes24] = ACTIONS(909),
    [anon_sym_bytes25] = ACTIONS(909),
    [anon_sym_bytes26] = ACTIONS(909),
    [anon_sym_bytes27] = ACTIONS(909),
    [anon_sym_bytes28] = ACTIONS(909),
    [anon_sym_bytes29] = ACTIONS(909),
    [anon_sym_bytes30] = ACTIONS(909),
    [anon_sym_bytes31] = ACTIONS(909),
    [anon_sym_bytes32] = ACTIONS(909),
    [anon_sym_fixed] = ACTIONS(909),
    [aux_sym__fixed_token1] = ACTIONS(909),
    [anon_sym_ufixed] = ACTIONS(909),
    [aux_sym__ufixed_token1] = ACTIONS(909),
    [sym_comment] = ACTIONS(3),
  },
  [269] = {
    [sym_identifier] = ACTIONS(913),
    [anon_sym_RBRACE] = ACTIONS(915),
    [anon_sym_type] = ACTIONS(913),
    [anon_sym_error] = ACTIONS(913),
    [anon_sym_struct] = ACTIONS(913),
    [anon_sym_enum] = ACTIONS(913),
    [anon_sym_event] = ACTIONS(913),
    [anon_sym_using] = ACTIONS(913),
    [anon_sym_function] = ACTIONS(913),
    [anon_sym_byte] = ACTIONS(913),
    [anon_sym_address] = ACTIONS(913),
    [anon_sym_var] = ACTIONS(913),
    [anon_sym_modifier] = ACTIONS(913),
    [anon_sym_constructor] = ACTIONS(913),
    [anon_sym_fallback] = ACTIONS(913),
    [anon_sym_receive] = ACTIONS(913),
    [anon_sym_mapping] = ACTIONS(913),
    [anon_sym_bool] = ACTIONS(913),
    [anon_sym_string] = ACTIONS(913),
    [anon_sym_int] = ACTIONS(913),
    [anon_sym_int8] = ACTIONS(913),
    [anon_sym_int16] = ACTIONS(913),
    [anon_sym_int24] = ACTIONS(913),
    [anon_sym_int32] = ACTIONS(913),
    [anon_sym_int40] = ACTIONS(913),
    [anon_sym_int48] = ACTIONS(913),
    [anon_sym_int56] = ACTIONS(913),
    [anon_sym_int64] = ACTIONS(913),
    [anon_sym_int72] = ACTIONS(913),
    [anon_sym_int80] = ACTIONS(913),
    [anon_sym_int88] = ACTIONS(913),
    [anon_sym_int96] = ACTIONS(913),
    [anon_sym_int104] = ACTIONS(913),
    [anon_sym_int112] = ACTIONS(913),
    [anon_sym_int120] = ACTIONS(913),
    [anon_sym_int128] = ACTIONS(913),
    [anon_sym_int136] = ACTIONS(913),
    [anon_sym_int144] = ACTIONS(913),
    [anon_sym_int152] = ACTIONS(913),
    [anon_sym_int160] = ACTIONS(913),
    [anon_sym_int168] = ACTIONS(913),
    [anon_sym_int176] = ACTIONS(913),
    [anon_sym_int184] = ACTIONS(913),
    [anon_sym_int192] = ACTIONS(913),
    [anon_sym_int200] = ACTIONS(913),
    [anon_sym_int208] = ACTIONS(913),
    [anon_sym_int216] = ACTIONS(913),
    [anon_sym_int224] = ACTIONS(913),
    [anon_sym_int232] = ACTIONS(913),
    [anon_sym_int240] = ACTIONS(913),
    [anon_sym_int248] = ACTIONS(913),
    [anon_sym_int256] = ACTIONS(913),
    [anon_sym_uint] = ACTIONS(913),
    [anon_sym_uint8] = ACTIONS(913),
    [anon_sym_uint16] = ACTIONS(913),
    [anon_sym_uint24] = ACTIONS(913),
    [anon_sym_uint32] = ACTIONS(913),
    [anon_sym_uint40] = ACTIONS(913),
    [anon_sym_uint48] = ACTIONS(913),
    [anon_sym_uint56] = ACTIONS(913),
    [anon_sym_uint64] = ACTIONS(913),
    [anon_sym_uint72] = ACTIONS(913),
    [anon_sym_uint80] = ACTIONS(913),
    [anon_sym_uint88] = ACTIONS(913),
    [anon_sym_uint96] = ACTIONS(913),
    [anon_sym_uint104] = ACTIONS(913),
    [anon_sym_uint112] = ACTIONS(913),
    [anon_sym_uint120] = ACTIONS(913),
    [anon_sym_uint128] = ACTIONS(913),
    [anon_sym_uint136] = ACTIONS(913),
    [anon_sym_uint144] = ACTIONS(913),
    [anon_sym_uint152] = ACTIONS(913),
    [anon_sym_uint160] = ACTIONS(913),
    [anon_sym_uint168] = ACTIONS(913),
    [anon_sym_uint176] = ACTIONS(913),
    [anon_sym_uint184] = ACTIONS(913),
    [anon_sym_uint192] = ACTIONS(913),
    [anon_sym_uint200] = ACTIONS(913),
    [anon_sym_uint208] = ACTIONS(913),
    [anon_sym_uint216] = ACTIONS(913),
    [anon_sym_uint224] = ACTIONS(913),
    [anon_sym_uint232] = ACTIONS(913),
    [anon_sym_uint240] = ACTIONS(913),
    [anon_sym_uint248] = ACTIONS(913),
    [anon_sym_uint256] = ACTIONS(913),
    [anon_sym_bytes] = ACTIONS(913),
    [anon_sym_bytes1] = ACTIONS(913),
    [anon_sym_bytes2] = ACTIONS(913),
    [anon_sym_bytes3] = ACTIONS(913),
    [anon_sym_bytes4] = ACTIONS(913),
    [anon_sym_bytes5] = ACTIONS(913),
    [anon_sym_bytes6] = ACTIONS(913),
    [anon_sym_bytes7] = ACTIONS(913),
    [anon_sym_bytes8] = ACTIONS(913),
    [anon_sym_bytes9] = ACTIONS(913),
    [anon_sym_bytes10] = ACTIONS(913),
    [anon_sym_bytes11] = ACTIONS(913),
    [anon_sym_bytes12] = ACTIONS(913),
    [anon_sym_bytes13] = ACTIONS(913),
    [anon_sym_bytes14] = ACTIONS(913),
    [anon_sym_bytes15] = ACTIONS(913),
    [anon_sym_bytes16] = ACTIONS(913),
    [anon_sym_bytes17] = ACTIONS(913),
    [anon_sym_bytes18] = ACTIONS(913),
    [anon_sym_bytes19] = ACTIONS(913),
    [anon_sym_bytes20] = ACTIONS(913),
    [anon_sym_bytes21] = ACTIONS(913),
    [anon_sym_bytes22] = ACTIONS(913),
    [anon_sym_bytes23] = ACTIONS(913),
    [anon_sym_bytes24] = ACTIONS(913),
    [anon_sym_bytes25] = ACTIONS(913),
    [anon_sym_bytes26] = ACTIONS(913),
    [anon_sym_bytes27] = ACTIONS(913),
    [anon_sym_bytes28] = ACTIONS(913),
    [anon_sym_bytes29] = ACTIONS(913),
    [anon_sym_bytes30] = ACTIONS(913),
    [anon_sym_bytes31] = ACTIONS(913),
    [anon_sym_bytes32] = ACTIONS(913),
    [anon_sym_fixed] = ACTIONS(913),
    [aux_sym__fixed_token1] = ACTIONS(913),
    [anon_sym_ufixed] = ACTIONS(913),
    [aux_sym__ufixed_token1] = ACTIONS(913),
    [sym_comment] = ACTIONS(3),
  },
  [270] = {
    [sym_identifier] = ACTIONS(677),
    [anon_sym_RBRACE] = ACTIONS(675),
    [anon_sym_type] = ACTIONS(677),
    [anon_sym_error] = ACTIONS(677),
    [anon_sym_struct] = ACTIONS(677),
    [anon_sym_enum] = ACTIONS(677),
    [anon_sym_event] = ACTIONS(677),
    [anon_sym_using] = ACTIONS(677),
    [anon_sym_function] = ACTIONS(677),
    [anon_sym_byte] = ACTIONS(677),
    [anon_sym_address] = ACTIONS(677),
    [anon_sym_var] = ACTIONS(677),
    [anon_sym_modifier] = ACTIONS(677),
    [anon_sym_constructor] = ACTIONS(677),
    [anon_sym_fallback] = ACTIONS(677),
    [anon_sym_receive] = ACTIONS(677),
    [anon_sym_mapping] = ACTIONS(677),
    [anon_sym_bool] = ACTIONS(677),
    [anon_sym_string] = ACTIONS(677),
    [anon_sym_int] = ACTIONS(677),
    [anon_sym_int8] = ACTIONS(677),
    [anon_sym_int16] = ACTIONS(677),
    [anon_sym_int24] = ACTIONS(677),
    [anon_sym_int32] = ACTIONS(677),
    [anon_sym_int40] = ACTIONS(677),
    [anon_sym_int48] = ACTIONS(677),
    [anon_sym_int56] = ACTIONS(677),
    [anon_sym_int64] = ACTIONS(677),
    [anon_sym_int72] = ACTIONS(677),
    [anon_sym_int80] = ACTIONS(677),
    [anon_sym_int88] = ACTIONS(677),
    [anon_sym_int96] = ACTIONS(677),
    [anon_sym_int104] = ACTIONS(677),
    [anon_sym_int112] = ACTIONS(677),
    [anon_sym_int120] = ACTIONS(677),
    [anon_sym_int128] = ACTIONS(677),
    [anon_sym_int136] = ACTIONS(677),
    [anon_sym_int144] = ACTIONS(677),
    [anon_sym_int152] = ACTIONS(677),
    [anon_sym_int160] = ACTIONS(677),
    [anon_sym_int168] = ACTIONS(677),
    [anon_sym_int176] = ACTIONS(677),
    [anon_sym_int184] = ACTIONS(677),
    [anon_sym_int192] = ACTIONS(677),
    [anon_sym_int200] = ACTIONS(677),
    [anon_sym_int208] = ACTIONS(677),
    [anon_sym_int216] = ACTIONS(677),
    [anon_sym_int224] = ACTIONS(677),
    [anon_sym_int232] = ACTIONS(677),
    [anon_sym_int240] = ACTIONS(677),
    [anon_sym_int248] = ACTIONS(677),
    [anon_sym_int256] = ACTIONS(677),
    [anon_sym_uint] = ACTIONS(677),
    [anon_sym_uint8] = ACTIONS(677),
    [anon_sym_uint16] = ACTIONS(677),
    [anon_sym_uint24] = ACTIONS(677),
    [anon_sym_uint32] = ACTIONS(677),
    [anon_sym_uint40] = ACTIONS(677),
    [anon_sym_uint48] = ACTIONS(677),
    [anon_sym_uint56] = ACTIONS(677),
    [anon_sym_uint64] = ACTIONS(677),
    [anon_sym_uint72] = ACTIONS(677),
    [anon_sym_uint80] = ACTIONS(677),
    [anon_sym_uint88] = ACTIONS(677),
    [anon_sym_uint96] = ACTIONS(677),
    [anon_sym_uint104] = ACTIONS(677),
    [anon_sym_uint112] = ACTIONS(677),
    [anon_sym_uint120] = ACTIONS(677),
    [anon_sym_uint128] = ACTIONS(677),
    [anon_sym_uint136] = ACTIONS(677),
    [anon_sym_uint144] = ACTIONS(677),
    [anon_sym_uint152] = ACTIONS(677),
    [anon_sym_uint160] = ACTIONS(677),
    [anon_sym_uint168] = ACTIONS(677),
    [anon_sym_uint176] = ACTIONS(677),
    [anon_sym_uint184] = ACTIONS(677),
    [anon_sym_uint192] = ACTIONS(677),
    [anon_sym_uint200] = ACTIONS(677),
    [anon_sym_uint208] = ACTIONS(677),
    [anon_sym_uint216] = ACTIONS(677),
    [anon_sym_uint224] = ACTIONS(677),
    [anon_sym_uint232] = ACTIONS(677),
    [anon_sym_uint240] = ACTIONS(677),
    [anon_sym_uint248] = ACTIONS(677),
    [anon_sym_uint256] = ACTIONS(677),
    [anon_sym_bytes] = ACTIONS(677),
    [anon_sym_bytes1] = ACTIONS(677),
    [anon_sym_bytes2] = ACTIONS(677),
    [anon_sym_bytes3] = ACTIONS(677),
    [anon_sym_bytes4] = ACTIONS(677),
    [anon_sym_bytes5] = ACTIONS(677),
    [anon_sym_bytes6] = ACTIONS(677),
    [anon_sym_bytes7] = ACTIONS(677),
    [anon_sym_bytes8] = ACTIONS(677),
    [anon_sym_bytes9] = ACTIONS(677),
    [anon_sym_bytes10] = ACTIONS(677),
    [anon_sym_bytes11] = ACTIONS(677),
    [anon_sym_bytes12] = ACTIONS(677),
    [anon_sym_bytes13] = ACTIONS(677),
    [anon_sym_bytes14] = ACTIONS(677),
    [anon_sym_bytes15] = ACTIONS(677),
    [anon_sym_bytes16] = ACTIONS(677),
    [anon_sym_bytes17] = ACTIONS(677),
    [anon_sym_bytes18] = ACTIONS(677),
    [anon_sym_bytes19] = ACTIONS(677),
    [anon_sym_bytes20] = ACTIONS(677),
    [anon_sym_bytes21] = ACTIONS(677),
    [anon_sym_bytes22] = ACTIONS(677),
    [anon_sym_bytes23] = ACTIONS(677),
    [anon_sym_bytes24] = ACTIONS(677),
    [anon_sym_bytes25] = ACTIONS(677),
    [anon_sym_bytes26] = ACTIONS(677),
    [anon_sym_bytes27] = ACTIONS(677),
    [anon_sym_bytes28] = ACTIONS(677),
    [anon_sym_bytes29] = ACTIONS(677),
    [anon_sym_bytes30] = ACTIONS(677),
    [anon_sym_bytes31] = ACTIONS(677),
    [anon_sym_bytes32] = ACTIONS(677),
    [anon_sym_fixed] = ACTIONS(677),
    [aux_sym__fixed_token1] = ACTIONS(677),
    [anon_sym_ufixed] = ACTIONS(677),
    [aux_sym__ufixed_token1] = ACTIONS(677),
    [sym_comment] = ACTIONS(3),
  },
  [271] = {
    [sym_identifier] = ACTIONS(917),
    [anon_sym_RBRACE] = ACTIONS(919),
    [anon_sym_type] = ACTIONS(917),
    [anon_sym_error] = ACTIONS(917),
    [anon_sym_struct] = ACTIONS(917),
    [anon_sym_enum] = ACTIONS(917),
    [anon_sym_event] = ACTIONS(917),
    [anon_sym_using] = ACTIONS(917),
    [anon_sym_function] = ACTIONS(917),
    [anon_sym_byte] = ACTIONS(917),
    [anon_sym_address] = ACTIONS(917),
    [anon_sym_var] = ACTIONS(917),
    [anon_sym_modifier] = ACTIONS(917),
    [anon_sym_constructor] = ACTIONS(917),
    [anon_sym_fallback] = ACTIONS(917),
    [anon_sym_receive] = ACTIONS(917),
    [anon_sym_mapping] = ACTIONS(917),
    [anon_sym_bool] = ACTIONS(917),
    [anon_sym_string] = ACTIONS(917),
    [anon_sym_int] = ACTIONS(917),
    [anon_sym_int8] = ACTIONS(917),
    [anon_sym_int16] = ACTIONS(917),
    [anon_sym_int24] = ACTIONS(917),
    [anon_sym_int32] = ACTIONS(917),
    [anon_sym_int40] = ACTIONS(917),
    [anon_sym_int48] = ACTIONS(917),
    [anon_sym_int56] = ACTIONS(917),
    [anon_sym_int64] = ACTIONS(917),
    [anon_sym_int72] = ACTIONS(917),
    [anon_sym_int80] = ACTIONS(917),
    [anon_sym_int88] = ACTIONS(917),
    [anon_sym_int96] = ACTIONS(917),
    [anon_sym_int104] = ACTIONS(917),
    [anon_sym_int112] = ACTIONS(917),
    [anon_sym_int120] = ACTIONS(917),
    [anon_sym_int128] = ACTIONS(917),
    [anon_sym_int136] = ACTIONS(917),
    [anon_sym_int144] = ACTIONS(917),
    [anon_sym_int152] = ACTIONS(917),
    [anon_sym_int160] = ACTIONS(917),
    [anon_sym_int168] = ACTIONS(917),
    [anon_sym_int176] = ACTIONS(917),
    [anon_sym_int184] = ACTIONS(917),
    [anon_sym_int192] = ACTIONS(917),
    [anon_sym_int200] = ACTIONS(917),
    [anon_sym_int208] = ACTIONS(917),
    [anon_sym_int216] = ACTIONS(917),
    [anon_sym_int224] = ACTIONS(917),
    [anon_sym_int232] = ACTIONS(917),
    [anon_sym_int240] = ACTIONS(917),
    [anon_sym_int248] = ACTIONS(917),
    [anon_sym_int256] = ACTIONS(917),
    [anon_sym_uint] = ACTIONS(917),
    [anon_sym_uint8] = ACTIONS(917),
    [anon_sym_uint16] = ACTIONS(917),
    [anon_sym_uint24] = ACTIONS(917),
    [anon_sym_uint32] = ACTIONS(917),
    [anon_sym_uint40] = ACTIONS(917),
    [anon_sym_uint48] = ACTIONS(917),
    [anon_sym_uint56] = ACTIONS(917),
    [anon_sym_uint64] = ACTIONS(917),
    [anon_sym_uint72] = ACTIONS(917),
    [anon_sym_uint80] = ACTIONS(917),
    [anon_sym_uint88] = ACTIONS(917),
    [anon_sym_uint96] = ACTIONS(917),
    [anon_sym_uint104] = ACTIONS(917),
    [anon_sym_uint112] = ACTIONS(917),
    [anon_sym_uint120] = ACTIONS(917),
    [anon_sym_uint128] = ACTIONS(917),
    [anon_sym_uint136] = ACTIONS(917),
    [anon_sym_uint144] = ACTIONS(917),
    [anon_sym_uint152] = ACTIONS(917),
    [anon_sym_uint160] = ACTIONS(917),
    [anon_sym_uint168] = ACTIONS(917),
    [anon_sym_uint176] = ACTIONS(917),
    [anon_sym_uint184] = ACTIONS(917),
    [anon_sym_uint192] = ACTIONS(917),
    [anon_sym_uint200] = ACTIONS(917),
    [anon_sym_uint208] = ACTIONS(917),
    [anon_sym_uint216] = ACTIONS(917),
    [anon_sym_uint224] = ACTIONS(917),
    [anon_sym_uint232] = ACTIONS(917),
    [anon_sym_uint240] = ACTIONS(917),
    [anon_sym_uint248] = ACTIONS(917),
    [anon_sym_uint256] = ACTIONS(917),
    [anon_sym_bytes] = ACTIONS(917),
    [anon_sym_bytes1] = ACTIONS(917),
    [anon_sym_bytes2] = ACTIONS(917),
    [anon_sym_bytes3] = ACTIONS(917),
    [anon_sym_bytes4] = ACTIONS(917),
    [anon_sym_bytes5] = ACTIONS(917),
    [anon_sym_bytes6] = ACTIONS(917),
    [anon_sym_bytes7] = ACTIONS(917),
    [anon_sym_bytes8] = ACTIONS(917),
    [anon_sym_bytes9] = ACTIONS(917),
    [anon_sym_bytes10] = ACTIONS(917),
    [anon_sym_bytes11] = ACTIONS(917),
    [anon_sym_bytes12] = ACTIONS(917),
    [anon_sym_bytes13] = ACTIONS(917),
    [anon_sym_bytes14] = ACTIONS(917),
    [anon_sym_bytes15] = ACTIONS(917),
    [anon_sym_bytes16] = ACTIONS(917),
    [anon_sym_bytes17] = ACTIONS(917),
    [anon_sym_bytes18] = ACTIONS(917),
    [anon_sym_bytes19] = ACTIONS(917),
    [anon_sym_bytes20] = ACTIONS(917),
    [anon_sym_bytes21] = ACTIONS(917),
    [anon_sym_bytes22] = ACTIONS(917),
    [anon_sym_bytes23] = ACTIONS(917),
    [anon_sym_bytes24] = ACTIONS(917),
    [anon_sym_bytes25] = ACTIONS(917),
    [anon_sym_bytes26] = ACTIONS(917),
    [anon_sym_bytes27] = ACTIONS(917),
    [anon_sym_bytes28] = ACTIONS(917),
    [anon_sym_bytes29] = ACTIONS(917),
    [anon_sym_bytes30] = ACTIONS(917),
    [anon_sym_bytes31] = ACTIONS(917),
    [anon_sym_bytes32] = ACTIONS(917),
    [anon_sym_fixed] = ACTIONS(917),
    [aux_sym__fixed_token1] = ACTIONS(917),
    [anon_sym_ufixed] = ACTIONS(917),
    [aux_sym__ufixed_token1] = ACTIONS(917),
    [sym_comment] = ACTIONS(3),
  },
  [272] = {
    [sym_identifier] = ACTIONS(657),
    [anon_sym_RBRACE] = ACTIONS(655),
    [anon_sym_type] = ACTIONS(657),
    [anon_sym_error] = ACTIONS(657),
    [anon_sym_struct] = ACTIONS(657),
    [anon_sym_enum] = ACTIONS(657),
    [anon_sym_event] = ACTIONS(657),
    [anon_sym_using] = ACTIONS(657),
    [anon_sym_function] = ACTIONS(657),
    [anon_sym_byte] = ACTIONS(657),
    [anon_sym_address] = ACTIONS(657),
    [anon_sym_var] = ACTIONS(657),
    [anon_sym_modifier] = ACTIONS(657),
    [anon_sym_constructor] = ACTIONS(657),
    [anon_sym_fallback] = ACTIONS(657),
    [anon_sym_receive] = ACTIONS(657),
    [anon_sym_mapping] = ACTIONS(657),
    [anon_sym_bool] = ACTIONS(657),
    [anon_sym_string] = ACTIONS(657),
    [anon_sym_int] = ACTIONS(657),
    [anon_sym_int8] = ACTIONS(657),
    [anon_sym_int16] = ACTIONS(657),
    [anon_sym_int24] = ACTIONS(657),
    [anon_sym_int32] = ACTIONS(657),
    [anon_sym_int40] = ACTIONS(657),
    [anon_sym_int48] = ACTIONS(657),
    [anon_sym_int56] = ACTIONS(657),
    [anon_sym_int64] = ACTIONS(657),
    [anon_sym_int72] = ACTIONS(657),
    [anon_sym_int80] = ACTIONS(657),
    [anon_sym_int88] = ACTIONS(657),
    [anon_sym_int96] = ACTIONS(657),
    [anon_sym_int104] = ACTIONS(657),
    [anon_sym_int112] = ACTIONS(657),
    [anon_sym_int120] = ACTIONS(657),
    [anon_sym_int128] = ACTIONS(657),
    [anon_sym_int136] = ACTIONS(657),
    [anon_sym_int144] = ACTIONS(657),
    [anon_sym_int152] = ACTIONS(657),
    [anon_sym_int160] = ACTIONS(657),
    [anon_sym_int168] = ACTIONS(657),
    [anon_sym_int176] = ACTIONS(657),
    [anon_sym_int184] = ACTIONS(657),
    [anon_sym_int192] = ACTIONS(657),
    [anon_sym_int200] = ACTIONS(657),
    [anon_sym_int208] = ACTIONS(657),
    [anon_sym_int216] = ACTIONS(657),
    [anon_sym_int224] = ACTIONS(657),
    [anon_sym_int232] = ACTIONS(657),
    [anon_sym_int240] = ACTIONS(657),
    [anon_sym_int248] = ACTIONS(657),
    [anon_sym_int256] = ACTIONS(657),
    [anon_sym_uint] = ACTIONS(657),
    [anon_sym_uint8] = ACTIONS(657),
    [anon_sym_uint16] = ACTIONS(657),
    [anon_sym_uint24] = ACTIONS(657),
    [anon_sym_uint32] = ACTIONS(657),
    [anon_sym_uint40] = ACTIONS(657),
    [anon_sym_uint48] = ACTIONS(657),
    [anon_sym_uint56] = ACTIONS(657),
    [anon_sym_uint64] = ACTIONS(657),
    [anon_sym_uint72] = ACTIONS(657),
    [anon_sym_uint80] = ACTIONS(657),
    [anon_sym_uint88] = ACTIONS(657),
    [anon_sym_uint96] = ACTIONS(657),
    [anon_sym_uint104] = ACTIONS(657),
    [anon_sym_uint112] = ACTIONS(657),
    [anon_sym_uint120] = ACTIONS(657),
    [anon_sym_uint128] = ACTIONS(657),
    [anon_sym_uint136] = ACTIONS(657),
    [anon_sym_uint144] = ACTIONS(657),
    [anon_sym_uint152] = ACTIONS(657),
    [anon_sym_uint160] = ACTIONS(657),
    [anon_sym_uint168] = ACTIONS(657),
    [anon_sym_uint176] = ACTIONS(657),
    [anon_sym_uint184] = ACTIONS(657),
    [anon_sym_uint192] = ACTIONS(657),
    [anon_sym_uint200] = ACTIONS(657),
    [anon_sym_uint208] = ACTIONS(657),
    [anon_sym_uint216] = ACTIONS(657),
    [anon_sym_uint224] = ACTIONS(657),
    [anon_sym_uint232] = ACTIONS(657),
    [anon_sym_uint240] = ACTIONS(657),
    [anon_sym_uint248] = ACTIONS(657),
    [anon_sym_uint256] = ACTIONS(657),
    [anon_sym_bytes] = ACTIONS(657),
    [anon_sym_bytes1] = ACTIONS(657),
    [anon_sym_bytes2] = ACTIONS(657),
    [anon_sym_bytes3] = ACTIONS(657),
    [anon_sym_bytes4] = ACTIONS(657),
    [anon_sym_bytes5] = ACTIONS(657),
    [anon_sym_bytes6] = ACTIONS(657),
    [anon_sym_bytes7] = ACTIONS(657),
    [anon_sym_bytes8] = ACTIONS(657),
    [anon_sym_bytes9] = ACTIONS(657),
    [anon_sym_bytes10] = ACTIONS(657),
    [anon_sym_bytes11] = ACTIONS(657),
    [anon_sym_bytes12] = ACTIONS(657),
    [anon_sym_bytes13] = ACTIONS(657),
    [anon_sym_bytes14] = ACTIONS(657),
    [anon_sym_bytes15] = ACTIONS(657),
    [anon_sym_bytes16] = ACTIONS(657),
    [anon_sym_bytes17] = ACTIONS(657),
    [anon_sym_bytes18] = ACTIONS(657),
    [anon_sym_bytes19] = ACTIONS(657),
    [anon_sym_bytes20] = ACTIONS(657),
    [anon_sym_bytes21] = ACTIONS(657),
    [anon_sym_bytes22] = ACTIONS(657),
    [anon_sym_bytes23] = ACTIONS(657),
    [anon_sym_bytes24] = ACTIONS(657),
    [anon_sym_bytes25] = ACTIONS(657),
    [anon_sym_bytes26] = ACTIONS(657),
    [anon_sym_bytes27] = ACTIONS(657),
    [anon_sym_bytes28] = ACTIONS(657),
    [anon_sym_bytes29] = ACTIONS(657),
    [anon_sym_bytes30] = ACTIONS(657),
    [anon_sym_bytes31] = ACTIONS(657),
    [anon_sym_bytes32] = ACTIONS(657),
    [anon_sym_fixed] = ACTIONS(657),
    [aux_sym__fixed_token1] = ACTIONS(657),
    [anon_sym_ufixed] = ACTIONS(657),
    [aux_sym__ufixed_token1] = ACTIONS(657),
    [sym_comment] = ACTIONS(3),
  },
  [273] = {
    [sym_identifier] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(631),
    [anon_sym_type] = ACTIONS(633),
    [anon_sym_error] = ACTIONS(633),
    [anon_sym_struct] = ACTIONS(633),
    [anon_sym_enum] = ACTIONS(633),
    [anon_sym_event] = ACTIONS(633),
    [anon_sym_using] = ACTIONS(633),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_byte] = ACTIONS(633),
    [anon_sym_address] = ACTIONS(633),
    [anon_sym_var] = ACTIONS(633),
    [anon_sym_modifier] = ACTIONS(633),
    [anon_sym_constructor] = ACTIONS(633),
    [anon_sym_fallback] = ACTIONS(633),
    [anon_sym_receive] = ACTIONS(633),
    [anon_sym_mapping] = ACTIONS(633),
    [anon_sym_bool] = ACTIONS(633),
    [anon_sym_string] = ACTIONS(633),
    [anon_sym_int] = ACTIONS(633),
    [anon_sym_int8] = ACTIONS(633),
    [anon_sym_int16] = ACTIONS(633),
    [anon_sym_int24] = ACTIONS(633),
    [anon_sym_int32] = ACTIONS(633),
    [anon_sym_int40] = ACTIONS(633),
    [anon_sym_int48] = ACTIONS(633),
    [anon_sym_int56] = ACTIONS(633),
    [anon_sym_int64] = ACTIONS(633),
    [anon_sym_int72] = ACTIONS(633),
    [anon_sym_int80] = ACTIONS(633),
    [anon_sym_int88] = ACTIONS(633),
    [anon_sym_int96] = ACTIONS(633),
    [anon_sym_int104] = ACTIONS(633),
    [anon_sym_int112] = ACTIONS(633),
    [anon_sym_int120] = ACTIONS(633),
    [anon_sym_int128] = ACTIONS(633),
    [anon_sym_int136] = ACTIONS(633),
    [anon_sym_int144] = ACTIONS(633),
    [anon_sym_int152] = ACTIONS(633),
    [anon_sym_int160] = ACTIONS(633),
    [anon_sym_int168] = ACTIONS(633),
    [anon_sym_int176] = ACTIONS(633),
    [anon_sym_int184] = ACTIONS(633),
    [anon_sym_int192] = ACTIONS(633),
    [anon_sym_int200] = ACTIONS(633),
    [anon_sym_int208] = ACTIONS(633),
    [anon_sym_int216] = ACTIONS(633),
    [anon_sym_int224] = ACTIONS(633),
    [anon_sym_int232] = ACTIONS(633),
    [anon_sym_int240] = ACTIONS(633),
    [anon_sym_int248] = ACTIONS(633),
    [anon_sym_int256] = ACTIONS(633),
    [anon_sym_uint] = ACTIONS(633),
    [anon_sym_uint8] = ACTIONS(633),
    [anon_sym_uint16] = ACTIONS(633),
    [anon_sym_uint24] = ACTIONS(633),
    [anon_sym_uint32] = ACTIONS(633),
    [anon_sym_uint40] = ACTIONS(633),
    [anon_sym_uint48] = ACTIONS(633),
    [anon_sym_uint56] = ACTIONS(633),
    [anon_sym_uint64] = ACTIONS(633),
    [anon_sym_uint72] = ACTIONS(633),
    [anon_sym_uint80] = ACTIONS(633),
    [anon_sym_uint88] = ACTIONS(633),
    [anon_sym_uint96] = ACTIONS(633),
    [anon_sym_uint104] = ACTIONS(633),
    [anon_sym_uint112] = ACTIONS(633),
    [anon_sym_uint120] = ACTIONS(633),
    [anon_sym_uint128] = ACTIONS(633),
    [anon_sym_uint136] = ACTIONS(633),
    [anon_sym_uint144] = ACTIONS(633),
    [anon_sym_uint152] = ACTIONS(633),
    [anon_sym_uint160] = ACTIONS(633),
    [anon_sym_uint168] = ACTIONS(633),
    [anon_sym_uint176] = ACTIONS(633),
    [anon_sym_uint184] = ACTIONS(633),
    [anon_sym_uint192] = ACTIONS(633),
    [anon_sym_uint200] = ACTIONS(633),
    [anon_sym_uint208] = ACTIONS(633),
    [anon_sym_uint216] = ACTIONS(633),
    [anon_sym_uint224] = ACTIONS(633),
    [anon_sym_uint232] = ACTIONS(633),
    [anon_sym_uint240] = ACTIONS(633),
    [anon_sym_uint248] = ACTIONS(633),
    [anon_sym_uint256] = ACTIONS(633),
    [anon_sym_bytes] = ACTIONS(633),
    [anon_sym_bytes1] = ACTIONS(633),
    [anon_sym_bytes2] = ACTIONS(633),
    [anon_sym_bytes3] = ACTIONS(633),
    [anon_sym_bytes4] = ACTIONS(633),
    [anon_sym_bytes5] = ACTIONS(633),
    [anon_sym_bytes6] = ACTIONS(633),
    [anon_sym_bytes7] = ACTIONS(633),
    [anon_sym_bytes8] = ACTIONS(633),
    [anon_sym_bytes9] = ACTIONS(633),
    [anon_sym_bytes10] = ACTIONS(633),
    [anon_sym_bytes11] = ACTIONS(633),
    [anon_sym_bytes12] = ACTIONS(633),
    [anon_sym_bytes13] = ACTIONS(633),
    [anon_sym_bytes14] = ACTIONS(633),
    [anon_sym_bytes15] = ACTIONS(633),
    [anon_sym_bytes16] = ACTIONS(633),
    [anon_sym_bytes17] = ACTIONS(633),
    [anon_sym_bytes18] = ACTIONS(633),
    [anon_sym_bytes19] = ACTIONS(633),
    [anon_sym_bytes20] = ACTIONS(633),
    [anon_sym_bytes21] = ACTIONS(633),
    [anon_sym_bytes22] = ACTIONS(633),
    [anon_sym_bytes23] = ACTIONS(633),
    [anon_sym_bytes24] = ACTIONS(633),
    [anon_sym_bytes25] = ACTIONS(633),
    [anon_sym_bytes26] = ACTIONS(633),
    [anon_sym_bytes27] = ACTIONS(633),
    [anon_sym_bytes28] = ACTIONS(633),
    [anon_sym_bytes29] = ACTIONS(633),
    [anon_sym_bytes30] = ACTIONS(633),
    [anon_sym_bytes31] = ACTIONS(633),
    [anon_sym_bytes32] = ACTIONS(633),
    [anon_sym_fixed] = ACTIONS(633),
    [aux_sym__fixed_token1] = ACTIONS(633),
    [anon_sym_ufixed] = ACTIONS(633),
    [aux_sym__ufixed_token1] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
  },
  [274] = {
    [sym_identifier] = ACTIONS(665),
    [anon_sym_RBRACE] = ACTIONS(663),
    [anon_sym_type] = ACTIONS(665),
    [anon_sym_error] = ACTIONS(665),
    [anon_sym_struct] = ACTIONS(665),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_event] = ACTIONS(665),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_function] = ACTIONS(665),
    [anon_sym_byte] = ACTIONS(665),
    [anon_sym_address] = ACTIONS(665),
    [anon_sym_var] = ACTIONS(665),
    [anon_sym_modifier] = ACTIONS(665),
    [anon_sym_constructor] = ACTIONS(665),
    [anon_sym_fallback] = ACTIONS(665),
    [anon_sym_receive] = ACTIONS(665),
    [anon_sym_mapping] = ACTIONS(665),
    [anon_sym_bool] = ACTIONS(665),
    [anon_sym_string] = ACTIONS(665),
    [anon_sym_int] = ACTIONS(665),
    [anon_sym_int8] = ACTIONS(665),
    [anon_sym_int16] = ACTIONS(665),
    [anon_sym_int24] = ACTIONS(665),
    [anon_sym_int32] = ACTIONS(665),
    [anon_sym_int40] = ACTIONS(665),
    [anon_sym_int48] = ACTIONS(665),
    [anon_sym_int56] = ACTIONS(665),
    [anon_sym_int64] = ACTIONS(665),
    [anon_sym_int72] = ACTIONS(665),
    [anon_sym_int80] = ACTIONS(665),
    [anon_sym_int88] = ACTIONS(665),
    [anon_sym_int96] = ACTIONS(665),
    [anon_sym_int104] = ACTIONS(665),
    [anon_sym_int112] = ACTIONS(665),
    [anon_sym_int120] = ACTIONS(665),
    [anon_sym_int128] = ACTIONS(665),
    [anon_sym_int136] = ACTIONS(665),
    [anon_sym_int144] = ACTIONS(665),
    [anon_sym_int152] = ACTIONS(665),
    [anon_sym_int160] = ACTIONS(665),
    [anon_sym_int168] = ACTIONS(665),
    [anon_sym_int176] = ACTIONS(665),
    [anon_sym_int184] = ACTIONS(665),
    [anon_sym_int192] = ACTIONS(665),
    [anon_sym_int200] = ACTIONS(665),
    [anon_sym_int208] = ACTIONS(665),
    [anon_sym_int216] = ACTIONS(665),
    [anon_sym_int224] = ACTIONS(665),
    [anon_sym_int232] = ACTIONS(665),
    [anon_sym_int240] = ACTIONS(665),
    [anon_sym_int248] = ACTIONS(665),
    [anon_sym_int256] = ACTIONS(665),
    [anon_sym_uint] = ACTIONS(665),
    [anon_sym_uint8] = ACTIONS(665),
    [anon_sym_uint16] = ACTIONS(665),
    [anon_sym_uint24] = ACTIONS(665),
    [anon_sym_uint32] = ACTIONS(665),
    [anon_sym_uint40] = ACTIONS(665),
    [anon_sym_uint48] = ACTIONS(665),
    [anon_sym_uint56] = ACTIONS(665),
    [anon_sym_uint64] = ACTIONS(665),
    [anon_sym_uint72] = ACTIONS(665),
    [anon_sym_uint80] = ACTIONS(665),
    [anon_sym_uint88] = ACTIONS(665),
    [anon_sym_uint96] = ACTIONS(665),
    [anon_sym_uint104] = ACTIONS(665),
    [anon_sym_uint112] = ACTIONS(665),
    [anon_sym_uint120] = ACTIONS(665),
    [anon_sym_uint128] = ACTIONS(665),
    [anon_sym_uint136] = ACTIONS(665),
    [anon_sym_uint144] = ACTIONS(665),
    [anon_sym_uint152] = ACTIONS(665),
    [anon_sym_uint160] = ACTIONS(665),
    [anon_sym_uint168] = ACTIONS(665),
    [anon_sym_uint176] = ACTIONS(665),
    [anon_sym_uint184] = ACTIONS(665),
    [anon_sym_uint192] = ACTIONS(665),
    [anon_sym_uint200] = ACTIONS(665),
    [anon_sym_uint208] = ACTIONS(665),
    [anon_sym_uint216] = ACTIONS(665),
    [anon_sym_uint224] = ACTIONS(665),
    [anon_sym_uint232] = ACTIONS(665),
    [anon_sym_uint240] = ACTIONS(665),
    [anon_sym_uint248] = ACTIONS(665),
    [anon_sym_uint256] = ACTIONS(665),
    [anon_sym_bytes] = ACTIONS(665),
    [anon_sym_bytes1] = ACTIONS(665),
    [anon_sym_bytes2] = ACTIONS(665),
    [anon_sym_bytes3] = ACTIONS(665),
    [anon_sym_bytes4] = ACTIONS(665),
    [anon_sym_bytes5] = ACTIONS(665),
    [anon_sym_bytes6] = ACTIONS(665),
    [anon_sym_bytes7] = ACTIONS(665),
    [anon_sym_bytes8] = ACTIONS(665),
    [anon_sym_bytes9] = ACTIONS(665),
    [anon_sym_bytes10] = ACTIONS(665),
    [anon_sym_bytes11] = ACTIONS(665),
    [anon_sym_bytes12] = ACTIONS(665),
    [anon_sym_bytes13] = ACTIONS(665),
    [anon_sym_bytes14] = ACTIONS(665),
    [anon_sym_bytes15] = ACTIONS(665),
    [anon_sym_bytes16] = ACTIONS(665),
    [anon_sym_bytes17] = ACTIONS(665),
    [anon_sym_bytes18] = ACTIONS(665),
    [anon_sym_bytes19] = ACTIONS(665),
    [anon_sym_bytes20] = ACTIONS(665),
    [anon_sym_bytes21] = ACTIONS(665),
    [anon_sym_bytes22] = ACTIONS(665),
    [anon_sym_bytes23] = ACTIONS(665),
    [anon_sym_bytes24] = ACTIONS(665),
    [anon_sym_bytes25] = ACTIONS(665),
    [anon_sym_bytes26] = ACTIONS(665),
    [anon_sym_bytes27] = ACTIONS(665),
    [anon_sym_bytes28] = ACTIONS(665),
    [anon_sym_bytes29] = ACTIONS(665),
    [anon_sym_bytes30] = ACTIONS(665),
    [anon_sym_bytes31] = ACTIONS(665),
    [anon_sym_bytes32] = ACTIONS(665),
    [anon_sym_fixed] = ACTIONS(665),
    [aux_sym__fixed_token1] = ACTIONS(665),
    [anon_sym_ufixed] = ACTIONS(665),
    [aux_sym__ufixed_token1] = ACTIONS(665),
    [sym_comment] = ACTIONS(3),
  },
  [275] = {
    [sym_identifier] = ACTIONS(725),
    [anon_sym_RBRACE] = ACTIONS(723),
    [anon_sym_type] = ACTIONS(725),
    [anon_sym_error] = ACTIONS(725),
    [anon_sym_struct] = ACTIONS(725),
    [anon_sym_enum] = ACTIONS(725),
    [anon_sym_event] = ACTIONS(725),
    [anon_sym_using] = ACTIONS(725),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_byte] = ACTIONS(725),
    [anon_sym_address] = ACTIONS(725),
    [anon_sym_var] = ACTIONS(725),
    [anon_sym_modifier] = ACTIONS(725),
    [anon_sym_constructor] = ACTIONS(725),
    [anon_sym_fallback] = ACTIONS(725),
    [anon_sym_receive] = ACTIONS(725),
    [anon_sym_mapping] = ACTIONS(725),
    [anon_sym_bool] = ACTIONS(725),
    [anon_sym_string] = ACTIONS(725),
    [anon_sym_int] = ACTIONS(725),
    [anon_sym_int8] = ACTIONS(725),
    [anon_sym_int16] = ACTIONS(725),
    [anon_sym_int24] = ACTIONS(725),
    [anon_sym_int32] = ACTIONS(725),
    [anon_sym_int40] = ACTIONS(725),
    [anon_sym_int48] = ACTIONS(725),
    [anon_sym_int56] = ACTIONS(725),
    [anon_sym_int64] = ACTIONS(725),
    [anon_sym_int72] = ACTIONS(725),
    [anon_sym_int80] = ACTIONS(725),
    [anon_sym_int88] = ACTIONS(725),
    [anon_sym_int96] = ACTIONS(725),
    [anon_sym_int104] = ACTIONS(725),
    [anon_sym_int112] = ACTIONS(725),
    [anon_sym_int120] = ACTIONS(725),
    [anon_sym_int128] = ACTIONS(725),
    [anon_sym_int136] = ACTIONS(725),
    [anon_sym_int144] = ACTIONS(725),
    [anon_sym_int152] = ACTIONS(725),
    [anon_sym_int160] = ACTIONS(725),
    [anon_sym_int168] = ACTIONS(725),
    [anon_sym_int176] = ACTIONS(725),
    [anon_sym_int184] = ACTIONS(725),
    [anon_sym_int192] = ACTIONS(725),
    [anon_sym_int200] = ACTIONS(725),
    [anon_sym_int208] = ACTIONS(725),
    [anon_sym_int216] = ACTIONS(725),
    [anon_sym_int224] = ACTIONS(725),
    [anon_sym_int232] = ACTIONS(725),
    [anon_sym_int240] = ACTIONS(725),
    [anon_sym_int248] = ACTIONS(725),
    [anon_sym_int256] = ACTIONS(725),
    [anon_sym_uint] = ACTIONS(725),
    [anon_sym_uint8] = ACTIONS(725),
    [anon_sym_uint16] = ACTIONS(725),
    [anon_sym_uint24] = ACTIONS(725),
    [anon_sym_uint32] = ACTIONS(725),
    [anon_sym_uint40] = ACTIONS(725),
    [anon_sym_uint48] = ACTIONS(725),
    [anon_sym_uint56] = ACTIONS(725),
    [anon_sym_uint64] = ACTIONS(725),
    [anon_sym_uint72] = ACTIONS(725),
    [anon_sym_uint80] = ACTIONS(725),
    [anon_sym_uint88] = ACTIONS(725),
    [anon_sym_uint96] = ACTIONS(725),
    [anon_sym_uint104] = ACTIONS(725),
    [anon_sym_uint112] = ACTIONS(725),
    [anon_sym_uint120] = ACTIONS(725),
    [anon_sym_uint128] = ACTIONS(725),
    [anon_sym_uint136] = ACTIONS(725),
    [anon_sym_uint144] = ACTIONS(725),
    [anon_sym_uint152] = ACTIONS(725),
    [anon_sym_uint160] = ACTIONS(725),
    [anon_sym_uint168] = ACTIONS(725),
    [anon_sym_uint176] = ACTIONS(725),
    [anon_sym_uint184] = ACTIONS(725),
    [anon_sym_uint192] = ACTIONS(725),
    [anon_sym_uint200] = ACTIONS(725),
    [anon_sym_uint208] = ACTIONS(725),
    [anon_sym_uint216] = ACTIONS(725),
    [anon_sym_uint224] = ACTIONS(725),
    [anon_sym_uint232] = ACTIONS(725),
    [anon_sym_uint240] = ACTIONS(725),
    [anon_sym_uint248] = ACTIONS(725),
    [anon_sym_uint256] = ACTIONS(725),
    [anon_sym_bytes] = ACTIONS(725),
    [anon_sym_bytes1] = ACTIONS(725),
    [anon_sym_bytes2] = ACTIONS(725),
    [anon_sym_bytes3] = ACTIONS(725),
    [anon_sym_bytes4] = ACTIONS(725),
    [anon_sym_bytes5] = ACTIONS(725),
    [anon_sym_bytes6] = ACTIONS(725),
    [anon_sym_bytes7] = ACTIONS(725),
    [anon_sym_bytes8] = ACTIONS(725),
    [anon_sym_bytes9] = ACTIONS(725),
    [anon_sym_bytes10] = ACTIONS(725),
    [anon_sym_bytes11] = ACTIONS(725),
    [anon_sym_bytes12] = ACTIONS(725),
    [anon_sym_bytes13] = ACTIONS(725),
    [anon_sym_bytes14] = ACTIONS(725),
    [anon_sym_bytes15] = ACTIONS(725),
    [anon_sym_bytes16] = ACTIONS(725),
    [anon_sym_bytes17] = ACTIONS(725),
    [anon_sym_bytes18] = ACTIONS(725),
    [anon_sym_bytes19] = ACTIONS(725),
    [anon_sym_bytes20] = ACTIONS(725),
    [anon_sym_bytes21] = ACTIONS(725),
    [anon_sym_bytes22] = ACTIONS(725),
    [anon_sym_bytes23] = ACTIONS(725),
    [anon_sym_bytes24] = ACTIONS(725),
    [anon_sym_bytes25] = ACTIONS(725),
    [anon_sym_bytes26] = ACTIONS(725),
    [anon_sym_bytes27] = ACTIONS(725),
    [anon_sym_bytes28] = ACTIONS(725),
    [anon_sym_bytes29] = ACTIONS(725),
    [anon_sym_bytes30] = ACTIONS(725),
    [anon_sym_bytes31] = ACTIONS(725),
    [anon_sym_bytes32] = ACTIONS(725),
    [anon_sym_fixed] = ACTIONS(725),
    [aux_sym__fixed_token1] = ACTIONS(725),
    [anon_sym_ufixed] = ACTIONS(725),
    [aux_sym__ufixed_token1] = ACTIONS(725),
    [sym_comment] = ACTIONS(3),
  },
  [276] = {
    [sym_identifier] = ACTIONS(669),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_type] = ACTIONS(669),
    [anon_sym_error] = ACTIONS(669),
    [anon_sym_struct] = ACTIONS(669),
    [anon_sym_enum] = ACTIONS(669),
    [anon_sym_event] = ACTIONS(669),
    [anon_sym_using] = ACTIONS(669),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_byte] = ACTIONS(669),
    [anon_sym_address] = ACTIONS(669),
    [anon_sym_var] = ACTIONS(669),
    [anon_sym_modifier] = ACTIONS(669),
    [anon_sym_constructor] = ACTIONS(669),
    [anon_sym_fallback] = ACTIONS(669),
    [anon_sym_receive] = ACTIONS(669),
    [anon_sym_mapping] = ACTIONS(669),
    [anon_sym_bool] = ACTIONS(669),
    [anon_sym_string] = ACTIONS(669),
    [anon_sym_int] = ACTIONS(669),
    [anon_sym_int8] = ACTIONS(669),
    [anon_sym_int16] = ACTIONS(669),
    [anon_sym_int24] = ACTIONS(669),
    [anon_sym_int32] = ACTIONS(669),
    [anon_sym_int40] = ACTIONS(669),
    [anon_sym_int48] = ACTIONS(669),
    [anon_sym_int56] = ACTIONS(669),
    [anon_sym_int64] = ACTIONS(669),
    [anon_sym_int72] = ACTIONS(669),
    [anon_sym_int80] = ACTIONS(669),
    [anon_sym_int88] = ACTIONS(669),
    [anon_sym_int96] = ACTIONS(669),
    [anon_sym_int104] = ACTIONS(669),
    [anon_sym_int112] = ACTIONS(669),
    [anon_sym_int120] = ACTIONS(669),
    [anon_sym_int128] = ACTIONS(669),
    [anon_sym_int136] = ACTIONS(669),
    [anon_sym_int144] = ACTIONS(669),
    [anon_sym_int152] = ACTIONS(669),
    [anon_sym_int160] = ACTIONS(669),
    [anon_sym_int168] = ACTIONS(669),
    [anon_sym_int176] = ACTIONS(669),
    [anon_sym_int184] = ACTIONS(669),
    [anon_sym_int192] = ACTIONS(669),
    [anon_sym_int200] = ACTIONS(669),
    [anon_sym_int208] = ACTIONS(669),
    [anon_sym_int216] = ACTIONS(669),
    [anon_sym_int224] = ACTIONS(669),
    [anon_sym_int232] = ACTIONS(669),
    [anon_sym_int240] = ACTIONS(669),
    [anon_sym_int248] = ACTIONS(669),
    [anon_sym_int256] = ACTIONS(669),
    [anon_sym_uint] = ACTIONS(669),
    [anon_sym_uint8] = ACTIONS(669),
    [anon_sym_uint16] = ACTIONS(669),
    [anon_sym_uint24] = ACTIONS(669),
    [anon_sym_uint32] = ACTIONS(669),
    [anon_sym_uint40] = ACTIONS(669),
    [anon_sym_uint48] = ACTIONS(669),
    [anon_sym_uint56] = ACTIONS(669),
    [anon_sym_uint64] = ACTIONS(669),
    [anon_sym_uint72] = ACTIONS(669),
    [anon_sym_uint80] = ACTIONS(669),
    [anon_sym_uint88] = ACTIONS(669),
    [anon_sym_uint96] = ACTIONS(669),
    [anon_sym_uint104] = ACTIONS(669),
    [anon_sym_uint112] = ACTIONS(669),
    [anon_sym_uint120] = ACTIONS(669),
    [anon_sym_uint128] = ACTIONS(669),
    [anon_sym_uint136] = ACTIONS(669),
    [anon_sym_uint144] = ACTIONS(669),
    [anon_sym_uint152] = ACTIONS(669),
    [anon_sym_uint160] = ACTIONS(669),
    [anon_sym_uint168] = ACTIONS(669),
    [anon_sym_uint176] = ACTIONS(669),
    [anon_sym_uint184] = ACTIONS(669),
    [anon_sym_uint192] = ACTIONS(669),
    [anon_sym_uint200] = ACTIONS(669),
    [anon_sym_uint208] = ACTIONS(669),
    [anon_sym_uint216] = ACTIONS(669),
    [anon_sym_uint224] = ACTIONS(669),
    [anon_sym_uint232] = ACTIONS(669),
    [anon_sym_uint240] = ACTIONS(669),
    [anon_sym_uint248] = ACTIONS(669),
    [anon_sym_uint256] = ACTIONS(669),
    [anon_sym_bytes] = ACTIONS(669),
    [anon_sym_bytes1] = ACTIONS(669),
    [anon_sym_bytes2] = ACTIONS(669),
    [anon_sym_bytes3] = ACTIONS(669),
    [anon_sym_bytes4] = ACTIONS(669),
    [anon_sym_bytes5] = ACTIONS(669),
    [anon_sym_bytes6] = ACTIONS(669),
    [anon_sym_bytes7] = ACTIONS(669),
    [anon_sym_bytes8] = ACTIONS(669),
    [anon_sym_bytes9] = ACTIONS(669),
    [anon_sym_bytes10] = ACTIONS(669),
    [anon_sym_bytes11] = ACTIONS(669),
    [anon_sym_bytes12] = ACTIONS(669),
    [anon_sym_bytes13] = ACTIONS(669),
    [anon_sym_bytes14] = ACTIONS(669),
    [anon_sym_bytes15] = ACTIONS(669),
    [anon_sym_bytes16] = ACTIONS(669),
    [anon_sym_bytes17] = ACTIONS(669),
    [anon_sym_bytes18] = ACTIONS(669),
    [anon_sym_bytes19] = ACTIONS(669),
    [anon_sym_bytes20] = ACTIONS(669),
    [anon_sym_bytes21] = ACTIONS(669),
    [anon_sym_bytes22] = ACTIONS(669),
    [anon_sym_bytes23] = ACTIONS(669),
    [anon_sym_bytes24] = ACTIONS(669),
    [anon_sym_bytes25] = ACTIONS(669),
    [anon_sym_bytes26] = ACTIONS(669),
    [anon_sym_bytes27] = ACTIONS(669),
    [anon_sym_bytes28] = ACTIONS(669),
    [anon_sym_bytes29] = ACTIONS(669),
    [anon_sym_bytes30] = ACTIONS(669),
    [anon_sym_bytes31] = ACTIONS(669),
    [anon_sym_bytes32] = ACTIONS(669),
    [anon_sym_fixed] = ACTIONS(669),
    [aux_sym__fixed_token1] = ACTIONS(669),
    [anon_sym_ufixed] = ACTIONS(669),
    [aux_sym__ufixed_token1] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
  },
  [277] = {
    [sym_identifier] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(719),
    [anon_sym_type] = ACTIONS(721),
    [anon_sym_error] = ACTIONS(721),
    [anon_sym_struct] = ACTIONS(721),
    [anon_sym_enum] = ACTIONS(721),
    [anon_sym_event] = ACTIONS(721),
    [anon_sym_using] = ACTIONS(721),
    [anon_sym_function] = ACTIONS(721),
    [anon_sym_byte] = ACTIONS(721),
    [anon_sym_address] = ACTIONS(721),
    [anon_sym_var] = ACTIONS(721),
    [anon_sym_modifier] = ACTIONS(721),
    [anon_sym_constructor] = ACTIONS(721),
    [anon_sym_fallback] = ACTIONS(721),
    [anon_sym_receive] = ACTIONS(721),
    [anon_sym_mapping] = ACTIONS(721),
    [anon_sym_bool] = ACTIONS(721),
    [anon_sym_string] = ACTIONS(721),
    [anon_sym_int] = ACTIONS(721),
    [anon_sym_int8] = ACTIONS(721),
    [anon_sym_int16] = ACTIONS(721),
    [anon_sym_int24] = ACTIONS(721),
    [anon_sym_int32] = ACTIONS(721),
    [anon_sym_int40] = ACTIONS(721),
    [anon_sym_int48] = ACTIONS(721),
    [anon_sym_int56] = ACTIONS(721),
    [anon_sym_int64] = ACTIONS(721),
    [anon_sym_int72] = ACTIONS(721),
    [anon_sym_int80] = ACTIONS(721),
    [anon_sym_int88] = ACTIONS(721),
    [anon_sym_int96] = ACTIONS(721),
    [anon_sym_int104] = ACTIONS(721),
    [anon_sym_int112] = ACTIONS(721),
    [anon_sym_int120] = ACTIONS(721),
    [anon_sym_int128] = ACTIONS(721),
    [anon_sym_int136] = ACTIONS(721),
    [anon_sym_int144] = ACTIONS(721),
    [anon_sym_int152] = ACTIONS(721),
    [anon_sym_int160] = ACTIONS(721),
    [anon_sym_int168] = ACTIONS(721),
    [anon_sym_int176] = ACTIONS(721),
    [anon_sym_int184] = ACTIONS(721),
    [anon_sym_int192] = ACTIONS(721),
    [anon_sym_int200] = ACTIONS(721),
    [anon_sym_int208] = ACTIONS(721),
    [anon_sym_int216] = ACTIONS(721),
    [anon_sym_int224] = ACTIONS(721),
    [anon_sym_int232] = ACTIONS(721),
    [anon_sym_int240] = ACTIONS(721),
    [anon_sym_int248] = ACTIONS(721),
    [anon_sym_int256] = ACTIONS(721),
    [anon_sym_uint] = ACTIONS(721),
    [anon_sym_uint8] = ACTIONS(721),
    [anon_sym_uint16] = ACTIONS(721),
    [anon_sym_uint24] = ACTIONS(721),
    [anon_sym_uint32] = ACTIONS(721),
    [anon_sym_uint40] = ACTIONS(721),
    [anon_sym_uint48] = ACTIONS(721),
    [anon_sym_uint56] = ACTIONS(721),
    [anon_sym_uint64] = ACTIONS(721),
    [anon_sym_uint72] = ACTIONS(721),
    [anon_sym_uint80] = ACTIONS(721),
    [anon_sym_uint88] = ACTIONS(721),
    [anon_sym_uint96] = ACTIONS(721),
    [anon_sym_uint104] = ACTIONS(721),
    [anon_sym_uint112] = ACTIONS(721),
    [anon_sym_uint120] = ACTIONS(721),
    [anon_sym_uint128] = ACTIONS(721),
    [anon_sym_uint136] = ACTIONS(721),
    [anon_sym_uint144] = ACTIONS(721),
    [anon_sym_uint152] = ACTIONS(721),
    [anon_sym_uint160] = ACTIONS(721),
    [anon_sym_uint168] = ACTIONS(721),
    [anon_sym_uint176] = ACTIONS(721),
    [anon_sym_uint184] = ACTIONS(721),
    [anon_sym_uint192] = ACTIONS(721),
    [anon_sym_uint200] = ACTIONS(721),
    [anon_sym_uint208] = ACTIONS(721),
    [anon_sym_uint216] = ACTIONS(721),
    [anon_sym_uint224] = ACTIONS(721),
    [anon_sym_uint232] = ACTIONS(721),
    [anon_sym_uint240] = ACTIONS(721),
    [anon_sym_uint248] = ACTIONS(721),
    [anon_sym_uint256] = ACTIONS(721),
    [anon_sym_bytes] = ACTIONS(721),
    [anon_sym_bytes1] = ACTIONS(721),
    [anon_sym_bytes2] = ACTIONS(721),
    [anon_sym_bytes3] = ACTIONS(721),
    [anon_sym_bytes4] = ACTIONS(721),
    [anon_sym_bytes5] = ACTIONS(721),
    [anon_sym_bytes6] = ACTIONS(721),
    [anon_sym_bytes7] = ACTIONS(721),
    [anon_sym_bytes8] = ACTIONS(721),
    [anon_sym_bytes9] = ACTIONS(721),
    [anon_sym_bytes10] = ACTIONS(721),
    [anon_sym_bytes11] = ACTIONS(721),
    [anon_sym_bytes12] = ACTIONS(721),
    [anon_sym_bytes13] = ACTIONS(721),
    [anon_sym_bytes14] = ACTIONS(721),
    [anon_sym_bytes15] = ACTIONS(721),
    [anon_sym_bytes16] = ACTIONS(721),
    [anon_sym_bytes17] = ACTIONS(721),
    [anon_sym_bytes18] = ACTIONS(721),
    [anon_sym_bytes19] = ACTIONS(721),
    [anon_sym_bytes20] = ACTIONS(721),
    [anon_sym_bytes21] = ACTIONS(721),
    [anon_sym_bytes22] = ACTIONS(721),
    [anon_sym_bytes23] = ACTIONS(721),
    [anon_sym_bytes24] = ACTIONS(721),
    [anon_sym_bytes25] = ACTIONS(721),
    [anon_sym_bytes26] = ACTIONS(721),
    [anon_sym_bytes27] = ACTIONS(721),
    [anon_sym_bytes28] = ACTIONS(721),
    [anon_sym_bytes29] = ACTIONS(721),
    [anon_sym_bytes30] = ACTIONS(721),
    [anon_sym_bytes31] = ACTIONS(721),
    [anon_sym_bytes32] = ACTIONS(721),
    [anon_sym_fixed] = ACTIONS(721),
    [aux_sym__fixed_token1] = ACTIONS(721),
    [anon_sym_ufixed] = ACTIONS(721),
    [aux_sym__ufixed_token1] = ACTIONS(721),
    [sym_comment] = ACTIONS(3),
  },
  [278] = {
    [sym_identifier] = ACTIONS(921),
    [anon_sym_RBRACE] = ACTIONS(923),
    [anon_sym_type] = ACTIONS(921),
    [anon_sym_error] = ACTIONS(921),
    [anon_sym_struct] = ACTIONS(921),
    [anon_sym_enum] = ACTIONS(921),
    [anon_sym_event] = ACTIONS(921),
    [anon_sym_using] = ACTIONS(921),
    [anon_sym_function] = ACTIONS(921),
    [anon_sym_byte] = ACTIONS(921),
    [anon_sym_address] = ACTIONS(921),
    [anon_sym_var] = ACTIONS(921),
    [anon_sym_modifier] = ACTIONS(921),
    [anon_sym_constructor] = ACTIONS(921),
    [anon_sym_fallback] = ACTIONS(921),
    [anon_sym_receive] = ACTIONS(921),
    [anon_sym_mapping] = ACTIONS(921),
    [anon_sym_bool] = ACTIONS(921),
    [anon_sym_string] = ACTIONS(921),
    [anon_sym_int] = ACTIONS(921),
    [anon_sym_int8] = ACTIONS(921),
    [anon_sym_int16] = ACTIONS(921),
    [anon_sym_int24] = ACTIONS(921),
    [anon_sym_int32] = ACTIONS(921),
    [anon_sym_int40] = ACTIONS(921),
    [anon_sym_int48] = ACTIONS(921),
    [anon_sym_int56] = ACTIONS(921),
    [anon_sym_int64] = ACTIONS(921),
    [anon_sym_int72] = ACTIONS(921),
    [anon_sym_int80] = ACTIONS(921),
    [anon_sym_int88] = ACTIONS(921),
    [anon_sym_int96] = ACTIONS(921),
    [anon_sym_int104] = ACTIONS(921),
    [anon_sym_int112] = ACTIONS(921),
    [anon_sym_int120] = ACTIONS(921),
    [anon_sym_int128] = ACTIONS(921),
    [anon_sym_int136] = ACTIONS(921),
    [anon_sym_int144] = ACTIONS(921),
    [anon_sym_int152] = ACTIONS(921),
    [anon_sym_int160] = ACTIONS(921),
    [anon_sym_int168] = ACTIONS(921),
    [anon_sym_int176] = ACTIONS(921),
    [anon_sym_int184] = ACTIONS(921),
    [anon_sym_int192] = ACTIONS(921),
    [anon_sym_int200] = ACTIONS(921),
    [anon_sym_int208] = ACTIONS(921),
    [anon_sym_int216] = ACTIONS(921),
    [anon_sym_int224] = ACTIONS(921),
    [anon_sym_int232] = ACTIONS(921),
    [anon_sym_int240] = ACTIONS(921),
    [anon_sym_int248] = ACTIONS(921),
    [anon_sym_int256] = ACTIONS(921),
    [anon_sym_uint] = ACTIONS(921),
    [anon_sym_uint8] = ACTIONS(921),
    [anon_sym_uint16] = ACTIONS(921),
    [anon_sym_uint24] = ACTIONS(921),
    [anon_sym_uint32] = ACTIONS(921),
    [anon_sym_uint40] = ACTIONS(921),
    [anon_sym_uint48] = ACTIONS(921),
    [anon_sym_uint56] = ACTIONS(921),
    [anon_sym_uint64] = ACTIONS(921),
    [anon_sym_uint72] = ACTIONS(921),
    [anon_sym_uint80] = ACTIONS(921),
    [anon_sym_uint88] = ACTIONS(921),
    [anon_sym_uint96] = ACTIONS(921),
    [anon_sym_uint104] = ACTIONS(921),
    [anon_sym_uint112] = ACTIONS(921),
    [anon_sym_uint120] = ACTIONS(921),
    [anon_sym_uint128] = ACTIONS(921),
    [anon_sym_uint136] = ACTIONS(921),
    [anon_sym_uint144] = ACTIONS(921),
    [anon_sym_uint152] = ACTIONS(921),
    [anon_sym_uint160] = ACTIONS(921),
    [anon_sym_uint168] = ACTIONS(921),
    [anon_sym_uint176] = ACTIONS(921),
    [anon_sym_uint184] = ACTIONS(921),
    [anon_sym_uint192] = ACTIONS(921),
    [anon_sym_uint200] = ACTIONS(921),
    [anon_sym_uint208] = ACTIONS(921),
    [anon_sym_uint216] = ACTIONS(921),
    [anon_sym_uint224] = ACTIONS(921),
    [anon_sym_uint232] = ACTIONS(921),
    [anon_sym_uint240] = ACTIONS(921),
    [anon_sym_uint248] = ACTIONS(921),
    [anon_sym_uint256] = ACTIONS(921),
    [anon_sym_bytes] = ACTIONS(921),
    [anon_sym_bytes1] = ACTIONS(921),
    [anon_sym_bytes2] = ACTIONS(921),
    [anon_sym_bytes3] = ACTIONS(921),
    [anon_sym_bytes4] = ACTIONS(921),
    [anon_sym_bytes5] = ACTIONS(921),
    [anon_sym_bytes6] = ACTIONS(921),
    [anon_sym_bytes7] = ACTIONS(921),
    [anon_sym_bytes8] = ACTIONS(921),
    [anon_sym_bytes9] = ACTIONS(921),
    [anon_sym_bytes10] = ACTIONS(921),
    [anon_sym_bytes11] = ACTIONS(921),
    [anon_sym_bytes12] = ACTIONS(921),
    [anon_sym_bytes13] = ACTIONS(921),
    [anon_sym_bytes14] = ACTIONS(921),
    [anon_sym_bytes15] = ACTIONS(921),
    [anon_sym_bytes16] = ACTIONS(921),
    [anon_sym_bytes17] = ACTIONS(921),
    [anon_sym_bytes18] = ACTIONS(921),
    [anon_sym_bytes19] = ACTIONS(921),
    [anon_sym_bytes20] = ACTIONS(921),
    [anon_sym_bytes21] = ACTIONS(921),
    [anon_sym_bytes22] = ACTIONS(921),
    [anon_sym_bytes23] = ACTIONS(921),
    [anon_sym_bytes24] = ACTIONS(921),
    [anon_sym_bytes25] = ACTIONS(921),
    [anon_sym_bytes26] = ACTIONS(921),
    [anon_sym_bytes27] = ACTIONS(921),
    [anon_sym_bytes28] = ACTIONS(921),
    [anon_sym_bytes29] = ACTIONS(921),
    [anon_sym_bytes30] = ACTIONS(921),
    [anon_sym_bytes31] = ACTIONS(921),
    [anon_sym_bytes32] = ACTIONS(921),
    [anon_sym_fixed] = ACTIONS(921),
    [aux_sym__fixed_token1] = ACTIONS(921),
    [anon_sym_ufixed] = ACTIONS(921),
    [aux_sym__ufixed_token1] = ACTIONS(921),
    [sym_comment] = ACTIONS(3),
  },
  [279] = {
    [sym_identifier] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(631),
    [anon_sym_type] = ACTIONS(633),
    [anon_sym_error] = ACTIONS(633),
    [anon_sym_struct] = ACTIONS(633),
    [anon_sym_enum] = ACTIONS(633),
    [anon_sym_event] = ACTIONS(633),
    [anon_sym_using] = ACTIONS(633),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_byte] = ACTIONS(633),
    [anon_sym_address] = ACTIONS(633),
    [anon_sym_var] = ACTIONS(633),
    [anon_sym_modifier] = ACTIONS(633),
    [anon_sym_constructor] = ACTIONS(633),
    [anon_sym_fallback] = ACTIONS(633),
    [anon_sym_receive] = ACTIONS(633),
    [anon_sym_mapping] = ACTIONS(633),
    [anon_sym_bool] = ACTIONS(633),
    [anon_sym_string] = ACTIONS(633),
    [anon_sym_int] = ACTIONS(633),
    [anon_sym_int8] = ACTIONS(633),
    [anon_sym_int16] = ACTIONS(633),
    [anon_sym_int24] = ACTIONS(633),
    [anon_sym_int32] = ACTIONS(633),
    [anon_sym_int40] = ACTIONS(633),
    [anon_sym_int48] = ACTIONS(633),
    [anon_sym_int56] = ACTIONS(633),
    [anon_sym_int64] = ACTIONS(633),
    [anon_sym_int72] = ACTIONS(633),
    [anon_sym_int80] = ACTIONS(633),
    [anon_sym_int88] = ACTIONS(633),
    [anon_sym_int96] = ACTIONS(633),
    [anon_sym_int104] = ACTIONS(633),
    [anon_sym_int112] = ACTIONS(633),
    [anon_sym_int120] = ACTIONS(633),
    [anon_sym_int128] = ACTIONS(633),
    [anon_sym_int136] = ACTIONS(633),
    [anon_sym_int144] = ACTIONS(633),
    [anon_sym_int152] = ACTIONS(633),
    [anon_sym_int160] = ACTIONS(633),
    [anon_sym_int168] = ACTIONS(633),
    [anon_sym_int176] = ACTIONS(633),
    [anon_sym_int184] = ACTIONS(633),
    [anon_sym_int192] = ACTIONS(633),
    [anon_sym_int200] = ACTIONS(633),
    [anon_sym_int208] = ACTIONS(633),
    [anon_sym_int216] = ACTIONS(633),
    [anon_sym_int224] = ACTIONS(633),
    [anon_sym_int232] = ACTIONS(633),
    [anon_sym_int240] = ACTIONS(633),
    [anon_sym_int248] = ACTIONS(633),
    [anon_sym_int256] = ACTIONS(633),
    [anon_sym_uint] = ACTIONS(633),
    [anon_sym_uint8] = ACTIONS(633),
    [anon_sym_uint16] = ACTIONS(633),
    [anon_sym_uint24] = ACTIONS(633),
    [anon_sym_uint32] = ACTIONS(633),
    [anon_sym_uint40] = ACTIONS(633),
    [anon_sym_uint48] = ACTIONS(633),
    [anon_sym_uint56] = ACTIONS(633),
    [anon_sym_uint64] = ACTIONS(633),
    [anon_sym_uint72] = ACTIONS(633),
    [anon_sym_uint80] = ACTIONS(633),
    [anon_sym_uint88] = ACTIONS(633),
    [anon_sym_uint96] = ACTIONS(633),
    [anon_sym_uint104] = ACTIONS(633),
    [anon_sym_uint112] = ACTIONS(633),
    [anon_sym_uint120] = ACTIONS(633),
    [anon_sym_uint128] = ACTIONS(633),
    [anon_sym_uint136] = ACTIONS(633),
    [anon_sym_uint144] = ACTIONS(633),
    [anon_sym_uint152] = ACTIONS(633),
    [anon_sym_uint160] = ACTIONS(633),
    [anon_sym_uint168] = ACTIONS(633),
    [anon_sym_uint176] = ACTIONS(633),
    [anon_sym_uint184] = ACTIONS(633),
    [anon_sym_uint192] = ACTIONS(633),
    [anon_sym_uint200] = ACTIONS(633),
    [anon_sym_uint208] = ACTIONS(633),
    [anon_sym_uint216] = ACTIONS(633),
    [anon_sym_uint224] = ACTIONS(633),
    [anon_sym_uint232] = ACTIONS(633),
    [anon_sym_uint240] = ACTIONS(633),
    [anon_sym_uint248] = ACTIONS(633),
    [anon_sym_uint256] = ACTIONS(633),
    [anon_sym_bytes] = ACTIONS(633),
    [anon_sym_bytes1] = ACTIONS(633),
    [anon_sym_bytes2] = ACTIONS(633),
    [anon_sym_bytes3] = ACTIONS(633),
    [anon_sym_bytes4] = ACTIONS(633),
    [anon_sym_bytes5] = ACTIONS(633),
    [anon_sym_bytes6] = ACTIONS(633),
    [anon_sym_bytes7] = ACTIONS(633),
    [anon_sym_bytes8] = ACTIONS(633),
    [anon_sym_bytes9] = ACTIONS(633),
    [anon_sym_bytes10] = ACTIONS(633),
    [anon_sym_bytes11] = ACTIONS(633),
    [anon_sym_bytes12] = ACTIONS(633),
    [anon_sym_bytes13] = ACTIONS(633),
    [anon_sym_bytes14] = ACTIONS(633),
    [anon_sym_bytes15] = ACTIONS(633),
    [anon_sym_bytes16] = ACTIONS(633),
    [anon_sym_bytes17] = ACTIONS(633),
    [anon_sym_bytes18] = ACTIONS(633),
    [anon_sym_bytes19] = ACTIONS(633),
    [anon_sym_bytes20] = ACTIONS(633),
    [anon_sym_bytes21] = ACTIONS(633),
    [anon_sym_bytes22] = ACTIONS(633),
    [anon_sym_bytes23] = ACTIONS(633),
    [anon_sym_bytes24] = ACTIONS(633),
    [anon_sym_bytes25] = ACTIONS(633),
    [anon_sym_bytes26] = ACTIONS(633),
    [anon_sym_bytes27] = ACTIONS(633),
    [anon_sym_bytes28] = ACTIONS(633),
    [anon_sym_bytes29] = ACTIONS(633),
    [anon_sym_bytes30] = ACTIONS(633),
    [anon_sym_bytes31] = ACTIONS(633),
    [anon_sym_bytes32] = ACTIONS(633),
    [anon_sym_fixed] = ACTIONS(633),
    [aux_sym__fixed_token1] = ACTIONS(633),
    [anon_sym_ufixed] = ACTIONS(633),
    [aux_sym__ufixed_token1] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
  },
  [280] = {
    [sym_identifier] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(715),
    [anon_sym_type] = ACTIONS(717),
    [anon_sym_error] = ACTIONS(717),
    [anon_sym_struct] = ACTIONS(717),
    [anon_sym_enum] = ACTIONS(717),
    [anon_sym_event] = ACTIONS(717),
    [anon_sym_using] = ACTIONS(717),
    [anon_sym_function] = ACTIONS(717),
    [anon_sym_byte] = ACTIONS(717),
    [anon_sym_address] = ACTIONS(717),
    [anon_sym_var] = ACTIONS(717),
    [anon_sym_modifier] = ACTIONS(717),
    [anon_sym_constructor] = ACTIONS(717),
    [anon_sym_fallback] = ACTIONS(717),
    [anon_sym_receive] = ACTIONS(717),
    [anon_sym_mapping] = ACTIONS(717),
    [anon_sym_bool] = ACTIONS(717),
    [anon_sym_string] = ACTIONS(717),
    [anon_sym_int] = ACTIONS(717),
    [anon_sym_int8] = ACTIONS(717),
    [anon_sym_int16] = ACTIONS(717),
    [anon_sym_int24] = ACTIONS(717),
    [anon_sym_int32] = ACTIONS(717),
    [anon_sym_int40] = ACTIONS(717),
    [anon_sym_int48] = ACTIONS(717),
    [anon_sym_int56] = ACTIONS(717),
    [anon_sym_int64] = ACTIONS(717),
    [anon_sym_int72] = ACTIONS(717),
    [anon_sym_int80] = ACTIONS(717),
    [anon_sym_int88] = ACTIONS(717),
    [anon_sym_int96] = ACTIONS(717),
    [anon_sym_int104] = ACTIONS(717),
    [anon_sym_int112] = ACTIONS(717),
    [anon_sym_int120] = ACTIONS(717),
    [anon_sym_int128] = ACTIONS(717),
    [anon_sym_int136] = ACTIONS(717),
    [anon_sym_int144] = ACTIONS(717),
    [anon_sym_int152] = ACTIONS(717),
    [anon_sym_int160] = ACTIONS(717),
    [anon_sym_int168] = ACTIONS(717),
    [anon_sym_int176] = ACTIONS(717),
    [anon_sym_int184] = ACTIONS(717),
    [anon_sym_int192] = ACTIONS(717),
    [anon_sym_int200] = ACTIONS(717),
    [anon_sym_int208] = ACTIONS(717),
    [anon_sym_int216] = ACTIONS(717),
    [anon_sym_int224] = ACTIONS(717),
    [anon_sym_int232] = ACTIONS(717),
    [anon_sym_int240] = ACTIONS(717),
    [anon_sym_int248] = ACTIONS(717),
    [anon_sym_int256] = ACTIONS(717),
    [anon_sym_uint] = ACTIONS(717),
    [anon_sym_uint8] = ACTIONS(717),
    [anon_sym_uint16] = ACTIONS(717),
    [anon_sym_uint24] = ACTIONS(717),
    [anon_sym_uint32] = ACTIONS(717),
    [anon_sym_uint40] = ACTIONS(717),
    [anon_sym_uint48] = ACTIONS(717),
    [anon_sym_uint56] = ACTIONS(717),
    [anon_sym_uint64] = ACTIONS(717),
    [anon_sym_uint72] = ACTIONS(717),
    [anon_sym_uint80] = ACTIONS(717),
    [anon_sym_uint88] = ACTIONS(717),
    [anon_sym_uint96] = ACTIONS(717),
    [anon_sym_uint104] = ACTIONS(717),
    [anon_sym_uint112] = ACTIONS(717),
    [anon_sym_uint120] = ACTIONS(717),
    [anon_sym_uint128] = ACTIONS(717),
    [anon_sym_uint136] = ACTIONS(717),
    [anon_sym_uint144] = ACTIONS(717),
    [anon_sym_uint152] = ACTIONS(717),
    [anon_sym_uint160] = ACTIONS(717),
    [anon_sym_uint168] = ACTIONS(717),
    [anon_sym_uint176] = ACTIONS(717),
    [anon_sym_uint184] = ACTIONS(717),
    [anon_sym_uint192] = ACTIONS(717),
    [anon_sym_uint200] = ACTIONS(717),
    [anon_sym_uint208] = ACTIONS(717),
    [anon_sym_uint216] = ACTIONS(717),
    [anon_sym_uint224] = ACTIONS(717),
    [anon_sym_uint232] = ACTIONS(717),
    [anon_sym_uint240] = ACTIONS(717),
    [anon_sym_uint248] = ACTIONS(717),
    [anon_sym_uint256] = ACTIONS(717),
    [anon_sym_bytes] = ACTIONS(717),
    [anon_sym_bytes1] = ACTIONS(717),
    [anon_sym_bytes2] = ACTIONS(717),
    [anon_sym_bytes3] = ACTIONS(717),
    [anon_sym_bytes4] = ACTIONS(717),
    [anon_sym_bytes5] = ACTIONS(717),
    [anon_sym_bytes6] = ACTIONS(717),
    [anon_sym_bytes7] = ACTIONS(717),
    [anon_sym_bytes8] = ACTIONS(717),
    [anon_sym_bytes9] = ACTIONS(717),
    [anon_sym_bytes10] = ACTIONS(717),
    [anon_sym_bytes11] = ACTIONS(717),
    [anon_sym_bytes12] = ACTIONS(717),
    [anon_sym_bytes13] = ACTIONS(717),
    [anon_sym_bytes14] = ACTIONS(717),
    [anon_sym_bytes15] = ACTIONS(717),
    [anon_sym_bytes16] = ACTIONS(717),
    [anon_sym_bytes17] = ACTIONS(717),
    [anon_sym_bytes18] = ACTIONS(717),
    [anon_sym_bytes19] = ACTIONS(717),
    [anon_sym_bytes20] = ACTIONS(717),
    [anon_sym_bytes21] = ACTIONS(717),
    [anon_sym_bytes22] = ACTIONS(717),
    [anon_sym_bytes23] = ACTIONS(717),
    [anon_sym_bytes24] = ACTIONS(717),
    [anon_sym_bytes25] = ACTIONS(717),
    [anon_sym_bytes26] = ACTIONS(717),
    [anon_sym_bytes27] = ACTIONS(717),
    [anon_sym_bytes28] = ACTIONS(717),
    [anon_sym_bytes29] = ACTIONS(717),
    [anon_sym_bytes30] = ACTIONS(717),
    [anon_sym_bytes31] = ACTIONS(717),
    [anon_sym_bytes32] = ACTIONS(717),
    [anon_sym_fixed] = ACTIONS(717),
    [aux_sym__fixed_token1] = ACTIONS(717),
    [anon_sym_ufixed] = ACTIONS(717),
    [aux_sym__ufixed_token1] = ACTIONS(717),
    [sym_comment] = ACTIONS(3),
  },
  [281] = {
    [sym_identifier] = ACTIONS(789),
    [anon_sym_RBRACE] = ACTIONS(787),
    [anon_sym_type] = ACTIONS(789),
    [anon_sym_error] = ACTIONS(789),
    [anon_sym_struct] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(789),
    [anon_sym_event] = ACTIONS(789),
    [anon_sym_using] = ACTIONS(789),
    [anon_sym_function] = ACTIONS(789),
    [anon_sym_byte] = ACTIONS(789),
    [anon_sym_address] = ACTIONS(789),
    [anon_sym_var] = ACTIONS(789),
    [anon_sym_modifier] = ACTIONS(789),
    [anon_sym_constructor] = ACTIONS(789),
    [anon_sym_fallback] = ACTIONS(789),
    [anon_sym_receive] = ACTIONS(789),
    [anon_sym_mapping] = ACTIONS(789),
    [anon_sym_bool] = ACTIONS(789),
    [anon_sym_string] = ACTIONS(789),
    [anon_sym_int] = ACTIONS(789),
    [anon_sym_int8] = ACTIONS(789),
    [anon_sym_int16] = ACTIONS(789),
    [anon_sym_int24] = ACTIONS(789),
    [anon_sym_int32] = ACTIONS(789),
    [anon_sym_int40] = ACTIONS(789),
    [anon_sym_int48] = ACTIONS(789),
    [anon_sym_int56] = ACTIONS(789),
    [anon_sym_int64] = ACTIONS(789),
    [anon_sym_int72] = ACTIONS(789),
    [anon_sym_int80] = ACTIONS(789),
    [anon_sym_int88] = ACTIONS(789),
    [anon_sym_int96] = ACTIONS(789),
    [anon_sym_int104] = ACTIONS(789),
    [anon_sym_int112] = ACTIONS(789),
    [anon_sym_int120] = ACTIONS(789),
    [anon_sym_int128] = ACTIONS(789),
    [anon_sym_int136] = ACTIONS(789),
    [anon_sym_int144] = ACTIONS(789),
    [anon_sym_int152] = ACTIONS(789),
    [anon_sym_int160] = ACTIONS(789),
    [anon_sym_int168] = ACTIONS(789),
    [anon_sym_int176] = ACTIONS(789),
    [anon_sym_int184] = ACTIONS(789),
    [anon_sym_int192] = ACTIONS(789),
    [anon_sym_int200] = ACTIONS(789),
    [anon_sym_int208] = ACTIONS(789),
    [anon_sym_int216] = ACTIONS(789),
    [anon_sym_int224] = ACTIONS(789),
    [anon_sym_int232] = ACTIONS(789),
    [anon_sym_int240] = ACTIONS(789),
    [anon_sym_int248] = ACTIONS(789),
    [anon_sym_int256] = ACTIONS(789),
    [anon_sym_uint] = ACTIONS(789),
    [anon_sym_uint8] = ACTIONS(789),
    [anon_sym_uint16] = ACTIONS(789),
    [anon_sym_uint24] = ACTIONS(789),
    [anon_sym_uint32] = ACTIONS(789),
    [anon_sym_uint40] = ACTIONS(789),
    [anon_sym_uint48] = ACTIONS(789),
    [anon_sym_uint56] = ACTIONS(789),
    [anon_sym_uint64] = ACTIONS(789),
    [anon_sym_uint72] = ACTIONS(789),
    [anon_sym_uint80] = ACTIONS(789),
    [anon_sym_uint88] = ACTIONS(789),
    [anon_sym_uint96] = ACTIONS(789),
    [anon_sym_uint104] = ACTIONS(789),
    [anon_sym_uint112] = ACTIONS(789),
    [anon_sym_uint120] = ACTIONS(789),
    [anon_sym_uint128] = ACTIONS(789),
    [anon_sym_uint136] = ACTIONS(789),
    [anon_sym_uint144] = ACTIONS(789),
    [anon_sym_uint152] = ACTIONS(789),
    [anon_sym_uint160] = ACTIONS(789),
    [anon_sym_uint168] = ACTIONS(789),
    [anon_sym_uint176] = ACTIONS(789),
    [anon_sym_uint184] = ACTIONS(789),
    [anon_sym_uint192] = ACTIONS(789),
    [anon_sym_uint200] = ACTIONS(789),
    [anon_sym_uint208] = ACTIONS(789),
    [anon_sym_uint216] = ACTIONS(789),
    [anon_sym_uint224] = ACTIONS(789),
    [anon_sym_uint232] = ACTIONS(789),
    [anon_sym_uint240] = ACTIONS(789),
    [anon_sym_uint248] = ACTIONS(789),
    [anon_sym_uint256] = ACTIONS(789),
    [anon_sym_bytes] = ACTIONS(789),
    [anon_sym_bytes1] = ACTIONS(789),
    [anon_sym_bytes2] = ACTIONS(789),
    [anon_sym_bytes3] = ACTIONS(789),
    [anon_sym_bytes4] = ACTIONS(789),
    [anon_sym_bytes5] = ACTIONS(789),
    [anon_sym_bytes6] = ACTIONS(789),
    [anon_sym_bytes7] = ACTIONS(789),
    [anon_sym_bytes8] = ACTIONS(789),
    [anon_sym_bytes9] = ACTIONS(789),
    [anon_sym_bytes10] = ACTIONS(789),
    [anon_sym_bytes11] = ACTIONS(789),
    [anon_sym_bytes12] = ACTIONS(789),
    [anon_sym_bytes13] = ACTIONS(789),
    [anon_sym_bytes14] = ACTIONS(789),
    [anon_sym_bytes15] = ACTIONS(789),
    [anon_sym_bytes16] = ACTIONS(789),
    [anon_sym_bytes17] = ACTIONS(789),
    [anon_sym_bytes18] = ACTIONS(789),
    [anon_sym_bytes19] = ACTIONS(789),
    [anon_sym_bytes20] = ACTIONS(789),
    [anon_sym_bytes21] = ACTIONS(789),
    [anon_sym_bytes22] = ACTIONS(789),
    [anon_sym_bytes23] = ACTIONS(789),
    [anon_sym_bytes24] = ACTIONS(789),
    [anon_sym_bytes25] = ACTIONS(789),
    [anon_sym_bytes26] = ACTIONS(789),
    [anon_sym_bytes27] = ACTIONS(789),
    [anon_sym_bytes28] = ACTIONS(789),
    [anon_sym_bytes29] = ACTIONS(789),
    [anon_sym_bytes30] = ACTIONS(789),
    [anon_sym_bytes31] = ACTIONS(789),
    [anon_sym_bytes32] = ACTIONS(789),
    [anon_sym_fixed] = ACTIONS(789),
    [aux_sym__fixed_token1] = ACTIONS(789),
    [anon_sym_ufixed] = ACTIONS(789),
    [aux_sym__ufixed_token1] = ACTIONS(789),
    [sym_comment] = ACTIONS(3),
  },
  [282] = {
    [sym_identifier] = ACTIONS(685),
    [anon_sym_RBRACE] = ACTIONS(683),
    [anon_sym_type] = ACTIONS(685),
    [anon_sym_error] = ACTIONS(685),
    [anon_sym_struct] = ACTIONS(685),
    [anon_sym_enum] = ACTIONS(685),
    [anon_sym_event] = ACTIONS(685),
    [anon_sym_using] = ACTIONS(685),
    [anon_sym_function] = ACTIONS(685),
    [anon_sym_byte] = ACTIONS(685),
    [anon_sym_address] = ACTIONS(685),
    [anon_sym_var] = ACTIONS(685),
    [anon_sym_modifier] = ACTIONS(685),
    [anon_sym_constructor] = ACTIONS(685),
    [anon_sym_fallback] = ACTIONS(685),
    [anon_sym_receive] = ACTIONS(685),
    [anon_sym_mapping] = ACTIONS(685),
    [anon_sym_bool] = ACTIONS(685),
    [anon_sym_string] = ACTIONS(685),
    [anon_sym_int] = ACTIONS(685),
    [anon_sym_int8] = ACTIONS(685),
    [anon_sym_int16] = ACTIONS(685),
    [anon_sym_int24] = ACTIONS(685),
    [anon_sym_int32] = ACTIONS(685),
    [anon_sym_int40] = ACTIONS(685),
    [anon_sym_int48] = ACTIONS(685),
    [anon_sym_int56] = ACTIONS(685),
    [anon_sym_int64] = ACTIONS(685),
    [anon_sym_int72] = ACTIONS(685),
    [anon_sym_int80] = ACTIONS(685),
    [anon_sym_int88] = ACTIONS(685),
    [anon_sym_int96] = ACTIONS(685),
    [anon_sym_int104] = ACTIONS(685),
    [anon_sym_int112] = ACTIONS(685),
    [anon_sym_int120] = ACTIONS(685),
    [anon_sym_int128] = ACTIONS(685),
    [anon_sym_int136] = ACTIONS(685),
    [anon_sym_int144] = ACTIONS(685),
    [anon_sym_int152] = ACTIONS(685),
    [anon_sym_int160] = ACTIONS(685),
    [anon_sym_int168] = ACTIONS(685),
    [anon_sym_int176] = ACTIONS(685),
    [anon_sym_int184] = ACTIONS(685),
    [anon_sym_int192] = ACTIONS(685),
    [anon_sym_int200] = ACTIONS(685),
    [anon_sym_int208] = ACTIONS(685),
    [anon_sym_int216] = ACTIONS(685),
    [anon_sym_int224] = ACTIONS(685),
    [anon_sym_int232] = ACTIONS(685),
    [anon_sym_int240] = ACTIONS(685),
    [anon_sym_int248] = ACTIONS(685),
    [anon_sym_int256] = ACTIONS(685),
    [anon_sym_uint] = ACTIONS(685),
    [anon_sym_uint8] = ACTIONS(685),
    [anon_sym_uint16] = ACTIONS(685),
    [anon_sym_uint24] = ACTIONS(685),
    [anon_sym_uint32] = ACTIONS(685),
    [anon_sym_uint40] = ACTIONS(685),
    [anon_sym_uint48] = ACTIONS(685),
    [anon_sym_uint56] = ACTIONS(685),
    [anon_sym_uint64] = ACTIONS(685),
    [anon_sym_uint72] = ACTIONS(685),
    [anon_sym_uint80] = ACTIONS(685),
    [anon_sym_uint88] = ACTIONS(685),
    [anon_sym_uint96] = ACTIONS(685),
    [anon_sym_uint104] = ACTIONS(685),
    [anon_sym_uint112] = ACTIONS(685),
    [anon_sym_uint120] = ACTIONS(685),
    [anon_sym_uint128] = ACTIONS(685),
    [anon_sym_uint136] = ACTIONS(685),
    [anon_sym_uint144] = ACTIONS(685),
    [anon_sym_uint152] = ACTIONS(685),
    [anon_sym_uint160] = ACTIONS(685),
    [anon_sym_uint168] = ACTIONS(685),
    [anon_sym_uint176] = ACTIONS(685),
    [anon_sym_uint184] = ACTIONS(685),
    [anon_sym_uint192] = ACTIONS(685),
    [anon_sym_uint200] = ACTIONS(685),
    [anon_sym_uint208] = ACTIONS(685),
    [anon_sym_uint216] = ACTIONS(685),
    [anon_sym_uint224] = ACTIONS(685),
    [anon_sym_uint232] = ACTIONS(685),
    [anon_sym_uint240] = ACTIONS(685),
    [anon_sym_uint248] = ACTIONS(685),
    [anon_sym_uint256] = ACTIONS(685),
    [anon_sym_bytes] = ACTIONS(685),
    [anon_sym_bytes1] = ACTIONS(685),
    [anon_sym_bytes2] = ACTIONS(685),
    [anon_sym_bytes3] = ACTIONS(685),
    [anon_sym_bytes4] = ACTIONS(685),
    [anon_sym_bytes5] = ACTIONS(685),
    [anon_sym_bytes6] = ACTIONS(685),
    [anon_sym_bytes7] = ACTIONS(685),
    [anon_sym_bytes8] = ACTIONS(685),
    [anon_sym_bytes9] = ACTIONS(685),
    [anon_sym_bytes10] = ACTIONS(685),
    [anon_sym_bytes11] = ACTIONS(685),
    [anon_sym_bytes12] = ACTIONS(685),
    [anon_sym_bytes13] = ACTIONS(685),
    [anon_sym_bytes14] = ACTIONS(685),
    [anon_sym_bytes15] = ACTIONS(685),
    [anon_sym_bytes16] = ACTIONS(685),
    [anon_sym_bytes17] = ACTIONS(685),
    [anon_sym_bytes18] = ACTIONS(685),
    [anon_sym_bytes19] = ACTIONS(685),
    [anon_sym_bytes20] = ACTIONS(685),
    [anon_sym_bytes21] = ACTIONS(685),
    [anon_sym_bytes22] = ACTIONS(685),
    [anon_sym_bytes23] = ACTIONS(685),
    [anon_sym_bytes24] = ACTIONS(685),
    [anon_sym_bytes25] = ACTIONS(685),
    [anon_sym_bytes26] = ACTIONS(685),
    [anon_sym_bytes27] = ACTIONS(685),
    [anon_sym_bytes28] = ACTIONS(685),
    [anon_sym_bytes29] = ACTIONS(685),
    [anon_sym_bytes30] = ACTIONS(685),
    [anon_sym_bytes31] = ACTIONS(685),
    [anon_sym_bytes32] = ACTIONS(685),
    [anon_sym_fixed] = ACTIONS(685),
    [aux_sym__fixed_token1] = ACTIONS(685),
    [anon_sym_ufixed] = ACTIONS(685),
    [aux_sym__ufixed_token1] = ACTIONS(685),
    [sym_comment] = ACTIONS(3),
  },
  [283] = {
    [sym_identifier] = ACTIONS(925),
    [anon_sym_RBRACE] = ACTIONS(927),
    [anon_sym_type] = ACTIONS(925),
    [anon_sym_error] = ACTIONS(925),
    [anon_sym_struct] = ACTIONS(925),
    [anon_sym_enum] = ACTIONS(925),
    [anon_sym_event] = ACTIONS(925),
    [anon_sym_using] = ACTIONS(925),
    [anon_sym_function] = ACTIONS(925),
    [anon_sym_byte] = ACTIONS(925),
    [anon_sym_address] = ACTIONS(925),
    [anon_sym_var] = ACTIONS(925),
    [anon_sym_modifier] = ACTIONS(925),
    [anon_sym_constructor] = ACTIONS(925),
    [anon_sym_fallback] = ACTIONS(925),
    [anon_sym_receive] = ACTIONS(925),
    [anon_sym_mapping] = ACTIONS(925),
    [anon_sym_bool] = ACTIONS(925),
    [anon_sym_string] = ACTIONS(925),
    [anon_sym_int] = ACTIONS(925),
    [anon_sym_int8] = ACTIONS(925),
    [anon_sym_int16] = ACTIONS(925),
    [anon_sym_int24] = ACTIONS(925),
    [anon_sym_int32] = ACTIONS(925),
    [anon_sym_int40] = ACTIONS(925),
    [anon_sym_int48] = ACTIONS(925),
    [anon_sym_int56] = ACTIONS(925),
    [anon_sym_int64] = ACTIONS(925),
    [anon_sym_int72] = ACTIONS(925),
    [anon_sym_int80] = ACTIONS(925),
    [anon_sym_int88] = ACTIONS(925),
    [anon_sym_int96] = ACTIONS(925),
    [anon_sym_int104] = ACTIONS(925),
    [anon_sym_int112] = ACTIONS(925),
    [anon_sym_int120] = ACTIONS(925),
    [anon_sym_int128] = ACTIONS(925),
    [anon_sym_int136] = ACTIONS(925),
    [anon_sym_int144] = ACTIONS(925),
    [anon_sym_int152] = ACTIONS(925),
    [anon_sym_int160] = ACTIONS(925),
    [anon_sym_int168] = ACTIONS(925),
    [anon_sym_int176] = ACTIONS(925),
    [anon_sym_int184] = ACTIONS(925),
    [anon_sym_int192] = ACTIONS(925),
    [anon_sym_int200] = ACTIONS(925),
    [anon_sym_int208] = ACTIONS(925),
    [anon_sym_int216] = ACTIONS(925),
    [anon_sym_int224] = ACTIONS(925),
    [anon_sym_int232] = ACTIONS(925),
    [anon_sym_int240] = ACTIONS(925),
    [anon_sym_int248] = ACTIONS(925),
    [anon_sym_int256] = ACTIONS(925),
    [anon_sym_uint] = ACTIONS(925),
    [anon_sym_uint8] = ACTIONS(925),
    [anon_sym_uint16] = ACTIONS(925),
    [anon_sym_uint24] = ACTIONS(925),
    [anon_sym_uint32] = ACTIONS(925),
    [anon_sym_uint40] = ACTIONS(925),
    [anon_sym_uint48] = ACTIONS(925),
    [anon_sym_uint56] = ACTIONS(925),
    [anon_sym_uint64] = ACTIONS(925),
    [anon_sym_uint72] = ACTIONS(925),
    [anon_sym_uint80] = ACTIONS(925),
    [anon_sym_uint88] = ACTIONS(925),
    [anon_sym_uint96] = ACTIONS(925),
    [anon_sym_uint104] = ACTIONS(925),
    [anon_sym_uint112] = ACTIONS(925),
    [anon_sym_uint120] = ACTIONS(925),
    [anon_sym_uint128] = ACTIONS(925),
    [anon_sym_uint136] = ACTIONS(925),
    [anon_sym_uint144] = ACTIONS(925),
    [anon_sym_uint152] = ACTIONS(925),
    [anon_sym_uint160] = ACTIONS(925),
    [anon_sym_uint168] = ACTIONS(925),
    [anon_sym_uint176] = ACTIONS(925),
    [anon_sym_uint184] = ACTIONS(925),
    [anon_sym_uint192] = ACTIONS(925),
    [anon_sym_uint200] = ACTIONS(925),
    [anon_sym_uint208] = ACTIONS(925),
    [anon_sym_uint216] = ACTIONS(925),
    [anon_sym_uint224] = ACTIONS(925),
    [anon_sym_uint232] = ACTIONS(925),
    [anon_sym_uint240] = ACTIONS(925),
    [anon_sym_uint248] = ACTIONS(925),
    [anon_sym_uint256] = ACTIONS(925),
    [anon_sym_bytes] = ACTIONS(925),
    [anon_sym_bytes1] = ACTIONS(925),
    [anon_sym_bytes2] = ACTIONS(925),
    [anon_sym_bytes3] = ACTIONS(925),
    [anon_sym_bytes4] = ACTIONS(925),
    [anon_sym_bytes5] = ACTIONS(925),
    [anon_sym_bytes6] = ACTIONS(925),
    [anon_sym_bytes7] = ACTIONS(925),
    [anon_sym_bytes8] = ACTIONS(925),
    [anon_sym_bytes9] = ACTIONS(925),
    [anon_sym_bytes10] = ACTIONS(925),
    [anon_sym_bytes11] = ACTIONS(925),
    [anon_sym_bytes12] = ACTIONS(925),
    [anon_sym_bytes13] = ACTIONS(925),
    [anon_sym_bytes14] = ACTIONS(925),
    [anon_sym_bytes15] = ACTIONS(925),
    [anon_sym_bytes16] = ACTIONS(925),
    [anon_sym_bytes17] = ACTIONS(925),
    [anon_sym_bytes18] = ACTIONS(925),
    [anon_sym_bytes19] = ACTIONS(925),
    [anon_sym_bytes20] = ACTIONS(925),
    [anon_sym_bytes21] = ACTIONS(925),
    [anon_sym_bytes22] = ACTIONS(925),
    [anon_sym_bytes23] = ACTIONS(925),
    [anon_sym_bytes24] = ACTIONS(925),
    [anon_sym_bytes25] = ACTIONS(925),
    [anon_sym_bytes26] = ACTIONS(925),
    [anon_sym_bytes27] = ACTIONS(925),
    [anon_sym_bytes28] = ACTIONS(925),
    [anon_sym_bytes29] = ACTIONS(925),
    [anon_sym_bytes30] = ACTIONS(925),
    [anon_sym_bytes31] = ACTIONS(925),
    [anon_sym_bytes32] = ACTIONS(925),
    [anon_sym_fixed] = ACTIONS(925),
    [aux_sym__fixed_token1] = ACTIONS(925),
    [anon_sym_ufixed] = ACTIONS(925),
    [aux_sym__ufixed_token1] = ACTIONS(925),
    [sym_comment] = ACTIONS(3),
  },
  [284] = {
    [sym_identifier] = ACTIONS(737),
    [anon_sym_RBRACE] = ACTIONS(735),
    [anon_sym_type] = ACTIONS(737),
    [anon_sym_error] = ACTIONS(737),
    [anon_sym_struct] = ACTIONS(737),
    [anon_sym_enum] = ACTIONS(737),
    [anon_sym_event] = ACTIONS(737),
    [anon_sym_using] = ACTIONS(737),
    [anon_sym_function] = ACTIONS(737),
    [anon_sym_byte] = ACTIONS(737),
    [anon_sym_address] = ACTIONS(737),
    [anon_sym_var] = ACTIONS(737),
    [anon_sym_modifier] = ACTIONS(737),
    [anon_sym_constructor] = ACTIONS(737),
    [anon_sym_fallback] = ACTIONS(737),
    [anon_sym_receive] = ACTIONS(737),
    [anon_sym_mapping] = ACTIONS(737),
    [anon_sym_bool] = ACTIONS(737),
    [anon_sym_string] = ACTIONS(737),
    [anon_sym_int] = ACTIONS(737),
    [anon_sym_int8] = ACTIONS(737),
    [anon_sym_int16] = ACTIONS(737),
    [anon_sym_int24] = ACTIONS(737),
    [anon_sym_int32] = ACTIONS(737),
    [anon_sym_int40] = ACTIONS(737),
    [anon_sym_int48] = ACTIONS(737),
    [anon_sym_int56] = ACTIONS(737),
    [anon_sym_int64] = ACTIONS(737),
    [anon_sym_int72] = ACTIONS(737),
    [anon_sym_int80] = ACTIONS(737),
    [anon_sym_int88] = ACTIONS(737),
    [anon_sym_int96] = ACTIONS(737),
    [anon_sym_int104] = ACTIONS(737),
    [anon_sym_int112] = ACTIONS(737),
    [anon_sym_int120] = ACTIONS(737),
    [anon_sym_int128] = ACTIONS(737),
    [anon_sym_int136] = ACTIONS(737),
    [anon_sym_int144] = ACTIONS(737),
    [anon_sym_int152] = ACTIONS(737),
    [anon_sym_int160] = ACTIONS(737),
    [anon_sym_int168] = ACTIONS(737),
    [anon_sym_int176] = ACTIONS(737),
    [anon_sym_int184] = ACTIONS(737),
    [anon_sym_int192] = ACTIONS(737),
    [anon_sym_int200] = ACTIONS(737),
    [anon_sym_int208] = ACTIONS(737),
    [anon_sym_int216] = ACTIONS(737),
    [anon_sym_int224] = ACTIONS(737),
    [anon_sym_int232] = ACTIONS(737),
    [anon_sym_int240] = ACTIONS(737),
    [anon_sym_int248] = ACTIONS(737),
    [anon_sym_int256] = ACTIONS(737),
    [anon_sym_uint] = ACTIONS(737),
    [anon_sym_uint8] = ACTIONS(737),
    [anon_sym_uint16] = ACTIONS(737),
    [anon_sym_uint24] = ACTIONS(737),
    [anon_sym_uint32] = ACTIONS(737),
    [anon_sym_uint40] = ACTIONS(737),
    [anon_sym_uint48] = ACTIONS(737),
    [anon_sym_uint56] = ACTIONS(737),
    [anon_sym_uint64] = ACTIONS(737),
    [anon_sym_uint72] = ACTIONS(737),
    [anon_sym_uint80] = ACTIONS(737),
    [anon_sym_uint88] = ACTIONS(737),
    [anon_sym_uint96] = ACTIONS(737),
    [anon_sym_uint104] = ACTIONS(737),
    [anon_sym_uint112] = ACTIONS(737),
    [anon_sym_uint120] = ACTIONS(737),
    [anon_sym_uint128] = ACTIONS(737),
    [anon_sym_uint136] = ACTIONS(737),
    [anon_sym_uint144] = ACTIONS(737),
    [anon_sym_uint152] = ACTIONS(737),
    [anon_sym_uint160] = ACTIONS(737),
    [anon_sym_uint168] = ACTIONS(737),
    [anon_sym_uint176] = ACTIONS(737),
    [anon_sym_uint184] = ACTIONS(737),
    [anon_sym_uint192] = ACTIONS(737),
    [anon_sym_uint200] = ACTIONS(737),
    [anon_sym_uint208] = ACTIONS(737),
    [anon_sym_uint216] = ACTIONS(737),
    [anon_sym_uint224] = ACTIONS(737),
    [anon_sym_uint232] = ACTIONS(737),
    [anon_sym_uint240] = ACTIONS(737),
    [anon_sym_uint248] = ACTIONS(737),
    [anon_sym_uint256] = ACTIONS(737),
    [anon_sym_bytes] = ACTIONS(737),
    [anon_sym_bytes1] = ACTIONS(737),
    [anon_sym_bytes2] = ACTIONS(737),
    [anon_sym_bytes3] = ACTIONS(737),
    [anon_sym_bytes4] = ACTIONS(737),
    [anon_sym_bytes5] = ACTIONS(737),
    [anon_sym_bytes6] = ACTIONS(737),
    [anon_sym_bytes7] = ACTIONS(737),
    [anon_sym_bytes8] = ACTIONS(737),
    [anon_sym_bytes9] = ACTIONS(737),
    [anon_sym_bytes10] = ACTIONS(737),
    [anon_sym_bytes11] = ACTIONS(737),
    [anon_sym_bytes12] = ACTIONS(737),
    [anon_sym_bytes13] = ACTIONS(737),
    [anon_sym_bytes14] = ACTIONS(737),
    [anon_sym_bytes15] = ACTIONS(737),
    [anon_sym_bytes16] = ACTIONS(737),
    [anon_sym_bytes17] = ACTIONS(737),
    [anon_sym_bytes18] = ACTIONS(737),
    [anon_sym_bytes19] = ACTIONS(737),
    [anon_sym_bytes20] = ACTIONS(737),
    [anon_sym_bytes21] = ACTIONS(737),
    [anon_sym_bytes22] = ACTIONS(737),
    [anon_sym_bytes23] = ACTIONS(737),
    [anon_sym_bytes24] = ACTIONS(737),
    [anon_sym_bytes25] = ACTIONS(737),
    [anon_sym_bytes26] = ACTIONS(737),
    [anon_sym_bytes27] = ACTIONS(737),
    [anon_sym_bytes28] = ACTIONS(737),
    [anon_sym_bytes29] = ACTIONS(737),
    [anon_sym_bytes30] = ACTIONS(737),
    [anon_sym_bytes31] = ACTIONS(737),
    [anon_sym_bytes32] = ACTIONS(737),
    [anon_sym_fixed] = ACTIONS(737),
    [aux_sym__fixed_token1] = ACTIONS(737),
    [anon_sym_ufixed] = ACTIONS(737),
    [aux_sym__ufixed_token1] = ACTIONS(737),
    [sym_comment] = ACTIONS(3),
  },
  [285] = {
    [sym_identifier] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(703),
    [anon_sym_type] = ACTIONS(705),
    [anon_sym_error] = ACTIONS(705),
    [anon_sym_struct] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(705),
    [anon_sym_event] = ACTIONS(705),
    [anon_sym_using] = ACTIONS(705),
    [anon_sym_function] = ACTIONS(705),
    [anon_sym_byte] = ACTIONS(705),
    [anon_sym_address] = ACTIONS(705),
    [anon_sym_var] = ACTIONS(705),
    [anon_sym_modifier] = ACTIONS(705),
    [anon_sym_constructor] = ACTIONS(705),
    [anon_sym_fallback] = ACTIONS(705),
    [anon_sym_receive] = ACTIONS(705),
    [anon_sym_mapping] = ACTIONS(705),
    [anon_sym_bool] = ACTIONS(705),
    [anon_sym_string] = ACTIONS(705),
    [anon_sym_int] = ACTIONS(705),
    [anon_sym_int8] = ACTIONS(705),
    [anon_sym_int16] = ACTIONS(705),
    [anon_sym_int24] = ACTIONS(705),
    [anon_sym_int32] = ACTIONS(705),
    [anon_sym_int40] = ACTIONS(705),
    [anon_sym_int48] = ACTIONS(705),
    [anon_sym_int56] = ACTIONS(705),
    [anon_sym_int64] = ACTIONS(705),
    [anon_sym_int72] = ACTIONS(705),
    [anon_sym_int80] = ACTIONS(705),
    [anon_sym_int88] = ACTIONS(705),
    [anon_sym_int96] = ACTIONS(705),
    [anon_sym_int104] = ACTIONS(705),
    [anon_sym_int112] = ACTIONS(705),
    [anon_sym_int120] = ACTIONS(705),
    [anon_sym_int128] = ACTIONS(705),
    [anon_sym_int136] = ACTIONS(705),
    [anon_sym_int144] = ACTIONS(705),
    [anon_sym_int152] = ACTIONS(705),
    [anon_sym_int160] = ACTIONS(705),
    [anon_sym_int168] = ACTIONS(705),
    [anon_sym_int176] = ACTIONS(705),
    [anon_sym_int184] = ACTIONS(705),
    [anon_sym_int192] = ACTIONS(705),
    [anon_sym_int200] = ACTIONS(705),
    [anon_sym_int208] = ACTIONS(705),
    [anon_sym_int216] = ACTIONS(705),
    [anon_sym_int224] = ACTIONS(705),
    [anon_sym_int232] = ACTIONS(705),
    [anon_sym_int240] = ACTIONS(705),
    [anon_sym_int248] = ACTIONS(705),
    [anon_sym_int256] = ACTIONS(705),
    [anon_sym_uint] = ACTIONS(705),
    [anon_sym_uint8] = ACTIONS(705),
    [anon_sym_uint16] = ACTIONS(705),
    [anon_sym_uint24] = ACTIONS(705),
    [anon_sym_uint32] = ACTIONS(705),
    [anon_sym_uint40] = ACTIONS(705),
    [anon_sym_uint48] = ACTIONS(705),
    [anon_sym_uint56] = ACTIONS(705),
    [anon_sym_uint64] = ACTIONS(705),
    [anon_sym_uint72] = ACTIONS(705),
    [anon_sym_uint80] = ACTIONS(705),
    [anon_sym_uint88] = ACTIONS(705),
    [anon_sym_uint96] = ACTIONS(705),
    [anon_sym_uint104] = ACTIONS(705),
    [anon_sym_uint112] = ACTIONS(705),
    [anon_sym_uint120] = ACTIONS(705),
    [anon_sym_uint128] = ACTIONS(705),
    [anon_sym_uint136] = ACTIONS(705),
    [anon_sym_uint144] = ACTIONS(705),
    [anon_sym_uint152] = ACTIONS(705),
    [anon_sym_uint160] = ACTIONS(705),
    [anon_sym_uint168] = ACTIONS(705),
    [anon_sym_uint176] = ACTIONS(705),
    [anon_sym_uint184] = ACTIONS(705),
    [anon_sym_uint192] = ACTIONS(705),
    [anon_sym_uint200] = ACTIONS(705),
    [anon_sym_uint208] = ACTIONS(705),
    [anon_sym_uint216] = ACTIONS(705),
    [anon_sym_uint224] = ACTIONS(705),
    [anon_sym_uint232] = ACTIONS(705),
    [anon_sym_uint240] = ACTIONS(705),
    [anon_sym_uint248] = ACTIONS(705),
    [anon_sym_uint256] = ACTIONS(705),
    [anon_sym_bytes] = ACTIONS(705),
    [anon_sym_bytes1] = ACTIONS(705),
    [anon_sym_bytes2] = ACTIONS(705),
    [anon_sym_bytes3] = ACTIONS(705),
    [anon_sym_bytes4] = ACTIONS(705),
    [anon_sym_bytes5] = ACTIONS(705),
    [anon_sym_bytes6] = ACTIONS(705),
    [anon_sym_bytes7] = ACTIONS(705),
    [anon_sym_bytes8] = ACTIONS(705),
    [anon_sym_bytes9] = ACTIONS(705),
    [anon_sym_bytes10] = ACTIONS(705),
    [anon_sym_bytes11] = ACTIONS(705),
    [anon_sym_bytes12] = ACTIONS(705),
    [anon_sym_bytes13] = ACTIONS(705),
    [anon_sym_bytes14] = ACTIONS(705),
    [anon_sym_bytes15] = ACTIONS(705),
    [anon_sym_bytes16] = ACTIONS(705),
    [anon_sym_bytes17] = ACTIONS(705),
    [anon_sym_bytes18] = ACTIONS(705),
    [anon_sym_bytes19] = ACTIONS(705),
    [anon_sym_bytes20] = ACTIONS(705),
    [anon_sym_bytes21] = ACTIONS(705),
    [anon_sym_bytes22] = ACTIONS(705),
    [anon_sym_bytes23] = ACTIONS(705),
    [anon_sym_bytes24] = ACTIONS(705),
    [anon_sym_bytes25] = ACTIONS(705),
    [anon_sym_bytes26] = ACTIONS(705),
    [anon_sym_bytes27] = ACTIONS(705),
    [anon_sym_bytes28] = ACTIONS(705),
    [anon_sym_bytes29] = ACTIONS(705),
    [anon_sym_bytes30] = ACTIONS(705),
    [anon_sym_bytes31] = ACTIONS(705),
    [anon_sym_bytes32] = ACTIONS(705),
    [anon_sym_fixed] = ACTIONS(705),
    [aux_sym__fixed_token1] = ACTIONS(705),
    [anon_sym_ufixed] = ACTIONS(705),
    [aux_sym__ufixed_token1] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
  },
  [286] = {
    [sym_identifier] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(711),
    [anon_sym_type] = ACTIONS(713),
    [anon_sym_error] = ACTIONS(713),
    [anon_sym_struct] = ACTIONS(713),
    [anon_sym_enum] = ACTIONS(713),
    [anon_sym_event] = ACTIONS(713),
    [anon_sym_using] = ACTIONS(713),
    [anon_sym_function] = ACTIONS(713),
    [anon_sym_byte] = ACTIONS(713),
    [anon_sym_address] = ACTIONS(713),
    [anon_sym_var] = ACTIONS(713),
    [anon_sym_modifier] = ACTIONS(713),
    [anon_sym_constructor] = ACTIONS(713),
    [anon_sym_fallback] = ACTIONS(713),
    [anon_sym_receive] = ACTIONS(713),
    [anon_sym_mapping] = ACTIONS(713),
    [anon_sym_bool] = ACTIONS(713),
    [anon_sym_string] = ACTIONS(713),
    [anon_sym_int] = ACTIONS(713),
    [anon_sym_int8] = ACTIONS(713),
    [anon_sym_int16] = ACTIONS(713),
    [anon_sym_int24] = ACTIONS(713),
    [anon_sym_int32] = ACTIONS(713),
    [anon_sym_int40] = ACTIONS(713),
    [anon_sym_int48] = ACTIONS(713),
    [anon_sym_int56] = ACTIONS(713),
    [anon_sym_int64] = ACTIONS(713),
    [anon_sym_int72] = ACTIONS(713),
    [anon_sym_int80] = ACTIONS(713),
    [anon_sym_int88] = ACTIONS(713),
    [anon_sym_int96] = ACTIONS(713),
    [anon_sym_int104] = ACTIONS(713),
    [anon_sym_int112] = ACTIONS(713),
    [anon_sym_int120] = ACTIONS(713),
    [anon_sym_int128] = ACTIONS(713),
    [anon_sym_int136] = ACTIONS(713),
    [anon_sym_int144] = ACTIONS(713),
    [anon_sym_int152] = ACTIONS(713),
    [anon_sym_int160] = ACTIONS(713),
    [anon_sym_int168] = ACTIONS(713),
    [anon_sym_int176] = ACTIONS(713),
    [anon_sym_int184] = ACTIONS(713),
    [anon_sym_int192] = ACTIONS(713),
    [anon_sym_int200] = ACTIONS(713),
    [anon_sym_int208] = ACTIONS(713),
    [anon_sym_int216] = ACTIONS(713),
    [anon_sym_int224] = ACTIONS(713),
    [anon_sym_int232] = ACTIONS(713),
    [anon_sym_int240] = ACTIONS(713),
    [anon_sym_int248] = ACTIONS(713),
    [anon_sym_int256] = ACTIONS(713),
    [anon_sym_uint] = ACTIONS(713),
    [anon_sym_uint8] = ACTIONS(713),
    [anon_sym_uint16] = ACTIONS(713),
    [anon_sym_uint24] = ACTIONS(713),
    [anon_sym_uint32] = ACTIONS(713),
    [anon_sym_uint40] = ACTIONS(713),
    [anon_sym_uint48] = ACTIONS(713),
    [anon_sym_uint56] = ACTIONS(713),
    [anon_sym_uint64] = ACTIONS(713),
    [anon_sym_uint72] = ACTIONS(713),
    [anon_sym_uint80] = ACTIONS(713),
    [anon_sym_uint88] = ACTIONS(713),
    [anon_sym_uint96] = ACTIONS(713),
    [anon_sym_uint104] = ACTIONS(713),
    [anon_sym_uint112] = ACTIONS(713),
    [anon_sym_uint120] = ACTIONS(713),
    [anon_sym_uint128] = ACTIONS(713),
    [anon_sym_uint136] = ACTIONS(713),
    [anon_sym_uint144] = ACTIONS(713),
    [anon_sym_uint152] = ACTIONS(713),
    [anon_sym_uint160] = ACTIONS(713),
    [anon_sym_uint168] = ACTIONS(713),
    [anon_sym_uint176] = ACTIONS(713),
    [anon_sym_uint184] = ACTIONS(713),
    [anon_sym_uint192] = ACTIONS(713),
    [anon_sym_uint200] = ACTIONS(713),
    [anon_sym_uint208] = ACTIONS(713),
    [anon_sym_uint216] = ACTIONS(713),
    [anon_sym_uint224] = ACTIONS(713),
    [anon_sym_uint232] = ACTIONS(713),
    [anon_sym_uint240] = ACTIONS(713),
    [anon_sym_uint248] = ACTIONS(713),
    [anon_sym_uint256] = ACTIONS(713),
    [anon_sym_bytes] = ACTIONS(713),
    [anon_sym_bytes1] = ACTIONS(713),
    [anon_sym_bytes2] = ACTIONS(713),
    [anon_sym_bytes3] = ACTIONS(713),
    [anon_sym_bytes4] = ACTIONS(713),
    [anon_sym_bytes5] = ACTIONS(713),
    [anon_sym_bytes6] = ACTIONS(713),
    [anon_sym_bytes7] = ACTIONS(713),
    [anon_sym_bytes8] = ACTIONS(713),
    [anon_sym_bytes9] = ACTIONS(713),
    [anon_sym_bytes10] = ACTIONS(713),
    [anon_sym_bytes11] = ACTIONS(713),
    [anon_sym_bytes12] = ACTIONS(713),
    [anon_sym_bytes13] = ACTIONS(713),
    [anon_sym_bytes14] = ACTIONS(713),
    [anon_sym_bytes15] = ACTIONS(713),
    [anon_sym_bytes16] = ACTIONS(713),
    [anon_sym_bytes17] = ACTIONS(713),
    [anon_sym_bytes18] = ACTIONS(713),
    [anon_sym_bytes19] = ACTIONS(713),
    [anon_sym_bytes20] = ACTIONS(713),
    [anon_sym_bytes21] = ACTIONS(713),
    [anon_sym_bytes22] = ACTIONS(713),
    [anon_sym_bytes23] = ACTIONS(713),
    [anon_sym_bytes24] = ACTIONS(713),
    [anon_sym_bytes25] = ACTIONS(713),
    [anon_sym_bytes26] = ACTIONS(713),
    [anon_sym_bytes27] = ACTIONS(713),
    [anon_sym_bytes28] = ACTIONS(713),
    [anon_sym_bytes29] = ACTIONS(713),
    [anon_sym_bytes30] = ACTIONS(713),
    [anon_sym_bytes31] = ACTIONS(713),
    [anon_sym_bytes32] = ACTIONS(713),
    [anon_sym_fixed] = ACTIONS(713),
    [aux_sym__fixed_token1] = ACTIONS(713),
    [anon_sym_ufixed] = ACTIONS(713),
    [aux_sym__ufixed_token1] = ACTIONS(713),
    [sym_comment] = ACTIONS(3),
  },
  [287] = {
    [sym_identifier] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(679),
    [anon_sym_type] = ACTIONS(681),
    [anon_sym_error] = ACTIONS(681),
    [anon_sym_struct] = ACTIONS(681),
    [anon_sym_enum] = ACTIONS(681),
    [anon_sym_event] = ACTIONS(681),
    [anon_sym_using] = ACTIONS(681),
    [anon_sym_function] = ACTIONS(681),
    [anon_sym_byte] = ACTIONS(681),
    [anon_sym_address] = ACTIONS(681),
    [anon_sym_var] = ACTIONS(681),
    [anon_sym_modifier] = ACTIONS(681),
    [anon_sym_constructor] = ACTIONS(681),
    [anon_sym_fallback] = ACTIONS(681),
    [anon_sym_receive] = ACTIONS(681),
    [anon_sym_mapping] = ACTIONS(681),
    [anon_sym_bool] = ACTIONS(681),
    [anon_sym_string] = ACTIONS(681),
    [anon_sym_int] = ACTIONS(681),
    [anon_sym_int8] = ACTIONS(681),
    [anon_sym_int16] = ACTIONS(681),
    [anon_sym_int24] = ACTIONS(681),
    [anon_sym_int32] = ACTIONS(681),
    [anon_sym_int40] = ACTIONS(681),
    [anon_sym_int48] = ACTIONS(681),
    [anon_sym_int56] = ACTIONS(681),
    [anon_sym_int64] = ACTIONS(681),
    [anon_sym_int72] = ACTIONS(681),
    [anon_sym_int80] = ACTIONS(681),
    [anon_sym_int88] = ACTIONS(681),
    [anon_sym_int96] = ACTIONS(681),
    [anon_sym_int104] = ACTIONS(681),
    [anon_sym_int112] = ACTIONS(681),
    [anon_sym_int120] = ACTIONS(681),
    [anon_sym_int128] = ACTIONS(681),
    [anon_sym_int136] = ACTIONS(681),
    [anon_sym_int144] = ACTIONS(681),
    [anon_sym_int152] = ACTIONS(681),
    [anon_sym_int160] = ACTIONS(681),
    [anon_sym_int168] = ACTIONS(681),
    [anon_sym_int176] = ACTIONS(681),
    [anon_sym_int184] = ACTIONS(681),
    [anon_sym_int192] = ACTIONS(681),
    [anon_sym_int200] = ACTIONS(681),
    [anon_sym_int208] = ACTIONS(681),
    [anon_sym_int216] = ACTIONS(681),
    [anon_sym_int224] = ACTIONS(681),
    [anon_sym_int232] = ACTIONS(681),
    [anon_sym_int240] = ACTIONS(681),
    [anon_sym_int248] = ACTIONS(681),
    [anon_sym_int256] = ACTIONS(681),
    [anon_sym_uint] = ACTIONS(681),
    [anon_sym_uint8] = ACTIONS(681),
    [anon_sym_uint16] = ACTIONS(681),
    [anon_sym_uint24] = ACTIONS(681),
    [anon_sym_uint32] = ACTIONS(681),
    [anon_sym_uint40] = ACTIONS(681),
    [anon_sym_uint48] = ACTIONS(681),
    [anon_sym_uint56] = ACTIONS(681),
    [anon_sym_uint64] = ACTIONS(681),
    [anon_sym_uint72] = ACTIONS(681),
    [anon_sym_uint80] = ACTIONS(681),
    [anon_sym_uint88] = ACTIONS(681),
    [anon_sym_uint96] = ACTIONS(681),
    [anon_sym_uint104] = ACTIONS(681),
    [anon_sym_uint112] = ACTIONS(681),
    [anon_sym_uint120] = ACTIONS(681),
    [anon_sym_uint128] = ACTIONS(681),
    [anon_sym_uint136] = ACTIONS(681),
    [anon_sym_uint144] = ACTIONS(681),
    [anon_sym_uint152] = ACTIONS(681),
    [anon_sym_uint160] = ACTIONS(681),
    [anon_sym_uint168] = ACTIONS(681),
    [anon_sym_uint176] = ACTIONS(681),
    [anon_sym_uint184] = ACTIONS(681),
    [anon_sym_uint192] = ACTIONS(681),
    [anon_sym_uint200] = ACTIONS(681),
    [anon_sym_uint208] = ACTIONS(681),
    [anon_sym_uint216] = ACTIONS(681),
    [anon_sym_uint224] = ACTIONS(681),
    [anon_sym_uint232] = ACTIONS(681),
    [anon_sym_uint240] = ACTIONS(681),
    [anon_sym_uint248] = ACTIONS(681),
    [anon_sym_uint256] = ACTIONS(681),
    [anon_sym_bytes] = ACTIONS(681),
    [anon_sym_bytes1] = ACTIONS(681),
    [anon_sym_bytes2] = ACTIONS(681),
    [anon_sym_bytes3] = ACTIONS(681),
    [anon_sym_bytes4] = ACTIONS(681),
    [anon_sym_bytes5] = ACTIONS(681),
    [anon_sym_bytes6] = ACTIONS(681),
    [anon_sym_bytes7] = ACTIONS(681),
    [anon_sym_bytes8] = ACTIONS(681),
    [anon_sym_bytes9] = ACTIONS(681),
    [anon_sym_bytes10] = ACTIONS(681),
    [anon_sym_bytes11] = ACTIONS(681),
    [anon_sym_bytes12] = ACTIONS(681),
    [anon_sym_bytes13] = ACTIONS(681),
    [anon_sym_bytes14] = ACTIONS(681),
    [anon_sym_bytes15] = ACTIONS(681),
    [anon_sym_bytes16] = ACTIONS(681),
    [anon_sym_bytes17] = ACTIONS(681),
    [anon_sym_bytes18] = ACTIONS(681),
    [anon_sym_bytes19] = ACTIONS(681),
    [anon_sym_bytes20] = ACTIONS(681),
    [anon_sym_bytes21] = ACTIONS(681),
    [anon_sym_bytes22] = ACTIONS(681),
    [anon_sym_bytes23] = ACTIONS(681),
    [anon_sym_bytes24] = ACTIONS(681),
    [anon_sym_bytes25] = ACTIONS(681),
    [anon_sym_bytes26] = ACTIONS(681),
    [anon_sym_bytes27] = ACTIONS(681),
    [anon_sym_bytes28] = ACTIONS(681),
    [anon_sym_bytes29] = ACTIONS(681),
    [anon_sym_bytes30] = ACTIONS(681),
    [anon_sym_bytes31] = ACTIONS(681),
    [anon_sym_bytes32] = ACTIONS(681),
    [anon_sym_fixed] = ACTIONS(681),
    [aux_sym__fixed_token1] = ACTIONS(681),
    [anon_sym_ufixed] = ACTIONS(681),
    [aux_sym__ufixed_token1] = ACTIONS(681),
    [sym_comment] = ACTIONS(3),
  },
  [288] = {
    [sym_user_defined_type] = STATE(835),
    [sym__identifier_path] = STATE(399),
    [sym__mapping_key] = STATE(835),
    [sym_primitive_type] = STATE(835),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(33),
    [anon_sym_bool] = ACTIONS(33),
    [anon_sym_string] = ACTIONS(33),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(33),
    [anon_sym_int40] = ACTIONS(33),
    [anon_sym_int48] = ACTIONS(33),
    [anon_sym_int56] = ACTIONS(33),
    [anon_sym_int64] = ACTIONS(33),
    [anon_sym_int72] = ACTIONS(33),
    [anon_sym_int80] = ACTIONS(33),
    [anon_sym_int88] = ACTIONS(33),
    [anon_sym_int96] = ACTIONS(33),
    [anon_sym_int104] = ACTIONS(33),
    [anon_sym_int112] = ACTIONS(33),
    [anon_sym_int120] = ACTIONS(33),
    [anon_sym_int128] = ACTIONS(33),
    [anon_sym_int136] = ACTIONS(33),
    [anon_sym_int144] = ACTIONS(33),
    [anon_sym_int152] = ACTIONS(33),
    [anon_sym_int160] = ACTIONS(33),
    [anon_sym_int168] = ACTIONS(33),
    [anon_sym_int176] = ACTIONS(33),
    [anon_sym_int184] = ACTIONS(33),
    [anon_sym_int192] = ACTIONS(33),
    [anon_sym_int200] = ACTIONS(33),
    [anon_sym_int208] = ACTIONS(33),
    [anon_sym_int216] = ACTIONS(33),
    [anon_sym_int224] = ACTIONS(33),
    [anon_sym_int232] = ACTIONS(33),
    [anon_sym_int240] = ACTIONS(33),
    [anon_sym_int248] = ACTIONS(33),
    [anon_sym_int256] = ACTIONS(33),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(33),
    [anon_sym_uint40] = ACTIONS(33),
    [anon_sym_uint48] = ACTIONS(33),
    [anon_sym_uint56] = ACTIONS(33),
    [anon_sym_uint64] = ACTIONS(33),
    [anon_sym_uint72] = ACTIONS(33),
    [anon_sym_uint80] = ACTIONS(33),
    [anon_sym_uint88] = ACTIONS(33),
    [anon_sym_uint96] = ACTIONS(33),
    [anon_sym_uint104] = ACTIONS(33),
    [anon_sym_uint112] = ACTIONS(33),
    [anon_sym_uint120] = ACTIONS(33),
    [anon_sym_uint128] = ACTIONS(33),
    [anon_sym_uint136] = ACTIONS(33),
    [anon_sym_uint144] = ACTIONS(33),
    [anon_sym_uint152] = ACTIONS(33),
    [anon_sym_uint160] = ACTIONS(33),
    [anon_sym_uint168] = ACTIONS(33),
    [anon_sym_uint176] = ACTIONS(33),
    [anon_sym_uint184] = ACTIONS(33),
    [anon_sym_uint192] = ACTIONS(33),
    [anon_sym_uint200] = ACTIONS(33),
    [anon_sym_uint208] = ACTIONS(33),
    [anon_sym_uint216] = ACTIONS(33),
    [anon_sym_uint224] = ACTIONS(33),
    [anon_sym_uint232] = ACTIONS(33),
    [anon_sym_uint240] = ACTIONS(33),
    [anon_sym_uint248] = ACTIONS(33),
    [anon_sym_uint256] = ACTIONS(33),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(33),
    [anon_sym_bytes5] = ACTIONS(33),
    [anon_sym_bytes6] = ACTIONS(33),
    [anon_sym_bytes7] = ACTIONS(33),
    [anon_sym_bytes8] = ACTIONS(33),
    [anon_sym_bytes9] = ACTIONS(33),
    [anon_sym_bytes10] = ACTIONS(33),
    [anon_sym_bytes11] = ACTIONS(33),
    [anon_sym_bytes12] = ACTIONS(33),
    [anon_sym_bytes13] = ACTIONS(33),
    [anon_sym_bytes14] = ACTIONS(33),
    [anon_sym_bytes15] = ACTIONS(33),
    [anon_sym_bytes16] = ACTIONS(33),
    [anon_sym_bytes17] = ACTIONS(33),
    [anon_sym_bytes18] = ACTIONS(33),
    [anon_sym_bytes19] = ACTIONS(33),
    [anon_sym_bytes20] = ACTIONS(33),
    [anon_sym_bytes21] = ACTIONS(33),
    [anon_sym_bytes22] = ACTIONS(33),
    [anon_sym_bytes23] = ACTIONS(33),
    [anon_sym_bytes24] = ACTIONS(33),
    [anon_sym_bytes25] = ACTIONS(33),
    [anon_sym_bytes26] = ACTIONS(33),
    [anon_sym_bytes27] = ACTIONS(33),
    [anon_sym_bytes28] = ACTIONS(33),
    [anon_sym_bytes29] = ACTIONS(33),
    [anon_sym_bytes30] = ACTIONS(33),
    [anon_sym_bytes31] = ACTIONS(33),
    [anon_sym_bytes32] = ACTIONS(33),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(33),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(33),
    [sym_comment] = ACTIONS(3),
  },
  [289] = {
    [sym_primitive_type] = STATE(934),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(929),
    [anon_sym_var] = ACTIONS(931),
    [anon_sym_bool] = ACTIONS(931),
    [anon_sym_string] = ACTIONS(931),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(931),
    [anon_sym_int40] = ACTIONS(931),
    [anon_sym_int48] = ACTIONS(931),
    [anon_sym_int56] = ACTIONS(931),
    [anon_sym_int64] = ACTIONS(931),
    [anon_sym_int72] = ACTIONS(931),
    [anon_sym_int80] = ACTIONS(931),
    [anon_sym_int88] = ACTIONS(931),
    [anon_sym_int96] = ACTIONS(931),
    [anon_sym_int104] = ACTIONS(931),
    [anon_sym_int112] = ACTIONS(931),
    [anon_sym_int120] = ACTIONS(931),
    [anon_sym_int128] = ACTIONS(931),
    [anon_sym_int136] = ACTIONS(931),
    [anon_sym_int144] = ACTIONS(931),
    [anon_sym_int152] = ACTIONS(931),
    [anon_sym_int160] = ACTIONS(931),
    [anon_sym_int168] = ACTIONS(931),
    [anon_sym_int176] = ACTIONS(931),
    [anon_sym_int184] = ACTIONS(931),
    [anon_sym_int192] = ACTIONS(931),
    [anon_sym_int200] = ACTIONS(931),
    [anon_sym_int208] = ACTIONS(931),
    [anon_sym_int216] = ACTIONS(931),
    [anon_sym_int224] = ACTIONS(931),
    [anon_sym_int232] = ACTIONS(931),
    [anon_sym_int240] = ACTIONS(931),
    [anon_sym_int248] = ACTIONS(931),
    [anon_sym_int256] = ACTIONS(931),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(931),
    [anon_sym_uint40] = ACTIONS(931),
    [anon_sym_uint48] = ACTIONS(931),
    [anon_sym_uint56] = ACTIONS(931),
    [anon_sym_uint64] = ACTIONS(931),
    [anon_sym_uint72] = ACTIONS(931),
    [anon_sym_uint80] = ACTIONS(931),
    [anon_sym_uint88] = ACTIONS(931),
    [anon_sym_uint96] = ACTIONS(931),
    [anon_sym_uint104] = ACTIONS(931),
    [anon_sym_uint112] = ACTIONS(931),
    [anon_sym_uint120] = ACTIONS(931),
    [anon_sym_uint128] = ACTIONS(931),
    [anon_sym_uint136] = ACTIONS(931),
    [anon_sym_uint144] = ACTIONS(931),
    [anon_sym_uint152] = ACTIONS(931),
    [anon_sym_uint160] = ACTIONS(931),
    [anon_sym_uint168] = ACTIONS(931),
    [anon_sym_uint176] = ACTIONS(931),
    [anon_sym_uint184] = ACTIONS(931),
    [anon_sym_uint192] = ACTIONS(931),
    [anon_sym_uint200] = ACTIONS(931),
    [anon_sym_uint208] = ACTIONS(931),
    [anon_sym_uint216] = ACTIONS(931),
    [anon_sym_uint224] = ACTIONS(931),
    [anon_sym_uint232] = ACTIONS(931),
    [anon_sym_uint240] = ACTIONS(931),
    [anon_sym_uint248] = ACTIONS(931),
    [anon_sym_uint256] = ACTIONS(931),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(931),
    [anon_sym_bytes5] = ACTIONS(931),
    [anon_sym_bytes6] = ACTIONS(931),
    [anon_sym_bytes7] = ACTIONS(931),
    [anon_sym_bytes8] = ACTIONS(931),
    [anon_sym_bytes9] = ACTIONS(931),
    [anon_sym_bytes10] = ACTIONS(931),
    [anon_sym_bytes11] = ACTIONS(931),
    [anon_sym_bytes12] = ACTIONS(931),
    [anon_sym_bytes13] = ACTIONS(931),
    [anon_sym_bytes14] = ACTIONS(931),
    [anon_sym_bytes15] = ACTIONS(931),
    [anon_sym_bytes16] = ACTIONS(931),
    [anon_sym_bytes17] = ACTIONS(931),
    [anon_sym_bytes18] = ACTIONS(931),
    [anon_sym_bytes19] = ACTIONS(931),
    [anon_sym_bytes20] = ACTIONS(931),
    [anon_sym_bytes21] = ACTIONS(931),
    [anon_sym_bytes22] = ACTIONS(931),
    [anon_sym_bytes23] = ACTIONS(931),
    [anon_sym_bytes24] = ACTIONS(931),
    [anon_sym_bytes25] = ACTIONS(931),
    [anon_sym_bytes26] = ACTIONS(931),
    [anon_sym_bytes27] = ACTIONS(931),
    [anon_sym_bytes28] = ACTIONS(931),
    [anon_sym_bytes29] = ACTIONS(931),
    [anon_sym_bytes30] = ACTIONS(931),
    [anon_sym_bytes31] = ACTIONS(931),
    [anon_sym_bytes32] = ACTIONS(931),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(931),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(931),
    [sym_comment] = ACTIONS(3),
  },
  [290] = {
    [sym_primitive_type] = STATE(931),
    [sym__int] = STATE(401),
    [sym__uint] = STATE(401),
    [sym__bytes] = STATE(401),
    [sym__fixed] = STATE(401),
    [sym__ufixed] = STATE(401),
    [anon_sym_byte] = ACTIONS(33),
    [anon_sym_address] = ACTIONS(929),
    [anon_sym_var] = ACTIONS(931),
    [anon_sym_bool] = ACTIONS(931),
    [anon_sym_string] = ACTIONS(931),
    [anon_sym_int] = ACTIONS(33),
    [anon_sym_int8] = ACTIONS(33),
    [anon_sym_int16] = ACTIONS(33),
    [anon_sym_int24] = ACTIONS(33),
    [anon_sym_int32] = ACTIONS(931),
    [anon_sym_int40] = ACTIONS(931),
    [anon_sym_int48] = ACTIONS(931),
    [anon_sym_int56] = ACTIONS(931),
    [anon_sym_int64] = ACTIONS(931),
    [anon_sym_int72] = ACTIONS(931),
    [anon_sym_int80] = ACTIONS(931),
    [anon_sym_int88] = ACTIONS(931),
    [anon_sym_int96] = ACTIONS(931),
    [anon_sym_int104] = ACTIONS(931),
    [anon_sym_int112] = ACTIONS(931),
    [anon_sym_int120] = ACTIONS(931),
    [anon_sym_int128] = ACTIONS(931),
    [anon_sym_int136] = ACTIONS(931),
    [anon_sym_int144] = ACTIONS(931),
    [anon_sym_int152] = ACTIONS(931),
    [anon_sym_int160] = ACTIONS(931),
    [anon_sym_int168] = ACTIONS(931),
    [anon_sym_int176] = ACTIONS(931),
    [anon_sym_int184] = ACTIONS(931),
    [anon_sym_int192] = ACTIONS(931),
    [anon_sym_int200] = ACTIONS(931),
    [anon_sym_int208] = ACTIONS(931),
    [anon_sym_int216] = ACTIONS(931),
    [anon_sym_int224] = ACTIONS(931),
    [anon_sym_int232] = ACTIONS(931),
    [anon_sym_int240] = ACTIONS(931),
    [anon_sym_int248] = ACTIONS(931),
    [anon_sym_int256] = ACTIONS(931),
    [anon_sym_uint] = ACTIONS(33),
    [anon_sym_uint8] = ACTIONS(33),
    [anon_sym_uint16] = ACTIONS(33),
    [anon_sym_uint24] = ACTIONS(33),
    [anon_sym_uint32] = ACTIONS(931),
    [anon_sym_uint40] = ACTIONS(931),
    [anon_sym_uint48] = ACTIONS(931),
    [anon_sym_uint56] = ACTIONS(931),
    [anon_sym_uint64] = ACTIONS(931),
    [anon_sym_uint72] = ACTIONS(931),
    [anon_sym_uint80] = ACTIONS(931),
    [anon_sym_uint88] = ACTIONS(931),
    [anon_sym_uint96] = ACTIONS(931),
    [anon_sym_uint104] = ACTIONS(931),
    [anon_sym_uint112] = ACTIONS(931),
    [anon_sym_uint120] = ACTIONS(931),
    [anon_sym_uint128] = ACTIONS(931),
    [anon_sym_uint136] = ACTIONS(931),
    [anon_sym_uint144] = ACTIONS(931),
    [anon_sym_uint152] = ACTIONS(931),
    [anon_sym_uint160] = ACTIONS(931),
    [anon_sym_uint168] = ACTIONS(931),
    [anon_sym_uint176] = ACTIONS(931),
    [anon_sym_uint184] = ACTIONS(931),
    [anon_sym_uint192] = ACTIONS(931),
    [anon_sym_uint200] = ACTIONS(931),
    [anon_sym_uint208] = ACTIONS(931),
    [anon_sym_uint216] = ACTIONS(931),
    [anon_sym_uint224] = ACTIONS(931),
    [anon_sym_uint232] = ACTIONS(931),
    [anon_sym_uint240] = ACTIONS(931),
    [anon_sym_uint248] = ACTIONS(931),
    [anon_sym_uint256] = ACTIONS(931),
    [anon_sym_bytes] = ACTIONS(33),
    [anon_sym_bytes1] = ACTIONS(33),
    [anon_sym_bytes2] = ACTIONS(33),
    [anon_sym_bytes3] = ACTIONS(33),
    [anon_sym_bytes4] = ACTIONS(931),
    [anon_sym_bytes5] = ACTIONS(931),
    [anon_sym_bytes6] = ACTIONS(931),
    [anon_sym_bytes7] = ACTIONS(931),
    [anon_sym_bytes8] = ACTIONS(931),
    [anon_sym_bytes9] = ACTIONS(931),
    [anon_sym_bytes10] = ACTIONS(931),
    [anon_sym_bytes11] = ACTIONS(931),
    [anon_sym_bytes12] = ACTIONS(931),
    [anon_sym_bytes13] = ACTIONS(931),
    [anon_sym_bytes14] = ACTIONS(931),
    [anon_sym_bytes15] = ACTIONS(931),
    [anon_sym_bytes16] = ACTIONS(931),
    [anon_sym_bytes17] = ACTIONS(931),
    [anon_sym_bytes18] = ACTIONS(931),
    [anon_sym_bytes19] = ACTIONS(931),
    [anon_sym_bytes20] = ACTIONS(931),
    [anon_sym_bytes21] = ACTIONS(931),
    [anon_sym_bytes22] = ACTIONS(931),
    [anon_sym_bytes23] = ACTIONS(931),
    [anon_sym_bytes24] = ACTIONS(931),
    [anon_sym_bytes25] = ACTIONS(931),
    [anon_sym_bytes26] = ACTIONS(931),
    [anon_sym_bytes27] = ACTIONS(931),
    [anon_sym_bytes28] = ACTIONS(931),
    [anon_sym_bytes29] = ACTIONS(931),
    [anon_sym_bytes30] = ACTIONS(931),
    [anon_sym_bytes31] = ACTIONS(931),
    [anon_sym_bytes32] = ACTIONS(931),
    [anon_sym_fixed] = ACTIONS(33),
    [aux_sym__fixed_token1] = ACTIONS(931),
    [anon_sym_ufixed] = ACTIONS(33),
    [aux_sym__ufixed_token1] = ACTIONS(931),
    [sym_comment] = ACTIONS(3),
  },
  [291] = {
    [sym__yul_statement] = STATE(293),
    [sym_yul_label] = STATE(293),
    [sym_yul_break] = STATE(293),
    [sym_yul_continue] = STATE(293),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(293),
    [sym_yul_string_literal] = STATE(293),
    [sym_yul_boolean] = STATE(293),
    [sym_yul_block] = STATE(293),
    [sym_yul_variable_declaration] = STATE(293),
    [sym_yul_assignment] = STATE(293),
    [sym_yul_function_call] = STATE(293),
    [sym_yul_if_statement] = STATE(293),
    [sym_yul_for_statement] = STATE(293),
    [sym_yul_switch_statement] = STATE(293),
    [sym_yul_function_definition] = STATE(293),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(293),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(293),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(937),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(941),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(941),
    [sym_yul_hex_number] = ACTIONS(947),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [292] = {
    [sym__yul_statement] = STATE(300),
    [sym_yul_label] = STATE(300),
    [sym_yul_break] = STATE(300),
    [sym_yul_continue] = STATE(300),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(300),
    [sym_yul_string_literal] = STATE(300),
    [sym_yul_boolean] = STATE(300),
    [sym_yul_block] = STATE(300),
    [sym_yul_variable_declaration] = STATE(300),
    [sym_yul_assignment] = STATE(300),
    [sym_yul_function_call] = STATE(300),
    [sym_yul_if_statement] = STATE(300),
    [sym_yul_for_statement] = STATE(300),
    [sym_yul_switch_statement] = STATE(300),
    [sym_yul_function_definition] = STATE(300),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(300),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(300),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(969),
    [sym_yul_hex_number] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [293] = {
    [sym__yul_statement] = STATE(300),
    [sym_yul_label] = STATE(300),
    [sym_yul_break] = STATE(300),
    [sym_yul_continue] = STATE(300),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(300),
    [sym_yul_string_literal] = STATE(300),
    [sym_yul_boolean] = STATE(300),
    [sym_yul_block] = STATE(300),
    [sym_yul_variable_declaration] = STATE(300),
    [sym_yul_assignment] = STATE(300),
    [sym_yul_function_call] = STATE(300),
    [sym_yul_if_statement] = STATE(300),
    [sym_yul_for_statement] = STATE(300),
    [sym_yul_switch_statement] = STATE(300),
    [sym_yul_function_definition] = STATE(300),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(300),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(300),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(973),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(969),
    [sym_yul_hex_number] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [294] = {
    [sym__yul_statement] = STATE(300),
    [sym_yul_label] = STATE(300),
    [sym_yul_break] = STATE(300),
    [sym_yul_continue] = STATE(300),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(300),
    [sym_yul_string_literal] = STATE(300),
    [sym_yul_boolean] = STATE(300),
    [sym_yul_block] = STATE(300),
    [sym_yul_variable_declaration] = STATE(300),
    [sym_yul_assignment] = STATE(300),
    [sym_yul_function_call] = STATE(300),
    [sym_yul_if_statement] = STATE(300),
    [sym_yul_for_statement] = STATE(300),
    [sym_yul_switch_statement] = STATE(300),
    [sym_yul_function_definition] = STATE(300),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(300),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(300),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(975),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(969),
    [sym_yul_hex_number] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [295] = {
    [sym__yul_statement] = STATE(296),
    [sym_yul_label] = STATE(296),
    [sym_yul_break] = STATE(296),
    [sym_yul_continue] = STATE(296),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(296),
    [sym_yul_string_literal] = STATE(296),
    [sym_yul_boolean] = STATE(296),
    [sym_yul_block] = STATE(296),
    [sym_yul_variable_declaration] = STATE(296),
    [sym_yul_assignment] = STATE(296),
    [sym_yul_function_call] = STATE(296),
    [sym_yul_if_statement] = STATE(296),
    [sym_yul_for_statement] = STATE(296),
    [sym_yul_switch_statement] = STATE(296),
    [sym_yul_function_definition] = STATE(296),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(296),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(296),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(977),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(979),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(979),
    [sym_yul_hex_number] = ACTIONS(981),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [296] = {
    [sym__yul_statement] = STATE(300),
    [sym_yul_label] = STATE(300),
    [sym_yul_break] = STATE(300),
    [sym_yul_continue] = STATE(300),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(300),
    [sym_yul_string_literal] = STATE(300),
    [sym_yul_boolean] = STATE(300),
    [sym_yul_block] = STATE(300),
    [sym_yul_variable_declaration] = STATE(300),
    [sym_yul_assignment] = STATE(300),
    [sym_yul_function_call] = STATE(300),
    [sym_yul_if_statement] = STATE(300),
    [sym_yul_for_statement] = STATE(300),
    [sym_yul_switch_statement] = STATE(300),
    [sym_yul_function_definition] = STATE(300),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(300),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(300),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(969),
    [sym_yul_hex_number] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [297] = {
    [sym_identifier] = ACTIONS(985),
    [anon_sym_RBRACE] = ACTIONS(987),
    [anon_sym_function] = ACTIONS(985),
    [anon_sym_byte] = ACTIONS(985),
    [anon_sym_address] = ACTIONS(985),
    [anon_sym_var] = ACTIONS(985),
    [anon_sym_mapping] = ACTIONS(985),
    [anon_sym_bool] = ACTIONS(985),
    [anon_sym_string] = ACTIONS(985),
    [anon_sym_int] = ACTIONS(985),
    [anon_sym_int8] = ACTIONS(985),
    [anon_sym_int16] = ACTIONS(985),
    [anon_sym_int24] = ACTIONS(985),
    [anon_sym_int32] = ACTIONS(985),
    [anon_sym_int40] = ACTIONS(985),
    [anon_sym_int48] = ACTIONS(985),
    [anon_sym_int56] = ACTIONS(985),
    [anon_sym_int64] = ACTIONS(985),
    [anon_sym_int72] = ACTIONS(985),
    [anon_sym_int80] = ACTIONS(985),
    [anon_sym_int88] = ACTIONS(985),
    [anon_sym_int96] = ACTIONS(985),
    [anon_sym_int104] = ACTIONS(985),
    [anon_sym_int112] = ACTIONS(985),
    [anon_sym_int120] = ACTIONS(985),
    [anon_sym_int128] = ACTIONS(985),
    [anon_sym_int136] = ACTIONS(985),
    [anon_sym_int144] = ACTIONS(985),
    [anon_sym_int152] = ACTIONS(985),
    [anon_sym_int160] = ACTIONS(985),
    [anon_sym_int168] = ACTIONS(985),
    [anon_sym_int176] = ACTIONS(985),
    [anon_sym_int184] = ACTIONS(985),
    [anon_sym_int192] = ACTIONS(985),
    [anon_sym_int200] = ACTIONS(985),
    [anon_sym_int208] = ACTIONS(985),
    [anon_sym_int216] = ACTIONS(985),
    [anon_sym_int224] = ACTIONS(985),
    [anon_sym_int232] = ACTIONS(985),
    [anon_sym_int240] = ACTIONS(985),
    [anon_sym_int248] = ACTIONS(985),
    [anon_sym_int256] = ACTIONS(985),
    [anon_sym_uint] = ACTIONS(985),
    [anon_sym_uint8] = ACTIONS(985),
    [anon_sym_uint16] = ACTIONS(985),
    [anon_sym_uint24] = ACTIONS(985),
    [anon_sym_uint32] = ACTIONS(985),
    [anon_sym_uint40] = ACTIONS(985),
    [anon_sym_uint48] = ACTIONS(985),
    [anon_sym_uint56] = ACTIONS(985),
    [anon_sym_uint64] = ACTIONS(985),
    [anon_sym_uint72] = ACTIONS(985),
    [anon_sym_uint80] = ACTIONS(985),
    [anon_sym_uint88] = ACTIONS(985),
    [anon_sym_uint96] = ACTIONS(985),
    [anon_sym_uint104] = ACTIONS(985),
    [anon_sym_uint112] = ACTIONS(985),
    [anon_sym_uint120] = ACTIONS(985),
    [anon_sym_uint128] = ACTIONS(985),
    [anon_sym_uint136] = ACTIONS(985),
    [anon_sym_uint144] = ACTIONS(985),
    [anon_sym_uint152] = ACTIONS(985),
    [anon_sym_uint160] = ACTIONS(985),
    [anon_sym_uint168] = ACTIONS(985),
    [anon_sym_uint176] = ACTIONS(985),
    [anon_sym_uint184] = ACTIONS(985),
    [anon_sym_uint192] = ACTIONS(985),
    [anon_sym_uint200] = ACTIONS(985),
    [anon_sym_uint208] = ACTIONS(985),
    [anon_sym_uint216] = ACTIONS(985),
    [anon_sym_uint224] = ACTIONS(985),
    [anon_sym_uint232] = ACTIONS(985),
    [anon_sym_uint240] = ACTIONS(985),
    [anon_sym_uint248] = ACTIONS(985),
    [anon_sym_uint256] = ACTIONS(985),
    [anon_sym_bytes] = ACTIONS(985),
    [anon_sym_bytes1] = ACTIONS(985),
    [anon_sym_bytes2] = ACTIONS(985),
    [anon_sym_bytes3] = ACTIONS(985),
    [anon_sym_bytes4] = ACTIONS(985),
    [anon_sym_bytes5] = ACTIONS(985),
    [anon_sym_bytes6] = ACTIONS(985),
    [anon_sym_bytes7] = ACTIONS(985),
    [anon_sym_bytes8] = ACTIONS(985),
    [anon_sym_bytes9] = ACTIONS(985),
    [anon_sym_bytes10] = ACTIONS(985),
    [anon_sym_bytes11] = ACTIONS(985),
    [anon_sym_bytes12] = ACTIONS(985),
    [anon_sym_bytes13] = ACTIONS(985),
    [anon_sym_bytes14] = ACTIONS(985),
    [anon_sym_bytes15] = ACTIONS(985),
    [anon_sym_bytes16] = ACTIONS(985),
    [anon_sym_bytes17] = ACTIONS(985),
    [anon_sym_bytes18] = ACTIONS(985),
    [anon_sym_bytes19] = ACTIONS(985),
    [anon_sym_bytes20] = ACTIONS(985),
    [anon_sym_bytes21] = ACTIONS(985),
    [anon_sym_bytes22] = ACTIONS(985),
    [anon_sym_bytes23] = ACTIONS(985),
    [anon_sym_bytes24] = ACTIONS(985),
    [anon_sym_bytes25] = ACTIONS(985),
    [anon_sym_bytes26] = ACTIONS(985),
    [anon_sym_bytes27] = ACTIONS(985),
    [anon_sym_bytes28] = ACTIONS(985),
    [anon_sym_bytes29] = ACTIONS(985),
    [anon_sym_bytes30] = ACTIONS(985),
    [anon_sym_bytes31] = ACTIONS(985),
    [anon_sym_bytes32] = ACTIONS(985),
    [anon_sym_fixed] = ACTIONS(985),
    [aux_sym__fixed_token1] = ACTIONS(985),
    [anon_sym_ufixed] = ACTIONS(985),
    [aux_sym__ufixed_token1] = ACTIONS(985),
    [sym_comment] = ACTIONS(3),
  },
  [298] = {
    [sym__yul_statement] = STATE(294),
    [sym_yul_label] = STATE(294),
    [sym_yul_break] = STATE(294),
    [sym_yul_continue] = STATE(294),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(294),
    [sym_yul_string_literal] = STATE(294),
    [sym_yul_boolean] = STATE(294),
    [sym_yul_block] = STATE(294),
    [sym_yul_variable_declaration] = STATE(294),
    [sym_yul_assignment] = STATE(294),
    [sym_yul_function_call] = STATE(294),
    [sym_yul_if_statement] = STATE(294),
    [sym_yul_for_statement] = STATE(294),
    [sym_yul_switch_statement] = STATE(294),
    [sym_yul_function_definition] = STATE(294),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(294),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(294),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(989),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(991),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(991),
    [sym_yul_hex_number] = ACTIONS(993),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [299] = {
    [sym__yul_statement] = STATE(300),
    [sym_yul_label] = STATE(300),
    [sym_yul_break] = STATE(300),
    [sym_yul_continue] = STATE(300),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(300),
    [sym_yul_string_literal] = STATE(300),
    [sym_yul_boolean] = STATE(300),
    [sym_yul_block] = STATE(300),
    [sym_yul_variable_declaration] = STATE(300),
    [sym_yul_assignment] = STATE(300),
    [sym_yul_function_call] = STATE(300),
    [sym_yul_if_statement] = STATE(300),
    [sym_yul_for_statement] = STATE(300),
    [sym_yul_switch_statement] = STATE(300),
    [sym_yul_function_definition] = STATE(300),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(300),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(300),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(995),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(969),
    [sym_yul_hex_number] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [300] = {
    [sym__yul_statement] = STATE(300),
    [sym_yul_label] = STATE(300),
    [sym_yul_break] = STATE(300),
    [sym_yul_continue] = STATE(300),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(300),
    [sym_yul_string_literal] = STATE(300),
    [sym_yul_boolean] = STATE(300),
    [sym_yul_block] = STATE(300),
    [sym_yul_variable_declaration] = STATE(300),
    [sym_yul_assignment] = STATE(300),
    [sym_yul_function_call] = STATE(300),
    [sym_yul_if_statement] = STATE(300),
    [sym_yul_for_statement] = STATE(300),
    [sym_yul_switch_statement] = STATE(300),
    [sym_yul_function_definition] = STATE(300),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(300),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(300),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(997),
    [anon_sym_LBRACE] = ACTIONS(1000),
    [anon_sym_RBRACE] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [sym_yul_leave] = ACTIONS(1008),
    [anon_sym_break] = ACTIONS(1011),
    [anon_sym_continue] = ACTIONS(1014),
    [sym_yul_decimal_number] = ACTIONS(1008),
    [sym_yul_hex_number] = ACTIONS(1017),
    [anon_sym_true] = ACTIONS(1020),
    [anon_sym_false] = ACTIONS(1020),
    [anon_sym_let] = ACTIONS(1023),
    [anon_sym_if] = ACTIONS(1026),
    [anon_sym_switch] = ACTIONS(1029),
    [anon_sym_function] = ACTIONS(1032),
    [anon_sym_stop] = ACTIONS(1035),
    [anon_sym_add] = ACTIONS(1035),
    [anon_sym_sub] = ACTIONS(1035),
    [anon_sym_mul] = ACTIONS(1035),
    [anon_sym_div] = ACTIONS(1035),
    [anon_sym_sdiv] = ACTIONS(1035),
    [anon_sym_mod] = ACTIONS(1035),
    [anon_sym_smod] = ACTIONS(1035),
    [anon_sym_exp] = ACTIONS(1035),
    [anon_sym_not] = ACTIONS(1035),
    [anon_sym_lt] = ACTIONS(1035),
    [anon_sym_gt] = ACTIONS(1035),
    [anon_sym_slt] = ACTIONS(1035),
    [anon_sym_sgt] = ACTIONS(1035),
    [anon_sym_eq] = ACTIONS(1035),
    [anon_sym_iszero] = ACTIONS(1035),
    [anon_sym_and] = ACTIONS(1035),
    [anon_sym_or] = ACTIONS(1035),
    [anon_sym_xor] = ACTIONS(1035),
    [anon_sym_byte] = ACTIONS(1035),
    [anon_sym_shl] = ACTIONS(1035),
    [anon_sym_shr] = ACTIONS(1035),
    [anon_sym_sar] = ACTIONS(1035),
    [anon_sym_addmod] = ACTIONS(1035),
    [anon_sym_mulmod] = ACTIONS(1035),
    [anon_sym_signextend] = ACTIONS(1035),
    [anon_sym_keccak256] = ACTIONS(1035),
    [anon_sym_pop] = ACTIONS(1035),
    [anon_sym_mload] = ACTIONS(1035),
    [anon_sym_mstore] = ACTIONS(1035),
    [anon_sym_mstore8] = ACTIONS(1035),
    [anon_sym_sload] = ACTIONS(1035),
    [anon_sym_sstore] = ACTIONS(1035),
    [anon_sym_msize] = ACTIONS(1035),
    [anon_sym_gas] = ACTIONS(1035),
    [anon_sym_address] = ACTIONS(1035),
    [anon_sym_balance] = ACTIONS(1035),
    [anon_sym_selfbalance] = ACTIONS(1035),
    [anon_sym_caller] = ACTIONS(1035),
    [anon_sym_callvalue] = ACTIONS(1035),
    [anon_sym_calldataload] = ACTIONS(1035),
    [anon_sym_calldatasize] = ACTIONS(1035),
    [anon_sym_calldatacopy] = ACTIONS(1035),
    [anon_sym_extcodesize] = ACTIONS(1035),
    [anon_sym_extcodecopy] = ACTIONS(1035),
    [anon_sym_returndatasize] = ACTIONS(1035),
    [anon_sym_returndatacopy] = ACTIONS(1035),
    [anon_sym_extcodehash] = ACTIONS(1035),
    [anon_sym_create] = ACTIONS(1035),
    [anon_sym_create2] = ACTIONS(1035),
    [anon_sym_call] = ACTIONS(1035),
    [anon_sym_callcode] = ACTIONS(1035),
    [anon_sym_delegatecall] = ACTIONS(1035),
    [anon_sym_staticcall] = ACTIONS(1035),
    [anon_sym_return] = ACTIONS(1035),
    [anon_sym_revert] = ACTIONS(1035),
    [anon_sym_selfdestruct] = ACTIONS(1035),
    [anon_sym_invalid] = ACTIONS(1035),
    [anon_sym_log0] = ACTIONS(1035),
    [anon_sym_log1] = ACTIONS(1035),
    [anon_sym_log2] = ACTIONS(1035),
    [anon_sym_log3] = ACTIONS(1035),
    [anon_sym_log4] = ACTIONS(1035),
    [anon_sym_chainid] = ACTIONS(1035),
    [anon_sym_origin] = ACTIONS(1035),
    [anon_sym_gasprice] = ACTIONS(1035),
    [anon_sym_blockhash] = ACTIONS(1035),
    [anon_sym_coinbase] = ACTIONS(1035),
    [anon_sym_timestamp] = ACTIONS(1035),
    [anon_sym_number] = ACTIONS(1035),
    [anon_sym_difficulty] = ACTIONS(1035),
    [anon_sym_gaslimit] = ACTIONS(1035),
    [anon_sym_hex] = ACTIONS(1038),
    [anon_sym_DQUOTE] = ACTIONS(1041),
    [anon_sym_SQUOTE] = ACTIONS(1044),
    [sym_comment] = ACTIONS(3),
  },
  [301] = {
    [sym__yul_statement] = STATE(299),
    [sym_yul_label] = STATE(299),
    [sym_yul_break] = STATE(299),
    [sym_yul_continue] = STATE(299),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(299),
    [sym_yul_string_literal] = STATE(299),
    [sym_yul_boolean] = STATE(299),
    [sym_yul_block] = STATE(299),
    [sym_yul_variable_declaration] = STATE(299),
    [sym_yul_assignment] = STATE(299),
    [sym_yul_function_call] = STATE(299),
    [sym_yul_if_statement] = STATE(299),
    [sym_yul_for_statement] = STATE(299),
    [sym_yul_switch_statement] = STATE(299),
    [sym_yul_function_definition] = STATE(299),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(299),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(299),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(1047),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(1047),
    [sym_yul_hex_number] = ACTIONS(1049),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [302] = {
    [sym__yul_statement] = STATE(292),
    [sym_yul_label] = STATE(292),
    [sym_yul_break] = STATE(292),
    [sym_yul_continue] = STATE(292),
    [sym_yul_identifier] = STATE(303),
    [sym_yul_path] = STATE(310),
    [sym__yul_literal] = STATE(292),
    [sym_yul_string_literal] = STATE(292),
    [sym_yul_boolean] = STATE(292),
    [sym_yul_block] = STATE(292),
    [sym_yul_variable_declaration] = STATE(292),
    [sym_yul_assignment] = STATE(292),
    [sym_yul_function_call] = STATE(292),
    [sym_yul_if_statement] = STATE(292),
    [sym_yul_for_statement] = STATE(292),
    [sym_yul_switch_statement] = STATE(292),
    [sym_yul_function_definition] = STATE(292),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(292),
    [sym_string] = STATE(318),
    [aux_sym_assembly_statement_repeat1] = STATE(292),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(939),
    [sym_yul_leave] = ACTIONS(1053),
    [anon_sym_break] = ACTIONS(943),
    [anon_sym_continue] = ACTIONS(945),
    [sym_yul_decimal_number] = ACTIONS(1053),
    [sym_yul_hex_number] = ACTIONS(1055),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(955),
    [anon_sym_function] = ACTIONS(957),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [303] = {
    [aux_sym_yul_path_repeat1] = STATE(304),
    [sym_identifier] = ACTIONS(1057),
    [anon_sym_LBRACE] = ACTIONS(1059),
    [anon_sym_COMMA] = ACTIONS(1059),
    [anon_sym_RBRACE] = ACTIONS(1059),
    [anon_sym_LPAREN] = ACTIONS(1061),
    [anon_sym_RPAREN] = ACTIONS(1059),
    [anon_sym_for] = ACTIONS(1057),
    [anon_sym_COLON] = ACTIONS(1057),
    [sym_yul_leave] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_continue] = ACTIONS(1057),
    [anon_sym_DOT] = ACTIONS(1063),
    [sym_yul_decimal_number] = ACTIONS(1057),
    [sym_yul_hex_number] = ACTIONS(1059),
    [anon_sym_true] = ACTIONS(1057),
    [anon_sym_false] = ACTIONS(1057),
    [anon_sym_let] = ACTIONS(1057),
    [anon_sym_COLON_EQ] = ACTIONS(1059),
    [anon_sym_if] = ACTIONS(1057),
    [anon_sym_switch] = ACTIONS(1057),
    [anon_sym_default] = ACTIONS(1057),
    [anon_sym_case] = ACTIONS(1057),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_stop] = ACTIONS(1057),
    [anon_sym_add] = ACTIONS(1057),
    [anon_sym_sub] = ACTIONS(1057),
    [anon_sym_mul] = ACTIONS(1057),
    [anon_sym_div] = ACTIONS(1057),
    [anon_sym_sdiv] = ACTIONS(1057),
    [anon_sym_mod] = ACTIONS(1057),
    [anon_sym_smod] = ACTIONS(1057),
    [anon_sym_exp] = ACTIONS(1057),
    [anon_sym_not] = ACTIONS(1057),
    [anon_sym_lt] = ACTIONS(1057),
    [anon_sym_gt] = ACTIONS(1057),
    [anon_sym_slt] = ACTIONS(1057),
    [anon_sym_sgt] = ACTIONS(1057),
    [anon_sym_eq] = ACTIONS(1057),
    [anon_sym_iszero] = ACTIONS(1057),
    [anon_sym_and] = ACTIONS(1057),
    [anon_sym_or] = ACTIONS(1057),
    [anon_sym_xor] = ACTIONS(1057),
    [anon_sym_byte] = ACTIONS(1057),
    [anon_sym_shl] = ACTIONS(1057),
    [anon_sym_shr] = ACTIONS(1057),
    [anon_sym_sar] = ACTIONS(1057),
    [anon_sym_addmod] = ACTIONS(1057),
    [anon_sym_mulmod] = ACTIONS(1057),
    [anon_sym_signextend] = ACTIONS(1057),
    [anon_sym_keccak256] = ACTIONS(1057),
    [anon_sym_pop] = ACTIONS(1057),
    [anon_sym_mload] = ACTIONS(1057),
    [anon_sym_mstore] = ACTIONS(1057),
    [anon_sym_mstore8] = ACTIONS(1057),
    [anon_sym_sload] = ACTIONS(1057),
    [anon_sym_sstore] = ACTIONS(1057),
    [anon_sym_msize] = ACTIONS(1057),
    [anon_sym_gas] = ACTIONS(1057),
    [anon_sym_address] = ACTIONS(1057),
    [anon_sym_balance] = ACTIONS(1057),
    [anon_sym_selfbalance] = ACTIONS(1057),
    [anon_sym_caller] = ACTIONS(1057),
    [anon_sym_callvalue] = ACTIONS(1057),
    [anon_sym_calldataload] = ACTIONS(1057),
    [anon_sym_calldatasize] = ACTIONS(1057),
    [anon_sym_calldatacopy] = ACTIONS(1057),
    [anon_sym_extcodesize] = ACTIONS(1057),
    [anon_sym_extcodecopy] = ACTIONS(1057),
    [anon_sym_returndatasize] = ACTIONS(1057),
    [anon_sym_returndatacopy] = ACTIONS(1057),
    [anon_sym_extcodehash] = ACTIONS(1057),
    [anon_sym_create] = ACTIONS(1057),
    [anon_sym_create2] = ACTIONS(1057),
    [anon_sym_call] = ACTIONS(1057),
    [anon_sym_callcode] = ACTIONS(1057),
    [anon_sym_delegatecall] = ACTIONS(1057),
    [anon_sym_staticcall] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1057),
    [anon_sym_revert] = ACTIONS(1057),
    [anon_sym_selfdestruct] = ACTIONS(1057),
    [anon_sym_invalid] = ACTIONS(1057),
    [anon_sym_log0] = ACTIONS(1057),
    [anon_sym_log1] = ACTIONS(1057),
    [anon_sym_log2] = ACTIONS(1057),
    [anon_sym_log3] = ACTIONS(1057),
    [anon_sym_log4] = ACTIONS(1057),
    [anon_sym_chainid] = ACTIONS(1057),
    [anon_sym_origin] = ACTIONS(1057),
    [anon_sym_gasprice] = ACTIONS(1057),
    [anon_sym_blockhash] = ACTIONS(1057),
    [anon_sym_coinbase] = ACTIONS(1057),
    [anon_sym_timestamp] = ACTIONS(1057),
    [anon_sym_number] = ACTIONS(1057),
    [anon_sym_difficulty] = ACTIONS(1057),
    [anon_sym_gaslimit] = ACTIONS(1057),
    [anon_sym_hex] = ACTIONS(1057),
    [anon_sym_DQUOTE] = ACTIONS(1059),
    [anon_sym_SQUOTE] = ACTIONS(1059),
    [sym_comment] = ACTIONS(3),
  },
  [304] = {
    [aux_sym_yul_path_repeat1] = STATE(306),
    [sym_identifier] = ACTIONS(1065),
    [anon_sym_LBRACE] = ACTIONS(1067),
    [anon_sym_COMMA] = ACTIONS(1067),
    [anon_sym_RBRACE] = ACTIONS(1067),
    [anon_sym_RPAREN] = ACTIONS(1067),
    [anon_sym_for] = ACTIONS(1065),
    [anon_sym_COLON] = ACTIONS(1065),
    [sym_yul_leave] = ACTIONS(1065),
    [anon_sym_break] = ACTIONS(1065),
    [anon_sym_continue] = ACTIONS(1065),
    [anon_sym_DOT] = ACTIONS(1063),
    [sym_yul_decimal_number] = ACTIONS(1065),
    [sym_yul_hex_number] = ACTIONS(1067),
    [anon_sym_true] = ACTIONS(1065),
    [anon_sym_false] = ACTIONS(1065),
    [anon_sym_let] = ACTIONS(1065),
    [anon_sym_COLON_EQ] = ACTIONS(1067),
    [anon_sym_if] = ACTIONS(1065),
    [anon_sym_switch] = ACTIONS(1065),
    [anon_sym_default] = ACTIONS(1065),
    [anon_sym_case] = ACTIONS(1065),
    [anon_sym_function] = ACTIONS(1065),
    [anon_sym_stop] = ACTIONS(1065),
    [anon_sym_add] = ACTIONS(1065),
    [anon_sym_sub] = ACTIONS(1065),
    [anon_sym_mul] = ACTIONS(1065),
    [anon_sym_div] = ACTIONS(1065),
    [anon_sym_sdiv] = ACTIONS(1065),
    [anon_sym_mod] = ACTIONS(1065),
    [anon_sym_smod] = ACTIONS(1065),
    [anon_sym_exp] = ACTIONS(1065),
    [anon_sym_not] = ACTIONS(1065),
    [anon_sym_lt] = ACTIONS(1065),
    [anon_sym_gt] = ACTIONS(1065),
    [anon_sym_slt] = ACTIONS(1065),
    [anon_sym_sgt] = ACTIONS(1065),
    [anon_sym_eq] = ACTIONS(1065),
    [anon_sym_iszero] = ACTIONS(1065),
    [anon_sym_and] = ACTIONS(1065),
    [anon_sym_or] = ACTIONS(1065),
    [anon_sym_xor] = ACTIONS(1065),
    [anon_sym_byte] = ACTIONS(1065),
    [anon_sym_shl] = ACTIONS(1065),
    [anon_sym_shr] = ACTIONS(1065),
    [anon_sym_sar] = ACTIONS(1065),
    [anon_sym_addmod] = ACTIONS(1065),
    [anon_sym_mulmod] = ACTIONS(1065),
    [anon_sym_signextend] = ACTIONS(1065),
    [anon_sym_keccak256] = ACTIONS(1065),
    [anon_sym_pop] = ACTIONS(1065),
    [anon_sym_mload] = ACTIONS(1065),
    [anon_sym_mstore] = ACTIONS(1065),
    [anon_sym_mstore8] = ACTIONS(1065),
    [anon_sym_sload] = ACTIONS(1065),
    [anon_sym_sstore] = ACTIONS(1065),
    [anon_sym_msize] = ACTIONS(1065),
    [anon_sym_gas] = ACTIONS(1065),
    [anon_sym_address] = ACTIONS(1065),
    [anon_sym_balance] = ACTIONS(1065),
    [anon_sym_selfbalance] = ACTIONS(1065),
    [anon_sym_caller] = ACTIONS(1065),
    [anon_sym_callvalue] = ACTIONS(1065),
    [anon_sym_calldataload] = ACTIONS(1065),
    [anon_sym_calldatasize] = ACTIONS(1065),
    [anon_sym_calldatacopy] = ACTIONS(1065),
    [anon_sym_extcodesize] = ACTIONS(1065),
    [anon_sym_extcodecopy] = ACTIONS(1065),
    [anon_sym_returndatasize] = ACTIONS(1065),
    [anon_sym_returndatacopy] = ACTIONS(1065),
    [anon_sym_extcodehash] = ACTIONS(1065),
    [anon_sym_create] = ACTIONS(1065),
    [anon_sym_create2] = ACTIONS(1065),
    [anon_sym_call] = ACTIONS(1065),
    [anon_sym_callcode] = ACTIONS(1065),
    [anon_sym_delegatecall] = ACTIONS(1065),
    [anon_sym_staticcall] = ACTIONS(1065),
    [anon_sym_return] = ACTIONS(1065),
    [anon_sym_revert] = ACTIONS(1065),
    [anon_sym_selfdestruct] = ACTIONS(1065),
    [anon_sym_invalid] = ACTIONS(1065),
    [anon_sym_log0] = ACTIONS(1065),
    [anon_sym_log1] = ACTIONS(1065),
    [anon_sym_log2] = ACTIONS(1065),
    [anon_sym_log3] = ACTIONS(1065),
    [anon_sym_log4] = ACTIONS(1065),
    [anon_sym_chainid] = ACTIONS(1065),
    [anon_sym_origin] = ACTIONS(1065),
    [anon_sym_gasprice] = ACTIONS(1065),
    [anon_sym_blockhash] = ACTIONS(1065),
    [anon_sym_coinbase] = ACTIONS(1065),
    [anon_sym_timestamp] = ACTIONS(1065),
    [anon_sym_number] = ACTIONS(1065),
    [anon_sym_difficulty] = ACTIONS(1065),
    [anon_sym_gaslimit] = ACTIONS(1065),
    [anon_sym_hex] = ACTIONS(1065),
    [anon_sym_DQUOTE] = ACTIONS(1067),
    [anon_sym_SQUOTE] = ACTIONS(1067),
    [sym_comment] = ACTIONS(3),
  },
  [305] = {
    [sym_identifier] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_COMMA] = ACTIONS(1071),
    [anon_sym_RBRACE] = ACTIONS(1071),
    [anon_sym_LPAREN] = ACTIONS(1071),
    [anon_sym_RPAREN] = ACTIONS(1071),
    [anon_sym_for] = ACTIONS(1069),
    [anon_sym_COLON] = ACTIONS(1069),
    [sym_yul_leave] = ACTIONS(1069),
    [anon_sym_break] = ACTIONS(1069),
    [anon_sym_continue] = ACTIONS(1069),
    [anon_sym_DOT] = ACTIONS(1071),
    [sym_yul_decimal_number] = ACTIONS(1069),
    [sym_yul_hex_number] = ACTIONS(1071),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_let] = ACTIONS(1069),
    [anon_sym_COLON_EQ] = ACTIONS(1071),
    [anon_sym_if] = ACTIONS(1069),
    [anon_sym_switch] = ACTIONS(1069),
    [anon_sym_default] = ACTIONS(1069),
    [anon_sym_case] = ACTIONS(1069),
    [anon_sym_function] = ACTIONS(1069),
    [anon_sym_stop] = ACTIONS(1069),
    [anon_sym_add] = ACTIONS(1069),
    [anon_sym_sub] = ACTIONS(1069),
    [anon_sym_mul] = ACTIONS(1069),
    [anon_sym_div] = ACTIONS(1069),
    [anon_sym_sdiv] = ACTIONS(1069),
    [anon_sym_mod] = ACTIONS(1069),
    [anon_sym_smod] = ACTIONS(1069),
    [anon_sym_exp] = ACTIONS(1069),
    [anon_sym_not] = ACTIONS(1069),
    [anon_sym_lt] = ACTIONS(1069),
    [anon_sym_gt] = ACTIONS(1069),
    [anon_sym_slt] = ACTIONS(1069),
    [anon_sym_sgt] = ACTIONS(1069),
    [anon_sym_eq] = ACTIONS(1069),
    [anon_sym_iszero] = ACTIONS(1069),
    [anon_sym_and] = ACTIONS(1069),
    [anon_sym_or] = ACTIONS(1069),
    [anon_sym_xor] = ACTIONS(1069),
    [anon_sym_byte] = ACTIONS(1069),
    [anon_sym_shl] = ACTIONS(1069),
    [anon_sym_shr] = ACTIONS(1069),
    [anon_sym_sar] = ACTIONS(1069),
    [anon_sym_addmod] = ACTIONS(1069),
    [anon_sym_mulmod] = ACTIONS(1069),
    [anon_sym_signextend] = ACTIONS(1069),
    [anon_sym_keccak256] = ACTIONS(1069),
    [anon_sym_pop] = ACTIONS(1069),
    [anon_sym_mload] = ACTIONS(1069),
    [anon_sym_mstore] = ACTIONS(1069),
    [anon_sym_mstore8] = ACTIONS(1069),
    [anon_sym_sload] = ACTIONS(1069),
    [anon_sym_sstore] = ACTIONS(1069),
    [anon_sym_msize] = ACTIONS(1069),
    [anon_sym_gas] = ACTIONS(1069),
    [anon_sym_address] = ACTIONS(1069),
    [anon_sym_balance] = ACTIONS(1069),
    [anon_sym_selfbalance] = ACTIONS(1069),
    [anon_sym_caller] = ACTIONS(1069),
    [anon_sym_callvalue] = ACTIONS(1069),
    [anon_sym_calldataload] = ACTIONS(1069),
    [anon_sym_calldatasize] = ACTIONS(1069),
    [anon_sym_calldatacopy] = ACTIONS(1069),
    [anon_sym_extcodesize] = ACTIONS(1069),
    [anon_sym_extcodecopy] = ACTIONS(1069),
    [anon_sym_returndatasize] = ACTIONS(1069),
    [anon_sym_returndatacopy] = ACTIONS(1069),
    [anon_sym_extcodehash] = ACTIONS(1069),
    [anon_sym_create] = ACTIONS(1069),
    [anon_sym_create2] = ACTIONS(1069),
    [anon_sym_call] = ACTIONS(1069),
    [anon_sym_callcode] = ACTIONS(1069),
    [anon_sym_delegatecall] = ACTIONS(1069),
    [anon_sym_staticcall] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_revert] = ACTIONS(1069),
    [anon_sym_selfdestruct] = ACTIONS(1069),
    [anon_sym_invalid] = ACTIONS(1069),
    [anon_sym_log0] = ACTIONS(1069),
    [anon_sym_log1] = ACTIONS(1069),
    [anon_sym_log2] = ACTIONS(1069),
    [anon_sym_log3] = ACTIONS(1069),
    [anon_sym_log4] = ACTIONS(1069),
    [anon_sym_chainid] = ACTIONS(1069),
    [anon_sym_origin] = ACTIONS(1069),
    [anon_sym_gasprice] = ACTIONS(1069),
    [anon_sym_blockhash] = ACTIONS(1069),
    [anon_sym_coinbase] = ACTIONS(1069),
    [anon_sym_timestamp] = ACTIONS(1069),
    [anon_sym_number] = ACTIONS(1069),
    [anon_sym_difficulty] = ACTIONS(1069),
    [anon_sym_gaslimit] = ACTIONS(1069),
    [anon_sym_hex] = ACTIONS(1069),
    [anon_sym_DQUOTE] = ACTIONS(1071),
    [anon_sym_SQUOTE] = ACTIONS(1071),
    [sym_comment] = ACTIONS(3),
  },
  [306] = {
    [aux_sym_yul_path_repeat1] = STATE(306),
    [sym_identifier] = ACTIONS(1073),
    [anon_sym_LBRACE] = ACTIONS(1075),
    [anon_sym_COMMA] = ACTIONS(1075),
    [anon_sym_RBRACE] = ACTIONS(1075),
    [anon_sym_RPAREN] = ACTIONS(1075),
    [anon_sym_for] = ACTIONS(1073),
    [anon_sym_COLON] = ACTIONS(1073),
    [sym_yul_leave] = ACTIONS(1073),
    [anon_sym_break] = ACTIONS(1073),
    [anon_sym_continue] = ACTIONS(1073),
    [anon_sym_DOT] = ACTIONS(1077),
    [sym_yul_decimal_number] = ACTIONS(1073),
    [sym_yul_hex_number] = ACTIONS(1075),
    [anon_sym_true] = ACTIONS(1073),
    [anon_sym_false] = ACTIONS(1073),
    [anon_sym_let] = ACTIONS(1073),
    [anon_sym_COLON_EQ] = ACTIONS(1075),
    [anon_sym_if] = ACTIONS(1073),
    [anon_sym_switch] = ACTIONS(1073),
    [anon_sym_default] = ACTIONS(1073),
    [anon_sym_case] = ACTIONS(1073),
    [anon_sym_function] = ACTIONS(1073),
    [anon_sym_stop] = ACTIONS(1073),
    [anon_sym_add] = ACTIONS(1073),
    [anon_sym_sub] = ACTIONS(1073),
    [anon_sym_mul] = ACTIONS(1073),
    [anon_sym_div] = ACTIONS(1073),
    [anon_sym_sdiv] = ACTIONS(1073),
    [anon_sym_mod] = ACTIONS(1073),
    [anon_sym_smod] = ACTIONS(1073),
    [anon_sym_exp] = ACTIONS(1073),
    [anon_sym_not] = ACTIONS(1073),
    [anon_sym_lt] = ACTIONS(1073),
    [anon_sym_gt] = ACTIONS(1073),
    [anon_sym_slt] = ACTIONS(1073),
    [anon_sym_sgt] = ACTIONS(1073),
    [anon_sym_eq] = ACTIONS(1073),
    [anon_sym_iszero] = ACTIONS(1073),
    [anon_sym_and] = ACTIONS(1073),
    [anon_sym_or] = ACTIONS(1073),
    [anon_sym_xor] = ACTIONS(1073),
    [anon_sym_byte] = ACTIONS(1073),
    [anon_sym_shl] = ACTIONS(1073),
    [anon_sym_shr] = ACTIONS(1073),
    [anon_sym_sar] = ACTIONS(1073),
    [anon_sym_addmod] = ACTIONS(1073),
    [anon_sym_mulmod] = ACTIONS(1073),
    [anon_sym_signextend] = ACTIONS(1073),
    [anon_sym_keccak256] = ACTIONS(1073),
    [anon_sym_pop] = ACTIONS(1073),
    [anon_sym_mload] = ACTIONS(1073),
    [anon_sym_mstore] = ACTIONS(1073),
    [anon_sym_mstore8] = ACTIONS(1073),
    [anon_sym_sload] = ACTIONS(1073),
    [anon_sym_sstore] = ACTIONS(1073),
    [anon_sym_msize] = ACTIONS(1073),
    [anon_sym_gas] = ACTIONS(1073),
    [anon_sym_address] = ACTIONS(1073),
    [anon_sym_balance] = ACTIONS(1073),
    [anon_sym_selfbalance] = ACTIONS(1073),
    [anon_sym_caller] = ACTIONS(1073),
    [anon_sym_callvalue] = ACTIONS(1073),
    [anon_sym_calldataload] = ACTIONS(1073),
    [anon_sym_calldatasize] = ACTIONS(1073),
    [anon_sym_calldatacopy] = ACTIONS(1073),
    [anon_sym_extcodesize] = ACTIONS(1073),
    [anon_sym_extcodecopy] = ACTIONS(1073),
    [anon_sym_returndatasize] = ACTIONS(1073),
    [anon_sym_returndatacopy] = ACTIONS(1073),
    [anon_sym_extcodehash] = ACTIONS(1073),
    [anon_sym_create] = ACTIONS(1073),
    [anon_sym_create2] = ACTIONS(1073),
    [anon_sym_call] = ACTIONS(1073),
    [anon_sym_callcode] = ACTIONS(1073),
    [anon_sym_delegatecall] = ACTIONS(1073),
    [anon_sym_staticcall] = ACTIONS(1073),
    [anon_sym_return] = ACTIONS(1073),
    [anon_sym_revert] = ACTIONS(1073),
    [anon_sym_selfdestruct] = ACTIONS(1073),
    [anon_sym_invalid] = ACTIONS(1073),
    [anon_sym_log0] = ACTIONS(1073),
    [anon_sym_log1] = ACTIONS(1073),
    [anon_sym_log2] = ACTIONS(1073),
    [anon_sym_log3] = ACTIONS(1073),
    [anon_sym_log4] = ACTIONS(1073),
    [anon_sym_chainid] = ACTIONS(1073),
    [anon_sym_origin] = ACTIONS(1073),
    [anon_sym_gasprice] = ACTIONS(1073),
    [anon_sym_blockhash] = ACTIONS(1073),
    [anon_sym_coinbase] = ACTIONS(1073),
    [anon_sym_timestamp] = ACTIONS(1073),
    [anon_sym_number] = ACTIONS(1073),
    [anon_sym_difficulty] = ACTIONS(1073),
    [anon_sym_gaslimit] = ACTIONS(1073),
    [anon_sym_hex] = ACTIONS(1073),
    [anon_sym_DQUOTE] = ACTIONS(1075),
    [anon_sym_SQUOTE] = ACTIONS(1075),
    [sym_comment] = ACTIONS(3),
  },
  [307] = {
    [sym_identifier] = ACTIONS(1073),
    [anon_sym_LBRACE] = ACTIONS(1075),
    [anon_sym_COMMA] = ACTIONS(1075),
    [anon_sym_RBRACE] = ACTIONS(1075),
    [anon_sym_RPAREN] = ACTIONS(1075),
    [anon_sym_for] = ACTIONS(1073),
    [anon_sym_COLON] = ACTIONS(1073),
    [sym_yul_leave] = ACTIONS(1073),
    [anon_sym_break] = ACTIONS(1073),
    [anon_sym_continue] = ACTIONS(1073),
    [anon_sym_DOT] = ACTIONS(1075),
    [sym_yul_decimal_number] = ACTIONS(1073),
    [sym_yul_hex_number] = ACTIONS(1075),
    [anon_sym_true] = ACTIONS(1073),
    [anon_sym_false] = ACTIONS(1073),
    [anon_sym_let] = ACTIONS(1073),
    [anon_sym_COLON_EQ] = ACTIONS(1075),
    [anon_sym_if] = ACTIONS(1073),
    [anon_sym_switch] = ACTIONS(1073),
    [anon_sym_default] = ACTIONS(1073),
    [anon_sym_case] = ACTIONS(1073),
    [anon_sym_function] = ACTIONS(1073),
    [anon_sym_stop] = ACTIONS(1073),
    [anon_sym_add] = ACTIONS(1073),
    [anon_sym_sub] = ACTIONS(1073),
    [anon_sym_mul] = ACTIONS(1073),
    [anon_sym_div] = ACTIONS(1073),
    [anon_sym_sdiv] = ACTIONS(1073),
    [anon_sym_mod] = ACTIONS(1073),
    [anon_sym_smod] = ACTIONS(1073),
    [anon_sym_exp] = ACTIONS(1073),
    [anon_sym_not] = ACTIONS(1073),
    [anon_sym_lt] = ACTIONS(1073),
    [anon_sym_gt] = ACTIONS(1073),
    [anon_sym_slt] = ACTIONS(1073),
    [anon_sym_sgt] = ACTIONS(1073),
    [anon_sym_eq] = ACTIONS(1073),
    [anon_sym_iszero] = ACTIONS(1073),
    [anon_sym_and] = ACTIONS(1073),
    [anon_sym_or] = ACTIONS(1073),
    [anon_sym_xor] = ACTIONS(1073),
    [anon_sym_byte] = ACTIONS(1073),
    [anon_sym_shl] = ACTIONS(1073),
    [anon_sym_shr] = ACTIONS(1073),
    [anon_sym_sar] = ACTIONS(1073),
    [anon_sym_addmod] = ACTIONS(1073),
    [anon_sym_mulmod] = ACTIONS(1073),
    [anon_sym_signextend] = ACTIONS(1073),
    [anon_sym_keccak256] = ACTIONS(1073),
    [anon_sym_pop] = ACTIONS(1073),
    [anon_sym_mload] = ACTIONS(1073),
    [anon_sym_mstore] = ACTIONS(1073),
    [anon_sym_mstore8] = ACTIONS(1073),
    [anon_sym_sload] = ACTIONS(1073),
    [anon_sym_sstore] = ACTIONS(1073),
    [anon_sym_msize] = ACTIONS(1073),
    [anon_sym_gas] = ACTIONS(1073),
    [anon_sym_address] = ACTIONS(1073),
    [anon_sym_balance] = ACTIONS(1073),
    [anon_sym_selfbalance] = ACTIONS(1073),
    [anon_sym_caller] = ACTIONS(1073),
    [anon_sym_callvalue] = ACTIONS(1073),
    [anon_sym_calldataload] = ACTIONS(1073),
    [anon_sym_calldatasize] = ACTIONS(1073),
    [anon_sym_calldatacopy] = ACTIONS(1073),
    [anon_sym_extcodesize] = ACTIONS(1073),
    [anon_sym_extcodecopy] = ACTIONS(1073),
    [anon_sym_returndatasize] = ACTIONS(1073),
    [anon_sym_returndatacopy] = ACTIONS(1073),
    [anon_sym_extcodehash] = ACTIONS(1073),
    [anon_sym_create] = ACTIONS(1073),
    [anon_sym_create2] = ACTIONS(1073),
    [anon_sym_call] = ACTIONS(1073),
    [anon_sym_callcode] = ACTIONS(1073),
    [anon_sym_delegatecall] = ACTIONS(1073),
    [anon_sym_staticcall] = ACTIONS(1073),
    [anon_sym_return] = ACTIONS(1073),
    [anon_sym_revert] = ACTIONS(1073),
    [anon_sym_selfdestruct] = ACTIONS(1073),
    [anon_sym_invalid] = ACTIONS(1073),
    [anon_sym_log0] = ACTIONS(1073),
    [anon_sym_log1] = ACTIONS(1073),
    [anon_sym_log2] = ACTIONS(1073),
    [anon_sym_log3] = ACTIONS(1073),
    [anon_sym_log4] = ACTIONS(1073),
    [anon_sym_chainid] = ACTIONS(1073),
    [anon_sym_origin] = ACTIONS(1073),
    [anon_sym_gasprice] = ACTIONS(1073),
    [anon_sym_blockhash] = ACTIONS(1073),
    [anon_sym_coinbase] = ACTIONS(1073),
    [anon_sym_timestamp] = ACTIONS(1073),
    [anon_sym_number] = ACTIONS(1073),
    [anon_sym_difficulty] = ACTIONS(1073),
    [anon_sym_gaslimit] = ACTIONS(1073),
    [anon_sym_hex] = ACTIONS(1073),
    [anon_sym_DQUOTE] = ACTIONS(1075),
    [anon_sym_SQUOTE] = ACTIONS(1075),
    [sym_comment] = ACTIONS(3),
  },
  [308] = {
    [sym_identifier] = ACTIONS(1080),
    [anon_sym_LBRACE] = ACTIONS(1082),
    [anon_sym_COMMA] = ACTIONS(1082),
    [anon_sym_RBRACE] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(1082),
    [anon_sym_RPAREN] = ACTIONS(1082),
    [anon_sym_for] = ACTIONS(1080),
    [sym_yul_leave] = ACTIONS(1080),
    [anon_sym_break] = ACTIONS(1080),
    [anon_sym_continue] = ACTIONS(1080),
    [sym_yul_decimal_number] = ACTIONS(1080),
    [sym_yul_hex_number] = ACTIONS(1082),
    [anon_sym_true] = ACTIONS(1080),
    [anon_sym_false] = ACTIONS(1080),
    [anon_sym_let] = ACTIONS(1080),
    [anon_sym_if] = ACTIONS(1080),
    [anon_sym_switch] = ACTIONS(1080),
    [anon_sym_default] = ACTIONS(1080),
    [anon_sym_case] = ACTIONS(1080),
    [anon_sym_function] = ACTIONS(1080),
    [anon_sym_stop] = ACTIONS(1080),
    [anon_sym_add] = ACTIONS(1080),
    [anon_sym_sub] = ACTIONS(1080),
    [anon_sym_mul] = ACTIONS(1080),
    [anon_sym_div] = ACTIONS(1080),
    [anon_sym_sdiv] = ACTIONS(1080),
    [anon_sym_mod] = ACTIONS(1080),
    [anon_sym_smod] = ACTIONS(1080),
    [anon_sym_exp] = ACTIONS(1080),
    [anon_sym_not] = ACTIONS(1080),
    [anon_sym_lt] = ACTIONS(1080),
    [anon_sym_gt] = ACTIONS(1080),
    [anon_sym_slt] = ACTIONS(1080),
    [anon_sym_sgt] = ACTIONS(1080),
    [anon_sym_eq] = ACTIONS(1080),
    [anon_sym_iszero] = ACTIONS(1080),
    [anon_sym_and] = ACTIONS(1080),
    [anon_sym_or] = ACTIONS(1080),
    [anon_sym_xor] = ACTIONS(1080),
    [anon_sym_byte] = ACTIONS(1080),
    [anon_sym_shl] = ACTIONS(1080),
    [anon_sym_shr] = ACTIONS(1080),
    [anon_sym_sar] = ACTIONS(1080),
    [anon_sym_addmod] = ACTIONS(1080),
    [anon_sym_mulmod] = ACTIONS(1080),
    [anon_sym_signextend] = ACTIONS(1080),
    [anon_sym_keccak256] = ACTIONS(1080),
    [anon_sym_pop] = ACTIONS(1080),
    [anon_sym_mload] = ACTIONS(1080),
    [anon_sym_mstore] = ACTIONS(1080),
    [anon_sym_mstore8] = ACTIONS(1080),
    [anon_sym_sload] = ACTIONS(1080),
    [anon_sym_sstore] = ACTIONS(1080),
    [anon_sym_msize] = ACTIONS(1080),
    [anon_sym_gas] = ACTIONS(1080),
    [anon_sym_address] = ACTIONS(1080),
    [anon_sym_balance] = ACTIONS(1080),
    [anon_sym_selfbalance] = ACTIONS(1080),
    [anon_sym_caller] = ACTIONS(1080),
    [anon_sym_callvalue] = ACTIONS(1080),
    [anon_sym_calldataload] = ACTIONS(1080),
    [anon_sym_calldatasize] = ACTIONS(1080),
    [anon_sym_calldatacopy] = ACTIONS(1080),
    [anon_sym_extcodesize] = ACTIONS(1080),
    [anon_sym_extcodecopy] = ACTIONS(1080),
    [anon_sym_returndatasize] = ACTIONS(1080),
    [anon_sym_returndatacopy] = ACTIONS(1080),
    [anon_sym_extcodehash] = ACTIONS(1080),
    [anon_sym_create] = ACTIONS(1080),
    [anon_sym_create2] = ACTIONS(1080),
    [anon_sym_call] = ACTIONS(1080),
    [anon_sym_callcode] = ACTIONS(1080),
    [anon_sym_delegatecall] = ACTIONS(1080),
    [anon_sym_staticcall] = ACTIONS(1080),
    [anon_sym_return] = ACTIONS(1080),
    [anon_sym_revert] = ACTIONS(1080),
    [anon_sym_selfdestruct] = ACTIONS(1080),
    [anon_sym_invalid] = ACTIONS(1080),
    [anon_sym_log0] = ACTIONS(1080),
    [anon_sym_log1] = ACTIONS(1080),
    [anon_sym_log2] = ACTIONS(1080),
    [anon_sym_log3] = ACTIONS(1080),
    [anon_sym_log4] = ACTIONS(1080),
    [anon_sym_chainid] = ACTIONS(1080),
    [anon_sym_origin] = ACTIONS(1080),
    [anon_sym_gasprice] = ACTIONS(1080),
    [anon_sym_blockhash] = ACTIONS(1080),
    [anon_sym_coinbase] = ACTIONS(1080),
    [anon_sym_timestamp] = ACTIONS(1080),
    [anon_sym_number] = ACTIONS(1080),
    [anon_sym_difficulty] = ACTIONS(1080),
    [anon_sym_gaslimit] = ACTIONS(1080),
    [anon_sym_hex] = ACTIONS(1080),
    [anon_sym_DQUOTE] = ACTIONS(1082),
    [anon_sym_SQUOTE] = ACTIONS(1082),
    [sym_comment] = ACTIONS(3),
  },
  [309] = {
    [sym_identifier] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_COMMA] = ACTIONS(1071),
    [anon_sym_RBRACE] = ACTIONS(1071),
    [anon_sym_LPAREN] = ACTIONS(1071),
    [anon_sym_for] = ACTIONS(1069),
    [anon_sym_COLON] = ACTIONS(1084),
    [sym_yul_leave] = ACTIONS(1069),
    [anon_sym_break] = ACTIONS(1069),
    [anon_sym_continue] = ACTIONS(1069),
    [anon_sym_DOT] = ACTIONS(1071),
    [sym_yul_decimal_number] = ACTIONS(1069),
    [sym_yul_hex_number] = ACTIONS(1071),
    [anon_sym_true] = ACTIONS(1069),
    [anon_sym_false] = ACTIONS(1069),
    [anon_sym_let] = ACTIONS(1069),
    [anon_sym_COLON_EQ] = ACTIONS(1071),
    [anon_sym_if] = ACTIONS(1069),
    [anon_sym_switch] = ACTIONS(1069),
    [anon_sym_function] = ACTIONS(1069),
    [anon_sym_stop] = ACTIONS(1069),
    [anon_sym_add] = ACTIONS(1069),
    [anon_sym_sub] = ACTIONS(1069),
    [anon_sym_mul] = ACTIONS(1069),
    [anon_sym_div] = ACTIONS(1069),
    [anon_sym_sdiv] = ACTIONS(1069),
    [anon_sym_mod] = ACTIONS(1069),
    [anon_sym_smod] = ACTIONS(1069),
    [anon_sym_exp] = ACTIONS(1069),
    [anon_sym_not] = ACTIONS(1069),
    [anon_sym_lt] = ACTIONS(1069),
    [anon_sym_gt] = ACTIONS(1069),
    [anon_sym_slt] = ACTIONS(1069),
    [anon_sym_sgt] = ACTIONS(1069),
    [anon_sym_eq] = ACTIONS(1069),
    [anon_sym_iszero] = ACTIONS(1069),
    [anon_sym_and] = ACTIONS(1069),
    [anon_sym_or] = ACTIONS(1069),
    [anon_sym_xor] = ACTIONS(1069),
    [anon_sym_byte] = ACTIONS(1069),
    [anon_sym_shl] = ACTIONS(1069),
    [anon_sym_shr] = ACTIONS(1069),
    [anon_sym_sar] = ACTIONS(1069),
    [anon_sym_addmod] = ACTIONS(1069),
    [anon_sym_mulmod] = ACTIONS(1069),
    [anon_sym_signextend] = ACTIONS(1069),
    [anon_sym_keccak256] = ACTIONS(1069),
    [anon_sym_pop] = ACTIONS(1069),
    [anon_sym_mload] = ACTIONS(1069),
    [anon_sym_mstore] = ACTIONS(1069),
    [anon_sym_mstore8] = ACTIONS(1069),
    [anon_sym_sload] = ACTIONS(1069),
    [anon_sym_sstore] = ACTIONS(1069),
    [anon_sym_msize] = ACTIONS(1069),
    [anon_sym_gas] = ACTIONS(1069),
    [anon_sym_address] = ACTIONS(1069),
    [anon_sym_balance] = ACTIONS(1069),
    [anon_sym_selfbalance] = ACTIONS(1069),
    [anon_sym_caller] = ACTIONS(1069),
    [anon_sym_callvalue] = ACTIONS(1069),
    [anon_sym_calldataload] = ACTIONS(1069),
    [anon_sym_calldatasize] = ACTIONS(1069),
    [anon_sym_calldatacopy] = ACTIONS(1069),
    [anon_sym_extcodesize] = ACTIONS(1069),
    [anon_sym_extcodecopy] = ACTIONS(1069),
    [anon_sym_returndatasize] = ACTIONS(1069),
    [anon_sym_returndatacopy] = ACTIONS(1069),
    [anon_sym_extcodehash] = ACTIONS(1069),
    [anon_sym_create] = ACTIONS(1069),
    [anon_sym_create2] = ACTIONS(1069),
    [anon_sym_call] = ACTIONS(1069),
    [anon_sym_callcode] = ACTIONS(1069),
    [anon_sym_delegatecall] = ACTIONS(1069),
    [anon_sym_staticcall] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_revert] = ACTIONS(1069),
    [anon_sym_selfdestruct] = ACTIONS(1069),
    [anon_sym_invalid] = ACTIONS(1069),
    [anon_sym_log0] = ACTIONS(1069),
    [anon_sym_log1] = ACTIONS(1069),
    [anon_sym_log2] = ACTIONS(1069),
    [anon_sym_log3] = ACTIONS(1069),
    [anon_sym_log4] = ACTIONS(1069),
    [anon_sym_chainid] = ACTIONS(1069),
    [anon_sym_origin] = ACTIONS(1069),
    [anon_sym_gasprice] = ACTIONS(1069),
    [anon_sym_blockhash] = ACTIONS(1069),
    [anon_sym_coinbase] = ACTIONS(1069),
    [anon_sym_timestamp] = ACTIONS(1069),
    [anon_sym_number] = ACTIONS(1069),
    [anon_sym_difficulty] = ACTIONS(1069),
    [anon_sym_gaslimit] = ACTIONS(1069),
    [anon_sym_hex] = ACTIONS(1069),
    [anon_sym_DQUOTE] = ACTIONS(1071),
    [anon_sym_SQUOTE] = ACTIONS(1071),
    [sym_comment] = ACTIONS(3),
  },
  [310] = {
    [sym__yul_assignment_operator] = STATE(345),
    [aux_sym_yul_assignment_repeat1] = STATE(314),
    [sym_identifier] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_COMMA] = ACTIONS(1091),
    [anon_sym_RBRACE] = ACTIONS(1089),
    [anon_sym_for] = ACTIONS(1087),
    [anon_sym_COLON] = ACTIONS(1093),
    [sym_yul_leave] = ACTIONS(1087),
    [anon_sym_break] = ACTIONS(1087),
    [anon_sym_continue] = ACTIONS(1087),
    [sym_yul_decimal_number] = ACTIONS(1087),
    [sym_yul_hex_number] = ACTIONS(1089),
    [anon_sym_true] = ACTIONS(1087),
    [anon_sym_false] = ACTIONS(1087),
    [anon_sym_let] = ACTIONS(1087),
    [anon_sym_COLON_EQ] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1087),
    [anon_sym_switch] = ACTIONS(1087),
    [anon_sym_function] = ACTIONS(1087),
    [anon_sym_stop] = ACTIONS(1087),
    [anon_sym_add] = ACTIONS(1087),
    [anon_sym_sub] = ACTIONS(1087),
    [anon_sym_mul] = ACTIONS(1087),
    [anon_sym_div] = ACTIONS(1087),
    [anon_sym_sdiv] = ACTIONS(1087),
    [anon_sym_mod] = ACTIONS(1087),
    [anon_sym_smod] = ACTIONS(1087),
    [anon_sym_exp] = ACTIONS(1087),
    [anon_sym_not] = ACTIONS(1087),
    [anon_sym_lt] = ACTIONS(1087),
    [anon_sym_gt] = ACTIONS(1087),
    [anon_sym_slt] = ACTIONS(1087),
    [anon_sym_sgt] = ACTIONS(1087),
    [anon_sym_eq] = ACTIONS(1087),
    [anon_sym_iszero] = ACTIONS(1087),
    [anon_sym_and] = ACTIONS(1087),
    [anon_sym_or] = ACTIONS(1087),
    [anon_sym_xor] = ACTIONS(1087),
    [anon_sym_byte] = ACTIONS(1087),
    [anon_sym_shl] = ACTIONS(1087),
    [anon_sym_shr] = ACTIONS(1087),
    [anon_sym_sar] = ACTIONS(1087),
    [anon_sym_addmod] = ACTIONS(1087),
    [anon_sym_mulmod] = ACTIONS(1087),
    [anon_sym_signextend] = ACTIONS(1087),
    [anon_sym_keccak256] = ACTIONS(1087),
    [anon_sym_pop] = ACTIONS(1087),
    [anon_sym_mload] = ACTIONS(1087),
    [anon_sym_mstore] = ACTIONS(1087),
    [anon_sym_mstore8] = ACTIONS(1087),
    [anon_sym_sload] = ACTIONS(1087),
    [anon_sym_sstore] = ACTIONS(1087),
    [anon_sym_msize] = ACTIONS(1087),
    [anon_sym_gas] = ACTIONS(1087),
    [anon_sym_address] = ACTIONS(1087),
    [anon_sym_balance] = ACTIONS(1087),
    [anon_sym_selfbalance] = ACTIONS(1087),
    [anon_sym_caller] = ACTIONS(1087),
    [anon_sym_callvalue] = ACTIONS(1087),
    [anon_sym_calldataload] = ACTIONS(1087),
    [anon_sym_calldatasize] = ACTIONS(1087),
    [anon_sym_calldatacopy] = ACTIONS(1087),
    [anon_sym_extcodesize] = ACTIONS(1087),
    [anon_sym_extcodecopy] = ACTIONS(1087),
    [anon_sym_returndatasize] = ACTIONS(1087),
    [anon_sym_returndatacopy] = ACTIONS(1087),
    [anon_sym_extcodehash] = ACTIONS(1087),
    [anon_sym_create] = ACTIONS(1087),
    [anon_sym_create2] = ACTIONS(1087),
    [anon_sym_call] = ACTIONS(1087),
    [anon_sym_callcode] = ACTIONS(1087),
    [anon_sym_delegatecall] = ACTIONS(1087),
    [anon_sym_staticcall] = ACTIONS(1087),
    [anon_sym_return] = ACTIONS(1087),
    [anon_sym_revert] = ACTIONS(1087),
    [anon_sym_selfdestruct] = ACTIONS(1087),
    [anon_sym_invalid] = ACTIONS(1087),
    [anon_sym_log0] = ACTIONS(1087),
    [anon_sym_log1] = ACTIONS(1087),
    [anon_sym_log2] = ACTIONS(1087),
    [anon_sym_log3] = ACTIONS(1087),
    [anon_sym_log4] = ACTIONS(1087),
    [anon_sym_chainid] = ACTIONS(1087),
    [anon_sym_origin] = ACTIONS(1087),
    [anon_sym_gasprice] = ACTIONS(1087),
    [anon_sym_blockhash] = ACTIONS(1087),
    [anon_sym_coinbase] = ACTIONS(1087),
    [anon_sym_timestamp] = ACTIONS(1087),
    [anon_sym_number] = ACTIONS(1087),
    [anon_sym_difficulty] = ACTIONS(1087),
    [anon_sym_gaslimit] = ACTIONS(1087),
    [anon_sym_hex] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(1089),
    [anon_sym_SQUOTE] = ACTIONS(1089),
    [sym_comment] = ACTIONS(3),
  },
  [311] = {
    [aux_sym_yul_path_repeat1] = STATE(304),
    [sym_identifier] = ACTIONS(1057),
    [anon_sym_LBRACE] = ACTIONS(1059),
    [anon_sym_COMMA] = ACTIONS(1059),
    [anon_sym_RBRACE] = ACTIONS(1059),
    [anon_sym_for] = ACTIONS(1057),
    [anon_sym_COLON] = ACTIONS(1057),
    [sym_yul_leave] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_continue] = ACTIONS(1057),
    [anon_sym_DOT] = ACTIONS(1063),
    [sym_yul_decimal_number] = ACTIONS(1057),
    [sym_yul_hex_number] = ACTIONS(1059),
    [anon_sym_true] = ACTIONS(1057),
    [anon_sym_false] = ACTIONS(1057),
    [anon_sym_let] = ACTIONS(1057),
    [anon_sym_COLON_EQ] = ACTIONS(1059),
    [anon_sym_if] = ACTIONS(1057),
    [anon_sym_switch] = ACTIONS(1057),
    [anon_sym_function] = ACTIONS(1057),
    [anon_sym_stop] = ACTIONS(1057),
    [anon_sym_add] = ACTIONS(1057),
    [anon_sym_sub] = ACTIONS(1057),
    [anon_sym_mul] = ACTIONS(1057),
    [anon_sym_div] = ACTIONS(1057),
    [anon_sym_sdiv] = ACTIONS(1057),
    [anon_sym_mod] = ACTIONS(1057),
    [anon_sym_smod] = ACTIONS(1057),
    [anon_sym_exp] = ACTIONS(1057),
    [anon_sym_not] = ACTIONS(1057),
    [anon_sym_lt] = ACTIONS(1057),
    [anon_sym_gt] = ACTIONS(1057),
    [anon_sym_slt] = ACTIONS(1057),
    [anon_sym_sgt] = ACTIONS(1057),
    [anon_sym_eq] = ACTIONS(1057),
    [anon_sym_iszero] = ACTIONS(1057),
    [anon_sym_and] = ACTIONS(1057),
    [anon_sym_or] = ACTIONS(1057),
    [anon_sym_xor] = ACTIONS(1057),
    [anon_sym_byte] = ACTIONS(1057),
    [anon_sym_shl] = ACTIONS(1057),
    [anon_sym_shr] = ACTIONS(1057),
    [anon_sym_sar] = ACTIONS(1057),
    [anon_sym_addmod] = ACTIONS(1057),
    [anon_sym_mulmod] = ACTIONS(1057),
    [anon_sym_signextend] = ACTIONS(1057),
    [anon_sym_keccak256] = ACTIONS(1057),
    [anon_sym_pop] = ACTIONS(1057),
    [anon_sym_mload] = ACTIONS(1057),
    [anon_sym_mstore] = ACTIONS(1057),
    [anon_sym_mstore8] = ACTIONS(1057),
    [anon_sym_sload] = ACTIONS(1057),
    [anon_sym_sstore] = ACTIONS(1057),
    [anon_sym_msize] = ACTIONS(1057),
    [anon_sym_gas] = ACTIONS(1057),
    [anon_sym_address] = ACTIONS(1057),
    [anon_sym_balance] = ACTIONS(1057),
    [anon_sym_selfbalance] = ACTIONS(1057),
    [anon_sym_caller] = ACTIONS(1057),
    [anon_sym_callvalue] = ACTIONS(1057),
    [anon_sym_calldataload] = ACTIONS(1057),
    [anon_sym_calldatasize] = ACTIONS(1057),
    [anon_sym_calldatacopy] = ACTIONS(1057),
    [anon_sym_extcodesize] = ACTIONS(1057),
    [anon_sym_extcodecopy] = ACTIONS(1057),
    [anon_sym_returndatasize] = ACTIONS(1057),
    [anon_sym_returndatacopy] = ACTIONS(1057),
    [anon_sym_extcodehash] = ACTIONS(1057),
    [anon_sym_create] = ACTIONS(1057),
    [anon_sym_create2] = ACTIONS(1057),
    [anon_sym_call] = ACTIONS(1057),
    [anon_sym_callcode] = ACTIONS(1057),
    [anon_sym_delegatecall] = ACTIONS(1057),
    [anon_sym_staticcall] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1057),
    [anon_sym_revert] = ACTIONS(1057),
    [anon_sym_selfdestruct] = ACTIONS(1057),
    [anon_sym_invalid] = ACTIONS(1057),
    [anon_sym_log0] = ACTIONS(1057),
    [anon_sym_log1] = ACTIONS(1057),
    [anon_sym_log2] = ACTIONS(1057),
    [anon_sym_log3] = ACTIONS(1057),
    [anon_sym_log4] = ACTIONS(1057),
    [anon_sym_chainid] = ACTIONS(1057),
    [anon_sym_origin] = ACTIONS(1057),
    [anon_sym_gasprice] = ACTIONS(1057),
    [anon_sym_blockhash] = ACTIONS(1057),
    [anon_sym_coinbase] = ACTIONS(1057),
    [anon_sym_timestamp] = ACTIONS(1057),
    [anon_sym_number] = ACTIONS(1057),
    [anon_sym_difficulty] = ACTIONS(1057),
    [anon_sym_gaslimit] = ACTIONS(1057),
    [anon_sym_hex] = ACTIONS(1057),
    [anon_sym_DQUOTE] = ACTIONS(1059),
    [anon_sym_SQUOTE] = ACTIONS(1059),
    [sym_comment] = ACTIONS(3),
  },
  [312] = {
    [sym_identifier] = ACTIONS(1097),
    [anon_sym_LBRACE] = ACTIONS(1099),
    [anon_sym_COMMA] = ACTIONS(1099),
    [anon_sym_RBRACE] = ACTIONS(1099),
    [anon_sym_LPAREN] = ACTIONS(1061),
    [anon_sym_RPAREN] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1097),
    [sym_yul_leave] = ACTIONS(1097),
    [anon_sym_break] = ACTIONS(1097),
    [anon_sym_continue] = ACTIONS(1097),
    [sym_yul_decimal_number] = ACTIONS(1097),
    [sym_yul_hex_number] = ACTIONS(1099),
    [anon_sym_true] = ACTIONS(1097),
    [anon_sym_false] = ACTIONS(1097),
    [anon_sym_let] = ACTIONS(1097),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_switch] = ACTIONS(1097),
    [anon_sym_default] = ACTIONS(1097),
    [anon_sym_case] = ACTIONS(1097),
    [anon_sym_function] = ACTIONS(1097),
    [anon_sym_stop] = ACTIONS(1097),
    [anon_sym_add] = ACTIONS(1097),
    [anon_sym_sub] = ACTIONS(1097),
    [anon_sym_mul] = ACTIONS(1097),
    [anon_sym_div] = ACTIONS(1097),
    [anon_sym_sdiv] = ACTIONS(1097),
    [anon_sym_mod] = ACTIONS(1097),
    [anon_sym_smod] = ACTIONS(1097),
    [anon_sym_exp] = ACTIONS(1097),
    [anon_sym_not] = ACTIONS(1097),
    [anon_sym_lt] = ACTIONS(1097),
    [anon_sym_gt] = ACTIONS(1097),
    [anon_sym_slt] = ACTIONS(1097),
    [anon_sym_sgt] = ACTIONS(1097),
    [anon_sym_eq] = ACTIONS(1097),
    [anon_sym_iszero] = ACTIONS(1097),
    [anon_sym_and] = ACTIONS(1097),
    [anon_sym_or] = ACTIONS(1097),
    [anon_sym_xor] = ACTIONS(1097),
    [anon_sym_byte] = ACTIONS(1097),
    [anon_sym_shl] = ACTIONS(1097),
    [anon_sym_shr] = ACTIONS(1097),
    [anon_sym_sar] = ACTIONS(1097),
    [anon_sym_addmod] = ACTIONS(1097),
    [anon_sym_mulmod] = ACTIONS(1097),
    [anon_sym_signextend] = ACTIONS(1097),
    [anon_sym_keccak256] = ACTIONS(1097),
    [anon_sym_pop] = ACTIONS(1097),
    [anon_sym_mload] = ACTIONS(1097),
    [anon_sym_mstore] = ACTIONS(1097),
    [anon_sym_mstore8] = ACTIONS(1097),
    [anon_sym_sload] = ACTIONS(1097),
    [anon_sym_sstore] = ACTIONS(1097),
    [anon_sym_msize] = ACTIONS(1097),
    [anon_sym_gas] = ACTIONS(1097),
    [anon_sym_address] = ACTIONS(1097),
    [anon_sym_balance] = ACTIONS(1097),
    [anon_sym_selfbalance] = ACTIONS(1097),
    [anon_sym_caller] = ACTIONS(1097),
    [anon_sym_callvalue] = ACTIONS(1097),
    [anon_sym_calldataload] = ACTIONS(1097),
    [anon_sym_calldatasize] = ACTIONS(1097),
    [anon_sym_calldatacopy] = ACTIONS(1097),
    [anon_sym_extcodesize] = ACTIONS(1097),
    [anon_sym_extcodecopy] = ACTIONS(1097),
    [anon_sym_returndatasize] = ACTIONS(1097),
    [anon_sym_returndatacopy] = ACTIONS(1097),
    [anon_sym_extcodehash] = ACTIONS(1097),
    [anon_sym_create] = ACTIONS(1097),
    [anon_sym_create2] = ACTIONS(1097),
    [anon_sym_call] = ACTIONS(1097),
    [anon_sym_callcode] = ACTIONS(1097),
    [anon_sym_delegatecall] = ACTIONS(1097),
    [anon_sym_staticcall] = ACTIONS(1097),
    [anon_sym_return] = ACTIONS(1097),
    [anon_sym_revert] = ACTIONS(1097),
    [anon_sym_selfdestruct] = ACTIONS(1097),
    [anon_sym_invalid] = ACTIONS(1097),
    [anon_sym_log0] = ACTIONS(1097),
    [anon_sym_log1] = ACTIONS(1097),
    [anon_sym_log2] = ACTIONS(1097),
    [anon_sym_log3] = ACTIONS(1097),
    [anon_sym_log4] = ACTIONS(1097),
    [anon_sym_chainid] = ACTIONS(1097),
    [anon_sym_origin] = ACTIONS(1097),
    [anon_sym_gasprice] = ACTIONS(1097),
    [anon_sym_blockhash] = ACTIONS(1097),
    [anon_sym_coinbase] = ACTIONS(1097),
    [anon_sym_timestamp] = ACTIONS(1097),
    [anon_sym_number] = ACTIONS(1097),
    [anon_sym_difficulty] = ACTIONS(1097),
    [anon_sym_gaslimit] = ACTIONS(1097),
    [anon_sym_hex] = ACTIONS(1097),
    [anon_sym_DQUOTE] = ACTIONS(1099),
    [anon_sym_SQUOTE] = ACTIONS(1099),
    [sym_comment] = ACTIONS(3),
  },
  [313] = {
    [sym_yul_identifier] = STATE(311),
    [sym_yul_path] = STATE(327),
    [sym__yul_assignment_operator] = STATE(382),
    [sym_identifier] = ACTIONS(1101),
    [anon_sym_LBRACE] = ACTIONS(1103),
    [anon_sym_RBRACE] = ACTIONS(1103),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_COLON] = ACTIONS(1093),
    [sym_yul_leave] = ACTIONS(1101),
    [anon_sym_break] = ACTIONS(1101),
    [anon_sym_continue] = ACTIONS(1101),
    [sym_yul_decimal_number] = ACTIONS(1101),
    [sym_yul_hex_number] = ACTIONS(1103),
    [anon_sym_true] = ACTIONS(1101),
    [anon_sym_false] = ACTIONS(1101),
    [anon_sym_let] = ACTIONS(1101),
    [anon_sym_COLON_EQ] = ACTIONS(1105),
    [anon_sym_if] = ACTIONS(1101),
    [anon_sym_switch] = ACTIONS(1101),
    [anon_sym_function] = ACTIONS(1101),
    [anon_sym_stop] = ACTIONS(1101),
    [anon_sym_add] = ACTIONS(1101),
    [anon_sym_sub] = ACTIONS(1101),
    [anon_sym_mul] = ACTIONS(1101),
    [anon_sym_div] = ACTIONS(1101),
    [anon_sym_sdiv] = ACTIONS(1101),
    [anon_sym_mod] = ACTIONS(1101),
    [anon_sym_smod] = ACTIONS(1101),
    [anon_sym_exp] = ACTIONS(1101),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_lt] = ACTIONS(1101),
    [anon_sym_gt] = ACTIONS(1101),
    [anon_sym_slt] = ACTIONS(1101),
    [anon_sym_sgt] = ACTIONS(1101),
    [anon_sym_eq] = ACTIONS(1101),
    [anon_sym_iszero] = ACTIONS(1101),
    [anon_sym_and] = ACTIONS(1101),
    [anon_sym_or] = ACTIONS(1101),
    [anon_sym_xor] = ACTIONS(1101),
    [anon_sym_byte] = ACTIONS(1101),
    [anon_sym_shl] = ACTIONS(1101),
    [anon_sym_shr] = ACTIONS(1101),
    [anon_sym_sar] = ACTIONS(1101),
    [anon_sym_addmod] = ACTIONS(1101),
    [anon_sym_mulmod] = ACTIONS(1101),
    [anon_sym_signextend] = ACTIONS(1101),
    [anon_sym_keccak256] = ACTIONS(1101),
    [anon_sym_pop] = ACTIONS(1101),
    [anon_sym_mload] = ACTIONS(1101),
    [anon_sym_mstore] = ACTIONS(1101),
    [anon_sym_mstore8] = ACTIONS(1101),
    [anon_sym_sload] = ACTIONS(1101),
    [anon_sym_sstore] = ACTIONS(1101),
    [anon_sym_msize] = ACTIONS(1101),
    [anon_sym_gas] = ACTIONS(1101),
    [anon_sym_address] = ACTIONS(1101),
    [anon_sym_balance] = ACTIONS(1101),
    [anon_sym_selfbalance] = ACTIONS(1101),
    [anon_sym_caller] = ACTIONS(1101),
    [anon_sym_callvalue] = ACTIONS(1101),
    [anon_sym_calldataload] = ACTIONS(1101),
    [anon_sym_calldatasize] = ACTIONS(1101),
    [anon_sym_calldatacopy] = ACTIONS(1101),
    [anon_sym_extcodesize] = ACTIONS(1101),
    [anon_sym_extcodecopy] = ACTIONS(1101),
    [anon_sym_returndatasize] = ACTIONS(1101),
    [anon_sym_returndatacopy] = ACTIONS(1101),
    [anon_sym_extcodehash] = ACTIONS(1101),
    [anon_sym_create] = ACTIONS(1101),
    [anon_sym_create2] = ACTIONS(1101),
    [anon_sym_call] = ACTIONS(1101),
    [anon_sym_callcode] = ACTIONS(1101),
    [anon_sym_delegatecall] = ACTIONS(1101),
    [anon_sym_staticcall] = ACTIONS(1101),
    [anon_sym_return] = ACTIONS(1101),
    [anon_sym_revert] = ACTIONS(1101),
    [anon_sym_selfdestruct] = ACTIONS(1101),
    [anon_sym_invalid] = ACTIONS(1101),
    [anon_sym_log0] = ACTIONS(1101),
    [anon_sym_log1] = ACTIONS(1101),
    [anon_sym_log2] = ACTIONS(1101),
    [anon_sym_log3] = ACTIONS(1101),
    [anon_sym_log4] = ACTIONS(1101),
    [anon_sym_chainid] = ACTIONS(1101),
    [anon_sym_origin] = ACTIONS(1101),
    [anon_sym_gasprice] = ACTIONS(1101),
    [anon_sym_blockhash] = ACTIONS(1101),
    [anon_sym_coinbase] = ACTIONS(1101),
    [anon_sym_timestamp] = ACTIONS(1101),
    [anon_sym_number] = ACTIONS(1101),
    [anon_sym_difficulty] = ACTIONS(1101),
    [anon_sym_gaslimit] = ACTIONS(1101),
    [anon_sym_hex] = ACTIONS(1101),
    [anon_sym_DQUOTE] = ACTIONS(1103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [sym_comment] = ACTIONS(3),
  },
  [314] = {
    [sym__yul_assignment_operator] = STATE(383),
    [aux_sym_yul_assignment_repeat1] = STATE(321),
    [sym_identifier] = ACTIONS(1107),
    [anon_sym_LBRACE] = ACTIONS(1109),
    [anon_sym_COMMA] = ACTIONS(1111),
    [anon_sym_RBRACE] = ACTIONS(1109),
    [anon_sym_for] = ACTIONS(1107),
    [anon_sym_COLON] = ACTIONS(1093),
    [sym_yul_leave] = ACTIONS(1107),
    [anon_sym_break] = ACTIONS(1107),
    [anon_sym_continue] = ACTIONS(1107),
    [sym_yul_decimal_number] = ACTIONS(1107),
    [sym_yul_hex_number] = ACTIONS(1109),
    [anon_sym_true] = ACTIONS(1107),
    [anon_sym_false] = ACTIONS(1107),
    [anon_sym_let] = ACTIONS(1107),
    [anon_sym_COLON_EQ] = ACTIONS(1113),
    [anon_sym_if] = ACTIONS(1107),
    [anon_sym_switch] = ACTIONS(1107),
    [anon_sym_function] = ACTIONS(1107),
    [anon_sym_stop] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1107),
    [anon_sym_sub] = ACTIONS(1107),
    [anon_sym_mul] = ACTIONS(1107),
    [anon_sym_div] = ACTIONS(1107),
    [anon_sym_sdiv] = ACTIONS(1107),
    [anon_sym_mod] = ACTIONS(1107),
    [anon_sym_smod] = ACTIONS(1107),
    [anon_sym_exp] = ACTIONS(1107),
    [anon_sym_not] = ACTIONS(1107),
    [anon_sym_lt] = ACTIONS(1107),
    [anon_sym_gt] = ACTIONS(1107),
    [anon_sym_slt] = ACTIONS(1107),
    [anon_sym_sgt] = ACTIONS(1107),
    [anon_sym_eq] = ACTIONS(1107),
    [anon_sym_iszero] = ACTIONS(1107),
    [anon_sym_and] = ACTIONS(1107),
    [anon_sym_or] = ACTIONS(1107),
    [anon_sym_xor] = ACTIONS(1107),
    [anon_sym_byte] = ACTIONS(1107),
    [anon_sym_shl] = ACTIONS(1107),
    [anon_sym_shr] = ACTIONS(1107),
    [anon_sym_sar] = ACTIONS(1107),
    [anon_sym_addmod] = ACTIONS(1107),
    [anon_sym_mulmod] = ACTIONS(1107),
    [anon_sym_signextend] = ACTIONS(1107),
    [anon_sym_keccak256] = ACTIONS(1107),
    [anon_sym_pop] = ACTIONS(1107),
    [anon_sym_mload] = ACTIONS(1107),
    [anon_sym_mstore] = ACTIONS(1107),
    [anon_sym_mstore8] = ACTIONS(1107),
    [anon_sym_sload] = ACTIONS(1107),
    [anon_sym_sstore] = ACTIONS(1107),
    [anon_sym_msize] = ACTIONS(1107),
    [anon_sym_gas] = ACTIONS(1107),
    [anon_sym_address] = ACTIONS(1107),
    [anon_sym_balance] = ACTIONS(1107),
    [anon_sym_selfbalance] = ACTIONS(1107),
    [anon_sym_caller] = ACTIONS(1107),
    [anon_sym_callvalue] = ACTIONS(1107),
    [anon_sym_calldataload] = ACTIONS(1107),
    [anon_sym_calldatasize] = ACTIONS(1107),
    [anon_sym_calldatacopy] = ACTIONS(1107),
    [anon_sym_extcodesize] = ACTIONS(1107),
    [anon_sym_extcodecopy] = ACTIONS(1107),
    [anon_sym_returndatasize] = ACTIONS(1107),
    [anon_sym_returndatacopy] = ACTIONS(1107),
    [anon_sym_extcodehash] = ACTIONS(1107),
    [anon_sym_create] = ACTIONS(1107),
    [anon_sym_create2] = ACTIONS(1107),
    [anon_sym_call] = ACTIONS(1107),
    [anon_sym_callcode] = ACTIONS(1107),
    [anon_sym_delegatecall] = ACTIONS(1107),
    [anon_sym_staticcall] = ACTIONS(1107),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_revert] = ACTIONS(1107),
    [anon_sym_selfdestruct] = ACTIONS(1107),
    [anon_sym_invalid] = ACTIONS(1107),
    [anon_sym_log0] = ACTIONS(1107),
    [anon_sym_log1] = ACTIONS(1107),
    [anon_sym_log2] = ACTIONS(1107),
    [anon_sym_log3] = ACTIONS(1107),
    [anon_sym_log4] = ACTIONS(1107),
    [anon_sym_chainid] = ACTIONS(1107),
    [anon_sym_origin] = ACTIONS(1107),
    [anon_sym_gasprice] = ACTIONS(1107),
    [anon_sym_blockhash] = ACTIONS(1107),
    [anon_sym_coinbase] = ACTIONS(1107),
    [anon_sym_timestamp] = ACTIONS(1107),
    [anon_sym_number] = ACTIONS(1107),
    [anon_sym_difficulty] = ACTIONS(1107),
    [anon_sym_gaslimit] = ACTIONS(1107),
    [anon_sym_hex] = ACTIONS(1107),
    [anon_sym_DQUOTE] = ACTIONS(1109),
    [anon_sym_SQUOTE] = ACTIONS(1109),
    [sym_comment] = ACTIONS(3),
  },
  [315] = {
    [sym_yul_identifier] = STATE(311),
    [sym_yul_path] = STATE(327),
    [sym__yul_assignment_operator] = STATE(383),
    [sym_identifier] = ACTIONS(1107),
    [anon_sym_LBRACE] = ACTIONS(1109),
    [anon_sym_RBRACE] = ACTIONS(1109),
    [anon_sym_for] = ACTIONS(1107),
    [anon_sym_COLON] = ACTIONS(1093),
    [sym_yul_leave] = ACTIONS(1107),
    [anon_sym_break] = ACTIONS(1107),
    [anon_sym_continue] = ACTIONS(1107),
    [sym_yul_decimal_number] = ACTIONS(1107),
    [sym_yul_hex_number] = ACTIONS(1109),
    [anon_sym_true] = ACTIONS(1107),
    [anon_sym_false] = ACTIONS(1107),
    [anon_sym_let] = ACTIONS(1107),
    [anon_sym_COLON_EQ] = ACTIONS(1113),
    [anon_sym_if] = ACTIONS(1107),
    [anon_sym_switch] = ACTIONS(1107),
    [anon_sym_function] = ACTIONS(1107),
    [anon_sym_stop] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1107),
    [anon_sym_sub] = ACTIONS(1107),
    [anon_sym_mul] = ACTIONS(1107),
    [anon_sym_div] = ACTIONS(1107),
    [anon_sym_sdiv] = ACTIONS(1107),
    [anon_sym_mod] = ACTIONS(1107),
    [anon_sym_smod] = ACTIONS(1107),
    [anon_sym_exp] = ACTIONS(1107),
    [anon_sym_not] = ACTIONS(1107),
    [anon_sym_lt] = ACTIONS(1107),
    [anon_sym_gt] = ACTIONS(1107),
    [anon_sym_slt] = ACTIONS(1107),
    [anon_sym_sgt] = ACTIONS(1107),
    [anon_sym_eq] = ACTIONS(1107),
    [anon_sym_iszero] = ACTIONS(1107),
    [anon_sym_and] = ACTIONS(1107),
    [anon_sym_or] = ACTIONS(1107),
    [anon_sym_xor] = ACTIONS(1107),
    [anon_sym_byte] = ACTIONS(1107),
    [anon_sym_shl] = ACTIONS(1107),
    [anon_sym_shr] = ACTIONS(1107),
    [anon_sym_sar] = ACTIONS(1107),
    [anon_sym_addmod] = ACTIONS(1107),
    [anon_sym_mulmod] = ACTIONS(1107),
    [anon_sym_signextend] = ACTIONS(1107),
    [anon_sym_keccak256] = ACTIONS(1107),
    [anon_sym_pop] = ACTIONS(1107),
    [anon_sym_mload] = ACTIONS(1107),
    [anon_sym_mstore] = ACTIONS(1107),
    [anon_sym_mstore8] = ACTIONS(1107),
    [anon_sym_sload] = ACTIONS(1107),
    [anon_sym_sstore] = ACTIONS(1107),
    [anon_sym_msize] = ACTIONS(1107),
    [anon_sym_gas] = ACTIONS(1107),
    [anon_sym_address] = ACTIONS(1107),
    [anon_sym_balance] = ACTIONS(1107),
    [anon_sym_selfbalance] = ACTIONS(1107),
    [anon_sym_caller] = ACTIONS(1107),
    [anon_sym_callvalue] = ACTIONS(1107),
    [anon_sym_calldataload] = ACTIONS(1107),
    [anon_sym_calldatasize] = ACTIONS(1107),
    [anon_sym_calldatacopy] = ACTIONS(1107),
    [anon_sym_extcodesize] = ACTIONS(1107),
    [anon_sym_extcodecopy] = ACTIONS(1107),
    [anon_sym_returndatasize] = ACTIONS(1107),
    [anon_sym_returndatacopy] = ACTIONS(1107),
    [anon_sym_extcodehash] = ACTIONS(1107),
    [anon_sym_create] = ACTIONS(1107),
    [anon_sym_create2] = ACTIONS(1107),
    [anon_sym_call] = ACTIONS(1107),
    [anon_sym_callcode] = ACTIONS(1107),
    [anon_sym_delegatecall] = ACTIONS(1107),
    [anon_sym_staticcall] = ACTIONS(1107),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_revert] = ACTIONS(1107),
    [anon_sym_selfdestruct] = ACTIONS(1107),
    [anon_sym_invalid] = ACTIONS(1107),
    [anon_sym_log0] = ACTIONS(1107),
    [anon_sym_log1] = ACTIONS(1107),
    [anon_sym_log2] = ACTIONS(1107),
    [anon_sym_log3] = ACTIONS(1107),
    [anon_sym_log4] = ACTIONS(1107),
    [anon_sym_chainid] = ACTIONS(1107),
    [anon_sym_origin] = ACTIONS(1107),
    [anon_sym_gasprice] = ACTIONS(1107),
    [anon_sym_blockhash] = ACTIONS(1107),
    [anon_sym_coinbase] = ACTIONS(1107),
    [anon_sym_timestamp] = ACTIONS(1107),
    [anon_sym_number] = ACTIONS(1107),
    [anon_sym_difficulty] = ACTIONS(1107),
    [anon_sym_gaslimit] = ACTIONS(1107),
    [anon_sym_hex] = ACTIONS(1107),
    [anon_sym_DQUOTE] = ACTIONS(1109),
    [anon_sym_SQUOTE] = ACTIONS(1109),
    [sym_comment] = ACTIONS(3),
  },
  [316] = {
    [aux_sym_yul_variable_declaration_repeat1] = STATE(316),
    [sym_identifier] = ACTIONS(1115),
    [anon_sym_LBRACE] = ACTIONS(1117),
    [anon_sym_COMMA] = ACTIONS(1119),
    [anon_sym_RBRACE] = ACTIONS(1117),
    [anon_sym_RPAREN] = ACTIONS(1117),
    [anon_sym_for] = ACTIONS(1115),
    [sym_yul_leave] = ACTIONS(1115),
    [anon_sym_break] = ACTIONS(1115),
    [anon_sym_continue] = ACTIONS(1115),
    [sym_yul_decimal_number] = ACTIONS(1115),
    [sym_yul_hex_number] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(1115),
    [anon_sym_false] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1115),
    [anon_sym_COLON_EQ] = ACTIONS(1117),
    [anon_sym_if] = ACTIONS(1115),
    [anon_sym_switch] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(1115),
    [anon_sym_stop] = ACTIONS(1115),
    [anon_sym_add] = ACTIONS(1115),
    [anon_sym_sub] = ACTIONS(1115),
    [anon_sym_mul] = ACTIONS(1115),
    [anon_sym_div] = ACTIONS(1115),
    [anon_sym_sdiv] = ACTIONS(1115),
    [anon_sym_mod] = ACTIONS(1115),
    [anon_sym_smod] = ACTIONS(1115),
    [anon_sym_exp] = ACTIONS(1115),
    [anon_sym_not] = ACTIONS(1115),
    [anon_sym_lt] = ACTIONS(1115),
    [anon_sym_gt] = ACTIONS(1115),
    [anon_sym_slt] = ACTIONS(1115),
    [anon_sym_sgt] = ACTIONS(1115),
    [anon_sym_eq] = ACTIONS(1115),
    [anon_sym_iszero] = ACTIONS(1115),
    [anon_sym_and] = ACTIONS(1115),
    [anon_sym_or] = ACTIONS(1115),
    [anon_sym_xor] = ACTIONS(1115),
    [anon_sym_byte] = ACTIONS(1115),
    [anon_sym_shl] = ACTIONS(1115),
    [anon_sym_shr] = ACTIONS(1115),
    [anon_sym_sar] = ACTIONS(1115),
    [anon_sym_addmod] = ACTIONS(1115),
    [anon_sym_mulmod] = ACTIONS(1115),
    [anon_sym_signextend] = ACTIONS(1115),
    [anon_sym_keccak256] = ACTIONS(1115),
    [anon_sym_pop] = ACTIONS(1115),
    [anon_sym_mload] = ACTIONS(1115),
    [anon_sym_mstore] = ACTIONS(1115),
    [anon_sym_mstore8] = ACTIONS(1115),
    [anon_sym_sload] = ACTIONS(1115),
    [anon_sym_sstore] = ACTIONS(1115),
    [anon_sym_msize] = ACTIONS(1115),
    [anon_sym_gas] = ACTIONS(1115),
    [anon_sym_address] = ACTIONS(1115),
    [anon_sym_balance] = ACTIONS(1115),
    [anon_sym_selfbalance] = ACTIONS(1115),
    [anon_sym_caller] = ACTIONS(1115),
    [anon_sym_callvalue] = ACTIONS(1115),
    [anon_sym_calldataload] = ACTIONS(1115),
    [anon_sym_calldatasize] = ACTIONS(1115),
    [anon_sym_calldatacopy] = ACTIONS(1115),
    [anon_sym_extcodesize] = ACTIONS(1115),
    [anon_sym_extcodecopy] = ACTIONS(1115),
    [anon_sym_returndatasize] = ACTIONS(1115),
    [anon_sym_returndatacopy] = ACTIONS(1115),
    [anon_sym_extcodehash] = ACTIONS(1115),
    [anon_sym_create] = ACTIONS(1115),
    [anon_sym_create2] = ACTIONS(1115),
    [anon_sym_call] = ACTIONS(1115),
    [anon_sym_callcode] = ACTIONS(1115),
    [anon_sym_delegatecall] = ACTIONS(1115),
    [anon_sym_staticcall] = ACTIONS(1115),
    [anon_sym_return] = ACTIONS(1115),
    [anon_sym_revert] = ACTIONS(1115),
    [anon_sym_selfdestruct] = ACTIONS(1115),
    [anon_sym_invalid] = ACTIONS(1115),
    [anon_sym_log0] = ACTIONS(1115),
    [anon_sym_log1] = ACTIONS(1115),
    [anon_sym_log2] = ACTIONS(1115),
    [anon_sym_log3] = ACTIONS(1115),
    [anon_sym_log4] = ACTIONS(1115),
    [anon_sym_chainid] = ACTIONS(1115),
    [anon_sym_origin] = ACTIONS(1115),
    [anon_sym_gasprice] = ACTIONS(1115),
    [anon_sym_blockhash] = ACTIONS(1115),
    [anon_sym_coinbase] = ACTIONS(1115),
    [anon_sym_timestamp] = ACTIONS(1115),
    [anon_sym_number] = ACTIONS(1115),
    [anon_sym_difficulty] = ACTIONS(1115),
    [anon_sym_gaslimit] = ACTIONS(1115),
    [anon_sym_hex] = ACTIONS(1115),
    [anon_sym_DQUOTE] = ACTIONS(1117),
    [anon_sym_SQUOTE] = ACTIONS(1117),
    [sym_comment] = ACTIONS(3),
  },
  [317] = {
    [sym_identifier] = ACTIONS(1122),
    [anon_sym_LBRACE] = ACTIONS(1124),
    [anon_sym_COMMA] = ACTIONS(1124),
    [anon_sym_RBRACE] = ACTIONS(1124),
    [anon_sym_RPAREN] = ACTIONS(1124),
    [anon_sym_for] = ACTIONS(1122),
    [sym_yul_leave] = ACTIONS(1122),
    [anon_sym_break] = ACTIONS(1122),
    [anon_sym_continue] = ACTIONS(1122),
    [sym_yul_decimal_number] = ACTIONS(1122),
    [sym_yul_hex_number] = ACTIONS(1124),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [anon_sym_let] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1122),
    [anon_sym_switch] = ACTIONS(1122),
    [anon_sym_default] = ACTIONS(1122),
    [anon_sym_case] = ACTIONS(1122),
    [anon_sym_function] = ACTIONS(1122),
    [anon_sym_stop] = ACTIONS(1122),
    [anon_sym_add] = ACTIONS(1122),
    [anon_sym_sub] = ACTIONS(1122),
    [anon_sym_mul] = ACTIONS(1122),
    [anon_sym_div] = ACTIONS(1122),
    [anon_sym_sdiv] = ACTIONS(1122),
    [anon_sym_mod] = ACTIONS(1122),
    [anon_sym_smod] = ACTIONS(1122),
    [anon_sym_exp] = ACTIONS(1122),
    [anon_sym_not] = ACTIONS(1122),
    [anon_sym_lt] = ACTIONS(1122),
    [anon_sym_gt] = ACTIONS(1122),
    [anon_sym_slt] = ACTIONS(1122),
    [anon_sym_sgt] = ACTIONS(1122),
    [anon_sym_eq] = ACTIONS(1122),
    [anon_sym_iszero] = ACTIONS(1122),
    [anon_sym_and] = ACTIONS(1122),
    [anon_sym_or] = ACTIONS(1122),
    [anon_sym_xor] = ACTIONS(1122),
    [anon_sym_byte] = ACTIONS(1122),
    [anon_sym_shl] = ACTIONS(1122),
    [anon_sym_shr] = ACTIONS(1122),
    [anon_sym_sar] = ACTIONS(1122),
    [anon_sym_addmod] = ACTIONS(1122),
    [anon_sym_mulmod] = ACTIONS(1122),
    [anon_sym_signextend] = ACTIONS(1122),
    [anon_sym_keccak256] = ACTIONS(1122),
    [anon_sym_pop] = ACTIONS(1122),
    [anon_sym_mload] = ACTIONS(1122),
    [anon_sym_mstore] = ACTIONS(1122),
    [anon_sym_mstore8] = ACTIONS(1122),
    [anon_sym_sload] = ACTIONS(1122),
    [anon_sym_sstore] = ACTIONS(1122),
    [anon_sym_msize] = ACTIONS(1122),
    [anon_sym_gas] = ACTIONS(1122),
    [anon_sym_address] = ACTIONS(1122),
    [anon_sym_balance] = ACTIONS(1122),
    [anon_sym_selfbalance] = ACTIONS(1122),
    [anon_sym_caller] = ACTIONS(1122),
    [anon_sym_callvalue] = ACTIONS(1122),
    [anon_sym_calldataload] = ACTIONS(1122),
    [anon_sym_calldatasize] = ACTIONS(1122),
    [anon_sym_calldatacopy] = ACTIONS(1122),
    [anon_sym_extcodesize] = ACTIONS(1122),
    [anon_sym_extcodecopy] = ACTIONS(1122),
    [anon_sym_returndatasize] = ACTIONS(1122),
    [anon_sym_returndatacopy] = ACTIONS(1122),
    [anon_sym_extcodehash] = ACTIONS(1122),
    [anon_sym_create] = ACTIONS(1122),
    [anon_sym_create2] = ACTIONS(1122),
    [anon_sym_call] = ACTIONS(1122),
    [anon_sym_callcode] = ACTIONS(1122),
    [anon_sym_delegatecall] = ACTIONS(1122),
    [anon_sym_staticcall] = ACTIONS(1122),
    [anon_sym_return] = ACTIONS(1122),
    [anon_sym_revert] = ACTIONS(1122),
    [anon_sym_selfdestruct] = ACTIONS(1122),
    [anon_sym_invalid] = ACTIONS(1122),
    [anon_sym_log0] = ACTIONS(1122),
    [anon_sym_log1] = ACTIONS(1122),
    [anon_sym_log2] = ACTIONS(1122),
    [anon_sym_log3] = ACTIONS(1122),
    [anon_sym_log4] = ACTIONS(1122),
    [anon_sym_chainid] = ACTIONS(1122),
    [anon_sym_origin] = ACTIONS(1122),
    [anon_sym_gasprice] = ACTIONS(1122),
    [anon_sym_blockhash] = ACTIONS(1122),
    [anon_sym_coinbase] = ACTIONS(1122),
    [anon_sym_timestamp] = ACTIONS(1122),
    [anon_sym_number] = ACTIONS(1122),
    [anon_sym_difficulty] = ACTIONS(1122),
    [anon_sym_gaslimit] = ACTIONS(1122),
    [anon_sym_hex] = ACTIONS(1122),
    [anon_sym_DQUOTE] = ACTIONS(1124),
    [anon_sym_SQUOTE] = ACTIONS(1124),
    [sym_comment] = ACTIONS(3),
  },
  [318] = {
    [sym_identifier] = ACTIONS(1126),
    [anon_sym_LBRACE] = ACTIONS(1128),
    [anon_sym_COMMA] = ACTIONS(1128),
    [anon_sym_RBRACE] = ACTIONS(1128),
    [anon_sym_RPAREN] = ACTIONS(1128),
    [anon_sym_for] = ACTIONS(1126),
    [sym_yul_leave] = ACTIONS(1126),
    [anon_sym_break] = ACTIONS(1126),
    [anon_sym_continue] = ACTIONS(1126),
    [sym_yul_decimal_number] = ACTIONS(1126),
    [sym_yul_hex_number] = ACTIONS(1128),
    [anon_sym_true] = ACTIONS(1126),
    [anon_sym_false] = ACTIONS(1126),
    [anon_sym_let] = ACTIONS(1126),
    [anon_sym_if] = ACTIONS(1126),
    [anon_sym_switch] = ACTIONS(1126),
    [anon_sym_default] = ACTIONS(1126),
    [anon_sym_case] = ACTIONS(1126),
    [anon_sym_function] = ACTIONS(1126),
    [anon_sym_stop] = ACTIONS(1126),
    [anon_sym_add] = ACTIONS(1126),
    [anon_sym_sub] = ACTIONS(1126),
    [anon_sym_mul] = ACTIONS(1126),
    [anon_sym_div] = ACTIONS(1126),
    [anon_sym_sdiv] = ACTIONS(1126),
    [anon_sym_mod] = ACTIONS(1126),
    [anon_sym_smod] = ACTIONS(1126),
    [anon_sym_exp] = ACTIONS(1126),
    [anon_sym_not] = ACTIONS(1126),
    [anon_sym_lt] = ACTIONS(1126),
    [anon_sym_gt] = ACTIONS(1126),
    [anon_sym_slt] = ACTIONS(1126),
    [anon_sym_sgt] = ACTIONS(1126),
    [anon_sym_eq] = ACTIONS(1126),
    [anon_sym_iszero] = ACTIONS(1126),
    [anon_sym_and] = ACTIONS(1126),
    [anon_sym_or] = ACTIONS(1126),
    [anon_sym_xor] = ACTIONS(1126),
    [anon_sym_byte] = ACTIONS(1126),
    [anon_sym_shl] = ACTIONS(1126),
    [anon_sym_shr] = ACTIONS(1126),
    [anon_sym_sar] = ACTIONS(1126),
    [anon_sym_addmod] = ACTIONS(1126),
    [anon_sym_mulmod] = ACTIONS(1126),
    [anon_sym_signextend] = ACTIONS(1126),
    [anon_sym_keccak256] = ACTIONS(1126),
    [anon_sym_pop] = ACTIONS(1126),
    [anon_sym_mload] = ACTIONS(1126),
    [anon_sym_mstore] = ACTIONS(1126),
    [anon_sym_mstore8] = ACTIONS(1126),
    [anon_sym_sload] = ACTIONS(1126),
    [anon_sym_sstore] = ACTIONS(1126),
    [anon_sym_msize] = ACTIONS(1126),
    [anon_sym_gas] = ACTIONS(1126),
    [anon_sym_address] = ACTIONS(1126),
    [anon_sym_balance] = ACTIONS(1126),
    [anon_sym_selfbalance] = ACTIONS(1126),
    [anon_sym_caller] = ACTIONS(1126),
    [anon_sym_callvalue] = ACTIONS(1126),
    [anon_sym_calldataload] = ACTIONS(1126),
    [anon_sym_calldatasize] = ACTIONS(1126),
    [anon_sym_calldatacopy] = ACTIONS(1126),
    [anon_sym_extcodesize] = ACTIONS(1126),
    [anon_sym_extcodecopy] = ACTIONS(1126),
    [anon_sym_returndatasize] = ACTIONS(1126),
    [anon_sym_returndatacopy] = ACTIONS(1126),
    [anon_sym_extcodehash] = ACTIONS(1126),
    [anon_sym_create] = ACTIONS(1126),
    [anon_sym_create2] = ACTIONS(1126),
    [anon_sym_call] = ACTIONS(1126),
    [anon_sym_callcode] = ACTIONS(1126),
    [anon_sym_delegatecall] = ACTIONS(1126),
    [anon_sym_staticcall] = ACTIONS(1126),
    [anon_sym_return] = ACTIONS(1126),
    [anon_sym_revert] = ACTIONS(1126),
    [anon_sym_selfdestruct] = ACTIONS(1126),
    [anon_sym_invalid] = ACTIONS(1126),
    [anon_sym_log0] = ACTIONS(1126),
    [anon_sym_log1] = ACTIONS(1126),
    [anon_sym_log2] = ACTIONS(1126),
    [anon_sym_log3] = ACTIONS(1126),
    [anon_sym_log4] = ACTIONS(1126),
    [anon_sym_chainid] = ACTIONS(1126),
    [anon_sym_origin] = ACTIONS(1126),
    [anon_sym_gasprice] = ACTIONS(1126),
    [anon_sym_blockhash] = ACTIONS(1126),
    [anon_sym_coinbase] = ACTIONS(1126),
    [anon_sym_timestamp] = ACTIONS(1126),
    [anon_sym_number] = ACTIONS(1126),
    [anon_sym_difficulty] = ACTIONS(1126),
    [anon_sym_gaslimit] = ACTIONS(1126),
    [anon_sym_hex] = ACTIONS(1126),
    [anon_sym_DQUOTE] = ACTIONS(1128),
    [anon_sym_SQUOTE] = ACTIONS(1128),
    [sym_comment] = ACTIONS(3),
  },
  [319] = {
    [sym_identifier] = ACTIONS(1130),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym_COMMA] = ACTIONS(1132),
    [anon_sym_RBRACE] = ACTIONS(1132),
    [anon_sym_RPAREN] = ACTIONS(1132),
    [anon_sym_for] = ACTIONS(1130),
    [sym_yul_leave] = ACTIONS(1130),
    [anon_sym_break] = ACTIONS(1130),
    [anon_sym_continue] = ACTIONS(1130),
    [sym_yul_decimal_number] = ACTIONS(1130),
    [sym_yul_hex_number] = ACTIONS(1132),
    [anon_sym_true] = ACTIONS(1130),
    [anon_sym_false] = ACTIONS(1130),
    [anon_sym_let] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(1130),
    [anon_sym_switch] = ACTIONS(1130),
    [anon_sym_default] = ACTIONS(1130),
    [anon_sym_case] = ACTIONS(1130),
    [anon_sym_function] = ACTIONS(1130),
    [anon_sym_stop] = ACTIONS(1130),
    [anon_sym_add] = ACTIONS(1130),
    [anon_sym_sub] = ACTIONS(1130),
    [anon_sym_mul] = ACTIONS(1130),
    [anon_sym_div] = ACTIONS(1130),
    [anon_sym_sdiv] = ACTIONS(1130),
    [anon_sym_mod] = ACTIONS(1130),
    [anon_sym_smod] = ACTIONS(1130),
    [anon_sym_exp] = ACTIONS(1130),
    [anon_sym_not] = ACTIONS(1130),
    [anon_sym_lt] = ACTIONS(1130),
    [anon_sym_gt] = ACTIONS(1130),
    [anon_sym_slt] = ACTIONS(1130),
    [anon_sym_sgt] = ACTIONS(1130),
    [anon_sym_eq] = ACTIONS(1130),
    [anon_sym_iszero] = ACTIONS(1130),
    [anon_sym_and] = ACTIONS(1130),
    [anon_sym_or] = ACTIONS(1130),
    [anon_sym_xor] = ACTIONS(1130),
    [anon_sym_byte] = ACTIONS(1130),
    [anon_sym_shl] = ACTIONS(1130),
    [anon_sym_shr] = ACTIONS(1130),
    [anon_sym_sar] = ACTIONS(1130),
    [anon_sym_addmod] = ACTIONS(1130),
    [anon_sym_mulmod] = ACTIONS(1130),
    [anon_sym_signextend] = ACTIONS(1130),
    [anon_sym_keccak256] = ACTIONS(1130),
    [anon_sym_pop] = ACTIONS(1130),
    [anon_sym_mload] = ACTIONS(1130),
    [anon_sym_mstore] = ACTIONS(1130),
    [anon_sym_mstore8] = ACTIONS(1130),
    [anon_sym_sload] = ACTIONS(1130),
    [anon_sym_sstore] = ACTIONS(1130),
    [anon_sym_msize] = ACTIONS(1130),
    [anon_sym_gas] = ACTIONS(1130),
    [anon_sym_address] = ACTIONS(1130),
    [anon_sym_balance] = ACTIONS(1130),
    [anon_sym_selfbalance] = ACTIONS(1130),
    [anon_sym_caller] = ACTIONS(1130),
    [anon_sym_callvalue] = ACTIONS(1130),
    [anon_sym_calldataload] = ACTIONS(1130),
    [anon_sym_calldatasize] = ACTIONS(1130),
    [anon_sym_calldatacopy] = ACTIONS(1130),
    [anon_sym_extcodesize] = ACTIONS(1130),
    [anon_sym_extcodecopy] = ACTIONS(1130),
    [anon_sym_returndatasize] = ACTIONS(1130),
    [anon_sym_returndatacopy] = ACTIONS(1130),
    [anon_sym_extcodehash] = ACTIONS(1130),
    [anon_sym_create] = ACTIONS(1130),
    [anon_sym_create2] = ACTIONS(1130),
    [anon_sym_call] = ACTIONS(1130),
    [anon_sym_callcode] = ACTIONS(1130),
    [anon_sym_delegatecall] = ACTIONS(1130),
    [anon_sym_staticcall] = ACTIONS(1130),
    [anon_sym_return] = ACTIONS(1130),
    [anon_sym_revert] = ACTIONS(1130),
    [anon_sym_selfdestruct] = ACTIONS(1130),
    [anon_sym_invalid] = ACTIONS(1130),
    [anon_sym_log0] = ACTIONS(1130),
    [anon_sym_log1] = ACTIONS(1130),
    [anon_sym_log2] = ACTIONS(1130),
    [anon_sym_log3] = ACTIONS(1130),
    [anon_sym_log4] = ACTIONS(1130),
    [anon_sym_chainid] = ACTIONS(1130),
    [anon_sym_origin] = ACTIONS(1130),
    [anon_sym_gasprice] = ACTIONS(1130),
    [anon_sym_blockhash] = ACTIONS(1130),
    [anon_sym_coinbase] = ACTIONS(1130),
    [anon_sym_timestamp] = ACTIONS(1130),
    [anon_sym_number] = ACTIONS(1130),
    [anon_sym_difficulty] = ACTIONS(1130),
    [anon_sym_gaslimit] = ACTIONS(1130),
    [anon_sym_hex] = ACTIONS(1130),
    [anon_sym_DQUOTE] = ACTIONS(1132),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym_comment] = ACTIONS(3),
  },
  [320] = {
    [sym_identifier] = ACTIONS(1134),
    [anon_sym_LBRACE] = ACTIONS(1136),
    [anon_sym_COMMA] = ACTIONS(1136),
    [anon_sym_RBRACE] = ACTIONS(1136),
    [anon_sym_RPAREN] = ACTIONS(1136),
    [anon_sym_for] = ACTIONS(1134),
    [sym_yul_leave] = ACTIONS(1134),
    [anon_sym_break] = ACTIONS(1134),
    [anon_sym_continue] = ACTIONS(1134),
    [sym_yul_decimal_number] = ACTIONS(1134),
    [sym_yul_hex_number] = ACTIONS(1136),
    [anon_sym_true] = ACTIONS(1134),
    [anon_sym_false] = ACTIONS(1134),
    [anon_sym_let] = ACTIONS(1134),
    [anon_sym_if] = ACTIONS(1134),
    [anon_sym_switch] = ACTIONS(1134),
    [anon_sym_default] = ACTIONS(1134),
    [anon_sym_case] = ACTIONS(1134),
    [anon_sym_function] = ACTIONS(1134),
    [anon_sym_stop] = ACTIONS(1134),
    [anon_sym_add] = ACTIONS(1134),
    [anon_sym_sub] = ACTIONS(1134),
    [anon_sym_mul] = ACTIONS(1134),
    [anon_sym_div] = ACTIONS(1134),
    [anon_sym_sdiv] = ACTIONS(1134),
    [anon_sym_mod] = ACTIONS(1134),
    [anon_sym_smod] = ACTIONS(1134),
    [anon_sym_exp] = ACTIONS(1134),
    [anon_sym_not] = ACTIONS(1134),
    [anon_sym_lt] = ACTIONS(1134),
    [anon_sym_gt] = ACTIONS(1134),
    [anon_sym_slt] = ACTIONS(1134),
    [anon_sym_sgt] = ACTIONS(1134),
    [anon_sym_eq] = ACTIONS(1134),
    [anon_sym_iszero] = ACTIONS(1134),
    [anon_sym_and] = ACTIONS(1134),
    [anon_sym_or] = ACTIONS(1134),
    [anon_sym_xor] = ACTIONS(1134),
    [anon_sym_byte] = ACTIONS(1134),
    [anon_sym_shl] = ACTIONS(1134),
    [anon_sym_shr] = ACTIONS(1134),
    [anon_sym_sar] = ACTIONS(1134),
    [anon_sym_addmod] = ACTIONS(1134),
    [anon_sym_mulmod] = ACTIONS(1134),
    [anon_sym_signextend] = ACTIONS(1134),
    [anon_sym_keccak256] = ACTIONS(1134),
    [anon_sym_pop] = ACTIONS(1134),
    [anon_sym_mload] = ACTIONS(1134),
    [anon_sym_mstore] = ACTIONS(1134),
    [anon_sym_mstore8] = ACTIONS(1134),
    [anon_sym_sload] = ACTIONS(1134),
    [anon_sym_sstore] = ACTIONS(1134),
    [anon_sym_msize] = ACTIONS(1134),
    [anon_sym_gas] = ACTIONS(1134),
    [anon_sym_address] = ACTIONS(1134),
    [anon_sym_balance] = ACTIONS(1134),
    [anon_sym_selfbalance] = ACTIONS(1134),
    [anon_sym_caller] = ACTIONS(1134),
    [anon_sym_callvalue] = ACTIONS(1134),
    [anon_sym_calldataload] = ACTIONS(1134),
    [anon_sym_calldatasize] = ACTIONS(1134),
    [anon_sym_calldatacopy] = ACTIONS(1134),
    [anon_sym_extcodesize] = ACTIONS(1134),
    [anon_sym_extcodecopy] = ACTIONS(1134),
    [anon_sym_returndatasize] = ACTIONS(1134),
    [anon_sym_returndatacopy] = ACTIONS(1134),
    [anon_sym_extcodehash] = ACTIONS(1134),
    [anon_sym_create] = ACTIONS(1134),
    [anon_sym_create2] = ACTIONS(1134),
    [anon_sym_call] = ACTIONS(1134),
    [anon_sym_callcode] = ACTIONS(1134),
    [anon_sym_delegatecall] = ACTIONS(1134),
    [anon_sym_staticcall] = ACTIONS(1134),
    [anon_sym_return] = ACTIONS(1134),
    [anon_sym_revert] = ACTIONS(1134),
    [anon_sym_selfdestruct] = ACTIONS(1134),
    [anon_sym_invalid] = ACTIONS(1134),
    [anon_sym_log0] = ACTIONS(1134),
    [anon_sym_log1] = ACTIONS(1134),
    [anon_sym_log2] = ACTIONS(1134),
    [anon_sym_log3] = ACTIONS(1134),
    [anon_sym_log4] = ACTIONS(1134),
    [anon_sym_chainid] = ACTIONS(1134),
    [anon_sym_origin] = ACTIONS(1134),
    [anon_sym_gasprice] = ACTIONS(1134),
    [anon_sym_blockhash] = ACTIONS(1134),
    [anon_sym_coinbase] = ACTIONS(1134),
    [anon_sym_timestamp] = ACTIONS(1134),
    [anon_sym_number] = ACTIONS(1134),
    [anon_sym_difficulty] = ACTIONS(1134),
    [anon_sym_gaslimit] = ACTIONS(1134),
    [anon_sym_hex] = ACTIONS(1134),
    [anon_sym_DQUOTE] = ACTIONS(1136),
    [anon_sym_SQUOTE] = ACTIONS(1136),
    [sym_comment] = ACTIONS(3),
  },
  [321] = {
    [aux_sym_yul_assignment_repeat1] = STATE(321),
    [sym_identifier] = ACTIONS(1138),
    [anon_sym_LBRACE] = ACTIONS(1140),
    [anon_sym_COMMA] = ACTIONS(1142),
    [anon_sym_RBRACE] = ACTIONS(1140),
    [anon_sym_for] = ACTIONS(1138),
    [anon_sym_COLON] = ACTIONS(1138),
    [sym_yul_leave] = ACTIONS(1138),
    [anon_sym_break] = ACTIONS(1138),
    [anon_sym_continue] = ACTIONS(1138),
    [sym_yul_decimal_number] = ACTIONS(1138),
    [sym_yul_hex_number] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1138),
    [anon_sym_false] = ACTIONS(1138),
    [anon_sym_let] = ACTIONS(1138),
    [anon_sym_COLON_EQ] = ACTIONS(1140),
    [anon_sym_if] = ACTIONS(1138),
    [anon_sym_switch] = ACTIONS(1138),
    [anon_sym_function] = ACTIONS(1138),
    [anon_sym_stop] = ACTIONS(1138),
    [anon_sym_add] = ACTIONS(1138),
    [anon_sym_sub] = ACTIONS(1138),
    [anon_sym_mul] = ACTIONS(1138),
    [anon_sym_div] = ACTIONS(1138),
    [anon_sym_sdiv] = ACTIONS(1138),
    [anon_sym_mod] = ACTIONS(1138),
    [anon_sym_smod] = ACTIONS(1138),
    [anon_sym_exp] = ACTIONS(1138),
    [anon_sym_not] = ACTIONS(1138),
    [anon_sym_lt] = ACTIONS(1138),
    [anon_sym_gt] = ACTIONS(1138),
    [anon_sym_slt] = ACTIONS(1138),
    [anon_sym_sgt] = ACTIONS(1138),
    [anon_sym_eq] = ACTIONS(1138),
    [anon_sym_iszero] = ACTIONS(1138),
    [anon_sym_and] = ACTIONS(1138),
    [anon_sym_or] = ACTIONS(1138),
    [anon_sym_xor] = ACTIONS(1138),
    [anon_sym_byte] = ACTIONS(1138),
    [anon_sym_shl] = ACTIONS(1138),
    [anon_sym_shr] = ACTIONS(1138),
    [anon_sym_sar] = ACTIONS(1138),
    [anon_sym_addmod] = ACTIONS(1138),
    [anon_sym_mulmod] = ACTIONS(1138),
    [anon_sym_signextend] = ACTIONS(1138),
    [anon_sym_keccak256] = ACTIONS(1138),
    [anon_sym_pop] = ACTIONS(1138),
    [anon_sym_mload] = ACTIONS(1138),
    [anon_sym_mstore] = ACTIONS(1138),
    [anon_sym_mstore8] = ACTIONS(1138),
    [anon_sym_sload] = ACTIONS(1138),
    [anon_sym_sstore] = ACTIONS(1138),
    [anon_sym_msize] = ACTIONS(1138),
    [anon_sym_gas] = ACTIONS(1138),
    [anon_sym_address] = ACTIONS(1138),
    [anon_sym_balance] = ACTIONS(1138),
    [anon_sym_selfbalance] = ACTIONS(1138),
    [anon_sym_caller] = ACTIONS(1138),
    [anon_sym_callvalue] = ACTIONS(1138),
    [anon_sym_calldataload] = ACTIONS(1138),
    [anon_sym_calldatasize] = ACTIONS(1138),
    [anon_sym_calldatacopy] = ACTIONS(1138),
    [anon_sym_extcodesize] = ACTIONS(1138),
    [anon_sym_extcodecopy] = ACTIONS(1138),
    [anon_sym_returndatasize] = ACTIONS(1138),
    [anon_sym_returndatacopy] = ACTIONS(1138),
    [anon_sym_extcodehash] = ACTIONS(1138),
    [anon_sym_create] = ACTIONS(1138),
    [anon_sym_create2] = ACTIONS(1138),
    [anon_sym_call] = ACTIONS(1138),
    [anon_sym_callcode] = ACTIONS(1138),
    [anon_sym_delegatecall] = ACTIONS(1138),
    [anon_sym_staticcall] = ACTIONS(1138),
    [anon_sym_return] = ACTIONS(1138),
    [anon_sym_revert] = ACTIONS(1138),
    [anon_sym_selfdestruct] = ACTIONS(1138),
    [anon_sym_invalid] = ACTIONS(1138),
    [anon_sym_log0] = ACTIONS(1138),
    [anon_sym_log1] = ACTIONS(1138),
    [anon_sym_log2] = ACTIONS(1138),
    [anon_sym_log3] = ACTIONS(1138),
    [anon_sym_log4] = ACTIONS(1138),
    [anon_sym_chainid] = ACTIONS(1138),
    [anon_sym_origin] = ACTIONS(1138),
    [anon_sym_gasprice] = ACTIONS(1138),
    [anon_sym_blockhash] = ACTIONS(1138),
    [anon_sym_coinbase] = ACTIONS(1138),
    [anon_sym_timestamp] = ACTIONS(1138),
    [anon_sym_number] = ACTIONS(1138),
    [anon_sym_difficulty] = ACTIONS(1138),
    [anon_sym_gaslimit] = ACTIONS(1138),
    [anon_sym_hex] = ACTIONS(1138),
    [anon_sym_DQUOTE] = ACTIONS(1140),
    [anon_sym_SQUOTE] = ACTIONS(1140),
    [sym_comment] = ACTIONS(3),
  },
  [322] = {
    [sym_identifier] = ACTIONS(1145),
    [anon_sym_LBRACE] = ACTIONS(1147),
    [anon_sym_COMMA] = ACTIONS(1147),
    [anon_sym_RBRACE] = ACTIONS(1147),
    [anon_sym_RPAREN] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1145),
    [sym_yul_leave] = ACTIONS(1145),
    [anon_sym_break] = ACTIONS(1145),
    [anon_sym_continue] = ACTIONS(1145),
    [sym_yul_decimal_number] = ACTIONS(1145),
    [sym_yul_hex_number] = ACTIONS(1147),
    [anon_sym_true] = ACTIONS(1145),
    [anon_sym_false] = ACTIONS(1145),
    [anon_sym_let] = ACTIONS(1145),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_switch] = ACTIONS(1145),
    [anon_sym_default] = ACTIONS(1145),
    [anon_sym_case] = ACTIONS(1145),
    [anon_sym_function] = ACTIONS(1145),
    [anon_sym_stop] = ACTIONS(1145),
    [anon_sym_add] = ACTIONS(1145),
    [anon_sym_sub] = ACTIONS(1145),
    [anon_sym_mul] = ACTIONS(1145),
    [anon_sym_div] = ACTIONS(1145),
    [anon_sym_sdiv] = ACTIONS(1145),
    [anon_sym_mod] = ACTIONS(1145),
    [anon_sym_smod] = ACTIONS(1145),
    [anon_sym_exp] = ACTIONS(1145),
    [anon_sym_not] = ACTIONS(1145),
    [anon_sym_lt] = ACTIONS(1145),
    [anon_sym_gt] = ACTIONS(1145),
    [anon_sym_slt] = ACTIONS(1145),
    [anon_sym_sgt] = ACTIONS(1145),
    [anon_sym_eq] = ACTIONS(1145),
    [anon_sym_iszero] = ACTIONS(1145),
    [anon_sym_and] = ACTIONS(1145),
    [anon_sym_or] = ACTIONS(1145),
    [anon_sym_xor] = ACTIONS(1145),
    [anon_sym_byte] = ACTIONS(1145),
    [anon_sym_shl] = ACTIONS(1145),
    [anon_sym_shr] = ACTIONS(1145),
    [anon_sym_sar] = ACTIONS(1145),
    [anon_sym_addmod] = ACTIONS(1145),
    [anon_sym_mulmod] = ACTIONS(1145),
    [anon_sym_signextend] = ACTIONS(1145),
    [anon_sym_keccak256] = ACTIONS(1145),
    [anon_sym_pop] = ACTIONS(1145),
    [anon_sym_mload] = ACTIONS(1145),
    [anon_sym_mstore] = ACTIONS(1145),
    [anon_sym_mstore8] = ACTIONS(1145),
    [anon_sym_sload] = ACTIONS(1145),
    [anon_sym_sstore] = ACTIONS(1145),
    [anon_sym_msize] = ACTIONS(1145),
    [anon_sym_gas] = ACTIONS(1145),
    [anon_sym_address] = ACTIONS(1145),
    [anon_sym_balance] = ACTIONS(1145),
    [anon_sym_selfbalance] = ACTIONS(1145),
    [anon_sym_caller] = ACTIONS(1145),
    [anon_sym_callvalue] = ACTIONS(1145),
    [anon_sym_calldataload] = ACTIONS(1145),
    [anon_sym_calldatasize] = ACTIONS(1145),
    [anon_sym_calldatacopy] = ACTIONS(1145),
    [anon_sym_extcodesize] = ACTIONS(1145),
    [anon_sym_extcodecopy] = ACTIONS(1145),
    [anon_sym_returndatasize] = ACTIONS(1145),
    [anon_sym_returndatacopy] = ACTIONS(1145),
    [anon_sym_extcodehash] = ACTIONS(1145),
    [anon_sym_create] = ACTIONS(1145),
    [anon_sym_create2] = ACTIONS(1145),
    [anon_sym_call] = ACTIONS(1145),
    [anon_sym_callcode] = ACTIONS(1145),
    [anon_sym_delegatecall] = ACTIONS(1145),
    [anon_sym_staticcall] = ACTIONS(1145),
    [anon_sym_return] = ACTIONS(1145),
    [anon_sym_revert] = ACTIONS(1145),
    [anon_sym_selfdestruct] = ACTIONS(1145),
    [anon_sym_invalid] = ACTIONS(1145),
    [anon_sym_log0] = ACTIONS(1145),
    [anon_sym_log1] = ACTIONS(1145),
    [anon_sym_log2] = ACTIONS(1145),
    [anon_sym_log3] = ACTIONS(1145),
    [anon_sym_log4] = ACTIONS(1145),
    [anon_sym_chainid] = ACTIONS(1145),
    [anon_sym_origin] = ACTIONS(1145),
    [anon_sym_gasprice] = ACTIONS(1145),
    [anon_sym_blockhash] = ACTIONS(1145),
    [anon_sym_coinbase] = ACTIONS(1145),
    [anon_sym_timestamp] = ACTIONS(1145),
    [anon_sym_number] = ACTIONS(1145),
    [anon_sym_difficulty] = ACTIONS(1145),
    [anon_sym_gaslimit] = ACTIONS(1145),
    [anon_sym_hex] = ACTIONS(1145),
    [anon_sym_DQUOTE] = ACTIONS(1147),
    [anon_sym_SQUOTE] = ACTIONS(1147),
    [sym_comment] = ACTIONS(3),
  },
  [323] = {
    [sym_identifier] = ACTIONS(1149),
    [anon_sym_LBRACE] = ACTIONS(1151),
    [anon_sym_COMMA] = ACTIONS(1151),
    [anon_sym_RBRACE] = ACTIONS(1151),
    [anon_sym_RPAREN] = ACTIONS(1151),
    [anon_sym_for] = ACTIONS(1149),
    [sym_yul_leave] = ACTIONS(1149),
    [anon_sym_break] = ACTIONS(1149),
    [anon_sym_continue] = ACTIONS(1149),
    [sym_yul_decimal_number] = ACTIONS(1149),
    [sym_yul_hex_number] = ACTIONS(1151),
    [anon_sym_true] = ACTIONS(1149),
    [anon_sym_false] = ACTIONS(1149),
    [anon_sym_let] = ACTIONS(1149),
    [anon_sym_if] = ACTIONS(1149),
    [anon_sym_switch] = ACTIONS(1149),
    [anon_sym_default] = ACTIONS(1149),
    [anon_sym_case] = ACTIONS(1149),
    [anon_sym_function] = ACTIONS(1149),
    [anon_sym_stop] = ACTIONS(1149),
    [anon_sym_add] = ACTIONS(1149),
    [anon_sym_sub] = ACTIONS(1149),
    [anon_sym_mul] = ACTIONS(1149),
    [anon_sym_div] = ACTIONS(1149),
    [anon_sym_sdiv] = ACTIONS(1149),
    [anon_sym_mod] = ACTIONS(1149),
    [anon_sym_smod] = ACTIONS(1149),
    [anon_sym_exp] = ACTIONS(1149),
    [anon_sym_not] = ACTIONS(1149),
    [anon_sym_lt] = ACTIONS(1149),
    [anon_sym_gt] = ACTIONS(1149),
    [anon_sym_slt] = ACTIONS(1149),
    [anon_sym_sgt] = ACTIONS(1149),
    [anon_sym_eq] = ACTIONS(1149),
    [anon_sym_iszero] = ACTIONS(1149),
    [anon_sym_and] = ACTIONS(1149),
    [anon_sym_or] = ACTIONS(1149),
    [anon_sym_xor] = ACTIONS(1149),
    [anon_sym_byte] = ACTIONS(1149),
    [anon_sym_shl] = ACTIONS(1149),
    [anon_sym_shr] = ACTIONS(1149),
    [anon_sym_sar] = ACTIONS(1149),
    [anon_sym_addmod] = ACTIONS(1149),
    [anon_sym_mulmod] = ACTIONS(1149),
    [anon_sym_signextend] = ACTIONS(1149),
    [anon_sym_keccak256] = ACTIONS(1149),
    [anon_sym_pop] = ACTIONS(1149),
    [anon_sym_mload] = ACTIONS(1149),
    [anon_sym_mstore] = ACTIONS(1149),
    [anon_sym_mstore8] = ACTIONS(1149),
    [anon_sym_sload] = ACTIONS(1149),
    [anon_sym_sstore] = ACTIONS(1149),
    [anon_sym_msize] = ACTIONS(1149),
    [anon_sym_gas] = ACTIONS(1149),
    [anon_sym_address] = ACTIONS(1149),
    [anon_sym_balance] = ACTIONS(1149),
    [anon_sym_selfbalance] = ACTIONS(1149),
    [anon_sym_caller] = ACTIONS(1149),
    [anon_sym_callvalue] = ACTIONS(1149),
    [anon_sym_calldataload] = ACTIONS(1149),
    [anon_sym_calldatasize] = ACTIONS(1149),
    [anon_sym_calldatacopy] = ACTIONS(1149),
    [anon_sym_extcodesize] = ACTIONS(1149),
    [anon_sym_extcodecopy] = ACTIONS(1149),
    [anon_sym_returndatasize] = ACTIONS(1149),
    [anon_sym_returndatacopy] = ACTIONS(1149),
    [anon_sym_extcodehash] = ACTIONS(1149),
    [anon_sym_create] = ACTIONS(1149),
    [anon_sym_create2] = ACTIONS(1149),
    [anon_sym_call] = ACTIONS(1149),
    [anon_sym_callcode] = ACTIONS(1149),
    [anon_sym_delegatecall] = ACTIONS(1149),
    [anon_sym_staticcall] = ACTIONS(1149),
    [anon_sym_return] = ACTIONS(1149),
    [anon_sym_revert] = ACTIONS(1149),
    [anon_sym_selfdestruct] = ACTIONS(1149),
    [anon_sym_invalid] = ACTIONS(1149),
    [anon_sym_log0] = ACTIONS(1149),
    [anon_sym_log1] = ACTIONS(1149),
    [anon_sym_log2] = ACTIONS(1149),
    [anon_sym_log3] = ACTIONS(1149),
    [anon_sym_log4] = ACTIONS(1149),
    [anon_sym_chainid] = ACTIONS(1149),
    [anon_sym_origin] = ACTIONS(1149),
    [anon_sym_gasprice] = ACTIONS(1149),
    [anon_sym_blockhash] = ACTIONS(1149),
    [anon_sym_coinbase] = ACTIONS(1149),
    [anon_sym_timestamp] = ACTIONS(1149),
    [anon_sym_number] = ACTIONS(1149),
    [anon_sym_difficulty] = ACTIONS(1149),
    [anon_sym_gaslimit] = ACTIONS(1149),
    [anon_sym_hex] = ACTIONS(1149),
    [anon_sym_DQUOTE] = ACTIONS(1151),
    [anon_sym_SQUOTE] = ACTIONS(1151),
    [sym_comment] = ACTIONS(3),
  },
  [324] = {
    [aux_sym_yul_switch_statement_repeat1] = STATE(324),
    [sym_identifier] = ACTIONS(1153),
    [anon_sym_LBRACE] = ACTIONS(1155),
    [anon_sym_RBRACE] = ACTIONS(1155),
    [anon_sym_for] = ACTIONS(1153),
    [sym_yul_leave] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_continue] = ACTIONS(1153),
    [sym_yul_decimal_number] = ACTIONS(1153),
    [sym_yul_hex_number] = ACTIONS(1155),
    [anon_sym_true] = ACTIONS(1153),
    [anon_sym_false] = ACTIONS(1153),
    [anon_sym_let] = ACTIONS(1153),
    [anon_sym_if] = ACTIONS(1153),
    [anon_sym_switch] = ACTIONS(1153),
    [anon_sym_default] = ACTIONS(1153),
    [anon_sym_case] = ACTIONS(1157),
    [anon_sym_function] = ACTIONS(1153),
    [anon_sym_stop] = ACTIONS(1153),
    [anon_sym_add] = ACTIONS(1153),
    [anon_sym_sub] = ACTIONS(1153),
    [anon_sym_mul] = ACTIONS(1153),
    [anon_sym_div] = ACTIONS(1153),
    [anon_sym_sdiv] = ACTIONS(1153),
    [anon_sym_mod] = ACTIONS(1153),
    [anon_sym_smod] = ACTIONS(1153),
    [anon_sym_exp] = ACTIONS(1153),
    [anon_sym_not] = ACTIONS(1153),
    [anon_sym_lt] = ACTIONS(1153),
    [anon_sym_gt] = ACTIONS(1153),
    [anon_sym_slt] = ACTIONS(1153),
    [anon_sym_sgt] = ACTIONS(1153),
    [anon_sym_eq] = ACTIONS(1153),
    [anon_sym_iszero] = ACTIONS(1153),
    [anon_sym_and] = ACTIONS(1153),
    [anon_sym_or] = ACTIONS(1153),
    [anon_sym_xor] = ACTIONS(1153),
    [anon_sym_byte] = ACTIONS(1153),
    [anon_sym_shl] = ACTIONS(1153),
    [anon_sym_shr] = ACTIONS(1153),
    [anon_sym_sar] = ACTIONS(1153),
    [anon_sym_addmod] = ACTIONS(1153),
    [anon_sym_mulmod] = ACTIONS(1153),
    [anon_sym_signextend] = ACTIONS(1153),
    [anon_sym_keccak256] = ACTIONS(1153),
    [anon_sym_pop] = ACTIONS(1153),
    [anon_sym_mload] = ACTIONS(1153),
    [anon_sym_mstore] = ACTIONS(1153),
    [anon_sym_mstore8] = ACTIONS(1153),
    [anon_sym_sload] = ACTIONS(1153),
    [anon_sym_sstore] = ACTIONS(1153),
    [anon_sym_msize] = ACTIONS(1153),
    [anon_sym_gas] = ACTIONS(1153),
    [anon_sym_address] = ACTIONS(1153),
    [anon_sym_balance] = ACTIONS(1153),
    [anon_sym_selfbalance] = ACTIONS(1153),
    [anon_sym_caller] = ACTIONS(1153),
    [anon_sym_callvalue] = ACTIONS(1153),
    [anon_sym_calldataload] = ACTIONS(1153),
    [anon_sym_calldatasize] = ACTIONS(1153),
    [anon_sym_calldatacopy] = ACTIONS(1153),
    [anon_sym_extcodesize] = ACTIONS(1153),
    [anon_sym_extcodecopy] = ACTIONS(1153),
    [anon_sym_returndatasize] = ACTIONS(1153),
    [anon_sym_returndatacopy] = ACTIONS(1153),
    [anon_sym_extcodehash] = ACTIONS(1153),
    [anon_sym_create] = ACTIONS(1153),
    [anon_sym_create2] = ACTIONS(1153),
    [anon_sym_call] = ACTIONS(1153),
    [anon_sym_callcode] = ACTIONS(1153),
    [anon_sym_delegatecall] = ACTIONS(1153),
    [anon_sym_staticcall] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1153),
    [anon_sym_revert] = ACTIONS(1153),
    [anon_sym_selfdestruct] = ACTIONS(1153),
    [anon_sym_invalid] = ACTIONS(1153),
    [anon_sym_log0] = ACTIONS(1153),
    [anon_sym_log1] = ACTIONS(1153),
    [anon_sym_log2] = ACTIONS(1153),
    [anon_sym_log3] = ACTIONS(1153),
    [anon_sym_log4] = ACTIONS(1153),
    [anon_sym_chainid] = ACTIONS(1153),
    [anon_sym_origin] = ACTIONS(1153),
    [anon_sym_gasprice] = ACTIONS(1153),
    [anon_sym_blockhash] = ACTIONS(1153),
    [anon_sym_coinbase] = ACTIONS(1153),
    [anon_sym_timestamp] = ACTIONS(1153),
    [anon_sym_number] = ACTIONS(1153),
    [anon_sym_difficulty] = ACTIONS(1153),
    [anon_sym_gaslimit] = ACTIONS(1153),
    [anon_sym_hex] = ACTIONS(1153),
    [anon_sym_DQUOTE] = ACTIONS(1155),
    [anon_sym_SQUOTE] = ACTIONS(1155),
    [sym_comment] = ACTIONS(3),
  },
  [325] = {
    [aux_sym_yul_variable_declaration_repeat1] = STATE(326),
    [sym_identifier] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(1162),
    [anon_sym_COMMA] = ACTIONS(1164),
    [anon_sym_RBRACE] = ACTIONS(1162),
    [anon_sym_for] = ACTIONS(1160),
    [sym_yul_leave] = ACTIONS(1160),
    [anon_sym_break] = ACTIONS(1160),
    [anon_sym_continue] = ACTIONS(1160),
    [sym_yul_decimal_number] = ACTIONS(1160),
    [sym_yul_hex_number] = ACTIONS(1162),
    [anon_sym_true] = ACTIONS(1160),
    [anon_sym_false] = ACTIONS(1160),
    [anon_sym_let] = ACTIONS(1160),
    [anon_sym_COLON_EQ] = ACTIONS(1166),
    [anon_sym_if] = ACTIONS(1160),
    [anon_sym_switch] = ACTIONS(1160),
    [anon_sym_function] = ACTIONS(1160),
    [anon_sym_stop] = ACTIONS(1160),
    [anon_sym_add] = ACTIONS(1160),
    [anon_sym_sub] = ACTIONS(1160),
    [anon_sym_mul] = ACTIONS(1160),
    [anon_sym_div] = ACTIONS(1160),
    [anon_sym_sdiv] = ACTIONS(1160),
    [anon_sym_mod] = ACTIONS(1160),
    [anon_sym_smod] = ACTIONS(1160),
    [anon_sym_exp] = ACTIONS(1160),
    [anon_sym_not] = ACTIONS(1160),
    [anon_sym_lt] = ACTIONS(1160),
    [anon_sym_gt] = ACTIONS(1160),
    [anon_sym_slt] = ACTIONS(1160),
    [anon_sym_sgt] = ACTIONS(1160),
    [anon_sym_eq] = ACTIONS(1160),
    [anon_sym_iszero] = ACTIONS(1160),
    [anon_sym_and] = ACTIONS(1160),
    [anon_sym_or] = ACTIONS(1160),
    [anon_sym_xor] = ACTIONS(1160),
    [anon_sym_byte] = ACTIONS(1160),
    [anon_sym_shl] = ACTIONS(1160),
    [anon_sym_shr] = ACTIONS(1160),
    [anon_sym_sar] = ACTIONS(1160),
    [anon_sym_addmod] = ACTIONS(1160),
    [anon_sym_mulmod] = ACTIONS(1160),
    [anon_sym_signextend] = ACTIONS(1160),
    [anon_sym_keccak256] = ACTIONS(1160),
    [anon_sym_pop] = ACTIONS(1160),
    [anon_sym_mload] = ACTIONS(1160),
    [anon_sym_mstore] = ACTIONS(1160),
    [anon_sym_mstore8] = ACTIONS(1160),
    [anon_sym_sload] = ACTIONS(1160),
    [anon_sym_sstore] = ACTIONS(1160),
    [anon_sym_msize] = ACTIONS(1160),
    [anon_sym_gas] = ACTIONS(1160),
    [anon_sym_address] = ACTIONS(1160),
    [anon_sym_balance] = ACTIONS(1160),
    [anon_sym_selfbalance] = ACTIONS(1160),
    [anon_sym_caller] = ACTIONS(1160),
    [anon_sym_callvalue] = ACTIONS(1160),
    [anon_sym_calldataload] = ACTIONS(1160),
    [anon_sym_calldatasize] = ACTIONS(1160),
    [anon_sym_calldatacopy] = ACTIONS(1160),
    [anon_sym_extcodesize] = ACTIONS(1160),
    [anon_sym_extcodecopy] = ACTIONS(1160),
    [anon_sym_returndatasize] = ACTIONS(1160),
    [anon_sym_returndatacopy] = ACTIONS(1160),
    [anon_sym_extcodehash] = ACTIONS(1160),
    [anon_sym_create] = ACTIONS(1160),
    [anon_sym_create2] = ACTIONS(1160),
    [anon_sym_call] = ACTIONS(1160),
    [anon_sym_callcode] = ACTIONS(1160),
    [anon_sym_delegatecall] = ACTIONS(1160),
    [anon_sym_staticcall] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1160),
    [anon_sym_revert] = ACTIONS(1160),
    [anon_sym_selfdestruct] = ACTIONS(1160),
    [anon_sym_invalid] = ACTIONS(1160),
    [anon_sym_log0] = ACTIONS(1160),
    [anon_sym_log1] = ACTIONS(1160),
    [anon_sym_log2] = ACTIONS(1160),
    [anon_sym_log3] = ACTIONS(1160),
    [anon_sym_log4] = ACTIONS(1160),
    [anon_sym_chainid] = ACTIONS(1160),
    [anon_sym_origin] = ACTIONS(1160),
    [anon_sym_gasprice] = ACTIONS(1160),
    [anon_sym_blockhash] = ACTIONS(1160),
    [anon_sym_coinbase] = ACTIONS(1160),
    [anon_sym_timestamp] = ACTIONS(1160),
    [anon_sym_number] = ACTIONS(1160),
    [anon_sym_difficulty] = ACTIONS(1160),
    [anon_sym_gaslimit] = ACTIONS(1160),
    [anon_sym_hex] = ACTIONS(1160),
    [anon_sym_DQUOTE] = ACTIONS(1162),
    [anon_sym_SQUOTE] = ACTIONS(1162),
    [sym_comment] = ACTIONS(3),
  },
  [326] = {
    [aux_sym_yul_variable_declaration_repeat1] = STATE(316),
    [sym_identifier] = ACTIONS(1168),
    [anon_sym_LBRACE] = ACTIONS(1170),
    [anon_sym_COMMA] = ACTIONS(1172),
    [anon_sym_RBRACE] = ACTIONS(1170),
    [anon_sym_for] = ACTIONS(1168),
    [sym_yul_leave] = ACTIONS(1168),
    [anon_sym_break] = ACTIONS(1168),
    [anon_sym_continue] = ACTIONS(1168),
    [sym_yul_decimal_number] = ACTIONS(1168),
    [sym_yul_hex_number] = ACTIONS(1170),
    [anon_sym_true] = ACTIONS(1168),
    [anon_sym_false] = ACTIONS(1168),
    [anon_sym_let] = ACTIONS(1168),
    [anon_sym_COLON_EQ] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1168),
    [anon_sym_switch] = ACTIONS(1168),
    [anon_sym_function] = ACTIONS(1168),
    [anon_sym_stop] = ACTIONS(1168),
    [anon_sym_add] = ACTIONS(1168),
    [anon_sym_sub] = ACTIONS(1168),
    [anon_sym_mul] = ACTIONS(1168),
    [anon_sym_div] = ACTIONS(1168),
    [anon_sym_sdiv] = ACTIONS(1168),
    [anon_sym_mod] = ACTIONS(1168),
    [anon_sym_smod] = ACTIONS(1168),
    [anon_sym_exp] = ACTIONS(1168),
    [anon_sym_not] = ACTIONS(1168),
    [anon_sym_lt] = ACTIONS(1168),
    [anon_sym_gt] = ACTIONS(1168),
    [anon_sym_slt] = ACTIONS(1168),
    [anon_sym_sgt] = ACTIONS(1168),
    [anon_sym_eq] = ACTIONS(1168),
    [anon_sym_iszero] = ACTIONS(1168),
    [anon_sym_and] = ACTIONS(1168),
    [anon_sym_or] = ACTIONS(1168),
    [anon_sym_xor] = ACTIONS(1168),
    [anon_sym_byte] = ACTIONS(1168),
    [anon_sym_shl] = ACTIONS(1168),
    [anon_sym_shr] = ACTIONS(1168),
    [anon_sym_sar] = ACTIONS(1168),
    [anon_sym_addmod] = ACTIONS(1168),
    [anon_sym_mulmod] = ACTIONS(1168),
    [anon_sym_signextend] = ACTIONS(1168),
    [anon_sym_keccak256] = ACTIONS(1168),
    [anon_sym_pop] = ACTIONS(1168),
    [anon_sym_mload] = ACTIONS(1168),
    [anon_sym_mstore] = ACTIONS(1168),
    [anon_sym_mstore8] = ACTIONS(1168),
    [anon_sym_sload] = ACTIONS(1168),
    [anon_sym_sstore] = ACTIONS(1168),
    [anon_sym_msize] = ACTIONS(1168),
    [anon_sym_gas] = ACTIONS(1168),
    [anon_sym_address] = ACTIONS(1168),
    [anon_sym_balance] = ACTIONS(1168),
    [anon_sym_selfbalance] = ACTIONS(1168),
    [anon_sym_caller] = ACTIONS(1168),
    [anon_sym_callvalue] = ACTIONS(1168),
    [anon_sym_calldataload] = ACTIONS(1168),
    [anon_sym_calldatasize] = ACTIONS(1168),
    [anon_sym_calldatacopy] = ACTIONS(1168),
    [anon_sym_extcodesize] = ACTIONS(1168),
    [anon_sym_extcodecopy] = ACTIONS(1168),
    [anon_sym_returndatasize] = ACTIONS(1168),
    [anon_sym_returndatacopy] = ACTIONS(1168),
    [anon_sym_extcodehash] = ACTIONS(1168),
    [anon_sym_create] = ACTIONS(1168),
    [anon_sym_create2] = ACTIONS(1168),
    [anon_sym_call] = ACTIONS(1168),
    [anon_sym_callcode] = ACTIONS(1168),
    [anon_sym_delegatecall] = ACTIONS(1168),
    [anon_sym_staticcall] = ACTIONS(1168),
    [anon_sym_return] = ACTIONS(1168),
    [anon_sym_revert] = ACTIONS(1168),
    [anon_sym_selfdestruct] = ACTIONS(1168),
    [anon_sym_invalid] = ACTIONS(1168),
    [anon_sym_log0] = ACTIONS(1168),
    [anon_sym_log1] = ACTIONS(1168),
    [anon_sym_log2] = ACTIONS(1168),
    [anon_sym_log3] = ACTIONS(1168),
    [anon_sym_log4] = ACTIONS(1168),
    [anon_sym_chainid] = ACTIONS(1168),
    [anon_sym_origin] = ACTIONS(1168),
    [anon_sym_gasprice] = ACTIONS(1168),
    [anon_sym_blockhash] = ACTIONS(1168),
    [anon_sym_coinbase] = ACTIONS(1168),
    [anon_sym_timestamp] = ACTIONS(1168),
    [anon_sym_number] = ACTIONS(1168),
    [anon_sym_difficulty] = ACTIONS(1168),
    [anon_sym_gaslimit] = ACTIONS(1168),
    [anon_sym_hex] = ACTIONS(1168),
    [anon_sym_DQUOTE] = ACTIONS(1170),
    [anon_sym_SQUOTE] = ACTIONS(1170),
    [sym_comment] = ACTIONS(3),
  },
  [327] = {
    [sym_identifier] = ACTIONS(1138),
    [anon_sym_LBRACE] = ACTIONS(1140),
    [anon_sym_COMMA] = ACTIONS(1140),
    [anon_sym_RBRACE] = ACTIONS(1140),
    [anon_sym_for] = ACTIONS(1138),
    [anon_sym_COLON] = ACTIONS(1138),
    [sym_yul_leave] = ACTIONS(1138),
    [anon_sym_break] = ACTIONS(1138),
    [anon_sym_continue] = ACTIONS(1138),
    [sym_yul_decimal_number] = ACTIONS(1138),
    [sym_yul_hex_number] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1138),
    [anon_sym_false] = ACTIONS(1138),
    [anon_sym_let] = ACTIONS(1138),
    [anon_sym_COLON_EQ] = ACTIONS(1140),
    [anon_sym_if] = ACTIONS(1138),
    [anon_sym_switch] = ACTIONS(1138),
    [anon_sym_function] = ACTIONS(1138),
    [anon_sym_stop] = ACTIONS(1138),
    [anon_sym_add] = ACTIONS(1138),
    [anon_sym_sub] = ACTIONS(1138),
    [anon_sym_mul] = ACTIONS(1138),
    [anon_sym_div] = ACTIONS(1138),
    [anon_sym_sdiv] = ACTIONS(1138),
    [anon_sym_mod] = ACTIONS(1138),
    [anon_sym_smod] = ACTIONS(1138),
    [anon_sym_exp] = ACTIONS(1138),
    [anon_sym_not] = ACTIONS(1138),
    [anon_sym_lt] = ACTIONS(1138),
    [anon_sym_gt] = ACTIONS(1138),
    [anon_sym_slt] = ACTIONS(1138),
    [anon_sym_sgt] = ACTIONS(1138),
    [anon_sym_eq] = ACTIONS(1138),
    [anon_sym_iszero] = ACTIONS(1138),
    [anon_sym_and] = ACTIONS(1138),
    [anon_sym_or] = ACTIONS(1138),
    [anon_sym_xor] = ACTIONS(1138),
    [anon_sym_byte] = ACTIONS(1138),
    [anon_sym_shl] = ACTIONS(1138),
    [anon_sym_shr] = ACTIONS(1138),
    [anon_sym_sar] = ACTIONS(1138),
    [anon_sym_addmod] = ACTIONS(1138),
    [anon_sym_mulmod] = ACTIONS(1138),
    [anon_sym_signextend] = ACTIONS(1138),
    [anon_sym_keccak256] = ACTIONS(1138),
    [anon_sym_pop] = ACTIONS(1138),
    [anon_sym_mload] = ACTIONS(1138),
    [anon_sym_mstore] = ACTIONS(1138),
    [anon_sym_mstore8] = ACTIONS(1138),
    [anon_sym_sload] = ACTIONS(1138),
    [anon_sym_sstore] = ACTIONS(1138),
    [anon_sym_msize] = ACTIONS(1138),
    [anon_sym_gas] = ACTIONS(1138),
    [anon_sym_address] = ACTIONS(1138),
    [anon_sym_balance] = ACTIONS(1138),
    [anon_sym_selfbalance] = ACTIONS(1138),
    [anon_sym_caller] = ACTIONS(1138),
    [anon_sym_callvalue] = ACTIONS(1138),
    [anon_sym_calldataload] = ACTIONS(1138),
    [anon_sym_calldatasize] = ACTIONS(1138),
    [anon_sym_calldatacopy] = ACTIONS(1138),
    [anon_sym_extcodesize] = ACTIONS(1138),
    [anon_sym_extcodecopy] = ACTIONS(1138),
    [anon_sym_returndatasize] = ACTIONS(1138),
    [anon_sym_returndatacopy] = ACTIONS(1138),
    [anon_sym_extcodehash] = ACTIONS(1138),
    [anon_sym_create] = ACTIONS(1138),
    [anon_sym_create2] = ACTIONS(1138),
    [anon_sym_call] = ACTIONS(1138),
    [anon_sym_callcode] = ACTIONS(1138),
    [anon_sym_delegatecall] = ACTIONS(1138),
    [anon_sym_staticcall] = ACTIONS(1138),
    [anon_sym_return] = ACTIONS(1138),
    [anon_sym_revert] = ACTIONS(1138),
    [anon_sym_selfdestruct] = ACTIONS(1138),
    [anon_sym_invalid] = ACTIONS(1138),
    [anon_sym_log0] = ACTIONS(1138),
    [anon_sym_log1] = ACTIONS(1138),
    [anon_sym_log2] = ACTIONS(1138),
    [anon_sym_log3] = ACTIONS(1138),
    [anon_sym_log4] = ACTIONS(1138),
    [anon_sym_chainid] = ACTIONS(1138),
    [anon_sym_origin] = ACTIONS(1138),
    [anon_sym_gasprice] = ACTIONS(1138),
    [anon_sym_blockhash] = ACTIONS(1138),
    [anon_sym_coinbase] = ACTIONS(1138),
    [anon_sym_timestamp] = ACTIONS(1138),
    [anon_sym_number] = ACTIONS(1138),
    [anon_sym_difficulty] = ACTIONS(1138),
    [anon_sym_gaslimit] = ACTIONS(1138),
    [anon_sym_hex] = ACTIONS(1138),
    [anon_sym_DQUOTE] = ACTIONS(1140),
    [anon_sym_SQUOTE] = ACTIONS(1140),
    [sym_comment] = ACTIONS(3),
  },
  [328] = {
    [sym_identifier] = ACTIONS(1115),
    [anon_sym_LBRACE] = ACTIONS(1117),
    [anon_sym_COMMA] = ACTIONS(1117),
    [anon_sym_RBRACE] = ACTIONS(1117),
    [anon_sym_RPAREN] = ACTIONS(1117),
    [anon_sym_for] = ACTIONS(1115),
    [sym_yul_leave] = ACTIONS(1115),
    [anon_sym_break] = ACTIONS(1115),
    [anon_sym_continue] = ACTIONS(1115),
    [sym_yul_decimal_number] = ACTIONS(1115),
    [sym_yul_hex_number] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(1115),
    [anon_sym_false] = ACTIONS(1115),
    [anon_sym_let] = ACTIONS(1115),
    [anon_sym_COLON_EQ] = ACTIONS(1117),
    [anon_sym_if] = ACTIONS(1115),
    [anon_sym_switch] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(1115),
    [anon_sym_stop] = ACTIONS(1115),
    [anon_sym_add] = ACTIONS(1115),
    [anon_sym_sub] = ACTIONS(1115),
    [anon_sym_mul] = ACTIONS(1115),
    [anon_sym_div] = ACTIONS(1115),
    [anon_sym_sdiv] = ACTIONS(1115),
    [anon_sym_mod] = ACTIONS(1115),
    [anon_sym_smod] = ACTIONS(1115),
    [anon_sym_exp] = ACTIONS(1115),
    [anon_sym_not] = ACTIONS(1115),
    [anon_sym_lt] = ACTIONS(1115),
    [anon_sym_gt] = ACTIONS(1115),
    [anon_sym_slt] = ACTIONS(1115),
    [anon_sym_sgt] = ACTIONS(1115),
    [anon_sym_eq] = ACTIONS(1115),
    [anon_sym_iszero] = ACTIONS(1115),
    [anon_sym_and] = ACTIONS(1115),
    [anon_sym_or] = ACTIONS(1115),
    [anon_sym_xor] = ACTIONS(1115),
    [anon_sym_byte] = ACTIONS(1115),
    [anon_sym_shl] = ACTIONS(1115),
    [anon_sym_shr] = ACTIONS(1115),
    [anon_sym_sar] = ACTIONS(1115),
    [anon_sym_addmod] = ACTIONS(1115),
    [anon_sym_mulmod] = ACTIONS(1115),
    [anon_sym_signextend] = ACTIONS(1115),
    [anon_sym_keccak256] = ACTIONS(1115),
    [anon_sym_pop] = ACTIONS(1115),
    [anon_sym_mload] = ACTIONS(1115),
    [anon_sym_mstore] = ACTIONS(1115),
    [anon_sym_mstore8] = ACTIONS(1115),
    [anon_sym_sload] = ACTIONS(1115),
    [anon_sym_sstore] = ACTIONS(1115),
    [anon_sym_msize] = ACTIONS(1115),
    [anon_sym_gas] = ACTIONS(1115),
    [anon_sym_address] = ACTIONS(1115),
    [anon_sym_balance] = ACTIONS(1115),
    [anon_sym_selfbalance] = ACTIONS(1115),
    [anon_sym_caller] = ACTIONS(1115),
    [anon_sym_callvalue] = ACTIONS(1115),
    [anon_sym_calldataload] = ACTIONS(1115),
    [anon_sym_calldatasize] = ACTIONS(1115),
    [anon_sym_calldatacopy] = ACTIONS(1115),
    [anon_sym_extcodesize] = ACTIONS(1115),
    [anon_sym_extcodecopy] = ACTIONS(1115),
    [anon_sym_returndatasize] = ACTIONS(1115),
    [anon_sym_returndatacopy] = ACTIONS(1115),
    [anon_sym_extcodehash] = ACTIONS(1115),
    [anon_sym_create] = ACTIONS(1115),
    [anon_sym_create2] = ACTIONS(1115),
    [anon_sym_call] = ACTIONS(1115),
    [anon_sym_callcode] = ACTIONS(1115),
    [anon_sym_delegatecall] = ACTIONS(1115),
    [anon_sym_staticcall] = ACTIONS(1115),
    [anon_sym_return] = ACTIONS(1115),
    [anon_sym_revert] = ACTIONS(1115),
    [anon_sym_selfdestruct] = ACTIONS(1115),
    [anon_sym_invalid] = ACTIONS(1115),
    [anon_sym_log0] = ACTIONS(1115),
    [anon_sym_log1] = ACTIONS(1115),
    [anon_sym_log2] = ACTIONS(1115),
    [anon_sym_log3] = ACTIONS(1115),
    [anon_sym_log4] = ACTIONS(1115),
    [anon_sym_chainid] = ACTIONS(1115),
    [anon_sym_origin] = ACTIONS(1115),
    [anon_sym_gasprice] = ACTIONS(1115),
    [anon_sym_blockhash] = ACTIONS(1115),
    [anon_sym_coinbase] = ACTIONS(1115),
    [anon_sym_timestamp] = ACTIONS(1115),
    [anon_sym_number] = ACTIONS(1115),
    [anon_sym_difficulty] = ACTIONS(1115),
    [anon_sym_gaslimit] = ACTIONS(1115),
    [anon_sym_hex] = ACTIONS(1115),
    [anon_sym_DQUOTE] = ACTIONS(1117),
    [anon_sym_SQUOTE] = ACTIONS(1117),
    [sym_comment] = ACTIONS(3),
  },
  [329] = {
    [aux_sym_yul_switch_statement_repeat1] = STATE(324),
    [sym_identifier] = ACTIONS(1176),
    [anon_sym_LBRACE] = ACTIONS(1178),
    [anon_sym_RBRACE] = ACTIONS(1178),
    [anon_sym_for] = ACTIONS(1176),
    [sym_yul_leave] = ACTIONS(1176),
    [anon_sym_break] = ACTIONS(1176),
    [anon_sym_continue] = ACTIONS(1176),
    [sym_yul_decimal_number] = ACTIONS(1176),
    [sym_yul_hex_number] = ACTIONS(1178),
    [anon_sym_true] = ACTIONS(1176),
    [anon_sym_false] = ACTIONS(1176),
    [anon_sym_let] = ACTIONS(1176),
    [anon_sym_if] = ACTIONS(1176),
    [anon_sym_switch] = ACTIONS(1176),
    [anon_sym_default] = ACTIONS(1180),
    [anon_sym_case] = ACTIONS(1182),
    [anon_sym_function] = ACTIONS(1176),
    [anon_sym_stop] = ACTIONS(1176),
    [anon_sym_add] = ACTIONS(1176),
    [anon_sym_sub] = ACTIONS(1176),
    [anon_sym_mul] = ACTIONS(1176),
    [anon_sym_div] = ACTIONS(1176),
    [anon_sym_sdiv] = ACTIONS(1176),
    [anon_sym_mod] = ACTIONS(1176),
    [anon_sym_smod] = ACTIONS(1176),
    [anon_sym_exp] = ACTIONS(1176),
    [anon_sym_not] = ACTIONS(1176),
    [anon_sym_lt] = ACTIONS(1176),
    [anon_sym_gt] = ACTIONS(1176),
    [anon_sym_slt] = ACTIONS(1176),
    [anon_sym_sgt] = ACTIONS(1176),
    [anon_sym_eq] = ACTIONS(1176),
    [anon_sym_iszero] = ACTIONS(1176),
    [anon_sym_and] = ACTIONS(1176),
    [anon_sym_or] = ACTIONS(1176),
    [anon_sym_xor] = ACTIONS(1176),
    [anon_sym_byte] = ACTIONS(1176),
    [anon_sym_shl] = ACTIONS(1176),
    [anon_sym_shr] = ACTIONS(1176),
    [anon_sym_sar] = ACTIONS(1176),
    [anon_sym_addmod] = ACTIONS(1176),
    [anon_sym_mulmod] = ACTIONS(1176),
    [anon_sym_signextend] = ACTIONS(1176),
    [anon_sym_keccak256] = ACTIONS(1176),
    [anon_sym_pop] = ACTIONS(1176),
    [anon_sym_mload] = ACTIONS(1176),
    [anon_sym_mstore] = ACTIONS(1176),
    [anon_sym_mstore8] = ACTIONS(1176),
    [anon_sym_sload] = ACTIONS(1176),
    [anon_sym_sstore] = ACTIONS(1176),
    [anon_sym_msize] = ACTIONS(1176),
    [anon_sym_gas] = ACTIONS(1176),
    [anon_sym_address] = ACTIONS(1176),
    [anon_sym_balance] = ACTIONS(1176),
    [anon_sym_selfbalance] = ACTIONS(1176),
    [anon_sym_caller] = ACTIONS(1176),
    [anon_sym_callvalue] = ACTIONS(1176),
    [anon_sym_calldataload] = ACTIONS(1176),
    [anon_sym_calldatasize] = ACTIONS(1176),
    [anon_sym_calldatacopy] = ACTIONS(1176),
    [anon_sym_extcodesize] = ACTIONS(1176),
    [anon_sym_extcodecopy] = ACTIONS(1176),
    [anon_sym_returndatasize] = ACTIONS(1176),
    [anon_sym_returndatacopy] = ACTIONS(1176),
    [anon_sym_extcodehash] = ACTIONS(1176),
    [anon_sym_create] = ACTIONS(1176),
    [anon_sym_create2] = ACTIONS(1176),
    [anon_sym_call] = ACTIONS(1176),
    [anon_sym_callcode] = ACTIONS(1176),
    [anon_sym_delegatecall] = ACTIONS(1176),
    [anon_sym_staticcall] = ACTIONS(1176),
    [anon_sym_return] = ACTIONS(1176),
    [anon_sym_revert] = ACTIONS(1176),
    [anon_sym_selfdestruct] = ACTIONS(1176),
    [anon_sym_invalid] = ACTIONS(1176),
    [anon_sym_log0] = ACTIONS(1176),
    [anon_sym_log1] = ACTIONS(1176),
    [anon_sym_log2] = ACTIONS(1176),
    [anon_sym_log3] = ACTIONS(1176),
    [anon_sym_log4] = ACTIONS(1176),
    [anon_sym_chainid] = ACTIONS(1176),
    [anon_sym_origin] = ACTIONS(1176),
    [anon_sym_gasprice] = ACTIONS(1176),
    [anon_sym_blockhash] = ACTIONS(1176),
    [anon_sym_coinbase] = ACTIONS(1176),
    [anon_sym_timestamp] = ACTIONS(1176),
    [anon_sym_number] = ACTIONS(1176),
    [anon_sym_difficulty] = ACTIONS(1176),
    [anon_sym_gaslimit] = ACTIONS(1176),
    [anon_sym_hex] = ACTIONS(1176),
    [anon_sym_DQUOTE] = ACTIONS(1178),
    [anon_sym_SQUOTE] = ACTIONS(1178),
    [sym_comment] = ACTIONS(3),
  },
  [330] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(831),
    [sym_yul_path] = STATE(831),
    [sym__yul_literal] = STATE(831),
    [sym_yul_string_literal] = STATE(831),
    [sym_yul_boolean] = STATE(831),
    [sym_yul_function_call] = STATE(831),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(831),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_RPAREN] = ACTIONS(1186),
    [sym_yul_decimal_number] = ACTIONS(1188),
    [sym_yul_hex_number] = ACTIONS(1190),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
  },
  [331] = {
    [sym_yul_identifier] = STATE(328),
    [sym_identifier] = ACTIONS(1192),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym_RBRACE] = ACTIONS(1194),
    [anon_sym_for] = ACTIONS(1192),
    [sym_yul_leave] = ACTIONS(1192),
    [anon_sym_break] = ACTIONS(1192),
    [anon_sym_continue] = ACTIONS(1192),
    [sym_yul_decimal_number] = ACTIONS(1192),
    [sym_yul_hex_number] = ACTIONS(1194),
    [anon_sym_true] = ACTIONS(1192),
    [anon_sym_false] = ACTIONS(1192),
    [anon_sym_let] = ACTIONS(1192),
    [anon_sym_COLON_EQ] = ACTIONS(1196),
    [anon_sym_if] = ACTIONS(1192),
    [anon_sym_switch] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(1192),
    [anon_sym_stop] = ACTIONS(1192),
    [anon_sym_add] = ACTIONS(1192),
    [anon_sym_sub] = ACTIONS(1192),
    [anon_sym_mul] = ACTIONS(1192),
    [anon_sym_div] = ACTIONS(1192),
    [anon_sym_sdiv] = ACTIONS(1192),
    [anon_sym_mod] = ACTIONS(1192),
    [anon_sym_smod] = ACTIONS(1192),
    [anon_sym_exp] = ACTIONS(1192),
    [anon_sym_not] = ACTIONS(1192),
    [anon_sym_lt] = ACTIONS(1192),
    [anon_sym_gt] = ACTIONS(1192),
    [anon_sym_slt] = ACTIONS(1192),
    [anon_sym_sgt] = ACTIONS(1192),
    [anon_sym_eq] = ACTIONS(1192),
    [anon_sym_iszero] = ACTIONS(1192),
    [anon_sym_and] = ACTIONS(1192),
    [anon_sym_or] = ACTIONS(1192),
    [anon_sym_xor] = ACTIONS(1192),
    [anon_sym_byte] = ACTIONS(1192),
    [anon_sym_shl] = ACTIONS(1192),
    [anon_sym_shr] = ACTIONS(1192),
    [anon_sym_sar] = ACTIONS(1192),
    [anon_sym_addmod] = ACTIONS(1192),
    [anon_sym_mulmod] = ACTIONS(1192),
    [anon_sym_signextend] = ACTIONS(1192),
    [anon_sym_keccak256] = ACTIONS(1192),
    [anon_sym_pop] = ACTIONS(1192),
    [anon_sym_mload] = ACTIONS(1192),
    [anon_sym_mstore] = ACTIONS(1192),
    [anon_sym_mstore8] = ACTIONS(1192),
    [anon_sym_sload] = ACTIONS(1192),
    [anon_sym_sstore] = ACTIONS(1192),
    [anon_sym_msize] = ACTIONS(1192),
    [anon_sym_gas] = ACTIONS(1192),
    [anon_sym_address] = ACTIONS(1192),
    [anon_sym_balance] = ACTIONS(1192),
    [anon_sym_selfbalance] = ACTIONS(1192),
    [anon_sym_caller] = ACTIONS(1192),
    [anon_sym_callvalue] = ACTIONS(1192),
    [anon_sym_calldataload] = ACTIONS(1192),
    [anon_sym_calldatasize] = ACTIONS(1192),
    [anon_sym_calldatacopy] = ACTIONS(1192),
    [anon_sym_extcodesize] = ACTIONS(1192),
    [anon_sym_extcodecopy] = ACTIONS(1192),
    [anon_sym_returndatasize] = ACTIONS(1192),
    [anon_sym_returndatacopy] = ACTIONS(1192),
    [anon_sym_extcodehash] = ACTIONS(1192),
    [anon_sym_create] = ACTIONS(1192),
    [anon_sym_create2] = ACTIONS(1192),
    [anon_sym_call] = ACTIONS(1192),
    [anon_sym_callcode] = ACTIONS(1192),
    [anon_sym_delegatecall] = ACTIONS(1192),
    [anon_sym_staticcall] = ACTIONS(1192),
    [anon_sym_return] = ACTIONS(1192),
    [anon_sym_revert] = ACTIONS(1192),
    [anon_sym_selfdestruct] = ACTIONS(1192),
    [anon_sym_invalid] = ACTIONS(1192),
    [anon_sym_log0] = ACTIONS(1192),
    [anon_sym_log1] = ACTIONS(1192),
    [anon_sym_log2] = ACTIONS(1192),
    [anon_sym_log3] = ACTIONS(1192),
    [anon_sym_log4] = ACTIONS(1192),
    [anon_sym_chainid] = ACTIONS(1192),
    [anon_sym_origin] = ACTIONS(1192),
    [anon_sym_gasprice] = ACTIONS(1192),
    [anon_sym_blockhash] = ACTIONS(1192),
    [anon_sym_coinbase] = ACTIONS(1192),
    [anon_sym_timestamp] = ACTIONS(1192),
    [anon_sym_number] = ACTIONS(1192),
    [anon_sym_difficulty] = ACTIONS(1192),
    [anon_sym_gaslimit] = ACTIONS(1192),
    [anon_sym_hex] = ACTIONS(1192),
    [anon_sym_DQUOTE] = ACTIONS(1194),
    [anon_sym_SQUOTE] = ACTIONS(1194),
    [sym_comment] = ACTIONS(3),
  },
  [332] = {
    [sym_yul_identifier] = STATE(328),
    [sym_identifier] = ACTIONS(1168),
    [anon_sym_LBRACE] = ACTIONS(1170),
    [anon_sym_RBRACE] = ACTIONS(1170),
    [anon_sym_for] = ACTIONS(1168),
    [sym_yul_leave] = ACTIONS(1168),
    [anon_sym_break] = ACTIONS(1168),
    [anon_sym_continue] = ACTIONS(1168),
    [sym_yul_decimal_number] = ACTIONS(1168),
    [sym_yul_hex_number] = ACTIONS(1170),
    [anon_sym_true] = ACTIONS(1168),
    [anon_sym_false] = ACTIONS(1168),
    [anon_sym_let] = ACTIONS(1168),
    [anon_sym_COLON_EQ] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1168),
    [anon_sym_switch] = ACTIONS(1168),
    [anon_sym_function] = ACTIONS(1168),
    [anon_sym_stop] = ACTIONS(1168),
    [anon_sym_add] = ACTIONS(1168),
    [anon_sym_sub] = ACTIONS(1168),
    [anon_sym_mul] = ACTIONS(1168),
    [anon_sym_div] = ACTIONS(1168),
    [anon_sym_sdiv] = ACTIONS(1168),
    [anon_sym_mod] = ACTIONS(1168),
    [anon_sym_smod] = ACTIONS(1168),
    [anon_sym_exp] = ACTIONS(1168),
    [anon_sym_not] = ACTIONS(1168),
    [anon_sym_lt] = ACTIONS(1168),
    [anon_sym_gt] = ACTIONS(1168),
    [anon_sym_slt] = ACTIONS(1168),
    [anon_sym_sgt] = ACTIONS(1168),
    [anon_sym_eq] = ACTIONS(1168),
    [anon_sym_iszero] = ACTIONS(1168),
    [anon_sym_and] = ACTIONS(1168),
    [anon_sym_or] = ACTIONS(1168),
    [anon_sym_xor] = ACTIONS(1168),
    [anon_sym_byte] = ACTIONS(1168),
    [anon_sym_shl] = ACTIONS(1168),
    [anon_sym_shr] = ACTIONS(1168),
    [anon_sym_sar] = ACTIONS(1168),
    [anon_sym_addmod] = ACTIONS(1168),
    [anon_sym_mulmod] = ACTIONS(1168),
    [anon_sym_signextend] = ACTIONS(1168),
    [anon_sym_keccak256] = ACTIONS(1168),
    [anon_sym_pop] = ACTIONS(1168),
    [anon_sym_mload] = ACTIONS(1168),
    [anon_sym_mstore] = ACTIONS(1168),
    [anon_sym_mstore8] = ACTIONS(1168),
    [anon_sym_sload] = ACTIONS(1168),
    [anon_sym_sstore] = ACTIONS(1168),
    [anon_sym_msize] = ACTIONS(1168),
    [anon_sym_gas] = ACTIONS(1168),
    [anon_sym_address] = ACTIONS(1168),
    [anon_sym_balance] = ACTIONS(1168),
    [anon_sym_selfbalance] = ACTIONS(1168),
    [anon_sym_caller] = ACTIONS(1168),
    [anon_sym_callvalue] = ACTIONS(1168),
    [anon_sym_calldataload] = ACTIONS(1168),
    [anon_sym_calldatasize] = ACTIONS(1168),
    [anon_sym_calldatacopy] = ACTIONS(1168),
    [anon_sym_extcodesize] = ACTIONS(1168),
    [anon_sym_extcodecopy] = ACTIONS(1168),
    [anon_sym_returndatasize] = ACTIONS(1168),
    [anon_sym_returndatacopy] = ACTIONS(1168),
    [anon_sym_extcodehash] = ACTIONS(1168),
    [anon_sym_create] = ACTIONS(1168),
    [anon_sym_create2] = ACTIONS(1168),
    [anon_sym_call] = ACTIONS(1168),
    [anon_sym_callcode] = ACTIONS(1168),
    [anon_sym_delegatecall] = ACTIONS(1168),
    [anon_sym_staticcall] = ACTIONS(1168),
    [anon_sym_return] = ACTIONS(1168),
    [anon_sym_revert] = ACTIONS(1168),
    [anon_sym_selfdestruct] = ACTIONS(1168),
    [anon_sym_invalid] = ACTIONS(1168),
    [anon_sym_log0] = ACTIONS(1168),
    [anon_sym_log1] = ACTIONS(1168),
    [anon_sym_log2] = ACTIONS(1168),
    [anon_sym_log3] = ACTIONS(1168),
    [anon_sym_log4] = ACTIONS(1168),
    [anon_sym_chainid] = ACTIONS(1168),
    [anon_sym_origin] = ACTIONS(1168),
    [anon_sym_gasprice] = ACTIONS(1168),
    [anon_sym_blockhash] = ACTIONS(1168),
    [anon_sym_coinbase] = ACTIONS(1168),
    [anon_sym_timestamp] = ACTIONS(1168),
    [anon_sym_number] = ACTIONS(1168),
    [anon_sym_difficulty] = ACTIONS(1168),
    [anon_sym_gaslimit] = ACTIONS(1168),
    [anon_sym_hex] = ACTIONS(1168),
    [anon_sym_DQUOTE] = ACTIONS(1170),
    [anon_sym_SQUOTE] = ACTIONS(1170),
    [sym_comment] = ACTIONS(3),
  },
  [333] = {
    [sym_identifier] = ACTIONS(1198),
    [anon_sym_LBRACE] = ACTIONS(1200),
    [anon_sym_RBRACE] = ACTIONS(1200),
    [anon_sym_for] = ACTIONS(1198),
    [sym_yul_leave] = ACTIONS(1198),
    [anon_sym_break] = ACTIONS(1198),
    [anon_sym_continue] = ACTIONS(1198),
    [sym_yul_decimal_number] = ACTIONS(1198),
    [sym_yul_hex_number] = ACTIONS(1200),
    [anon_sym_true] = ACTIONS(1198),
    [anon_sym_false] = ACTIONS(1198),
    [anon_sym_let] = ACTIONS(1198),
    [anon_sym_if] = ACTIONS(1198),
    [anon_sym_switch] = ACTIONS(1198),
    [anon_sym_default] = ACTIONS(1198),
    [anon_sym_case] = ACTIONS(1198),
    [anon_sym_function] = ACTIONS(1198),
    [anon_sym_stop] = ACTIONS(1198),
    [anon_sym_add] = ACTIONS(1198),
    [anon_sym_sub] = ACTIONS(1198),
    [anon_sym_mul] = ACTIONS(1198),
    [anon_sym_div] = ACTIONS(1198),
    [anon_sym_sdiv] = ACTIONS(1198),
    [anon_sym_mod] = ACTIONS(1198),
    [anon_sym_smod] = ACTIONS(1198),
    [anon_sym_exp] = ACTIONS(1198),
    [anon_sym_not] = ACTIONS(1198),
    [anon_sym_lt] = ACTIONS(1198),
    [anon_sym_gt] = ACTIONS(1198),
    [anon_sym_slt] = ACTIONS(1198),
    [anon_sym_sgt] = ACTIONS(1198),
    [anon_sym_eq] = ACTIONS(1198),
    [anon_sym_iszero] = ACTIONS(1198),
    [anon_sym_and] = ACTIONS(1198),
    [anon_sym_or] = ACTIONS(1198),
    [anon_sym_xor] = ACTIONS(1198),
    [anon_sym_byte] = ACTIONS(1198),
    [anon_sym_shl] = ACTIONS(1198),
    [anon_sym_shr] = ACTIONS(1198),
    [anon_sym_sar] = ACTIONS(1198),
    [anon_sym_addmod] = ACTIONS(1198),
    [anon_sym_mulmod] = ACTIONS(1198),
    [anon_sym_signextend] = ACTIONS(1198),
    [anon_sym_keccak256] = ACTIONS(1198),
    [anon_sym_pop] = ACTIONS(1198),
    [anon_sym_mload] = ACTIONS(1198),
    [anon_sym_mstore] = ACTIONS(1198),
    [anon_sym_mstore8] = ACTIONS(1198),
    [anon_sym_sload] = ACTIONS(1198),
    [anon_sym_sstore] = ACTIONS(1198),
    [anon_sym_msize] = ACTIONS(1198),
    [anon_sym_gas] = ACTIONS(1198),
    [anon_sym_address] = ACTIONS(1198),
    [anon_sym_balance] = ACTIONS(1198),
    [anon_sym_selfbalance] = ACTIONS(1198),
    [anon_sym_caller] = ACTIONS(1198),
    [anon_sym_callvalue] = ACTIONS(1198),
    [anon_sym_calldataload] = ACTIONS(1198),
    [anon_sym_calldatasize] = ACTIONS(1198),
    [anon_sym_calldatacopy] = ACTIONS(1198),
    [anon_sym_extcodesize] = ACTIONS(1198),
    [anon_sym_extcodecopy] = ACTIONS(1198),
    [anon_sym_returndatasize] = ACTIONS(1198),
    [anon_sym_returndatacopy] = ACTIONS(1198),
    [anon_sym_extcodehash] = ACTIONS(1198),
    [anon_sym_create] = ACTIONS(1198),
    [anon_sym_create2] = ACTIONS(1198),
    [anon_sym_call] = ACTIONS(1198),
    [anon_sym_callcode] = ACTIONS(1198),
    [anon_sym_delegatecall] = ACTIONS(1198),
    [anon_sym_staticcall] = ACTIONS(1198),
    [anon_sym_return] = ACTIONS(1198),
    [anon_sym_revert] = ACTIONS(1198),
    [anon_sym_selfdestruct] = ACTIONS(1198),
    [anon_sym_invalid] = ACTIONS(1198),
    [anon_sym_log0] = ACTIONS(1198),
    [anon_sym_log1] = ACTIONS(1198),
    [anon_sym_log2] = ACTIONS(1198),
    [anon_sym_log3] = ACTIONS(1198),
    [anon_sym_log4] = ACTIONS(1198),
    [anon_sym_chainid] = ACTIONS(1198),
    [anon_sym_origin] = ACTIONS(1198),
    [anon_sym_gasprice] = ACTIONS(1198),
    [anon_sym_blockhash] = ACTIONS(1198),
    [anon_sym_coinbase] = ACTIONS(1198),
    [anon_sym_timestamp] = ACTIONS(1198),
    [anon_sym_number] = ACTIONS(1198),
    [anon_sym_difficulty] = ACTIONS(1198),
    [anon_sym_gaslimit] = ACTIONS(1198),
    [anon_sym_hex] = ACTIONS(1198),
    [anon_sym_DQUOTE] = ACTIONS(1200),
    [anon_sym_SQUOTE] = ACTIONS(1200),
    [sym_comment] = ACTIONS(3),
  },
  [334] = {
    [sym_identifier] = ACTIONS(1202),
    [anon_sym_LBRACE] = ACTIONS(1204),
    [anon_sym_RBRACE] = ACTIONS(1204),
    [anon_sym_for] = ACTIONS(1202),
    [sym_yul_leave] = ACTIONS(1202),
    [anon_sym_break] = ACTIONS(1202),
    [anon_sym_continue] = ACTIONS(1202),
    [sym_yul_decimal_number] = ACTIONS(1202),
    [sym_yul_hex_number] = ACTIONS(1204),
    [anon_sym_true] = ACTIONS(1202),
    [anon_sym_false] = ACTIONS(1202),
    [anon_sym_let] = ACTIONS(1202),
    [anon_sym_if] = ACTIONS(1202),
    [anon_sym_switch] = ACTIONS(1202),
    [anon_sym_default] = ACTIONS(1202),
    [anon_sym_case] = ACTIONS(1202),
    [anon_sym_function] = ACTIONS(1202),
    [anon_sym_stop] = ACTIONS(1202),
    [anon_sym_add] = ACTIONS(1202),
    [anon_sym_sub] = ACTIONS(1202),
    [anon_sym_mul] = ACTIONS(1202),
    [anon_sym_div] = ACTIONS(1202),
    [anon_sym_sdiv] = ACTIONS(1202),
    [anon_sym_mod] = ACTIONS(1202),
    [anon_sym_smod] = ACTIONS(1202),
    [anon_sym_exp] = ACTIONS(1202),
    [anon_sym_not] = ACTIONS(1202),
    [anon_sym_lt] = ACTIONS(1202),
    [anon_sym_gt] = ACTIONS(1202),
    [anon_sym_slt] = ACTIONS(1202),
    [anon_sym_sgt] = ACTIONS(1202),
    [anon_sym_eq] = ACTIONS(1202),
    [anon_sym_iszero] = ACTIONS(1202),
    [anon_sym_and] = ACTIONS(1202),
    [anon_sym_or] = ACTIONS(1202),
    [anon_sym_xor] = ACTIONS(1202),
    [anon_sym_byte] = ACTIONS(1202),
    [anon_sym_shl] = ACTIONS(1202),
    [anon_sym_shr] = ACTIONS(1202),
    [anon_sym_sar] = ACTIONS(1202),
    [anon_sym_addmod] = ACTIONS(1202),
    [anon_sym_mulmod] = ACTIONS(1202),
    [anon_sym_signextend] = ACTIONS(1202),
    [anon_sym_keccak256] = ACTIONS(1202),
    [anon_sym_pop] = ACTIONS(1202),
    [anon_sym_mload] = ACTIONS(1202),
    [anon_sym_mstore] = ACTIONS(1202),
    [anon_sym_mstore8] = ACTIONS(1202),
    [anon_sym_sload] = ACTIONS(1202),
    [anon_sym_sstore] = ACTIONS(1202),
    [anon_sym_msize] = ACTIONS(1202),
    [anon_sym_gas] = ACTIONS(1202),
    [anon_sym_address] = ACTIONS(1202),
    [anon_sym_balance] = ACTIONS(1202),
    [anon_sym_selfbalance] = ACTIONS(1202),
    [anon_sym_caller] = ACTIONS(1202),
    [anon_sym_callvalue] = ACTIONS(1202),
    [anon_sym_calldataload] = ACTIONS(1202),
    [anon_sym_calldatasize] = ACTIONS(1202),
    [anon_sym_calldatacopy] = ACTIONS(1202),
    [anon_sym_extcodesize] = ACTIONS(1202),
    [anon_sym_extcodecopy] = ACTIONS(1202),
    [anon_sym_returndatasize] = ACTIONS(1202),
    [anon_sym_returndatacopy] = ACTIONS(1202),
    [anon_sym_extcodehash] = ACTIONS(1202),
    [anon_sym_create] = ACTIONS(1202),
    [anon_sym_create2] = ACTIONS(1202),
    [anon_sym_call] = ACTIONS(1202),
    [anon_sym_callcode] = ACTIONS(1202),
    [anon_sym_delegatecall] = ACTIONS(1202),
    [anon_sym_staticcall] = ACTIONS(1202),
    [anon_sym_return] = ACTIONS(1202),
    [anon_sym_revert] = ACTIONS(1202),
    [anon_sym_selfdestruct] = ACTIONS(1202),
    [anon_sym_invalid] = ACTIONS(1202),
    [anon_sym_log0] = ACTIONS(1202),
    [anon_sym_log1] = ACTIONS(1202),
    [anon_sym_log2] = ACTIONS(1202),
    [anon_sym_log3] = ACTIONS(1202),
    [anon_sym_log4] = ACTIONS(1202),
    [anon_sym_chainid] = ACTIONS(1202),
    [anon_sym_origin] = ACTIONS(1202),
    [anon_sym_gasprice] = ACTIONS(1202),
    [anon_sym_blockhash] = ACTIONS(1202),
    [anon_sym_coinbase] = ACTIONS(1202),
    [anon_sym_timestamp] = ACTIONS(1202),
    [anon_sym_number] = ACTIONS(1202),
    [anon_sym_difficulty] = ACTIONS(1202),
    [anon_sym_gaslimit] = ACTIONS(1202),
    [anon_sym_hex] = ACTIONS(1202),
    [anon_sym_DQUOTE] = ACTIONS(1204),
    [anon_sym_SQUOTE] = ACTIONS(1204),
    [sym_comment] = ACTIONS(3),
  },
  [335] = {
    [sym_identifier] = ACTIONS(1206),
    [anon_sym_LBRACE] = ACTIONS(1208),
    [anon_sym_RBRACE] = ACTIONS(1208),
    [anon_sym_for] = ACTIONS(1206),
    [sym_yul_leave] = ACTIONS(1206),
    [anon_sym_break] = ACTIONS(1206),
    [anon_sym_continue] = ACTIONS(1206),
    [sym_yul_decimal_number] = ACTIONS(1206),
    [sym_yul_hex_number] = ACTIONS(1208),
    [anon_sym_true] = ACTIONS(1206),
    [anon_sym_false] = ACTIONS(1206),
    [anon_sym_let] = ACTIONS(1206),
    [anon_sym_if] = ACTIONS(1206),
    [anon_sym_switch] = ACTIONS(1206),
    [anon_sym_default] = ACTIONS(1206),
    [anon_sym_case] = ACTIONS(1206),
    [anon_sym_function] = ACTIONS(1206),
    [anon_sym_stop] = ACTIONS(1206),
    [anon_sym_add] = ACTIONS(1206),
    [anon_sym_sub] = ACTIONS(1206),
    [anon_sym_mul] = ACTIONS(1206),
    [anon_sym_div] = ACTIONS(1206),
    [anon_sym_sdiv] = ACTIONS(1206),
    [anon_sym_mod] = ACTIONS(1206),
    [anon_sym_smod] = ACTIONS(1206),
    [anon_sym_exp] = ACTIONS(1206),
    [anon_sym_not] = ACTIONS(1206),
    [anon_sym_lt] = ACTIONS(1206),
    [anon_sym_gt] = ACTIONS(1206),
    [anon_sym_slt] = ACTIONS(1206),
    [anon_sym_sgt] = ACTIONS(1206),
    [anon_sym_eq] = ACTIONS(1206),
    [anon_sym_iszero] = ACTIONS(1206),
    [anon_sym_and] = ACTIONS(1206),
    [anon_sym_or] = ACTIONS(1206),
    [anon_sym_xor] = ACTIONS(1206),
    [anon_sym_byte] = ACTIONS(1206),
    [anon_sym_shl] = ACTIONS(1206),
    [anon_sym_shr] = ACTIONS(1206),
    [anon_sym_sar] = ACTIONS(1206),
    [anon_sym_addmod] = ACTIONS(1206),
    [anon_sym_mulmod] = ACTIONS(1206),
    [anon_sym_signextend] = ACTIONS(1206),
    [anon_sym_keccak256] = ACTIONS(1206),
    [anon_sym_pop] = ACTIONS(1206),
    [anon_sym_mload] = ACTIONS(1206),
    [anon_sym_mstore] = ACTIONS(1206),
    [anon_sym_mstore8] = ACTIONS(1206),
    [anon_sym_sload] = ACTIONS(1206),
    [anon_sym_sstore] = ACTIONS(1206),
    [anon_sym_msize] = ACTIONS(1206),
    [anon_sym_gas] = ACTIONS(1206),
    [anon_sym_address] = ACTIONS(1206),
    [anon_sym_balance] = ACTIONS(1206),
    [anon_sym_selfbalance] = ACTIONS(1206),
    [anon_sym_caller] = ACTIONS(1206),
    [anon_sym_callvalue] = ACTIONS(1206),
    [anon_sym_calldataload] = ACTIONS(1206),
    [anon_sym_calldatasize] = ACTIONS(1206),
    [anon_sym_calldatacopy] = ACTIONS(1206),
    [anon_sym_extcodesize] = ACTIONS(1206),
    [anon_sym_extcodecopy] = ACTIONS(1206),
    [anon_sym_returndatasize] = ACTIONS(1206),
    [anon_sym_returndatacopy] = ACTIONS(1206),
    [anon_sym_extcodehash] = ACTIONS(1206),
    [anon_sym_create] = ACTIONS(1206),
    [anon_sym_create2] = ACTIONS(1206),
    [anon_sym_call] = ACTIONS(1206),
    [anon_sym_callcode] = ACTIONS(1206),
    [anon_sym_delegatecall] = ACTIONS(1206),
    [anon_sym_staticcall] = ACTIONS(1206),
    [anon_sym_return] = ACTIONS(1206),
    [anon_sym_revert] = ACTIONS(1206),
    [anon_sym_selfdestruct] = ACTIONS(1206),
    [anon_sym_invalid] = ACTIONS(1206),
    [anon_sym_log0] = ACTIONS(1206),
    [anon_sym_log1] = ACTIONS(1206),
    [anon_sym_log2] = ACTIONS(1206),
    [anon_sym_log3] = ACTIONS(1206),
    [anon_sym_log4] = ACTIONS(1206),
    [anon_sym_chainid] = ACTIONS(1206),
    [anon_sym_origin] = ACTIONS(1206),
    [anon_sym_gasprice] = ACTIONS(1206),
    [anon_sym_blockhash] = ACTIONS(1206),
    [anon_sym_coinbase] = ACTIONS(1206),
    [anon_sym_timestamp] = ACTIONS(1206),
    [anon_sym_number] = ACTIONS(1206),
    [anon_sym_difficulty] = ACTIONS(1206),
    [anon_sym_gaslimit] = ACTIONS(1206),
    [anon_sym_hex] = ACTIONS(1206),
    [anon_sym_DQUOTE] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1208),
    [sym_comment] = ACTIONS(3),
  },
  [336] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(831),
    [sym_yul_path] = STATE(831),
    [sym__yul_literal] = STATE(831),
    [sym_yul_string_literal] = STATE(831),
    [sym_yul_boolean] = STATE(831),
    [sym_yul_function_call] = STATE(831),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(831),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_RPAREN] = ACTIONS(1210),
    [sym_yul_decimal_number] = ACTIONS(1188),
    [sym_yul_hex_number] = ACTIONS(1190),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
  },
  [337] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(729),
    [sym_yul_path] = STATE(729),
    [sym__yul_literal] = STATE(729),
    [sym_yul_string_literal] = STATE(729),
    [sym_yul_boolean] = STATE(729),
    [sym_yul_function_call] = STATE(729),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(729),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_RPAREN] = ACTIONS(1212),
    [sym_yul_decimal_number] = ACTIONS(1214),
    [sym_yul_hex_number] = ACTIONS(1216),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
  },
  [338] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(352),
    [sym_yul_path] = STATE(352),
    [sym__yul_literal] = STATE(352),
    [sym_yul_string_literal] = STATE(352),
    [sym_yul_boolean] = STATE(352),
    [sym_yul_function_call] = STATE(351),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(352),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(1184),
    [sym_yul_decimal_number] = ACTIONS(1218),
    [sym_yul_hex_number] = ACTIONS(1220),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [339] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(828),
    [sym_yul_path] = STATE(828),
    [sym__yul_literal] = STATE(828),
    [sym_yul_string_literal] = STATE(828),
    [sym_yul_boolean] = STATE(828),
    [sym_yul_function_call] = STATE(828),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(828),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [sym_identifier] = ACTIONS(1184),
    [sym_yul_decimal_number] = ACTIONS(1222),
    [sym_yul_hex_number] = ACTIONS(1224),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
  },
  [340] = {
    [aux_sym_hex_string_literal_repeat2] = STATE(344),
    [sym_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym_RBRACE] = ACTIONS(1228),
    [anon_sym_for] = ACTIONS(1226),
    [sym_yul_leave] = ACTIONS(1226),
    [anon_sym_break] = ACTIONS(1226),
    [anon_sym_continue] = ACTIONS(1226),
    [sym_yul_decimal_number] = ACTIONS(1226),
    [sym_yul_hex_number] = ACTIONS(1228),
    [anon_sym_true] = ACTIONS(1226),
    [anon_sym_false] = ACTIONS(1226),
    [anon_sym_let] = ACTIONS(1226),
    [anon_sym_if] = ACTIONS(1226),
    [anon_sym_switch] = ACTIONS(1226),
    [anon_sym_function] = ACTIONS(1226),
    [anon_sym_stop] = ACTIONS(1226),
    [anon_sym_add] = ACTIONS(1226),
    [anon_sym_sub] = ACTIONS(1226),
    [anon_sym_mul] = ACTIONS(1226),
    [anon_sym_div] = ACTIONS(1226),
    [anon_sym_sdiv] = ACTIONS(1226),
    [anon_sym_mod] = ACTIONS(1226),
    [anon_sym_smod] = ACTIONS(1226),
    [anon_sym_exp] = ACTIONS(1226),
    [anon_sym_not] = ACTIONS(1226),
    [anon_sym_lt] = ACTIONS(1226),
    [anon_sym_gt] = ACTIONS(1226),
    [anon_sym_slt] = ACTIONS(1226),
    [anon_sym_sgt] = ACTIONS(1226),
    [anon_sym_eq] = ACTIONS(1226),
    [anon_sym_iszero] = ACTIONS(1226),
    [anon_sym_and] = ACTIONS(1226),
    [anon_sym_or] = ACTIONS(1226),
    [anon_sym_xor] = ACTIONS(1226),
    [anon_sym_byte] = ACTIONS(1226),
    [anon_sym_shl] = ACTIONS(1226),
    [anon_sym_shr] = ACTIONS(1226),
    [anon_sym_sar] = ACTIONS(1226),
    [anon_sym_addmod] = ACTIONS(1226),
    [anon_sym_mulmod] = ACTIONS(1226),
    [anon_sym_signextend] = ACTIONS(1226),
    [anon_sym_keccak256] = ACTIONS(1226),
    [anon_sym_pop] = ACTIONS(1226),
    [anon_sym_mload] = ACTIONS(1226),
    [anon_sym_mstore] = ACTIONS(1226),
    [anon_sym_mstore8] = ACTIONS(1226),
    [anon_sym_sload] = ACTIONS(1226),
    [anon_sym_sstore] = ACTIONS(1226),
    [anon_sym_msize] = ACTIONS(1226),
    [anon_sym_gas] = ACTIONS(1226),
    [anon_sym_address] = ACTIONS(1226),
    [anon_sym_balance] = ACTIONS(1226),
    [anon_sym_selfbalance] = ACTIONS(1226),
    [anon_sym_caller] = ACTIONS(1226),
    [anon_sym_callvalue] = ACTIONS(1226),
    [anon_sym_calldataload] = ACTIONS(1226),
    [anon_sym_calldatasize] = ACTIONS(1226),
    [anon_sym_calldatacopy] = ACTIONS(1226),
    [anon_sym_extcodesize] = ACTIONS(1226),
    [anon_sym_extcodecopy] = ACTIONS(1226),
    [anon_sym_returndatasize] = ACTIONS(1226),
    [anon_sym_returndatacopy] = ACTIONS(1226),
    [anon_sym_extcodehash] = ACTIONS(1226),
    [anon_sym_create] = ACTIONS(1226),
    [anon_sym_create2] = ACTIONS(1226),
    [anon_sym_call] = ACTIONS(1226),
    [anon_sym_callcode] = ACTIONS(1226),
    [anon_sym_delegatecall] = ACTIONS(1226),
    [anon_sym_staticcall] = ACTIONS(1226),
    [anon_sym_return] = ACTIONS(1226),
    [anon_sym_revert] = ACTIONS(1226),
    [anon_sym_selfdestruct] = ACTIONS(1226),
    [anon_sym_invalid] = ACTIONS(1226),
    [anon_sym_log0] = ACTIONS(1226),
    [anon_sym_log1] = ACTIONS(1226),
    [anon_sym_log2] = ACTIONS(1226),
    [anon_sym_log3] = ACTIONS(1226),
    [anon_sym_log4] = ACTIONS(1226),
    [anon_sym_chainid] = ACTIONS(1226),
    [anon_sym_origin] = ACTIONS(1226),
    [anon_sym_gasprice] = ACTIONS(1226),
    [anon_sym_blockhash] = ACTIONS(1226),
    [anon_sym_coinbase] = ACTIONS(1226),
    [anon_sym_timestamp] = ACTIONS(1226),
    [anon_sym_number] = ACTIONS(1226),
    [anon_sym_difficulty] = ACTIONS(1226),
    [anon_sym_gaslimit] = ACTIONS(1226),
    [anon_sym_hex] = ACTIONS(1226),
    [anon_sym_DQUOTE] = ACTIONS(1228),
    [anon_sym_SQUOTE] = ACTIONS(1228),
    [sym_comment] = ACTIONS(3),
  },
  [341] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(803),
    [sym_yul_path] = STATE(803),
    [sym__yul_literal] = STATE(803),
    [sym_yul_string_literal] = STATE(803),
    [sym_yul_boolean] = STATE(803),
    [sym_yul_function_call] = STATE(803),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(803),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [sym_identifier] = ACTIONS(1184),
    [sym_yul_decimal_number] = ACTIONS(1230),
    [sym_yul_hex_number] = ACTIONS(1232),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
  },
  [342] = {
    [sym_identifier] = ACTIONS(1234),
    [anon_sym_LBRACE] = ACTIONS(1236),
    [anon_sym_RBRACE] = ACTIONS(1236),
    [anon_sym_for] = ACTIONS(1234),
    [sym_yul_leave] = ACTIONS(1234),
    [anon_sym_break] = ACTIONS(1234),
    [anon_sym_continue] = ACTIONS(1234),
    [sym_yul_decimal_number] = ACTIONS(1234),
    [sym_yul_hex_number] = ACTIONS(1236),
    [anon_sym_true] = ACTIONS(1234),
    [anon_sym_false] = ACTIONS(1234),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_COLON_EQ] = ACTIONS(1238),
    [anon_sym_if] = ACTIONS(1234),
    [anon_sym_switch] = ACTIONS(1234),
    [anon_sym_function] = ACTIONS(1234),
    [anon_sym_stop] = ACTIONS(1234),
    [anon_sym_add] = ACTIONS(1234),
    [anon_sym_sub] = ACTIONS(1234),
    [anon_sym_mul] = ACTIONS(1234),
    [anon_sym_div] = ACTIONS(1234),
    [anon_sym_sdiv] = ACTIONS(1234),
    [anon_sym_mod] = ACTIONS(1234),
    [anon_sym_smod] = ACTIONS(1234),
    [anon_sym_exp] = ACTIONS(1234),
    [anon_sym_not] = ACTIONS(1234),
    [anon_sym_lt] = ACTIONS(1234),
    [anon_sym_gt] = ACTIONS(1234),
    [anon_sym_slt] = ACTIONS(1234),
    [anon_sym_sgt] = ACTIONS(1234),
    [anon_sym_eq] = ACTIONS(1234),
    [anon_sym_iszero] = ACTIONS(1234),
    [anon_sym_and] = ACTIONS(1234),
    [anon_sym_or] = ACTIONS(1234),
    [anon_sym_xor] = ACTIONS(1234),
    [anon_sym_byte] = ACTIONS(1234),
    [anon_sym_shl] = ACTIONS(1234),
    [anon_sym_shr] = ACTIONS(1234),
    [anon_sym_sar] = ACTIONS(1234),
    [anon_sym_addmod] = ACTIONS(1234),
    [anon_sym_mulmod] = ACTIONS(1234),
    [anon_sym_signextend] = ACTIONS(1234),
    [anon_sym_keccak256] = ACTIONS(1234),
    [anon_sym_pop] = ACTIONS(1234),
    [anon_sym_mload] = ACTIONS(1234),
    [anon_sym_mstore] = ACTIONS(1234),
    [anon_sym_mstore8] = ACTIONS(1234),
    [anon_sym_sload] = ACTIONS(1234),
    [anon_sym_sstore] = ACTIONS(1234),
    [anon_sym_msize] = ACTIONS(1234),
    [anon_sym_gas] = ACTIONS(1234),
    [anon_sym_address] = ACTIONS(1234),
    [anon_sym_balance] = ACTIONS(1234),
    [anon_sym_selfbalance] = ACTIONS(1234),
    [anon_sym_caller] = ACTIONS(1234),
    [anon_sym_callvalue] = ACTIONS(1234),
    [anon_sym_calldataload] = ACTIONS(1234),
    [anon_sym_calldatasize] = ACTIONS(1234),
    [anon_sym_calldatacopy] = ACTIONS(1234),
    [anon_sym_extcodesize] = ACTIONS(1234),
    [anon_sym_extcodecopy] = ACTIONS(1234),
    [anon_sym_returndatasize] = ACTIONS(1234),
    [anon_sym_returndatacopy] = ACTIONS(1234),
    [anon_sym_extcodehash] = ACTIONS(1234),
    [anon_sym_create] = ACTIONS(1234),
    [anon_sym_create2] = ACTIONS(1234),
    [anon_sym_call] = ACTIONS(1234),
    [anon_sym_callcode] = ACTIONS(1234),
    [anon_sym_delegatecall] = ACTIONS(1234),
    [anon_sym_staticcall] = ACTIONS(1234),
    [anon_sym_return] = ACTIONS(1234),
    [anon_sym_revert] = ACTIONS(1234),
    [anon_sym_selfdestruct] = ACTIONS(1234),
    [anon_sym_invalid] = ACTIONS(1234),
    [anon_sym_log0] = ACTIONS(1234),
    [anon_sym_log1] = ACTIONS(1234),
    [anon_sym_log2] = ACTIONS(1234),
    [anon_sym_log3] = ACTIONS(1234),
    [anon_sym_log4] = ACTIONS(1234),
    [anon_sym_chainid] = ACTIONS(1234),
    [anon_sym_origin] = ACTIONS(1234),
    [anon_sym_gasprice] = ACTIONS(1234),
    [anon_sym_blockhash] = ACTIONS(1234),
    [anon_sym_coinbase] = ACTIONS(1234),
    [anon_sym_timestamp] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_difficulty] = ACTIONS(1234),
    [anon_sym_gaslimit] = ACTIONS(1234),
    [anon_sym_hex] = ACTIONS(1234),
    [anon_sym_DQUOTE] = ACTIONS(1236),
    [anon_sym_SQUOTE] = ACTIONS(1236),
    [sym_comment] = ACTIONS(3),
  },
  [343] = {
    [sym_identifier] = ACTIONS(1240),
    [anon_sym_LBRACE] = ACTIONS(1242),
    [anon_sym_RBRACE] = ACTIONS(1242),
    [anon_sym_for] = ACTIONS(1240),
    [sym_yul_leave] = ACTIONS(1240),
    [anon_sym_break] = ACTIONS(1240),
    [anon_sym_continue] = ACTIONS(1240),
    [sym_yul_decimal_number] = ACTIONS(1240),
    [sym_yul_hex_number] = ACTIONS(1242),
    [anon_sym_true] = ACTIONS(1240),
    [anon_sym_false] = ACTIONS(1240),
    [anon_sym_let] = ACTIONS(1240),
    [anon_sym_COLON_EQ] = ACTIONS(1244),
    [anon_sym_if] = ACTIONS(1240),
    [anon_sym_switch] = ACTIONS(1240),
    [anon_sym_function] = ACTIONS(1240),
    [anon_sym_stop] = ACTIONS(1240),
    [anon_sym_add] = ACTIONS(1240),
    [anon_sym_sub] = ACTIONS(1240),
    [anon_sym_mul] = ACTIONS(1240),
    [anon_sym_div] = ACTIONS(1240),
    [anon_sym_sdiv] = ACTIONS(1240),
    [anon_sym_mod] = ACTIONS(1240),
    [anon_sym_smod] = ACTIONS(1240),
    [anon_sym_exp] = ACTIONS(1240),
    [anon_sym_not] = ACTIONS(1240),
    [anon_sym_lt] = ACTIONS(1240),
    [anon_sym_gt] = ACTIONS(1240),
    [anon_sym_slt] = ACTIONS(1240),
    [anon_sym_sgt] = ACTIONS(1240),
    [anon_sym_eq] = ACTIONS(1240),
    [anon_sym_iszero] = ACTIONS(1240),
    [anon_sym_and] = ACTIONS(1240),
    [anon_sym_or] = ACTIONS(1240),
    [anon_sym_xor] = ACTIONS(1240),
    [anon_sym_byte] = ACTIONS(1240),
    [anon_sym_shl] = ACTIONS(1240),
    [anon_sym_shr] = ACTIONS(1240),
    [anon_sym_sar] = ACTIONS(1240),
    [anon_sym_addmod] = ACTIONS(1240),
    [anon_sym_mulmod] = ACTIONS(1240),
    [anon_sym_signextend] = ACTIONS(1240),
    [anon_sym_keccak256] = ACTIONS(1240),
    [anon_sym_pop] = ACTIONS(1240),
    [anon_sym_mload] = ACTIONS(1240),
    [anon_sym_mstore] = ACTIONS(1240),
    [anon_sym_mstore8] = ACTIONS(1240),
    [anon_sym_sload] = ACTIONS(1240),
    [anon_sym_sstore] = ACTIONS(1240),
    [anon_sym_msize] = ACTIONS(1240),
    [anon_sym_gas] = ACTIONS(1240),
    [anon_sym_address] = ACTIONS(1240),
    [anon_sym_balance] = ACTIONS(1240),
    [anon_sym_selfbalance] = ACTIONS(1240),
    [anon_sym_caller] = ACTIONS(1240),
    [anon_sym_callvalue] = ACTIONS(1240),
    [anon_sym_calldataload] = ACTIONS(1240),
    [anon_sym_calldatasize] = ACTIONS(1240),
    [anon_sym_calldatacopy] = ACTIONS(1240),
    [anon_sym_extcodesize] = ACTIONS(1240),
    [anon_sym_extcodecopy] = ACTIONS(1240),
    [anon_sym_returndatasize] = ACTIONS(1240),
    [anon_sym_returndatacopy] = ACTIONS(1240),
    [anon_sym_extcodehash] = ACTIONS(1240),
    [anon_sym_create] = ACTIONS(1240),
    [anon_sym_create2] = ACTIONS(1240),
    [anon_sym_call] = ACTIONS(1240),
    [anon_sym_callcode] = ACTIONS(1240),
    [anon_sym_delegatecall] = ACTIONS(1240),
    [anon_sym_staticcall] = ACTIONS(1240),
    [anon_sym_return] = ACTIONS(1240),
    [anon_sym_revert] = ACTIONS(1240),
    [anon_sym_selfdestruct] = ACTIONS(1240),
    [anon_sym_invalid] = ACTIONS(1240),
    [anon_sym_log0] = ACTIONS(1240),
    [anon_sym_log1] = ACTIONS(1240),
    [anon_sym_log2] = ACTIONS(1240),
    [anon_sym_log3] = ACTIONS(1240),
    [anon_sym_log4] = ACTIONS(1240),
    [anon_sym_chainid] = ACTIONS(1240),
    [anon_sym_origin] = ACTIONS(1240),
    [anon_sym_gasprice] = ACTIONS(1240),
    [anon_sym_blockhash] = ACTIONS(1240),
    [anon_sym_coinbase] = ACTIONS(1240),
    [anon_sym_timestamp] = ACTIONS(1240),
    [anon_sym_number] = ACTIONS(1240),
    [anon_sym_difficulty] = ACTIONS(1240),
    [anon_sym_gaslimit] = ACTIONS(1240),
    [anon_sym_hex] = ACTIONS(1240),
    [anon_sym_DQUOTE] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1242),
    [sym_comment] = ACTIONS(3),
  },
  [344] = {
    [aux_sym_hex_string_literal_repeat2] = STATE(344),
    [sym_identifier] = ACTIONS(1246),
    [anon_sym_LBRACE] = ACTIONS(1248),
    [anon_sym_RBRACE] = ACTIONS(1248),
    [anon_sym_for] = ACTIONS(1246),
    [sym_yul_leave] = ACTIONS(1246),
    [anon_sym_break] = ACTIONS(1246),
    [anon_sym_continue] = ACTIONS(1246),
    [sym_yul_decimal_number] = ACTIONS(1246),
    [sym_yul_hex_number] = ACTIONS(1248),
    [anon_sym_true] = ACTIONS(1246),
    [anon_sym_false] = ACTIONS(1246),
    [anon_sym_let] = ACTIONS(1246),
    [anon_sym_if] = ACTIONS(1246),
    [anon_sym_switch] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(1246),
    [anon_sym_stop] = ACTIONS(1246),
    [anon_sym_add] = ACTIONS(1246),
    [anon_sym_sub] = ACTIONS(1246),
    [anon_sym_mul] = ACTIONS(1246),
    [anon_sym_div] = ACTIONS(1246),
    [anon_sym_sdiv] = ACTIONS(1246),
    [anon_sym_mod] = ACTIONS(1246),
    [anon_sym_smod] = ACTIONS(1246),
    [anon_sym_exp] = ACTIONS(1246),
    [anon_sym_not] = ACTIONS(1246),
    [anon_sym_lt] = ACTIONS(1246),
    [anon_sym_gt] = ACTIONS(1246),
    [anon_sym_slt] = ACTIONS(1246),
    [anon_sym_sgt] = ACTIONS(1246),
    [anon_sym_eq] = ACTIONS(1246),
    [anon_sym_iszero] = ACTIONS(1246),
    [anon_sym_and] = ACTIONS(1246),
    [anon_sym_or] = ACTIONS(1246),
    [anon_sym_xor] = ACTIONS(1246),
    [anon_sym_byte] = ACTIONS(1246),
    [anon_sym_shl] = ACTIONS(1246),
    [anon_sym_shr] = ACTIONS(1246),
    [anon_sym_sar] = ACTIONS(1246),
    [anon_sym_addmod] = ACTIONS(1246),
    [anon_sym_mulmod] = ACTIONS(1246),
    [anon_sym_signextend] = ACTIONS(1246),
    [anon_sym_keccak256] = ACTIONS(1246),
    [anon_sym_pop] = ACTIONS(1246),
    [anon_sym_mload] = ACTIONS(1246),
    [anon_sym_mstore] = ACTIONS(1246),
    [anon_sym_mstore8] = ACTIONS(1246),
    [anon_sym_sload] = ACTIONS(1246),
    [anon_sym_sstore] = ACTIONS(1246),
    [anon_sym_msize] = ACTIONS(1246),
    [anon_sym_gas] = ACTIONS(1246),
    [anon_sym_address] = ACTIONS(1246),
    [anon_sym_balance] = ACTIONS(1246),
    [anon_sym_selfbalance] = ACTIONS(1246),
    [anon_sym_caller] = ACTIONS(1246),
    [anon_sym_callvalue] = ACTIONS(1246),
    [anon_sym_calldataload] = ACTIONS(1246),
    [anon_sym_calldatasize] = ACTIONS(1246),
    [anon_sym_calldatacopy] = ACTIONS(1246),
    [anon_sym_extcodesize] = ACTIONS(1246),
    [anon_sym_extcodecopy] = ACTIONS(1246),
    [anon_sym_returndatasize] = ACTIONS(1246),
    [anon_sym_returndatacopy] = ACTIONS(1246),
    [anon_sym_extcodehash] = ACTIONS(1246),
    [anon_sym_create] = ACTIONS(1246),
    [anon_sym_create2] = ACTIONS(1246),
    [anon_sym_call] = ACTIONS(1246),
    [anon_sym_callcode] = ACTIONS(1246),
    [anon_sym_delegatecall] = ACTIONS(1246),
    [anon_sym_staticcall] = ACTIONS(1246),
    [anon_sym_return] = ACTIONS(1246),
    [anon_sym_revert] = ACTIONS(1246),
    [anon_sym_selfdestruct] = ACTIONS(1246),
    [anon_sym_invalid] = ACTIONS(1246),
    [anon_sym_log0] = ACTIONS(1246),
    [anon_sym_log1] = ACTIONS(1246),
    [anon_sym_log2] = ACTIONS(1246),
    [anon_sym_log3] = ACTIONS(1246),
    [anon_sym_log4] = ACTIONS(1246),
    [anon_sym_chainid] = ACTIONS(1246),
    [anon_sym_origin] = ACTIONS(1246),
    [anon_sym_gasprice] = ACTIONS(1246),
    [anon_sym_blockhash] = ACTIONS(1246),
    [anon_sym_coinbase] = ACTIONS(1246),
    [anon_sym_timestamp] = ACTIONS(1246),
    [anon_sym_number] = ACTIONS(1246),
    [anon_sym_difficulty] = ACTIONS(1246),
    [anon_sym_gaslimit] = ACTIONS(1246),
    [anon_sym_hex] = ACTIONS(1250),
    [anon_sym_DQUOTE] = ACTIONS(1248),
    [anon_sym_SQUOTE] = ACTIONS(1248),
    [sym_comment] = ACTIONS(3),
  },
  [345] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(376),
    [sym_yul_path] = STATE(376),
    [sym__yul_literal] = STATE(376),
    [sym_yul_string_literal] = STATE(376),
    [sym_yul_boolean] = STATE(376),
    [sym_yul_function_call] = STATE(374),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(376),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(340),
    [sym_identifier] = ACTIONS(1184),
    [sym_yul_decimal_number] = ACTIONS(1253),
    [sym_yul_hex_number] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(965),
    [sym_comment] = ACTIONS(3),
  },
  [346] = {
    [sym_identifier] = ACTIONS(1192),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym_RBRACE] = ACTIONS(1194),
    [anon_sym_for] = ACTIONS(1192),
    [sym_yul_leave] = ACTIONS(1192),
    [anon_sym_break] = ACTIONS(1192),
    [anon_sym_continue] = ACTIONS(1192),
    [sym_yul_decimal_number] = ACTIONS(1192),
    [sym_yul_hex_number] = ACTIONS(1194),
    [anon_sym_true] = ACTIONS(1192),
    [anon_sym_false] = ACTIONS(1192),
    [anon_sym_let] = ACTIONS(1192),
    [anon_sym_COLON_EQ] = ACTIONS(1196),
    [anon_sym_if] = ACTIONS(1192),
    [anon_sym_switch] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(1192),
    [anon_sym_stop] = ACTIONS(1192),
    [anon_sym_add] = ACTIONS(1192),
    [anon_sym_sub] = ACTIONS(1192),
    [anon_sym_mul] = ACTIONS(1192),
    [anon_sym_div] = ACTIONS(1192),
    [anon_sym_sdiv] = ACTIONS(1192),
    [anon_sym_mod] = ACTIONS(1192),
    [anon_sym_smod] = ACTIONS(1192),
    [anon_sym_exp] = ACTIONS(1192),
    [anon_sym_not] = ACTIONS(1192),
    [anon_sym_lt] = ACTIONS(1192),
    [anon_sym_gt] = ACTIONS(1192),
    [anon_sym_slt] = ACTIONS(1192),
    [anon_sym_sgt] = ACTIONS(1192),
    [anon_sym_eq] = ACTIONS(1192),
    [anon_sym_iszero] = ACTIONS(1192),
    [anon_sym_and] = ACTIONS(1192),
    [anon_sym_or] = ACTIONS(1192),
    [anon_sym_xor] = ACTIONS(1192),
    [anon_sym_byte] = ACTIONS(1192),
    [anon_sym_shl] = ACTIONS(1192),
    [anon_sym_shr] = ACTIONS(1192),
    [anon_sym_sar] = ACTIONS(1192),
    [anon_sym_addmod] = ACTIONS(1192),
    [anon_sym_mulmod] = ACTIONS(1192),
    [anon_sym_signextend] = ACTIONS(1192),
    [anon_sym_keccak256] = ACTIONS(1192),
    [anon_sym_pop] = ACTIONS(1192),
    [anon_sym_mload] = ACTIONS(1192),
    [anon_sym_mstore] = ACTIONS(1192),
    [anon_sym_mstore8] = ACTIONS(1192),
    [anon_sym_sload] = ACTIONS(1192),
    [anon_sym_sstore] = ACTIONS(1192),
    [anon_sym_msize] = ACTIONS(1192),
    [anon_sym_gas] = ACTIONS(1192),
    [anon_sym_address] = ACTIONS(1192),
    [anon_sym_balance] = ACTIONS(1192),
    [anon_sym_selfbalance] = ACTIONS(1192),
    [anon_sym_caller] = ACTIONS(1192),
    [anon_sym_callvalue] = ACTIONS(1192),
    [anon_sym_calldataload] = ACTIONS(1192),
    [anon_sym_calldatasize] = ACTIONS(1192),
    [anon_sym_calldatacopy] = ACTIONS(1192),
    [anon_sym_extcodesize] = ACTIONS(1192),
    [anon_sym_extcodecopy] = ACTIONS(1192),
    [anon_sym_returndatasize] = ACTIONS(1192),
    [anon_sym_returndatacopy] = ACTIONS(1192),
    [anon_sym_extcodehash] = ACTIONS(1192),
    [anon_sym_create] = ACTIONS(1192),
    [anon_sym_create2] = ACTIONS(1192),
    [anon_sym_call] = ACTIONS(1192),
    [anon_sym_callcode] = ACTIONS(1192),
    [anon_sym_delegatecall] = ACTIONS(1192),
    [anon_sym_staticcall] = ACTIONS(1192),
    [anon_sym_return] = ACTIONS(1192),
    [anon_sym_revert] = ACTIONS(1192),
    [anon_sym_selfdestruct] = ACTIONS(1192),
    [anon_sym_invalid] = ACTIONS(1192),
    [anon_sym_log0] = ACTIONS(1192),
    [anon_sym_log1] = ACTIONS(1192),
    [anon_sym_log2] = ACTIONS(1192),
    [anon_sym_log3] = ACTIONS(1192),
    [anon_sym_log4] = ACTIONS(1192),
    [anon_sym_chainid] = ACTIONS(1192),
    [anon_sym_origin] = ACTIONS(1192),
    [anon_sym_gasprice] = ACTIONS(1192),
    [anon_sym_blockhash] = ACTIONS(1192),
    [anon_sym_coinbase] = ACTIONS(1192),
    [anon_sym_timestamp] = ACTIONS(1192),
    [anon_sym_number] = ACTIONS(1192),
    [anon_sym_difficulty] = ACTIONS(1192),
    [anon_sym_gaslimit] = ACTIONS(1192),
    [anon_sym_hex] = ACTIONS(1192),
    [anon_sym_DQUOTE] = ACTIONS(1194),
    [anon_sym_SQUOTE] = ACTIONS(1194),
    [sym_comment] = ACTIONS(3),
  },
  [347] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(649),
    [sym_yul_path] = STATE(649),
    [sym__yul_literal] = STATE(649),
    [sym_yul_string_literal] = STATE(649),
    [sym_yul_boolean] = STATE(649),
    [sym_yul_function_call] = STATE(649),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(649),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [sym_identifier] = ACTIONS(1184),
    [sym_yul_decimal_number] = ACTIONS(1257),
    [sym_yul_hex_number] = ACTIONS(1259),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
  },
  [348] = {
    [sym_yul_identifier] = STATE(303),
    [sym__yul_expression] = STATE(831),
    [sym_yul_path] = STATE(831),
    [sym__yul_literal] = STATE(831),
    [sym_yul_string_literal] = STATE(831),
    [sym_yul_boolean] = STATE(831),
    [sym_yul_function_call] = STATE(831),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_hex_string_literal] = STATE(831),
    [sym_string] = STATE(318),
    [aux_sym_hex_string_literal_repeat2] = STATE(428),
    [sym_identifier] = ACTIONS(1184),
    [sym_yul_decimal_number] = ACTIONS(1188),
    [sym_yul_hex_number] = ACTIONS(1190),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [anon_sym_hex] = ACTIONS(99),
    [anon_sym_DQUOTE] = ACTIONS(101),
    [anon_sym_SQUOTE] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
  },
  [349] = {
    [sym_identifier] = ACTIONS(1261),
    [anon_sym_LBRACE] = ACTIONS(1263),
    [anon_sym_RBRACE] = ACTIONS(1263),
    [anon_sym_for] = ACTIONS(1261),
    [sym_yul_leave] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_continue] = ACTIONS(1261),
    [sym_yul_decimal_number] = ACTIONS(1261),
    [sym_yul_hex_number] = ACTIONS(1263),
    [anon_sym_true] = ACTIONS(1261),
    [anon_sym_false] = ACTIONS(1261),
    [anon_sym_let] = ACTIONS(1261),
    [anon_sym_if] = ACTIONS(1261),
    [anon_sym_switch] = ACTIONS(1261),
    [anon_sym_function] = ACTIONS(1261),
    [anon_sym_stop] = ACTIONS(1261),
    [anon_sym_add] = ACTIONS(1261),
    [anon_sym_sub] = ACTIONS(1261),
    [anon_sym_mul] = ACTIONS(1261),
    [anon_sym_div] = ACTIONS(1261),
    [anon_sym_sdiv] = ACTIONS(1261),
    [anon_sym_mod] = ACTIONS(1261),
    [anon_sym_smod] = ACTIONS(1261),
    [anon_sym_exp] = ACTIONS(1261),
    [anon_sym_not] = ACTIONS(1261),
    [anon_sym_lt] = ACTIONS(1261),
    [anon_sym_gt] = ACTIONS(1261),
    [anon_sym_slt] = ACTIONS(1261),
    [anon_sym_sgt] = ACTIONS(1261),
    [anon_sym_eq] = ACTIONS(1261),
    [anon_sym_iszero] = ACTIONS(1261),
    [anon_sym_and] = ACTIONS(1261),
    [anon_sym_or] = ACTIONS(1261),
    [anon_sym_xor] = ACTIONS(1261),
    [anon_sym_byte] = ACTIONS(1261),
    [anon_sym_shl] = ACTIONS(1261),
    [anon_sym_shr] = ACTIONS(1261),
    [anon_sym_sar] = ACTIONS(1261),
    [anon_sym_addmod] = ACTIONS(1261),
    [anon_sym_mulmod] = ACTIONS(1261),
    [anon_sym_signextend] = ACTIONS(1261),
    [anon_sym_keccak256] = ACTIONS(1261),
    [anon_sym_pop] = ACTIONS(1261),
    [anon_sym_mload] = ACTIONS(1261),
    [anon_sym_mstore] = ACTIONS(1261),
    [anon_sym_mstore8] = ACTIONS(1261),
    [anon_sym_sload] = ACTIONS(1261),
    [anon_sym_sstore] = ACTIONS(1261),
    [anon_sym_msize] = ACTIONS(1261),
    [anon_sym_gas] = ACTIONS(1261),
    [anon_sym_address] = ACTIONS(1261),
    [anon_sym_balance] = ACTIONS(1261),
    [anon_sym_selfbalance] = ACTIONS(1261),
    [anon_sym_caller] = ACTIONS(1261),
    [anon_sym_callvalue] = ACTIONS(1261),
    [anon_sym_calldataload] = ACTIONS(1261),
    [anon_sym_calldatasize] = ACTIONS(1261),
    [anon_sym_calldatacopy] = ACTIONS(1261),
    [anon_sym_extcodesize] = ACTIONS(1261),
    [anon_sym_extcodecopy] = ACTIONS(1261),
    [anon_sym_returndatasize] = ACTIONS(1261),
    [anon_sym_returndatacopy] = ACTIONS(1261),
    [anon_sym_extcodehash] = ACTIONS(1261),
    [anon_sym_create] = ACTIONS(1261),
    [anon_sym_create2] = ACTIONS(1261),
    [anon_sym_call] = ACTIONS(1261),
    [anon_sym_callcode] = ACTIONS(1261),
    [anon_sym_delegatecall] = ACTIONS(1261),
    [anon_sym_staticcall] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1261),
    [anon_sym_revert] = ACTIONS(1261),
    [anon_sym_selfdestruct] = ACTIONS(1261),
    [anon_sym_invalid] = ACTIONS(1261),
    [anon_sym_log0] = ACTIONS(1261),
    [anon_sym_log1] = ACTIONS(1261),
    [anon_sym_log2] = ACTIONS(1261),
    [anon_sym_log3] = ACTIONS(1261),
    [anon_sym_log4] = ACTIONS(1261),
    [anon_sym_chainid] = ACTIONS(1261),
    [anon_sym_origin] = ACTIONS(1261),
    [anon_sym_gasprice] = ACTIONS(1261),
    [anon_sym_blockhash] = ACTIONS(1261),
    [anon_sym_coinbase] = ACTIONS(1261),
    [anon_sym_timestamp] = ACTIONS(1261),
    [anon_sym_number] = ACTIONS(1261),
    [anon_sym_difficulty] = ACTIONS(1261),
    [anon_sym_gaslimit] = ACTIONS(1261),
    [anon_sym_hex] = ACTIONS(1261),
    [anon_sym_DQUOTE] = ACTIONS(1263),
    [anon_sym_SQUOTE] = ACTIONS(1263),
    [sym_comment] = ACTIONS(3),
  },
  [350] = {
    [sym_identifier] = ACTIONS(1265),
    [anon_sym_LBRACE] = ACTIONS(1267),
    [anon_sym_RBRACE] = ACTIONS(1267),
    [anon_sym_for] = ACTIONS(1265),
    [sym_yul_leave] = ACTIONS(1265),
    [anon_sym_break] = ACTIONS(1265),
    [anon_sym_continue] = ACTIONS(1265),
    [sym_yul_decimal_number] = ACTIONS(1265),
    [sym_yul_hex_number] = ACTIONS(1267),
    [anon_sym_true] = ACTIONS(1265),
    [anon_sym_false] = ACTIONS(1265),
    [anon_sym_let] = ACTIONS(1265),
    [anon_sym_if] = ACTIONS(1265),
    [anon_sym_switch] = ACTIONS(1265),
    [anon_sym_function] = ACTIONS(1265),
    [anon_sym_stop] = ACTIONS(1265),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_sub] = ACTIONS(1265),
    [anon_sym_mul] = ACTIONS(1265),
    [anon_sym_div] = ACTIONS(1265),
    [anon_sym_sdiv] = ACTIONS(1265),
    [anon_sym_mod] = ACTIONS(1265),
    [anon_sym_smod] = ACTIONS(1265),
    [anon_sym_exp] = ACTIONS(1265),
    [anon_sym_not] = ACTIONS(1265),
    [anon_sym_lt] = ACTIONS(1265),
    [anon_sym_gt] = ACTIONS(1265),
    [anon_sym_slt] = ACTIONS(1265),
    [anon_sym_sgt] = ACTIONS(1265),
    [anon_sym_eq] = ACTIONS(1265),
    [anon_sym_iszero] = ACTIONS(1265),
    [anon_sym_and] = ACTIONS(1265),
    [anon_sym_or] = ACTIONS(1265),
    [anon_sym_xor] = ACTIONS(1265),
    [anon_sym_byte] = ACTIONS(1265),
    [anon_sym_shl] = ACTIONS(1265),
    [anon_sym_shr] = ACTIONS(1265),
    [anon_sym_sar] = ACTIONS(1265),
    [anon_sym_addmod] = ACTIONS(1265),
    [anon_sym_mulmod] = ACTIONS(1265),
    [anon_sym_signextend] = ACTIONS(1265),
    [anon_sym_keccak256] = ACTIONS(1265),
    [anon_sym_pop] = ACTIONS(1265),
    [anon_sym_mload] = ACTIONS(1265),
    [anon_sym_mstore] = ACTIONS(1265),
    [anon_sym_mstore8] = ACTIONS(1265),
    [anon_sym_sload] = ACTIONS(1265),
    [anon_sym_sstore] = ACTIONS(1265),
    [anon_sym_msize] = ACTIONS(1265),
    [anon_sym_gas] = ACTIONS(1265),
    [anon_sym_address] = ACTIONS(1265),
    [anon_sym_balance] = ACTIONS(1265),
    [anon_sym_selfbalance] = ACTIONS(1265),
    [anon_sym_caller] = ACTIONS(1265),
    [anon_sym_callvalue] = ACTIONS(1265),
    [anon_sym_calldataload] = ACTIONS(1265),
    [anon_sym_calldatasize] = ACTIONS(1265),
    [anon_sym_calldatacopy] = ACTIONS(1265),
    [anon_sym_extcodesize] = ACTIONS(1265),
    [anon_sym_extcodecopy] = ACTIONS(1265),
    [anon_sym_returndatasize] = ACTIONS(1265),
    [anon_sym_returndatacopy] = ACTIONS(1265),
    [anon_sym_extcodehash] = ACTIONS(1265),
    [anon_sym_create] = ACTIONS(1265),
    [anon_sym_create2] = ACTIONS(1265),
    [anon_sym_call] = ACTIONS(1265),
    [anon_sym_callcode] = ACTIONS(1265),
    [anon_sym_delegatecall] = ACTIONS(1265),
    [anon_sym_staticcall] = ACTIONS(1265),
    [anon_sym_return] = ACTIONS(1265),
    [anon_sym_revert] = ACTIONS(1265),
    [anon_sym_selfdestruct] = ACTIONS(1265),
    [anon_sym_invalid] = ACTIONS(1265),
    [anon_sym_log0] = ACTIONS(1265),
    [anon_sym_log1] = ACTIONS(1265),
    [anon_sym_log2] = ACTIONS(1265),
    [anon_sym_log3] = ACTIONS(1265),
    [anon_sym_log4] = ACTIONS(1265),
    [anon_sym_chainid] = ACTIONS(1265),
    [anon_sym_origin] = ACTIONS(1265),
    [anon_sym_gasprice] = ACTIONS(1265),
    [anon_sym_blockhash] = ACTIONS(1265),
    [anon_sym_coinbase] = ACTIONS(1265),
    [anon_sym_timestamp] = ACTIONS(1265),
    [anon_sym_number] = ACTIONS(1265),
    [anon_sym_difficulty] = ACTIONS(1265),
    [anon_sym_gaslimit] = ACTIONS(1265),
    [anon_sym_hex] = ACTIONS(1265),
    [anon_sym_DQUOTE] = ACTIONS(1267),
    [anon_sym_SQUOTE] = ACTIONS(1267),
    [sym_comment] = ACTIONS(3),
  },
  [351] = {
    [sym_identifier] = ACTIONS(1269),
    [anon_sym_LBRACE] = ACTIONS(1271),
    [anon_sym_RBRACE] = ACTIONS(1271),
    [anon_sym_for] = ACTIONS(1269),
    [sym_yul_leave] = ACTIONS(1269),
    [anon_sym_break] = ACTIONS(1269),
    [anon_sym_continue] = ACTIONS(1269),
    [sym_yul_decimal_number] = ACTIONS(1269),
    [sym_yul_hex_number] = ACTIONS(1271),
    [anon_sym_true] = ACTIONS(1269),
    [anon_sym_false] = ACTIONS(1269),
    [anon_sym_let] = ACTIONS(1269),
    [anon_sym_if] = ACTIONS(1269),
    [anon_sym_switch] = ACTIONS(1269),
    [anon_sym_function] = ACTIONS(1269),
    [anon_sym_stop] = ACTIONS(1269),
    [anon_sym_add] = ACTIONS(1269),
    [anon_sym_sub] = ACTIONS(1269),
    [anon_sym_mul] = ACTIONS(1269),
    [anon_sym_div] = ACTIONS(1269),
    [anon_sym_sdiv] = ACTIONS(1269),
    [anon_sym_mod] = ACTIONS(1269),
    [anon_sym_smod] = ACTIONS(1269),
    [anon_sym_exp] = ACTIONS(1269),
    [anon_sym_not] = ACTIONS(1269),
    [anon_sym_lt] = ACTIONS(1269),
    [anon_sym_gt] = ACTIONS(1269),
    [anon_sym_slt] = ACTIONS(1269),
    [anon_sym_sgt] = ACTIONS(1269),
    [anon_sym_eq] = ACTIONS(1269),
    [anon_sym_iszero] = ACTIONS(1269),
    [anon_sym_and] = ACTIONS(1269),
    [anon_sym_or] = ACTIONS(1269),
    [anon_sym_xor] = ACTIONS(1269),
    [anon_sym_byte] = ACTIONS(1269),
    [anon_sym_shl] = ACTIONS(1269),
    [anon_sym_shr] = ACTIONS(1269),
    [anon_sym_sar] = ACTIONS(1269),
    [anon_sym_addmod] = ACTIONS(1269),
    [anon_sym_mulmod] = ACTIONS(1269),
    [anon_sym_signextend] = ACTIONS(1269),
    [anon_sym_keccak256] = ACTIONS(1269),
    [anon_sym_pop] = ACTIONS(1269),
    [anon_sym_mload] = ACTIONS(1269),
    [anon_sym_mstore] = ACTIONS(1269),
    [anon_sym_mstore8] = ACTIONS(1269),
    [anon_sym_sload] = ACTIONS(1269),
    [anon_sym_sstore] = ACTIONS(1269),
    [anon_sym_msize] = ACTIONS(1269),
    [anon_sym_gas] = ACTIONS(1269),
    [anon_sym_address] = ACTIONS(1269),
    [anon_sym_balance] = ACTIONS(1269),
    [anon_sym_selfbalance] = ACTIONS(1269),
    [anon_sym_caller] = ACTIONS(1269),
    [anon_sym_callvalue] = ACTIONS(1269),
    [anon_sym_calldataload] = ACTIONS(1269),
    [anon_sym_calldatasize] = ACTIONS(1269),
    [anon_sym_calldatacopy] = ACTIONS(1269),
    [anon_sym_extcodesize] = ACTIONS(1269),
    [anon_sym_extcodecopy] = ACTIONS(1269),
    [anon_sym_returndatasize] = ACTIONS(1269),
    [anon_sym_returndatacopy] = ACTIONS(1269),
    [anon_sym_extcodehash] = ACTIONS(1269),
    [anon_sym_create] = ACTIONS(1269),
    [anon_sym_create2] = ACTIONS(1269),
    [anon_sym_call] = ACTIONS(1269),
    [anon_sym_callcode] = ACTIONS(1269),
    [anon_sym_delegatecall] = ACTIONS(1269),
    [anon_sym_staticcall] = ACTIONS(1269),
    [anon_sym_return] = ACTIONS(1269),
    [anon_sym_revert] = ACTIONS(1269),
    [anon_sym_selfdestruct] = ACTIONS(1269),
    [anon_sym_invalid] = ACTIONS(1269),
    [anon_sym_log0] = ACTIONS(1269),
    [anon_sym_log1] = ACTIONS(1269),
    [anon_sym_log2] = ACTIONS(1269),
    [anon_sym_log3] = ACTIONS(1269),
    [anon_sym_log4] = ACTIONS(1269),
    [anon_sym_chainid] = ACTIONS(1269),
    [anon_sym_origin] = ACTIONS(1269),
    [anon_sym_gasprice] = ACTIONS(1269),
    [anon_sym_blockhash] = ACTIONS(1269),
    [anon_sym_coinbase] = ACTIONS(1269),
    [anon_sym_timestamp] = ACTIONS(1269),
    [anon_sym_number] = ACTIONS(1269),
    [anon_sym_difficulty] = ACTIONS(1269),
    [anon_sym_gaslimit] = ACTIONS(1269),
    [anon_sym_hex] = ACTIONS(1269),
    [anon_sym_DQUOTE] = ACTIONS(1271),
    [anon_sym_SQUOTE] = ACTIONS(1271),
    [sym_comment] = ACTIONS(3),
  },
  [352] = {
    [sym_identifier] = ACTIONS(1269),
    [anon_sym_LBRACE] = ACTIONS(1271),
    [anon_sym_RBRACE] = ACTIONS(1271),
    [anon_sym_for] = ACTIONS(1269),
    [sym_yul_leave] = ACTIONS(1269),
    [anon_sym_break] = ACTIONS(1269),
    [anon_sym_continue] = ACTIONS(1269),
    [sym_yul_decimal_number] = ACTIONS(1269),
    [sym_yul_hex_number] = ACTIONS(1271),
    [anon_sym_true] = ACTIONS(1269),
    [anon_sym_false] = ACTIONS(1269),
    [anon_sym_let] = ACTIONS(1269),
    [anon_sym_if] = ACTIONS(1269),
    [anon_sym_switch] = ACTIONS(1269),
    [anon_sym_function] = ACTIONS(1269),
    [anon_sym_stop] = ACTIONS(1269),
    [anon_sym_add] = ACTIONS(1269),
    [anon_sym_sub] = ACTIONS(1269),
    [anon_sym_mul] = ACTIONS(1269),
    [anon_sym_div] = ACTIONS(1269),
    [anon_sym_sdiv] = ACTIONS(1269),
    [anon_sym_mod] = ACTIONS(1269),
    [anon_sym_smod] = ACTIONS(1269),
    [anon_sym_exp] = ACTIONS(1269),
    [anon_sym_not] = ACTIONS(1269),
    [anon_sym_lt] = ACTIONS(1269),
    [anon_sym_gt] = ACTIONS(1269),
    [anon_sym_slt] = ACTIONS(1269),
    [anon_sym_sgt] = ACTIONS(1269),
    [anon_sym_eq] = ACTIONS(1269),
    [anon_sym_iszero] = ACTIONS(1269),
    [anon_sym_and] = ACTIONS(1269),
    [anon_sym_or] = ACTIONS(1269),
    [anon_sym_xor] = ACTIONS(1269),
    [anon_sym_byte] = ACTIONS(1269),
    [anon_sym_shl] = ACTIONS(1269),
    [anon_sym_shr] = ACTIONS(1269),
    [anon_sym_sar] = ACTIONS(1269),
    [anon_sym_addmod] = ACTIONS(1269),
    [anon_sym_mulmod] = ACTIONS(1269),
    [anon_sym_signextend] = ACTIONS(1269),
    [anon_sym_keccak256] = ACTIONS(1269),
    [anon_sym_pop] = ACTIONS(1269),
    [anon_sym_mload] = ACTIONS(1269),
    [anon_sym_mstore] = ACTIONS(1269),
    [anon_sym_mstore8] = ACTIONS(1269),
    [anon_sym_sload] = ACTIONS(1269),
    [anon_sym_sstore] = ACTIONS(1269),
    [anon_sym_msize] = ACTIONS(1269),
    [anon_sym_gas] = ACTIONS(1269),
    [anon_sym_address] = ACTIONS(1269),
    [anon_sym_balance] = ACTIONS(1269),
    [anon_sym_selfbalance] = ACTIONS(1269),
    [anon_sym_caller] = ACTIONS(1269),
    [anon_sym_callvalue] = ACTIONS(1269),
    [anon_sym_calldataload] = ACTIONS(1269),
    [anon_sym_calldatasize] = ACTIONS(1269),
    [anon_sym_calldatacopy] = ACTIONS(1269),
    [anon_sym_extcodesize] = ACTIONS(1269),
    [anon_sym_extcodecopy] = ACTIONS(1269),
    [anon_sym_returndatasize] = ACTIONS(1269),
    [anon_sym_returndatacopy] = ACTIONS(1269),
    [anon_sym_extcodehash] = ACTIONS(1269),
    [anon_sym_create] = ACTIONS(1269),
    [anon_sym_create2] = ACTIONS(1269),
    [anon_sym_call] = ACTIONS(1269),
    [anon_sym_callcode] = ACTIONS(1269),
    [anon_sym_delegatecall] = ACTIONS(1269),
    [anon_sym_staticcall] = ACTIONS(1269),
    [anon_sym_return] = ACTIONS(1269),
    [anon_sym_revert] = ACTIONS(1269),
    [anon_sym_selfdestruct] = ACTIONS(1269),
    [anon_sym_invalid] = ACTIONS(1269),
    [anon_sym_log0] = ACTIONS(1269),
    [anon_sym_log1] = ACTIONS(1269),
    [anon_sym_log2] = ACTIONS(1269),
    [anon_sym_log3] = ACTIONS(1269),
    [anon_sym_log4] = ACTIONS(1269),
    [anon_sym_chainid] = ACTIONS(1269),
    [anon_sym_origin] = ACTIONS(1269),
    [anon_sym_gasprice] = ACTIONS(1269),
    [anon_sym_blockhash] = ACTIONS(1269),
    [anon_sym_coinbase] = ACTIONS(1269),
    [anon_sym_timestamp] = ACTIONS(1269),
    [anon_sym_number] = ACTIONS(1269),
    [anon_sym_difficulty] = ACTIONS(1269),
    [anon_sym_gaslimit] = ACTIONS(1269),
    [anon_sym_hex] = ACTIONS(1269),
    [anon_sym_DQUOTE] = ACTIONS(1271),
    [anon_sym_SQUOTE] = ACTIONS(1271),
    [sym_comment] = ACTIONS(3),
  },
  [353] = {
    [sym_identifier] = ACTIONS(1273),
    [anon_sym_LBRACE] = ACTIONS(1275),
    [anon_sym_RBRACE] = ACTIONS(1275),
    [anon_sym_for] = ACTIONS(1273),
    [sym_yul_leave] = ACTIONS(1273),
    [anon_sym_break] = ACTIONS(1273),
    [anon_sym_continue] = ACTIONS(1273),
    [sym_yul_decimal_number] = ACTIONS(1273),
    [sym_yul_hex_number] = ACTIONS(1275),
    [anon_sym_true] = ACTIONS(1273),
    [anon_sym_false] = ACTIONS(1273),
    [anon_sym_let] = ACTIONS(1273),
    [anon_sym_if] = ACTIONS(1273),
    [anon_sym_switch] = ACTIONS(1273),
    [anon_sym_function] = ACTIONS(1273),
    [anon_sym_stop] = ACTIONS(1273),
    [anon_sym_add] = ACTIONS(1273),
    [anon_sym_sub] = ACTIONS(1273),
    [anon_sym_mul] = ACTIONS(1273),
    [anon_sym_div] = ACTIONS(1273),
    [anon_sym_sdiv] = ACTIONS(1273),
    [anon_sym_mod] = ACTIONS(1273),
    [anon_sym_smod] = ACTIONS(1273),
    [anon_sym_exp] = ACTIONS(1273),
    [anon_sym_not] = ACTIONS(1273),
    [anon_sym_lt] = ACTIONS(1273),
    [anon_sym_gt] = ACTIONS(1273),
    [anon_sym_slt] = ACTIONS(1273),
    [anon_sym_sgt] = ACTIONS(1273),
    [anon_sym_eq] = ACTIONS(1273),
    [anon_sym_iszero] = ACTIONS(1273),
    [anon_sym_and] = ACTIONS(1273),
    [anon_sym_or] = ACTIONS(1273),
    [anon_sym_xor] = ACTIONS(1273),
    [anon_sym_byte] = ACTIONS(1273),
    [anon_sym_shl] = ACTIONS(1273),
    [anon_sym_shr] = ACTIONS(1273),
    [anon_sym_sar] = ACTIONS(1273),
    [anon_sym_addmod] = ACTIONS(1273),
    [anon_sym_mulmod] = ACTIONS(1273),
    [anon_sym_signextend] = ACTIONS(1273),
    [anon_sym_keccak256] = ACTIONS(1273),
    [anon_sym_pop] = ACTIONS(1273),
    [anon_sym_mload] = ACTIONS(1273),
    [anon_sym_mstore] = ACTIONS(1273),
    [anon_sym_mstore8] = ACTIONS(1273),
    [anon_sym_sload] = ACTIONS(1273),
    [anon_sym_sstore] = ACTIONS(1273),
    [anon_sym_msize] = ACTIONS(1273),
    [anon_sym_gas] = ACTIONS(1273),
    [anon_sym_address] = ACTIONS(1273),
    [anon_sym_balance] = ACTIONS(1273),
    [anon_sym_selfbalance] = ACTIONS(1273),
    [anon_sym_caller] = ACTIONS(1273),
    [anon_sym_callvalue] = ACTIONS(1273),
    [anon_sym_calldataload] = ACTIONS(1273),
    [anon_sym_calldatasize] = ACTIONS(1273),
    [anon_sym_calldatacopy] = ACTIONS(1273),
    [anon_sym_extcodesize] = ACTIONS(1273),
    [anon_sym_extcodecopy] = ACTIONS(1273),
    [anon_sym_returndatasize] = ACTIONS(1273),
    [anon_sym_returndatacopy] = ACTIONS(1273),
    [anon_sym_extcodehash] = ACTIONS(1273),
    [anon_sym_create] = ACTIONS(1273),
    [anon_sym_create2] = ACTIONS(1273),
    [anon_sym_call] = ACTIONS(1273),
    [anon_sym_callcode] = ACTIONS(1273),
    [anon_sym_delegatecall] = ACTIONS(1273),
    [anon_sym_staticcall] = ACTIONS(1273),
    [anon_sym_return] = ACTIONS(1273),
    [anon_sym_revert] = ACTIONS(1273),
    [anon_sym_selfdestruct] = ACTIONS(1273),
    [anon_sym_invalid] = ACTIONS(1273),
    [anon_sym_log0] = ACTIONS(1273),
    [anon_sym_log1] = ACTIONS(1273),
    [anon_sym_log2] = ACTIONS(1273),
    [anon_sym_log3] = ACTIONS(1273),
    [anon_sym_log4] = ACTIONS(1273),
    [anon_sym_chainid] = ACTIONS(1273),
    [anon_sym_origin] = ACTIONS(1273),
    [anon_sym_gasprice] = ACTIONS(1273),
    [anon_sym_blockhash] = ACTIONS(1273),
    [anon_sym_coinbase] = ACTIONS(1273),
    [anon_sym_timestamp] = ACTIONS(1273),
    [anon_sym_number] = ACTIONS(1273),
    [anon_sym_difficulty] = ACTIONS(1273),
    [anon_sym_gaslimit] = ACTIONS(1273),
    [anon_sym_hex] = ACTIONS(1273),
    [anon_sym_DQUOTE] = ACTIONS(1275),
    [anon_sym_SQUOTE] = ACTIONS(1275),
    [sym_comment] = ACTIONS(3),
  },
  [354] = {
    [sym_identifier] = ACTIONS(1277),
    [anon_sym_LBRACE] = ACTIONS(1279),
    [anon_sym_RBRACE] = ACTIONS(1279),
    [anon_sym_for] = ACTIONS(1277),
    [sym_yul_leave] = ACTIONS(1277),
    [anon_sym_break] = ACTIONS(1277),
    [anon_sym_continue] = ACTIONS(1277),
    [sym_yul_decimal_number] = ACTIONS(1277),
    [sym_yul_hex_number] = ACTIONS(1279),
    [anon_sym_true] = ACTIONS(1277),
    [anon_sym_false] = ACTIONS(1277),
    [anon_sym_let] = ACTIONS(1277),
    [anon_sym_if] = ACTIONS(1277),
    [anon_sym_switch] = ACTIONS(1277),
    [anon_sym_function] = ACTIONS(1277),
    [anon_sym_stop] = ACTIONS(1277),
    [anon_sym_add] = ACTIONS(1277),
    [anon_sym_sub] = ACTIONS(1277),
    [anon_sym_mul] = ACTIONS(1277),
    [anon_sym_div] = ACTIONS(1277),
    [anon_sym_sdiv] = ACTIONS(1277),
    [anon_sym_mod] = ACTIONS(1277),
    [anon_sym_smod] = ACTIONS(1277),
    [anon_sym_exp] = ACTIONS(1277),
    [anon_sym_not] = ACTIONS(1277),
    [anon_sym_lt] = ACTIONS(1277),
    [anon_sym_gt] = ACTIONS(1277),
    [anon_sym_slt] = ACTIONS(1277),
    [anon_sym_sgt] = ACTIONS(1277),
    [anon_sym_eq] = ACTIONS(1277),
    [anon_sym_iszero] = ACTIONS(1277),
    [anon_sym_and] = ACTIONS(1277),
    [anon_sym_or] = ACTIONS(1277),
    [anon_sym_xor] = ACTIONS(1277),
    [anon_sym_byte] = ACTIONS(1277),
    [anon_sym_shl] = ACTIONS(1277),
    [anon_sym_shr] = ACTIONS(1277),
    [anon_sym_sar] = ACTIONS(1277),
    [anon_sym_addmod] = ACTIONS(1277),
    [anon_sym_mulmod] = ACTIONS(1277),
    [anon_sym_signextend] = ACTIONS(1277),
    [anon_sym_keccak256] = ACTIONS(1277),
    [anon_sym_pop] = ACTIONS(1277),
    [anon_sym_mload] = ACTIONS(1277),
    [anon_sym_mstore] = ACTIONS(1277),
    [anon_sym_mstore8] = ACTIONS(1277),
    [anon_sym_sload] = ACTIONS(1277),
    [anon_sym_sstore] = ACTIONS(1277),
    [anon_sym_msize] = ACTIONS(1277),
    [anon_sym_gas] = ACTIONS(1277),
    [anon_sym_address] = ACTIONS(1277),
    [anon_sym_balance] = ACTIONS(1277),
    [anon_sym_selfbalance] = ACTIONS(1277),
    [anon_sym_caller] = ACTIONS(1277),
    [anon_sym_callvalue] = ACTIONS(1277),
    [anon_sym_calldataload] = ACTIONS(1277),
    [anon_sym_calldatasize] = ACTIONS(1277),
    [anon_sym_calldatacopy] = ACTIONS(1277),
    [anon_sym_extcodesize] = ACTIONS(1277),
    [anon_sym_extcodecopy] = ACTIONS(1277),
    [anon_sym_returndatasize] = ACTIONS(1277),
    [anon_sym_returndatacopy] = ACTIONS(1277),
    [anon_sym_extcodehash] = ACTIONS(1277),
    [anon_sym_create] = ACTIONS(1277),
    [anon_sym_create2] = ACTIONS(1277),
    [anon_sym_call] = ACTIONS(1277),
    [anon_sym_callcode] = ACTIONS(1277),
    [anon_sym_delegatecall] = ACTIONS(1277),
    [anon_sym_staticcall] = ACTIONS(1277),
    [anon_sym_return] = ACTIONS(1277),
    [anon_sym_revert] = ACTIONS(1277),
    [anon_sym_selfdestruct] = ACTIONS(1277),
    [anon_sym_invalid] = ACTIONS(1277),
    [anon_sym_log0] = ACTIONS(1277),
    [anon_sym_log1] = ACTIONS(1277),
    [anon_sym_log2] = ACTIONS(1277),
    [anon_sym_log3] = ACTIONS(1277),
    [anon_sym_log4] = ACTIONS(1277),
    [anon_sym_chainid] = ACTIONS(1277),
    [anon_sym_origin] = ACTIONS(1277),
    [anon_sym_gasprice] = ACTIONS(1277),
    [anon_sym_blockhash] = ACTIONS(1277),
    [anon_sym_coinbase] = ACTIONS(1277),
    [anon_sym_timestamp] = ACTIONS(1277),
    [anon_sym_number] = ACTIONS(1277),
    [anon_sym_difficulty] = ACTIONS(1277),
    [anon_sym_gaslimit] = ACTIONS(1277),
    [anon_sym_hex] = ACTIONS(1277),
    [anon_sym_DQUOTE] = ACTIONS(1279),
    [anon_sym_SQUOTE] = ACTIONS(1279),
    [sym_comment] = ACTIONS(3),
  },
  [355] = {
    [sym_identifier] = ACTIONS(1281),
    [anon_sym_LBRACE] = ACTIONS(1283),
    [anon_sym_RBRACE] = ACTIONS(1283),
    [anon_sym_for] = ACTIONS(1281),
    [sym_yul_leave] = ACTIONS(1281),
    [anon_sym_break] = ACTIONS(1281),
    [anon_sym_continue] = ACTIONS(1281),
    [sym_yul_decimal_number] = ACTIONS(1281),
    [sym_yul_hex_number] = ACTIONS(1283),
    [anon_sym_true] = ACTIONS(1281),
    [anon_sym_false] = ACTIONS(1281),
    [anon_sym_let] = ACTIONS(1281),
    [anon_sym_if] = ACTIONS(1281),
    [anon_sym_switch] = ACTIONS(1281),
    [anon_sym_function] = ACTIONS(1281),
    [anon_sym_stop] = ACTIONS(1281),
    [anon_sym_add] = ACTIONS(1281),
    [anon_sym_sub] = ACTIONS(1281),
    [anon_sym_mul] = ACTIONS(1281),
    [anon_sym_div] = ACTIONS(1281),
    [anon_sym_sdiv] = ACTIONS(1281),
    [anon_sym_mod] = ACTIONS(1281),
    [anon_sym_smod] = ACTIONS(1281),
    [anon_sym_exp] = ACTIONS(1281),
    [anon_sym_not] = ACTIONS(1281),
    [anon_sym_lt] = ACTIONS(1281),
    [anon_sym_gt] = ACTIONS(1281),
    [anon_sym_slt] = ACTIONS(1281),
    [anon_sym_sgt] = ACTIONS(1281),
    [anon_sym_eq] = ACTIONS(1281),
    [anon_sym_iszero] = ACTIONS(1281),
    [anon_sym_and] = ACTIONS(1281),
    [anon_sym_or] = ACTIONS(1281),
    [anon_sym_xor] = ACTIONS(1281),
    [anon_sym_byte] = ACTIONS(1281),
    [anon_sym_shl] = ACTIONS(1281),
    [anon_sym_shr] = ACTIONS(1281),
    [anon_sym_sar] = ACTIONS(1281),
    [anon_sym_addmod] = ACTIONS(1281),
    [anon_sym_mulmod] = ACTIONS(1281),
    [anon_sym_signextend] = ACTIONS(1281),
    [anon_sym_keccak256] = ACTIONS(1281),
    [anon_sym_pop] = ACTIONS(1281),
    [anon_sym_mload] = ACTIONS(1281),
    [anon_sym_mstore] = ACTIONS(1281),
    [anon_sym_mstore8] = ACTIONS(1281),
    [anon_sym_sload] = ACTIONS(1281),
    [anon_sym_sstore] = ACTIONS(1281),
    [anon_sym_msize] = ACTIONS(1281),
    [anon_sym_gas] = ACTIONS(1281),
    [anon_sym_address] = ACTIONS(1281),
    [anon_sym_balance] = ACTIONS(1281),
    [anon_sym_selfbalance] = ACTIONS(1281),
    [anon_sym_caller] = ACTIONS(1281),
    [anon_sym_callvalue] = ACTIONS(1281),
    [anon_sym_calldataload] = ACTIONS(1281),
    [anon_sym_calldatasize] = ACTIONS(1281),
    [anon_sym_calldatacopy] = ACTIONS(1281),
    [anon_sym_extcodesize] = ACTIONS(1281),
    [anon_sym_extcodecopy] = ACTIONS(1281),
    [anon_sym_returndatasize] = ACTIONS(1281),
    [anon_sym_returndatacopy] = ACTIONS(1281),
    [anon_sym_extcodehash] = ACTIONS(1281),
    [anon_sym_create] = ACTIONS(1281),
    [anon_sym_create2] = ACTIONS(1281),
    [anon_sym_call] = ACTIONS(1281),
    [anon_sym_callcode] = ACTIONS(1281),
    [anon_sym_delegatecall] = ACTIONS(1281),
    [anon_sym_staticcall] = ACTIONS(1281),
    [anon_sym_return] = ACTIONS(1281),
    [anon_sym_revert] = ACTIONS(1281),
    [anon_sym_selfdestruct] = ACTIONS(1281),
    [anon_sym_invalid] = ACTIONS(1281),
    [anon_sym_log0] = ACTIONS(1281),
    [anon_sym_log1] = ACTIONS(1281),
    [anon_sym_log2] = ACTIONS(1281),
    [anon_sym_log3] = ACTIONS(1281),
    [anon_sym_log4] = ACTIONS(1281),
    [anon_sym_chainid] = ACTIONS(1281),
    [anon_sym_origin] = ACTIONS(1281),
    [anon_sym_gasprice] = ACTIONS(1281),
    [anon_sym_blockhash] = ACTIONS(1281),
    [anon_sym_coinbase] = ACTIONS(1281),
    [anon_sym_timestamp] = ACTIONS(1281),
    [anon_sym_number] = ACTIONS(1281),
    [anon_sym_difficulty] = ACTIONS(1281),
    [anon_sym_gaslimit] = ACTIONS(1281),
    [anon_sym_hex] = ACTIONS(1281),
    [anon_sym_DQUOTE] = ACTIONS(1283),
    [anon_sym_SQUOTE] = ACTIONS(1283),
    [sym_comment] = ACTIONS(3),
  },
  [356] = {
    [sym_identifier] = ACTIONS(1285),
    [anon_sym_LBRACE] = ACTIONS(1287),
    [anon_sym_RBRACE] = ACTIONS(1287),
    [anon_sym_for] = ACTIONS(1285),
    [sym_yul_leave] = ACTIONS(1285),
    [anon_sym_break] = ACTIONS(1285),
    [anon_sym_continue] = ACTIONS(1285),
    [sym_yul_decimal_number] = ACTIONS(1285),
    [sym_yul_hex_number] = ACTIONS(1287),
    [anon_sym_true] = ACTIONS(1285),
    [anon_sym_false] = ACTIONS(1285),
    [anon_sym_let] = ACTIONS(1285),
    [anon_sym_if] = ACTIONS(1285),
    [anon_sym_switch] = ACTIONS(1285),
    [anon_sym_function] = ACTIONS(1285),
    [anon_sym_stop] = ACTIONS(1285),
    [anon_sym_add] = ACTIONS(1285),
    [anon_sym_sub] = ACTIONS(1285),
    [anon_sym_mul] = ACTIONS(1285),
    [anon_sym_div] = ACTIONS(1285),
    [anon_sym_sdiv] = ACTIONS(1285),
    [anon_sym_mod] = ACTIONS(1285),
    [anon_sym_smod] = ACTIONS(1285),
    [anon_sym_exp] = ACTIONS(1285),
    [anon_sym_not] = ACTIONS(1285),
    [anon_sym_lt] = ACTIONS(1285),
    [anon_sym_gt] = ACTIONS(1285),
    [anon_sym_slt] = ACTIONS(1285),
    [anon_sym_sgt] = ACTIONS(1285),
    [anon_sym_eq] = ACTIONS(1285),
    [anon_sym_iszero] = ACTIONS(1285),
    [anon_sym_and] = ACTIONS(1285),
    [anon_sym_or] = ACTIONS(1285),
    [anon_sym_xor] = ACTIONS(1285),
    [anon_sym_byte] = ACTIONS(1285),
    [anon_sym_shl] = ACTIONS(1285),
    [anon_sym_shr] = ACTIONS(1285),
    [anon_sym_sar] = ACTIONS(1285),
    [anon_sym_addmod] = ACTIONS(1285),
    [anon_sym_mulmod] = ACTIONS(1285),
    [anon_sym_signextend] = ACTIONS(1285),
    [anon_sym_keccak256] = ACTIONS(1285),
    [anon_sym_pop] = ACTIONS(1285),
    [anon_sym_mload] = ACTIONS(1285),
    [anon_sym_mstore] = ACTIONS(1285),
    [anon_sym_mstore8] = ACTIONS(1285),
    [anon_sym_sload] = ACTIONS(1285),
    [anon_sym_sstore] = ACTIONS(1285),
    [anon_sym_msize] = ACTIONS(1285),
    [anon_sym_gas] = ACTIONS(1285),
    [anon_sym_address] = ACTIONS(1285),
    [anon_sym_balance] = ACTIONS(1285),
    [anon_sym_selfbalance] = ACTIONS(1285),
    [anon_sym_caller] = ACTIONS(1285),
    [anon_sym_callvalue] = ACTIONS(1285),
    [anon_sym_calldataload] = ACTIONS(1285),
    [anon_sym_calldatasize] = ACTIONS(1285),
    [anon_sym_calldatacopy] = ACTIONS(1285),
    [anon_sym_extcodesize] = ACTIONS(1285),
    [anon_sym_extcodecopy] = ACTIONS(1285),
    [anon_sym_returndatasize] = ACTIONS(1285),
    [anon_sym_returndatacopy] = ACTIONS(1285),
    [anon_sym_extcodehash] = ACTIONS(1285),
    [anon_sym_create] = ACTIONS(1285),
    [anon_sym_create2] = ACTIONS(1285),
    [anon_sym_call] = ACTIONS(1285),
    [anon_sym_callcode] = ACTIONS(1285),
    [anon_sym_delegatecall] = ACTIONS(1285),
    [anon_sym_staticcall] = ACTIONS(1285),
    [anon_sym_return] = ACTIONS(1285),
    [anon_sym_revert] = ACTIONS(1285),
    [anon_sym_selfdestruct] = ACTIONS(1285),
    [anon_sym_invalid] = ACTIONS(1285),
    [anon_sym_log0] = ACTIONS(1285),
    [anon_sym_log1] = ACTIONS(1285),
    [anon_sym_log2] = ACTIONS(1285),
    [anon_sym_log3] = ACTIONS(1285),
    [anon_sym_log4] = ACTIONS(1285),
    [anon_sym_chainid] = ACTIONS(1285),
    [anon_sym_origin] = ACTIONS(1285),
    [anon_sym_gasprice] = ACTIONS(1285),
    [anon_sym_blockhash] = ACTIONS(1285),
    [anon_sym_coinbase] = ACTIONS(1285),
    [anon_sym_timestamp] = ACTIONS(1285),
    [anon_sym_number] = ACTIONS(1285),
    [anon_sym_difficulty] = ACTIONS(1285),
    [anon_sym_gaslimit] = ACTIONS(1285),
    [anon_sym_hex] = ACTIONS(1285),
    [anon_sym_DQUOTE] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1287),
    [sym_comment] = ACTIONS(3),
  },
  [357] = {
    [sym_identifier] = ACTIONS(1289),
    [anon_sym_LBRACE] = ACTIONS(1291),
    [anon_sym_RBRACE] = ACTIONS(1291),
    [anon_sym_for] = ACTIONS(1289),
    [sym_yul_leave] = ACTIONS(1289),
    [anon_sym_break] = ACTIONS(1289),
    [anon_sym_continue] = ACTIONS(1289),
    [sym_yul_decimal_number] = ACTIONS(1289),
    [sym_yul_hex_number] = ACTIONS(1291),
    [anon_sym_true] = ACTIONS(1289),
    [anon_sym_false] = ACTIONS(1289),
    [anon_sym_let] = ACTIONS(1289),
    [anon_sym_if] = ACTIONS(1289),
    [anon_sym_switch] = ACTIONS(1289),
    [anon_sym_function] = ACTIONS(1289),
    [anon_sym_stop] = ACTIONS(1289),
    [anon_sym_add] = ACTIONS(1289),
    [anon_sym_sub] = ACTIONS(1289),
    [anon_sym_mul] = ACTIONS(1289),
    [anon_sym_div] = ACTIONS(1289),
    [anon_sym_sdiv] = ACTIONS(1289),
    [anon_sym_mod] = ACTIONS(1289),
    [anon_sym_smod] = ACTIONS(1289),
    [anon_sym_exp] = ACTIONS(1289),
    [anon_sym_not] = ACTIONS(1289),
    [anon_sym_lt] = ACTIONS(1289),
    [anon_sym_gt] = ACTIONS(1289),
    [anon_sym_slt] = ACTIONS(1289),
    [anon_sym_sgt] = ACTIONS(1289),
    [anon_sym_eq] = ACTIONS(1289),
    [anon_sym_iszero] = ACTIONS(1289),
    [anon_sym_and] = ACTIONS(1289),
    [anon_sym_or] = ACTIONS(1289),
    [anon_sym_xor] = ACTIONS(1289),
    [anon_sym_byte] = ACTIONS(1289),
    [anon_sym_shl] = ACTIONS(1289),
    [anon_sym_shr] = ACTIONS(1289),
    [anon_sym_sar] = ACTIONS(1289),
    [anon_sym_addmod] = ACTIONS(1289),
    [anon_sym_mulmod] = ACTIONS(1289),
    [anon_sym_signextend] = ACTIONS(1289),
    [anon_sym_keccak256] = ACTIONS(1289),
    [anon_sym_pop] = ACTIONS(1289),
    [anon_sym_mload] = ACTIONS(1289),
    [anon_sym_mstore] = ACTIONS(1289),
    [anon_sym_mstore8] = ACTIONS(1289),
    [anon_sym_sload] = ACTIONS(1289),
    [anon_sym_sstore] = ACTIONS(1289),
    [anon_sym_msize] = ACTIONS(1289),
    [anon_sym_gas] = ACTIONS(1289),
    [anon_sym_address] = ACTIONS(1289),
    [anon_sym_balance] = ACTIONS(1289),
    [anon_sym_selfbalance] = ACTIONS(1289),
    [anon_sym_caller] = ACTIONS(1289),
    [anon_sym_callvalue] = ACTIONS(1289),
    [anon_sym_calldataload] = ACTIONS(1289),
    [anon_sym_calldatasize] = ACTIONS(1289),
    [anon_sym_calldatacopy] = ACTIONS(1289),
    [anon_sym_extcodesize] = ACTIONS(1289),
    [anon_sym_extcodecopy] = ACTIONS(1289),
    [anon_sym_returndatasize] = ACTIONS(1289),
    [anon_sym_returndatacopy] = ACTIONS(1289),
    [anon_sym_extcodehash] = ACTIONS(1289),
    [anon_sym_create] = ACTIONS(1289),
    [anon_sym_create2] = ACTIONS(1289),
    [anon_sym_call] = ACTIONS(1289),
    [anon_sym_callcode] = ACTIONS(1289),
    [anon_sym_delegatecall] = ACTIONS(1289),
    [anon_sym_staticcall] = ACTIONS(1289),
    [anon_sym_return] = ACTIONS(1289),
    [anon_sym_revert] = ACTIONS(1289),
    [anon_sym_selfdestruct] = ACTIONS(1289),
    [anon_sym_invalid] = ACTIONS(1289),
    [anon_sym_log0] = ACTIONS(1289),
    [anon_sym_log1] = ACTIONS(1289),
    [anon_sym_log2] = ACTIONS(1289),
    [anon_sym_log3] = ACTIONS(1289),
    [anon_sym_log4] = ACTIONS(1289),
    [anon_sym_chainid] = ACTIONS(1289),
    [anon_sym_origin] = ACTIONS(1289),
    [anon_sym_gasprice] = ACTIONS(1289),
    [anon_sym_blockhash] = ACTIONS(1289),
    [anon_sym_coinbase] = ACTIONS(1289),
    [anon_sym_timestamp] = ACTIONS(1289),
    [anon_sym_number] = ACTIONS(1289),
    [anon_sym_difficulty] = ACTIONS(1289),
    [anon_sym_gaslimit] = ACTIONS(1289),
    [anon_sym_hex] = ACTIONS(1289),
    [anon_sym_DQUOTE] = ACTIONS(1291),
    [anon_sym_SQUOTE] = ACTIONS(1291),
    [sym_comment] = ACTIONS(3),
  },
  [358] = {
    [sym_identifier] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_RBRACE] = ACTIONS(1295),
    [anon_sym_for] = ACTIONS(1293),
    [sym_yul_leave] = ACTIONS(1293),
    [anon_sym_break] = ACTIONS(1293),
    [anon_sym_continue] = ACTIONS(1293),
    [sym_yul_decimal_number] = ACTIONS(1293),
    [sym_yul_hex_number] = ACTIONS(1295),
    [anon_sym_true] = ACTIONS(1293),
    [anon_sym_false] = ACTIONS(1293),
    [anon_sym_let] = ACTIONS(1293),
    [anon_sym_if] = ACTIONS(1293),
    [anon_sym_switch] = ACTIONS(1293),
    [anon_sym_function] = ACTIONS(1293),
    [anon_sym_stop] = ACTIONS(1293),
    [anon_sym_add] = ACTIONS(1293),
    [anon_sym_sub] = ACTIONS(1293),
    [anon_sym_mul] = ACTIONS(1293),
    [anon_sym_div] = ACTIONS(1293),
    [anon_sym_sdiv] = ACTIONS(1293),
    [anon_sym_mod] = ACTIONS(1293),
    [anon_sym_smod] = ACTIONS(1293),
    [anon_sym_exp] = ACTIONS(1293),
    [anon_sym_not] = ACTIONS(1293),
    [anon_sym_lt] = ACTIONS(1293),
    [anon_sym_gt] = ACTIONS(1293),
    [anon_sym_slt] = ACTIONS(1293),
    [anon_sym_sgt] = ACTIONS(1293),
    [anon_sym_eq] = ACTIONS(1293),
    [anon_sym_iszero] = ACTIONS(1293),
    [anon_sym_and] = ACTIONS(1293),
    [anon_sym_or] = ACTIONS(1293),
    [anon_sym_xor] = ACTIONS(1293),
    [anon_sym_byte] = ACTIONS(1293),
    [anon_sym_shl] = ACTIONS(1293),
    [anon_sym_shr] = ACTIONS(1293),
    [anon_sym_sar] = ACTIONS(1293),
    [anon_sym_addmod] = ACTIONS(1293),
    [anon_sym_mulmod] = ACTIONS(1293),
    [anon_sym_signextend] = ACTIONS(1293),
    [anon_sym_keccak256] = ACTIONS(1293),
    [anon_sym_pop] = ACTIONS(1293),
    [anon_sym_mload] = ACTIONS(1293),
    [anon_sym_mstore] = ACTIONS(1293),
    [anon_sym_mstore8] = ACTIONS(1293),
    [anon_sym_sload] = ACTIONS(1293),
    [anon_sym_sstore] = ACTIONS(1293),
    [anon_sym_msize] = ACTIONS(1293),
    [anon_sym_gas] = ACTIONS(1293),
    [anon_sym_address] = ACTIONS(1293),
    [anon_sym_balance] = ACTIONS(1293),
    [anon_sym_selfbalance] = ACTIONS(1293),
    [anon_sym_caller] = ACTIONS(1293),
    [anon_sym_callvalue] = ACTIONS(1293),
    [anon_sym_calldataload] = ACTIONS(1293),
    [anon_sym_calldatasize] = ACTIONS(1293),
    [anon_sym_calldatacopy] = ACTIONS(1293),
    [anon_sym_extcodesize] = ACTIONS(1293),
    [anon_sym_extcodecopy] = ACTIONS(1293),
    [anon_sym_returndatasize] = ACTIONS(1293),
    [anon_sym_returndatacopy] = ACTIONS(1293),
    [anon_sym_extcodehash] = ACTIONS(1293),
    [anon_sym_create] = ACTIONS(1293),
    [anon_sym_create2] = ACTIONS(1293),
    [anon_sym_call] = ACTIONS(1293),
    [anon_sym_callcode] = ACTIONS(1293),
    [anon_sym_delegatecall] = ACTIONS(1293),
    [anon_sym_staticcall] = ACTIONS(1293),
    [anon_sym_return] = ACTIONS(1293),
    [anon_sym_revert] = ACTIONS(1293),
    [anon_sym_selfdestruct] = ACTIONS(1293),
    [anon_sym_invalid] = ACTIONS(1293),
    [anon_sym_log0] = ACTIONS(1293),
    [anon_sym_log1] = ACTIONS(1293),
    [anon_sym_log2] = ACTIONS(1293),
    [anon_sym_log3] = ACTIONS(1293),
    [anon_sym_log4] = ACTIONS(1293),
    [anon_sym_chainid] = ACTIONS(1293),
    [anon_sym_origin] = ACTIONS(1293),
    [anon_sym_gasprice] = ACTIONS(1293),
    [anon_sym_blockhash] = ACTIONS(1293),
    [anon_sym_coinbase] = ACTIONS(1293),
    [anon_sym_timestamp] = ACTIONS(1293),
    [anon_sym_number] = ACTIONS(1293),
    [anon_sym_difficulty] = ACTIONS(1293),
    [anon_sym_gaslimit] = ACTIONS(1293),
    [anon_sym_hex] = ACTIONS(1293),
    [anon_sym_DQUOTE] = ACTIONS(1295),
    [anon_sym_SQUOTE] = ACTIONS(1295),
    [sym_comment] = ACTIONS(3),
  },
  [359] = {
    [sym_identifier] = ACTIONS(1297),
    [anon_sym_LBRACE] = ACTIONS(1299),
    [anon_sym_RBRACE] = ACTIONS(1299),
    [anon_sym_for] = ACTIONS(1297),
    [sym_yul_leave] = ACTIONS(1297),
    [anon_sym_break] = ACTIONS(1297),
    [anon_sym_continue] = ACTIONS(1297),
    [sym_yul_decimal_number] = ACTIONS(1297),
    [sym_yul_hex_number] = ACTIONS(1299),
    [anon_sym_true] = ACTIONS(1297),
    [anon_sym_false] = ACTIONS(1297),
    [anon_sym_let] = ACTIONS(1297),
    [anon_sym_if] = ACTIONS(1297),
    [anon_sym_switch] = ACTIONS(1297),
    [anon_sym_function] = ACTIONS(1297),
    [anon_sym_stop] = ACTIONS(1297),
    [anon_sym_add] = ACTIONS(1297),
    [anon_sym_sub] = ACTIONS(1297),
    [anon_sym_mul] = ACTIONS(1297),
    [anon_sym_div] = ACTIONS(1297),
    [anon_sym_sdiv] = ACTIONS(1297),
    [anon_sym_mod] = ACTIONS(1297),
    [anon_sym_smod] = ACTIONS(1297),
    [anon_sym_exp] = ACTIONS(1297),
    [anon_sym_not] = ACTIONS(1297),
    [anon_sym_lt] = ACTIONS(1297),
    [anon_sym_gt] = ACTIONS(1297),
    [anon_sym_slt] = ACTIONS(1297),
    [anon_sym_sgt] = ACTIONS(1297),
    [anon_sym_eq] = ACTIONS(1297),
    [anon_sym_iszero] = ACTIONS(1297),
    [anon_sym_and] = ACTIONS(1297),
    [anon_sym_or] = ACTIONS(1297),
    [anon_sym_xor] = ACTIONS(1297),
    [anon_sym_byte] = ACTIONS(1297),
    [anon_sym_shl] = ACTIONS(1297),
    [anon_sym_shr] = ACTIONS(1297),
    [anon_sym_sar] = ACTIONS(1297),
    [anon_sym_addmod] = ACTIONS(1297),
    [anon_sym_mulmod] = ACTIONS(1297),
    [anon_sym_signextend] = ACTIONS(1297),
    [anon_sym_keccak256] = ACTIONS(1297),
    [anon_sym_pop] = ACTIONS(1297),
    [anon_sym_mload] = ACTIONS(1297),
    [anon_sym_mstore] = ACTIONS(1297),
    [anon_sym_mstore8] = ACTIONS(1297),
    [anon_sym_sload] = ACTIONS(1297),
    [anon_sym_sstore] = ACTIONS(1297),
    [anon_sym_msize] = ACTIONS(1297),
    [anon_sym_gas] = ACTIONS(1297),
    [anon_sym_address] = ACTIONS(1297),
    [anon_sym_balance] = ACTIONS(1297),
    [anon_sym_selfbalance] = ACTIONS(1297),
    [anon_sym_caller] = ACTIONS(1297),
    [anon_sym_callvalue] = ACTIONS(1297),
    [anon_sym_calldataload] = ACTIONS(1297),
    [anon_sym_calldatasize] = ACTIONS(1297),
    [anon_sym_calldatacopy] = ACTIONS(1297),
    [anon_sym_extcodesize] = ACTIONS(1297),
    [anon_sym_extcodecopy] = ACTIONS(1297),
    [anon_sym_returndatasize] = ACTIONS(1297),
    [anon_sym_returndatacopy] = ACTIONS(1297),
    [anon_sym_extcodehash] = ACTIONS(1297),
    [anon_sym_create] = ACTIONS(1297),
    [anon_sym_create2] = ACTIONS(1297),
    [anon_sym_call] = ACTIONS(1297),
    [anon_sym_callcode] = ACTIONS(1297),
    [anon_sym_delegatecall] = ACTIONS(1297),
    [anon_sym_staticcall] = ACTIONS(1297),
    [anon_sym_return] = ACTIONS(1297),
    [anon_sym_revert] = ACTIONS(1297),
    [anon_sym_selfdestruct] = ACTIONS(1297),
    [anon_sym_invalid] = ACTIONS(1297),
    [anon_sym_log0] = ACTIONS(1297),
    [anon_sym_log1] = ACTIONS(1297),
    [anon_sym_log2] = ACTIONS(1297),
    [anon_sym_log3] = ACTIONS(1297),
    [anon_sym_log4] = ACTIONS(1297),
    [anon_sym_chainid] = ACTIONS(1297),
    [anon_sym_origin] = ACTIONS(1297),
    [anon_sym_gasprice] = ACTIONS(1297),
    [anon_sym_blockhash] = ACTIONS(1297),
    [anon_sym_coinbase] = ACTIONS(1297),
    [anon_sym_timestamp] = ACTIONS(1297),
    [anon_sym_number] = ACTIONS(1297),
    [anon_sym_difficulty] = ACTIONS(1297),
    [anon_sym_gaslimit] = ACTIONS(1297),
    [anon_sym_hex] = ACTIONS(1297),
    [anon_sym_DQUOTE] = ACTIONS(1299),
    [anon_sym_SQUOTE] = ACTIONS(1299),
    [sym_comment] = ACTIONS(3),
  },
  [360] = {
    [sym_identifier] = ACTIONS(1301),
    [anon_sym_LBRACE] = ACTIONS(1303),
    [anon_sym_RBRACE] = ACTIONS(1303),
    [anon_sym_for] = ACTIONS(1301),
    [sym_yul_leave] = ACTIONS(1301),
    [anon_sym_break] = ACTIONS(1301),
    [anon_sym_continue] = ACTIONS(1301),
    [sym_yul_decimal_number] = ACTIONS(1301),
    [sym_yul_hex_number] = ACTIONS(1303),
    [anon_sym_true] = ACTIONS(1301),
    [anon_sym_false] = ACTIONS(1301),
    [anon_sym_let] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1301),
    [anon_sym_switch] = ACTIONS(1301),
    [anon_sym_function] = ACTIONS(1301),
    [anon_sym_stop] = ACTIONS(1301),
    [anon_sym_add] = ACTIONS(1301),
    [anon_sym_sub] = ACTIONS(1301),
    [anon_sym_mul] = ACTIONS(1301),
    [anon_sym_div] = ACTIONS(1301),
    [anon_sym_sdiv] = ACTIONS(1301),
    [anon_sym_mod] = ACTIONS(1301),
    [anon_sym_smod] = ACTIONS(1301),
    [anon_sym_exp] = ACTIONS(1301),
    [anon_sym_not] = ACTIONS(1301),
    [anon_sym_lt] = ACTIONS(1301),
    [anon_sym_gt] = ACTIONS(1301),
    [anon_sym_slt] = ACTIONS(1301),
    [anon_sym_sgt] = ACTIONS(1301),
    [anon_sym_eq] = ACTIONS(1301),
    [anon_sym_iszero] = ACTIONS(1301),
    [anon_sym_and] = ACTIONS(1301),
    [anon_sym_or] = ACTIONS(1301),
    [anon_sym_xor] = ACTIONS(1301),
    [anon_sym_byte] = ACTIONS(1301),
    [anon_sym_shl] = ACTIONS(1301),
    [anon_sym_shr] = ACTIONS(1301),
    [anon_sym_sar] = ACTIONS(1301),
    [anon_sym_addmod] = ACTIONS(1301),
    [anon_sym_mulmod] = ACTIONS(1301),
    [anon_sym_signextend] = ACTIONS(1301),
    [anon_sym_keccak256] = ACTIONS(1301),
    [anon_sym_pop] = ACTIONS(1301),
    [anon_sym_mload] = ACTIONS(1301),
    [anon_sym_mstore] = ACTIONS(1301),
    [anon_sym_mstore8] = ACTIONS(1301),
    [anon_sym_sload] = ACTIONS(1301),
    [anon_sym_sstore] = ACTIONS(1301),
    [anon_sym_msize] = ACTIONS(1301),
    [anon_sym_gas] = ACTIONS(1301),
    [anon_sym_address] = ACTIONS(1301),
    [anon_sym_balance] = ACTIONS(1301),
    [anon_sym_selfbalance] = ACTIONS(1301),
    [anon_sym_caller] = ACTIONS(1301),
    [anon_sym_callvalue] = ACTIONS(1301),
    [anon_sym_calldataload] = ACTIONS(1301),
    [anon_sym_calldatasize] = ACTIONS(1301),
    [anon_sym_calldatacopy] = ACTIONS(1301),
    [anon_sym_extcodesize] = ACTIONS(1301),
    [anon_sym_extcodecopy] = ACTIONS(1301),
    [anon_sym_returndatasize] = ACTIONS(1301),
    [anon_sym_returndatacopy] = ACTIONS(1301),
    [anon_sym_extcodehash] = ACTIONS(1301),
    [anon_sym_create] = ACTIONS(1301),
    [anon_sym_create2] = ACTIONS(1301),
    [anon_sym_call] = ACTIONS(1301),
    [anon_sym_callcode] = ACTIONS(1301),
    [anon_sym_delegatecall] = ACTIONS(1301),
    [anon_sym_staticcall] = ACTIONS(1301),
    [anon_sym_return] = ACTIONS(1301),
    [anon_sym_revert] = ACTIONS(1301),
    [anon_sym_selfdestruct] = ACTIONS(1301),
    [anon_sym_invalid] = ACTIONS(1301),
    [anon_sym_log0] = ACTIONS(1301),
    [anon_sym_log1] = ACTIONS(1301),
    [anon_sym_log2] = ACTIONS(1301),
    [anon_sym_log3] = ACTIONS(1301),
    [anon_sym_log4] = ACTIONS(1301),
    [anon_sym_chainid] = ACTIONS(1301),
    [anon_sym_origin] = ACTIONS(1301),
    [anon_sym_gasprice] = ACTIONS(1301),
    [anon_sym_blockhash] = ACTIONS(1301),
    [anon_sym_coinbase] = ACTIONS(1301),
    [anon_sym_timestamp] = ACTIONS(1301),
    [anon_sym_number] = ACTIONS(1301),
    [anon_sym_difficulty] = ACTIONS(1301),
    [anon_sym_gaslimit] = ACTIONS(1301),
    [anon_sym_hex] = ACTIONS(1301),
    [anon_sym_DQUOTE] = ACTIONS(1303),
    [anon_sym_SQUOTE] = ACTIONS(1303),
    [sym_comment] = ACTIONS(3),
  },
  [361] = {
    [sym_identifier] = ACTIONS(1305),
    [anon_sym_LBRACE] = ACTIONS(1307),
    [anon_sym_RBRACE] = ACTIONS(1307),
    [anon_sym_for] = ACTIONS(1305),
    [sym_yul_leave] = ACTIONS(1305),
    [anon_sym_break] = ACTIONS(1305),
    [anon_sym_continue] = ACTIONS(1305),
    [sym_yul_decimal_number] = ACTIONS(1305),
    [sym_yul_hex_number] = ACTIONS(1307),
    [anon_sym_true] = ACTIONS(1305),
    [anon_sym_false] = ACTIONS(1305),
    [anon_sym_let] = ACTIONS(1305),
    [anon_sym_if] = ACTIONS(1305),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_function] = ACTIONS(1305),
    [anon_sym_stop] = ACTIONS(1305),
    [anon_sym_add] = ACTIONS(1305),
    [anon_sym_sub] = ACTIONS(1305),
    [anon_sym_mul] = ACTIONS(1305),
    [anon_sym_div] = ACTIONS(1305),
    [anon_sym_sdiv] = ACTIONS(1305),
    [anon_sym_mod] = ACTIONS(1305),
    [anon_sym_smod] = ACTIONS(1305),
    [anon_sym_exp] = ACTIONS(1305),
    [anon_sym_not] = ACTIONS(1305),
    [anon_sym_lt] = ACTIONS(1305),
    [anon_sym_gt] = ACTIONS(1305),
    [anon_sym_slt] = ACTIONS(1305),
    [anon_sym_sgt] = ACTIONS(1305),
    [anon_sym_eq] = ACTIONS(1305),
    [anon_sym_iszero] = ACTIONS(1305),
    [anon_sym_and] = ACTIONS(1305),
    [anon_sym_or] = ACTIONS(1305),
    [anon_sym_xor] = ACTIONS(1305),
    [anon_sym_byte] = ACTIONS(1305),
    [anon_sym_shl] = ACTIONS(1305),
    [anon_sym_shr] = ACTIONS(1305),
    [anon_sym_sar] = ACTIONS(1305),
    [anon_sym_addmod] = ACTIONS(1305),
    [anon_sym_mulmod] = ACTIONS(1305),
    [anon_sym_signextend] = ACTIONS(1305),
    [anon_sym_keccak256] = ACTIONS(1305),
    [anon_sym_pop] = ACTIONS(1305),
    [anon_sym_mload] = ACTIONS(1305),
    [anon_sym_mstore] = ACTIONS(1305),
    [anon_sym_mstore8] = ACTIONS(1305),
    [anon_sym_sload] = ACTIONS(1305),
    [anon_sym_sstore] = ACTIONS(1305),
    [anon_sym_msize] = ACTIONS(1305),
    [anon_sym_gas] = ACTIONS(1305),
    [anon_sym_address] = ACTIONS(1305),
    [anon_sym_balance] = ACTIONS(1305),
    [anon_sym_selfbalance] = ACTIONS(1305),
    [anon_sym_caller] = ACTIONS(1305),
    [anon_sym_callvalue] = ACTIONS(1305),
    [anon_sym_calldataload] = ACTIONS(1305),
    [anon_sym_calldatasize] = ACTIONS(1305),
    [anon_sym_calldatacopy] = ACTIONS(1305),
    [anon_sym_extcodesize] = ACTIONS(1305),
    [anon_sym_extcodecopy] = ACTIONS(1305),
    [anon_sym_returndatasize] = ACTIONS(1305),
    [anon_sym_returndatacopy] = ACTIONS(1305),
    [anon_sym_extcodehash] = ACTIONS(1305),
    [anon_sym_create] = ACTIONS(1305),
    [anon_sym_create2] = ACTIONS(1305),
    [anon_sym_call] = ACTIONS(1305),
    [anon_sym_callcode] = ACTIONS(1305),
    [anon_sym_delegatecall] = ACTIONS(1305),
    [anon_sym_staticcall] = ACTIONS(1305),
    [anon_sym_return] = ACTIONS(1305),
    [anon_sym_revert] = ACTIONS(1305),
    [anon_sym_selfdestruct] = ACTIONS(1305),
    [anon_sym_invalid] = ACTIONS(1305),
    [anon_sym_log0] = ACTIONS(1305),
    [anon_sym_log1] = ACTIONS(1305),
    [anon_sym_log2] = ACTIONS(1305),
    [anon_sym_log3] = ACTIONS(1305),
    [anon_sym_log4] = ACTIONS(1305),
    [anon_sym_chainid] = ACTIONS(1305),
    [anon_sym_origin] = ACTIONS(1305),
    [anon_sym_gasprice] = ACTIONS(1305),
    [anon_sym_blockhash] = ACTIONS(1305),
    [anon_sym_coinbase] = ACTIONS(1305),
    [anon_sym_timestamp] = ACTIONS(1305),
    [anon_sym_number] = ACTIONS(1305),
    [anon_sym_difficulty] = ACTIONS(1305),
    [anon_sym_gaslimit] = ACTIONS(1305),
    [anon_sym_hex] = ACTIONS(1305),
    [anon_sym_DQUOTE] = ACTIONS(1307),
    [anon_sym_SQUOTE] = ACTIONS(1307),
    [sym_comment] = ACTIONS(3),
  },
  [362] = {
    [sym_identifier] = ACTIONS(1309),
    [anon_sym_LBRACE] = ACTIONS(1311),
    [anon_sym_RBRACE] = ACTIONS(1311),
    [anon_sym_for] = ACTIONS(1309),
    [sym_yul_leave] = ACTIONS(1309),
    [anon_sym_break] = ACTIONS(1309),
    [anon_sym_continue] = ACTIONS(1309),
    [sym_yul_decimal_number] = ACTIONS(1309),
    [sym_yul_hex_number] = ACTIONS(1311),
    [anon_sym_true] = ACTIONS(1309),
    [anon_sym_false] = ACTIONS(1309),
    [anon_sym_let] = ACTIONS(1309),
    [anon_sym_if] = ACTIONS(1309),
    [anon_sym_switch] = ACTIONS(1309),
    [anon_sym_function] = ACTIONS(1309),
    [anon_sym_stop] = ACTIONS(1309),
    [anon_sym_add] = ACTIONS(1309),
    [anon_sym_sub] = ACTIONS(1309),
    [anon_sym_mul] = ACTIONS(1309),
    [anon_sym_div] = ACTIONS(1309),
    [anon_sym_sdiv] = ACTIONS(1309),
    [anon_sym_mod] = ACTIONS(1309),
    [anon_sym_smod] = ACTIONS(1309),
    [anon_sym_exp] = ACTIONS(1309),
    [anon_sym_not] = ACTIONS(1309),
    [anon_sym_lt] = ACTIONS(1309),
    [anon_sym_gt] = ACTIONS(1309),
    [anon_sym_slt] = ACTIONS(1309),
    [anon_sym_sgt] = ACTIONS(1309),
    [anon_sym_eq] = ACTIONS(1309),
    [anon_sym_iszero] = ACTIONS(1309),
    [anon_sym_and] = ACTIONS(1309),
    [anon_sym_or] = ACTIONS(1309),
    [anon_sym_xor] = ACTIONS(1309),
    [anon_sym_byte] = ACTIONS(1309),
    [anon_sym_shl] = ACTIONS(1309),
    [anon_sym_shr] = ACTIONS(1309),
    [anon_sym_sar] = ACTIONS(1309),
    [anon_sym_addmod] = ACTIONS(1309),
    [anon_sym_mulmod] = ACTIONS(1309),
    [anon_sym_signextend] = ACTIONS(1309),
    [anon_sym_keccak256] = ACTIONS(1309),
    [anon_sym_pop] = ACTIONS(1309),
    [anon_sym_mload] = ACTIONS(1309),
    [anon_sym_mstore] = ACTIONS(1309),
    [anon_sym_mstore8] = ACTIONS(1309),
    [anon_sym_sload] = ACTIONS(1309),
    [anon_sym_sstore] = ACTIONS(1309),
    [anon_sym_msize] = ACTIONS(1309),
    [anon_sym_gas] = ACTIONS(1309),
    [anon_sym_address] = ACTIONS(1309),
    [anon_sym_balance] = ACTIONS(1309),
    [anon_sym_selfbalance] = ACTIONS(1309),
    [anon_sym_caller] = ACTIONS(1309),
    [anon_sym_callvalue] = ACTIONS(1309),
    [anon_sym_calldataload] = ACTIONS(1309),
    [anon_sym_calldatasize] = ACTIONS(1309),
    [anon_sym_calldatacopy] = ACTIONS(1309),
    [anon_sym_extcodesize] = ACTIONS(1309),
    [anon_sym_extcodecopy] = ACTIONS(1309),
    [anon_sym_returndatasize] = ACTIONS(1309),
    [anon_sym_returndatacopy] = ACTIONS(1309),
    [anon_sym_extcodehash] = ACTIONS(1309),
    [anon_sym_create] = ACTIONS(1309),
    [anon_sym_create2] = ACTIONS(1309),
    [anon_sym_call] = ACTIONS(1309),
    [anon_sym_callcode] = ACTIONS(1309),
    [anon_sym_delegatecall] = ACTIONS(1309),
    [anon_sym_staticcall] = ACTIONS(1309),
    [anon_sym_return] = ACTIONS(1309),
    [anon_sym_revert] = ACTIONS(1309),
    [anon_sym_selfdestruct] = ACTIONS(1309),
    [anon_sym_invalid] = ACTIONS(1309),
    [anon_sym_log0] = ACTIONS(1309),
    [anon_sym_log1] = ACTIONS(1309),
    [anon_sym_log2] = ACTIONS(1309),
    [anon_sym_log3] = ACTIONS(1309),
    [anon_sym_log4] = ACTIONS(1309),
    [anon_sym_chainid] = ACTIONS(1309),
    [anon_sym_origin] = ACTIONS(1309),
    [anon_sym_gasprice] = ACTIONS(1309),
    [anon_sym_blockhash] = ACTIONS(1309),
    [anon_sym_coinbase] = ACTIONS(1309),
    [anon_sym_timestamp] = ACTIONS(1309),
    [anon_sym_number] = ACTIONS(1309),
    [anon_sym_difficulty] = ACTIONS(1309),
    [anon_sym_gaslimit] = ACTIONS(1309),
    [anon_sym_hex] = ACTIONS(1309),
    [anon_sym_DQUOTE] = ACTIONS(1311),
    [anon_sym_SQUOTE] = ACTIONS(1311),
    [sym_comment] = ACTIONS(3),
  },
  [363] = {
    [sym_identifier] = ACTIONS(1313),
    [anon_sym_LBRACE] = ACTIONS(1315),
    [anon_sym_RBRACE] = ACTIONS(1315),
    [anon_sym_for] = ACTIONS(1313),
    [sym_yul_leave] = ACTIONS(1313),
    [anon_sym_break] = ACTIONS(1313),
    [anon_sym_continue] = ACTIONS(1313),
    [sym_yul_decimal_number] = ACTIONS(1313),
    [sym_yul_hex_number] = ACTIONS(1315),
    [anon_sym_true] = ACTIONS(1313),
    [anon_sym_false] = ACTIONS(1313),
    [anon_sym_let] = ACTIONS(1313),
    [anon_sym_if] = ACTIONS(1313),
    [anon_sym_switch] = ACTIONS(1313),
    [anon_sym_function] = ACTIONS(1313),
    [anon_sym_stop] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1313),
    [anon_sym_sub] = ACTIONS(1313),
    [anon_sym_mul] = ACTIONS(1313),
    [anon_sym_div] = ACTIONS(1313),
    [anon_sym_sdiv] = ACTIONS(1313),
    [anon_sym_mod] = ACTIONS(1313),
    [anon_sym_smod] = ACTIONS(1313),
    [anon_sym_exp] = ACTIONS(1313),
    [anon_sym_not] = ACTIONS(1313),
    [anon_sym_lt] = ACTIONS(1313),
    [anon_sym_gt] = ACTIONS(1313),
    [anon_sym_slt] = ACTIONS(1313),
    [anon_sym_sgt] = ACTIONS(1313),
    [anon_sym_eq] = ACTIONS(1313),
    [anon_sym_iszero] = ACTIONS(1313),
    [anon_sym_and] = ACTIONS(1313),
    [anon_sym_or] = ACTIONS(1313),
    [anon_sym_xor] = ACTIONS(1313),
    [anon_sym_byte] = ACTIONS(1313),
    [anon_sym_shl] = ACTIONS(1313),
    [anon_sym_shr] = ACTIONS(1313),
    [anon_sym_sar] = ACTIONS(1313),
    [anon_sym_addmod] = ACTIONS(1313),
    [anon_sym_mulmod] = ACTIONS(1313),
    [anon_sym_signextend] = ACTIONS(1313),
    [anon_sym_keccak256] = ACTIONS(1313),
    [anon_sym_pop] = ACTIONS(1313),
    [anon_sym_mload] = ACTIONS(1313),
    [anon_sym_mstore] = ACTIONS(1313),
    [anon_sym_mstore8] = ACTIONS(1313),
    [anon_sym_sload] = ACTIONS(1313),
    [anon_sym_sstore] = ACTIONS(1313),
    [anon_sym_msize] = ACTIONS(1313),
    [anon_sym_gas] = ACTIONS(1313),
    [anon_sym_address] = ACTIONS(1313),
    [anon_sym_balance] = ACTIONS(1313),
    [anon_sym_selfbalance] = ACTIONS(1313),
    [anon_sym_caller] = ACTIONS(1313),
    [anon_sym_callvalue] = ACTIONS(1313),
    [anon_sym_calldataload] = ACTIONS(1313),
    [anon_sym_calldatasize] = ACTIONS(1313),
    [anon_sym_calldatacopy] = ACTIONS(1313),
    [anon_sym_extcodesize] = ACTIONS(1313),
    [anon_sym_extcodecopy] = ACTIONS(1313),
    [anon_sym_returndatasize] = ACTIONS(1313),
    [anon_sym_returndatacopy] = ACTIONS(1313),
    [anon_sym_extcodehash] = ACTIONS(1313),
    [anon_sym_create] = ACTIONS(1313),
    [anon_sym_create2] = ACTIONS(1313),
    [anon_sym_call] = ACTIONS(1313),
    [anon_sym_callcode] = ACTIONS(1313),
    [anon_sym_delegatecall] = ACTIONS(1313),
    [anon_sym_staticcall] = ACTIONS(1313),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_revert] = ACTIONS(1313),
    [anon_sym_selfdestruct] = ACTIONS(1313),
    [anon_sym_invalid] = ACTIONS(1313),
    [anon_sym_log0] = ACTIONS(1313),
    [anon_sym_log1] = ACTIONS(1313),
    [anon_sym_log2] = ACTIONS(1313),
    [anon_sym_log3] = ACTIONS(1313),
    [anon_sym_log4] = ACTIONS(1313),
    [anon_sym_chainid] = ACTIONS(1313),
    [anon_sym_origin] = ACTIONS(1313),
    [anon_sym_gasprice] = ACTIONS(1313),
    [anon_sym_blockhash] = ACTIONS(1313),
    [anon_sym_coinbase] = ACTIONS(1313),
    [anon_sym_timestamp] = ACTIONS(1313),
    [anon_sym_number] = ACTIONS(1313),
    [anon_sym_difficulty] = ACTIONS(1313),
    [anon_sym_gaslimit] = ACTIONS(1313),
    [anon_sym_hex] = ACTIONS(1313),
    [anon_sym_DQUOTE] = ACTIONS(1315),
    [anon_sym_SQUOTE] = ACTIONS(1315),
    [sym_comment] = ACTIONS(3),
  },
  [364] = {
    [sym_identifier] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(1319),
    [anon_sym_RBRACE] = ACTIONS(1319),
    [anon_sym_for] = ACTIONS(1317),
    [sym_yul_leave] = ACTIONS(1317),
    [anon_sym_break] = ACTIONS(1317),
    [anon_sym_continue] = ACTIONS(1317),
    [sym_yul_decimal_number] = ACTIONS(1317),
    [sym_yul_hex_number] = ACTIONS(1319),
    [anon_sym_true] = ACTIONS(1317),
    [anon_sym_false] = ACTIONS(1317),
    [anon_sym_let] = ACTIONS(1317),
    [anon_sym_if] = ACTIONS(1317),
    [anon_sym_switch] = ACTIONS(1317),
    [anon_sym_function] = ACTIONS(1317),
    [anon_sym_stop] = ACTIONS(1317),
    [anon_sym_add] = ACTIONS(1317),
    [anon_sym_sub] = ACTIONS(1317),
    [anon_sym_mul] = ACTIONS(1317),
    [anon_sym_div] = ACTIONS(1317),
    [anon_sym_sdiv] = ACTIONS(1317),
    [anon_sym_mod] = ACTIONS(1317),
    [anon_sym_smod] = ACTIONS(1317),
    [anon_sym_exp] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1317),
    [anon_sym_lt] = ACTIONS(1317),
    [anon_sym_gt] = ACTIONS(1317),
    [anon_sym_slt] = ACTIONS(1317),
    [anon_sym_sgt] = ACTIONS(1317),
    [anon_sym_eq] = ACTIONS(1317),
    [anon_sym_iszero] = ACTIONS(1317),
    [anon_sym_and] = ACTIONS(1317),
    [anon_sym_or] = ACTIONS(1317),
    [anon_sym_xor] = ACTIONS(1317),
    [anon_sym_byte] = ACTIONS(1317),
    [anon_sym_shl] = ACTIONS(1317),
    [anon_sym_shr] = ACTIONS(1317),
    [anon_sym_sar] = ACTIONS(1317),
    [anon_sym_addmod] = ACTIONS(1317),
    [anon_sym_mulmod] = ACTIONS(1317),
    [anon_sym_signextend] = ACTIONS(1317),
    [anon_sym_keccak256] = ACTIONS(1317),
    [anon_sym_pop] = ACTIONS(1317),
    [anon_sym_mload] = ACTIONS(1317),
    [anon_sym_mstore] = ACTIONS(1317),
    [anon_sym_mstore8] = ACTIONS(1317),
    [anon_sym_sload] = ACTIONS(1317),
    [anon_sym_sstore] = ACTIONS(1317),
    [anon_sym_msize] = ACTIONS(1317),
    [anon_sym_gas] = ACTIONS(1317),
    [anon_sym_address] = ACTIONS(1317),
    [anon_sym_balance] = ACTIONS(1317),
    [anon_sym_selfbalance] = ACTIONS(1317),
    [anon_sym_caller] = ACTIONS(1317),
    [anon_sym_callvalue] = ACTIONS(1317),
    [anon_sym_calldataload] = ACTIONS(1317),
    [anon_sym_calldatasize] = ACTIONS(1317),
    [anon_sym_calldatacopy] = ACTIONS(1317),
    [anon_sym_extcodesize] = ACTIONS(1317),
    [anon_sym_extcodecopy] = ACTIONS(1317),
    [anon_sym_returndatasize] = ACTIONS(1317),
    [anon_sym_returndatacopy] = ACTIONS(1317),
    [anon_sym_extcodehash] = ACTIONS(1317),
    [anon_sym_create] = ACTIONS(1317),
    [anon_sym_create2] = ACTIONS(1317),
    [anon_sym_call] = ACTIONS(1317),
    [anon_sym_callcode] = ACTIONS(1317),
    [anon_sym_delegatecall] = ACTIONS(1317),
    [anon_sym_staticcall] = ACTIONS(1317),
    [anon_sym_return] = ACTIONS(1317),
    [anon_sym_revert] = ACTIONS(1317),
    [anon_sym_selfdestruct] = ACTIONS(1317),
    [anon_sym_invalid] = ACTIONS(1317),
    [anon_sym_log0] = ACTIONS(1317),
    [anon_sym_log1] = ACTIONS(1317),
    [anon_sym_log2] = ACTIONS(1317),
    [anon_sym_log3] = ACTIONS(1317),
    [anon_sym_log4] = ACTIONS(1317),
    [anon_sym_chainid] = ACTIONS(1317),
    [anon_sym_origin] = ACTIONS(1317),
    [anon_sym_gasprice] = ACTIONS(1317),
    [anon_sym_blockhash] = ACTIONS(1317),
    [anon_sym_coinbase] = ACTIONS(1317),
    [anon_sym_timestamp] = ACTIONS(1317),
    [anon_sym_number] = ACTIONS(1317),
    [anon_sym_difficulty] = ACTIONS(1317),
    [anon_sym_gaslimit] = ACTIONS(1317),
    [anon_sym_hex] = ACTIONS(1317),
    [anon_sym_DQUOTE] = ACTIONS(1319),
    [anon_sym_SQUOTE] = ACTIONS(1319),
    [sym_comment] = ACTIONS(3),
  },
  [365] = {
    [sym_identifier] = ACTIONS(1321),
    [anon_sym_LBRACE] = ACTIONS(1323),
    [anon_sym_RBRACE] = ACTIONS(1323),
    [anon_sym_for] = ACTIONS(1321),
    [sym_yul_leave] = ACTIONS(1321),
    [anon_sym_break] = ACTIONS(1321),
    [anon_sym_continue] = ACTIONS(1321),
    [sym_yul_decimal_number] = ACTIONS(1321),
    [sym_yul_hex_number] = ACTIONS(1323),
    [anon_sym_true] = ACTIONS(1321),
    [anon_sym_false] = ACTIONS(1321),
    [anon_sym_let] = ACTIONS(1321),
    [anon_sym_if] = ACTIONS(1321),
    [anon_sym_switch] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(1321),
    [anon_sym_stop] = ACTIONS(1321),
    [anon_sym_add] = ACTIONS(1321),
    [anon_sym_sub] = ACTIONS(1321),
    [anon_sym_mul] = ACTIONS(1321),
    [anon_sym_div] = ACTIONS(1321),
    [anon_sym_sdiv] = ACTIONS(1321),
    [anon_sym_mod] = ACTIONS(1321),
    [anon_sym_smod] = ACTIONS(1321),
    [anon_sym_exp] = ACTIONS(1321),
    [anon_sym_not] = ACTIONS(1321),
    [anon_sym_lt] = ACTIONS(1321),
    [anon_sym_gt] = ACTIONS(1321),
    [anon_sym_slt] = ACTIONS(1321),
    [anon_sym_sgt] = ACTIONS(1321),
    [anon_sym_eq] = ACTIONS(1321),
    [anon_sym_iszero] = ACTIONS(1321),
    [anon_sym_and] = ACTIONS(1321),
    [anon_sym_or] = ACTIONS(1321),
    [anon_sym_xor] = ACTIONS(1321),
    [anon_sym_byte] = ACTIONS(1321),
    [anon_sym_shl] = ACTIONS(1321),
    [anon_sym_shr] = ACTIONS(1321),
    [anon_sym_sar] = ACTIONS(1321),
    [anon_sym_addmod] = ACTIONS(1321),
    [anon_sym_mulmod] = ACTIONS(1321),
    [anon_sym_signextend] = ACTIONS(1321),
    [anon_sym_keccak256] = ACTIONS(1321),
    [anon_sym_pop] = ACTIONS(1321),
    [anon_sym_mload] = ACTIONS(1321),
    [anon_sym_mstore] = ACTIONS(1321),
    [anon_sym_mstore8] = ACTIONS(1321),
    [anon_sym_sload] = ACTIONS(1321),
    [anon_sym_sstore] = ACTIONS(1321),
    [anon_sym_msize] = ACTIONS(1321),
    [anon_sym_gas] = ACTIONS(1321),
    [anon_sym_address] = ACTIONS(1321),
    [anon_sym_balance] = ACTIONS(1321),
    [anon_sym_selfbalance] = ACTIONS(1321),
    [anon_sym_caller] = ACTIONS(1321),
    [anon_sym_callvalue] = ACTIONS(1321),
    [anon_sym_calldataload] = ACTIONS(1321),
    [anon_sym_calldatasize] = ACTIONS(1321),
    [anon_sym_calldatacopy] = ACTIONS(1321),
    [anon_sym_extcodesize] = ACTIONS(1321),
    [anon_sym_extcodecopy] = ACTIONS(1321),
    [anon_sym_returndatasize] = ACTIONS(1321),
    [anon_sym_returndatacopy] = ACTIONS(1321),
    [anon_sym_extcodehash] = ACTIONS(1321),
    [anon_sym_create] = ACTIONS(1321),
    [anon_sym_create2] = ACTIONS(1321),
    [anon_sym_call] = ACTIONS(1321),
    [anon_sym_callcode] = ACTIONS(1321),
    [anon_sym_delegatecall] = ACTIONS(1321),
    [anon_sym_staticcall] = ACTIONS(1321),
    [anon_sym_return] = ACTIONS(1321),
    [anon_sym_revert] = ACTIONS(1321),
    [anon_sym_selfdestruct] = ACTIONS(1321),
    [anon_sym_invalid] = ACTIONS(1321),
    [anon_sym_log0] = ACTIONS(1321),
    [anon_sym_log1] = ACTIONS(1321),
    [anon_sym_log2] = ACTIONS(1321),
    [anon_sym_log3] = ACTIONS(1321),
    [anon_sym_log4] = ACTIONS(1321),
    [anon_sym_chainid] = ACTIONS(1321),
    [anon_sym_origin] = ACTIONS(1321),
    [anon_sym_gasprice] = ACTIONS(1321),
    [anon_sym_blockhash] = ACTIONS(1321),
    [anon_sym_coinbase] = ACTIONS(1321),
    [anon_sym_timestamp] = ACTIONS(1321),
    [anon_sym_number] = ACTIONS(1321),
    [anon_sym_difficulty] = ACTIONS(1321),
    [anon_sym_gaslimit] = ACTIONS(1321),
    [anon_sym_hex] = ACTIONS(1321),
    [anon_sym_DQUOTE] = ACTIONS(1323),
    [anon_sym_SQUOTE] = ACTIONS(1323),
    [sym_comment] = ACTIONS(3),
  },
  [366] = {
    [sym_identifier] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(1327),
    [anon_sym_for] = ACTIONS(1325),
    [sym_yul_leave] = ACTIONS(1325),
    [anon_sym_break] = ACTIONS(1325),
    [anon_sym_continue] = ACTIONS(1325),
    [sym_yul_decimal_number] = ACTIONS(1325),
    [sym_yul_hex_number] = ACTIONS(1327),
    [anon_sym_true] = ACTIONS(1325),
    [anon_sym_false] = ACTIONS(1325),
    [anon_sym_let] = ACTIONS(1325),
    [anon_sym_if] = ACTIONS(1325),
    [anon_sym_switch] = ACTIONS(1325),
    [anon_sym_function] = ACTIONS(1325),
    [anon_sym_stop] = ACTIONS(1325),
    [anon_sym_add] = ACTIONS(1325),
    [anon_sym_sub] = ACTIONS(1325),
    [anon_sym_mul] = ACTIONS(1325),
    [anon_sym_div] = ACTIONS(1325),
    [anon_sym_sdiv] = ACTIONS(1325),
    [anon_sym_mod] = ACTIONS(1325),
    [anon_sym_smod] = ACTIONS(1325),
    [anon_sym_exp] = ACTIONS(1325),
    [anon_sym_not] = ACTIONS(1325),
    [anon_sym_lt] = ACTIONS(1325),
    [anon_sym_gt] = ACTIONS(1325),
    [anon_sym_slt] = ACTIONS(1325),
    [anon_sym_sgt] = ACTIONS(1325),
    [anon_sym_eq] = ACTIONS(1325),
    [anon_sym_iszero] = ACTIONS(1325),
    [anon_sym_and] = ACTIONS(1325),
    [anon_sym_or] = ACTIONS(1325),
    [anon_sym_xor] = ACTIONS(1325),
    [anon_sym_byte] = ACTIONS(1325),
    [anon_sym_shl] = ACTIONS(1325),
    [anon_sym_shr] = ACTIONS(1325),
    [anon_sym_sar] = ACTIONS(1325),
    [anon_sym_addmod] = ACTIONS(1325),
    [anon_sym_mulmod] = ACTIONS(1325),
    [anon_sym_signextend] = ACTIONS(1325),
    [anon_sym_keccak256] = ACTIONS(1325),
    [anon_sym_pop] = ACTIONS(1325),
    [anon_sym_mload] = ACTIONS(1325),
    [anon_sym_mstore] = ACTIONS(1325),
    [anon_sym_mstore8] = ACTIONS(1325),
    [anon_sym_sload] = ACTIONS(1325),
    [anon_sym_sstore] = ACTIONS(1325),
    [anon_sym_msize] = ACTIONS(1325),
    [anon_sym_gas] = ACTIONS(1325),
    [anon_sym_address] = ACTIONS(1325),
    [anon_sym_balance] = ACTIONS(1325),
    [anon_sym_selfbalance] = ACTIONS(1325),
    [anon_sym_caller] = ACTIONS(1325),
    [anon_sym_callvalue] = ACTIONS(1325),
    [anon_sym_calldataload] = ACTIONS(1325),
    [anon_sym_calldatasize] = ACTIONS(1325),
    [anon_sym_calldatacopy] = ACTIONS(1325),
    [anon_sym_extcodesize] = ACTIONS(1325),
    [anon_sym_extcodecopy] = ACTIONS(1325),
    [anon_sym_returndatasize] = ACTIONS(1325),
    [anon_sym_returndatacopy] = ACTIONS(1325),
    [anon_sym_extcodehash] = ACTIONS(1325),
    [anon_sym_create] = ACTIONS(1325),
    [anon_sym_create2] = ACTIONS(1325),
    [anon_sym_call] = ACTIONS(1325),
    [anon_sym_callcode] = ACTIONS(1325),
    [anon_sym_delegatecall] = ACTIONS(1325),
    [anon_sym_staticcall] = ACTIONS(1325),
    [anon_sym_return] = ACTIONS(1325),
    [anon_sym_revert] = ACTIONS(1325),
    [anon_sym_selfdestruct] = ACTIONS(1325),
    [anon_sym_invalid] = ACTIONS(1325),
    [anon_sym_log0] = ACTIONS(1325),
    [anon_sym_log1] = ACTIONS(1325),
    [anon_sym_log2] = ACTIONS(1325),
    [anon_sym_log3] = ACTIONS(1325),
    [anon_sym_log4] = ACTIONS(1325),
    [anon_sym_chainid] = ACTIONS(1325),
    [anon_sym_origin] = ACTIONS(1325),
    [anon_sym_gasprice] = ACTIONS(1325),
    [anon_sym_blockhash] = ACTIONS(1325),
    [anon_sym_coinbase] = ACTIONS(1325),
    [anon_sym_timestamp] = ACTIONS(1325),
    [anon_sym_number] = ACTIONS(1325),
    [anon_sym_difficulty] = ACTIONS(1325),
    [anon_sym_gaslimit] = ACTIONS(1325),
    [anon_sym_hex] = ACTIONS(1325),
    [anon_sym_DQUOTE] = ACTIONS(1327),
    [anon_sym_SQUOTE] = ACTIONS(1327),
    [sym_comment] = ACTIONS(3),
  },
  [367] = {
    [sym_identifier] = ACTIONS(1329),
    [anon_sym_LBRACE] = ACTIONS(1331),
    [anon_sym_RBRACE] = ACTIONS(1331),
    [anon_sym_for] = ACTIONS(1329),
    [sym_yul_leave] = ACTIONS(1329),
    [anon_sym_break] = ACTIONS(1329),
    [anon_sym_continue] = ACTIONS(1329),
    [sym_yul_decimal_number] = ACTIONS(1329),
    [sym_yul_hex_number] = ACTIONS(1331),
    [anon_sym_true] = ACTIONS(1329),
    [anon_sym_false] = ACTIONS(1329),
    [anon_sym_let] = ACTIONS(1329),
    [anon_sym_if] = ACTIONS(1329),
    [anon_sym_switch] = ACTIONS(1329),
    [anon_sym_function] = ACTIONS(1329),
    [anon_sym_stop] = ACTIONS(1329),
    [anon_sym_add] = ACTIONS(1329),
    [anon_sym_sub] = ACTIONS(1329),
    [anon_sym_mul] = ACTIONS(1329),
    [anon_sym_div] = ACTIONS(1329),
    [anon_sym_sdiv] = ACTIONS(1329),
    [anon_sym_mod] = ACTIONS(1329),
    [anon_sym_smod] = ACTIONS(1329),
    [anon_sym_exp] = ACTIONS(1329),
    [anon_sym_not] = ACTIONS(1329),
    [anon_sym_lt] = ACTIONS(1329),
    [anon_sym_gt] = ACTIONS(1329),
    [anon_sym_slt] = ACTIONS(1329),
    [anon_sym_sgt] = ACTIONS(1329),
    [anon_sym_eq] = ACTIONS(1329),
    [anon_sym_iszero] = ACTIONS(1329),
    [anon_sym_and] = ACTIONS(1329),
    [anon_sym_or] = ACTIONS(1329),
    [anon_sym_xor] = ACTIONS(1329),
    [anon_sym_byte] = ACTIONS(1329),
    [anon_sym_shl] = ACTIONS(1329),
    [anon_sym_shr] = ACTIONS(1329),
    [anon_sym_sar] = ACTIONS(1329),
    [anon_sym_addmod] = ACTIONS(1329),
    [anon_sym_mulmod] = ACTIONS(1329),
    [anon_sym_signextend] = ACTIONS(1329),
    [anon_sym_keccak256] = ACTIONS(1329),
    [anon_sym_pop] = ACTIONS(1329),
    [anon_sym_mload] = ACTIONS(1329),
    [anon_sym_mstore] = ACTIONS(1329),
    [anon_sym_mstore8] = ACTIONS(1329),
    [anon_sym_sload] = ACTIONS(1329),
    [anon_sym_sstore] = ACTIONS(1329),
    [anon_sym_msize] = ACTIONS(1329),
    [anon_sym_gas] = ACTIONS(1329),
    [anon_sym_address] = ACTIONS(1329),
    [anon_sym_balance] = ACTIONS(1329),
    [anon_sym_selfbalance] = ACTIONS(1329),
    [anon_sym_caller] = ACTIONS(1329),
    [anon_sym_callvalue] = ACTIONS(1329),
    [anon_sym_calldataload] = ACTIONS(1329),
    [anon_sym_calldatasize] = ACTIONS(1329),
    [anon_sym_calldatacopy] = ACTIONS(1329),
    [anon_sym_extcodesize] = ACTIONS(1329),
    [anon_sym_extcodecopy] = ACTIONS(1329),
    [anon_sym_returndatasize] = ACTIONS(1329),
    [anon_sym_returndatacopy] = ACTIONS(1329),
    [anon_sym_extcodehash] = ACTIONS(1329),
    [anon_sym_create] = ACTIONS(1329),
    [anon_sym_create2] = ACTIONS(1329),
    [anon_sym_call] = ACTIONS(1329),
    [anon_sym_callcode] = ACTIONS(1329),
    [anon_sym_delegatecall] = ACTIONS(1329),
    [anon_sym_staticcall] = ACTIONS(1329),
    [anon_sym_return] = ACTIONS(1329),
    [anon_sym_revert] = ACTIONS(1329),
    [anon_sym_selfdestruct] = ACTIONS(1329),
    [anon_sym_invalid] = ACTIONS(1329),
    [anon_sym_log0] = ACTIONS(1329),
    [anon_sym_log1] = ACTIONS(1329),
    [anon_sym_log2] = ACTIONS(1329),
    [anon_sym_log3] = ACTIONS(1329),
    [anon_sym_log4] = ACTIONS(1329),
    [anon_sym_chainid] = ACTIONS(1329),
    [anon_sym_origin] = ACTIONS(1329),
    [anon_sym_gasprice] = ACTIONS(1329),
    [anon_sym_blockhash] = ACTIONS(1329),
    [anon_sym_coinbase] = ACTIONS(1329),
    [anon_sym_timestamp] = ACTIONS(1329),
    [anon_sym_number] = ACTIONS(1329),
    [anon_sym_difficulty] = ACTIONS(1329),
    [anon_sym_gaslimit] = ACTIONS(1329),
    [anon_sym_hex] = ACTIONS(1329),
    [anon_sym_DQUOTE] = ACTIONS(1331),
    [anon_sym_SQUOTE] = ACTIONS(1331),
    [sym_comment] = ACTIONS(3),
  },
  [368] = {
    [sym_identifier] = ACTIONS(1333),
    [anon_sym_LBRACE] = ACTIONS(1335),
    [anon_sym_RBRACE] = ACTIONS(1335),
    [anon_sym_for] = ACTIONS(1333),
    [sym_yul_leave] = ACTIONS(1333),
    [anon_sym_break] = ACTIONS(1333),
    [anon_sym_continue] = ACTIONS(1333),
    [sym_yul_decimal_number] = ACTIONS(1333),
    [sym_yul_hex_number] = ACTIONS(1335),
    [anon_sym_true] = ACTIONS(1333),
    [anon_sym_false] = ACTIONS(1333),
    [anon_sym_let] = ACTIONS(1333),
    [anon_sym_if] = ACTIONS(1333),
    [anon_sym_switch] = ACTIONS(1333),
    [anon_sym_function] = ACTIONS(1333),
    [anon_sym_stop] = ACTIONS(1333),
    [anon_sym_add] = ACTIONS(1333),
    [anon_sym_sub] = ACTIONS(1333),
    [anon_sym_mul] = ACTIONS(1333),
    [anon_sym_div] = ACTIONS(1333),
    [anon_sym_sdiv] = ACTIONS(1333),
    [anon_sym_mod] = ACTIONS(1333),
    [anon_sym_smod] = ACTIONS(1333),
    [anon_sym_exp] = ACTIONS(1333),
    [anon_sym_not] = ACTIONS(1333),
    [anon_sym_lt] = ACTIONS(1333),
    [anon_sym_gt] = ACTIONS(1333),
    [anon_sym_slt] = ACTIONS(1333),
    [anon_sym_sgt] = ACTIONS(1333),
    [anon_sym_eq] = ACTIONS(1333),
    [anon_sym_iszero] = ACTIONS(1333),
    [anon_sym_and] = ACTIONS(1333),
    [anon_sym_or] = ACTIONS(1333),
    [anon_sym_xor] = ACTIONS(1333),
    [anon_sym_byte] = ACTIONS(1333),
    [anon_sym_shl] = ACTIONS(1333),
    [anon_sym_shr] = ACTIONS(1333),
    [anon_sym_sar] = ACTIONS(1333),
    [anon_sym_addmod] = ACTIONS(1333),
    [anon_sym_mulmod] = ACTIONS(1333),
    [anon_sym_signextend] = ACTIONS(1333),
    [anon_sym_keccak256] = ACTIONS(1333),
    [anon_sym_pop] = ACTIONS(1333),
    [anon_sym_mload] = ACTIONS(1333),
    [anon_sym_mstore] = ACTIONS(1333),
    [anon_sym_mstore8] = ACTIONS(1333),
    [anon_sym_sload] = ACTIONS(1333),
    [anon_sym_sstore] = ACTIONS(1333),
    [anon_sym_msize] = ACTIONS(1333),
    [anon_sym_gas] = ACTIONS(1333),
    [anon_sym_address] = ACTIONS(1333),
    [anon_sym_balance] = ACTIONS(1333),
    [anon_sym_selfbalance] = ACTIONS(1333),
    [anon_sym_caller] = ACTIONS(1333),
    [anon_sym_callvalue] = ACTIONS(1333),
    [anon_sym_calldataload] = ACTIONS(1333),
    [anon_sym_calldatasize] = ACTIONS(1333),
    [anon_sym_calldatacopy] = ACTIONS(1333),
    [anon_sym_extcodesize] = ACTIONS(1333),
    [anon_sym_extcodecopy] = ACTIONS(1333),
    [anon_sym_returndatasize] = ACTIONS(1333),
    [anon_sym_returndatacopy] = ACTIONS(1333),
    [anon_sym_extcodehash] = ACTIONS(1333),
    [anon_sym_create] = ACTIONS(1333),
    [anon_sym_create2] = ACTIONS(1333),
    [anon_sym_call] = ACTIONS(1333),
    [anon_sym_callcode] = ACTIONS(1333),
    [anon_sym_delegatecall] = ACTIONS(1333),
    [anon_sym_staticcall] = ACTIONS(1333),
    [anon_sym_return] = ACTIONS(1333),
    [anon_sym_revert] = ACTIONS(1333),
    [anon_sym_selfdestruct] = ACTIONS(1333),
    [anon_sym_invalid] = ACTIONS(1333),
    [anon_sym_log0] = ACTIONS(1333),
    [anon_sym_log1] = ACTIONS(1333),
    [anon_sym_log2] = ACTIONS(1333),
    [anon_sym_log3] = ACTIONS(1333),
    [anon_sym_log4] = ACTIONS(1333),
    [anon_sym_chainid] = ACTIONS(1333),
    [anon_sym_origin] = ACTIONS(1333),
    [anon_sym_gasprice] = ACTIONS(1333),
    [anon_sym_blockhash] = ACTIONS(1333),
    [anon_sym_coinbase] = ACTIONS(1333),
    [anon_sym_timestamp] = ACTIONS(1333),
    [anon_sym_number] = ACTIONS(1333),
    [anon_sym_difficulty] = ACTIONS(1333),
    [anon_sym_gaslimit] = ACTIONS(1333),
    [anon_sym_hex] = ACTIONS(1333),
    [anon_sym_DQUOTE] = ACTIONS(1335),
    [anon_sym_SQUOTE] = ACTIONS(1335),
    [sym_comment] = ACTIONS(3),
  },
  [369] = {
    [sym_identifier] = ACTIONS(1337),
    [anon_sym_LBRACE] = ACTIONS(1339),
    [anon_sym_RBRACE] = ACTIONS(1339),
    [anon_sym_for] = ACTIONS(1337),
    [sym_yul_leave] = ACTIONS(1337),
    [anon_sym_break] = ACTIONS(1337),
    [anon_sym_continue] = ACTIONS(1337),
    [sym_yul_decimal_number] = ACTIONS(1337),
    [sym_yul_hex_number] = ACTIONS(1339),
    [anon_sym_true] = ACTIONS(1337),
    [anon_sym_false] = ACTIONS(1337),
    [anon_sym_let] = ACTIONS(1337),
    [anon_sym_if] = ACTIONS(1337),
    [anon_sym_switch] = ACTIONS(1337),
    [anon_sym_function] = ACTIONS(1337),
    [anon_sym_stop] = ACTIONS(1337),
    [anon_sym_add] = ACTIONS(1337),
    [anon_sym_sub] = ACTIONS(1337),
    [anon_sym_mul] = ACTIONS(1337),
    [anon_sym_div] = ACTIONS(1337),
    [anon_sym_sdiv] = ACTIONS(1337),
    [anon_sym_mod] = ACTIONS(1337),
    [anon_sym_smod] = ACTIONS(1337),
    [anon_sym_exp] = ACTIONS(1337),
    [anon_sym_not] = ACTIONS(1337),
    [anon_sym_lt] = ACTIONS(1337),
    [anon_sym_gt] = ACTIONS(1337),
    [anon_sym_slt] = ACTIONS(1337),
    [anon_sym_sgt] = ACTIONS(1337),
    [anon_sym_eq] = ACTIONS(1337),
    [anon_sym_iszero] = ACTIONS(1337),
    [anon_sym_and] = ACTIONS(1337),
    [anon_sym_or] = ACTIONS(1337),
    [anon_sym_xor] = ACTIONS(1337),
    [anon_sym_byte] = ACTIONS(1337),
    [anon_sym_shl] = ACTIONS(1337),
    [anon_sym_shr] = ACTIONS(1337),
    [anon_sym_sar] = ACTIONS(1337),
    [anon_sym_addmod] = ACTIONS(1337),
    [anon_sym_mulmod] = ACTIONS(1337),
    [anon_sym_signextend] = ACTIONS(1337),
    [anon_sym_keccak256] = ACTIONS(1337),
    [anon_sym_pop] = ACTIONS(1337),
    [anon_sym_mload] = ACTIONS(1337),
    [anon_sym_mstore] = ACTIONS(1337),
    [anon_sym_mstore8] = ACTIONS(1337),
    [anon_sym_sload] = ACTIONS(1337),
    [anon_sym_sstore] = ACTIONS(1337),
    [anon_sym_msize] = ACTIONS(1337),
    [anon_sym_gas] = ACTIONS(1337),
    [anon_sym_address] = ACTIONS(1337),
    [anon_sym_balance] = ACTIONS(1337),
    [anon_sym_selfbalance] = ACTIONS(1337),
    [anon_sym_caller] = ACTIONS(1337),
    [anon_sym_callvalue] = ACTIONS(1337),
    [anon_sym_calldataload] = ACTIONS(1337),
    [anon_sym_calldatasize] = ACTIONS(1337),
    [anon_sym_calldatacopy] = ACTIONS(1337),
    [anon_sym_extcodesize] = ACTIONS(1337),
    [anon_sym_extcodecopy] = ACTIONS(1337),
    [anon_sym_returndatasize] = ACTIONS(1337),
    [anon_sym_returndatacopy] = ACTIONS(1337),
    [anon_sym_extcodehash] = ACTIONS(1337),
    [anon_sym_create] = ACTIONS(1337),
    [anon_sym_create2] = ACTIONS(1337),
    [anon_sym_call] = ACTIONS(1337),
    [anon_sym_callcode] = ACTIONS(1337),
    [anon_sym_delegatecall] = ACTIONS(1337),
    [anon_sym_staticcall] = ACTIONS(1337),
    [anon_sym_return] = ACTIONS(1337),
    [anon_sym_revert] = ACTIONS(1337),
    [anon_sym_selfdestruct] = ACTIONS(1337),
    [anon_sym_invalid] = ACTIONS(1337),
    [anon_sym_log0] = ACTIONS(1337),
    [anon_sym_log1] = ACTIONS(1337),
    [anon_sym_log2] = ACTIONS(1337),
    [anon_sym_log3] = ACTIONS(1337),
    [anon_sym_log4] = ACTIONS(1337),
    [anon_sym_chainid] = ACTIONS(1337),
    [anon_sym_origin] = ACTIONS(1337),
    [anon_sym_gasprice] = ACTIONS(1337),
    [anon_sym_blockhash] = ACTIONS(1337),
    [anon_sym_coinbase] = ACTIONS(1337),
    [anon_sym_timestamp] = ACTIONS(1337),
    [anon_sym_number] = ACTIONS(1337),
    [anon_sym_difficulty] = ACTIONS(1337),
    [anon_sym_gaslimit] = ACTIONS(1337),
    [anon_sym_hex] = ACTIONS(1337),
    [anon_sym_DQUOTE] = ACTIONS(1339),
    [anon_sym_SQUOTE] = ACTIONS(1339),
    [sym_comment] = ACTIONS(3),
  },
  [370] = {
    [sym_identifier] = ACTIONS(1341),
    [anon_sym_LBRACE] = ACTIONS(1343),
    [anon_sym_RBRACE] = ACTIONS(1343),
    [anon_sym_for] = ACTIONS(1341),
    [sym_yul_leave] = ACTIONS(1341),
    [anon_sym_break] = ACTIONS(1341),
    [anon_sym_continue] = ACTIONS(1341),
    [sym_yul_decimal_number] = ACTIONS(1341),
    [sym_yul_hex_number] = ACTIONS(1343),
    [anon_sym_true] = ACTIONS(1341),
    [anon_sym_false] = ACTIONS(1341),
    [anon_sym_let] = ACTIONS(1341),
    [anon_sym_if] = ACTIONS(1341),
    [anon_sym_switch] = ACTIONS(1341),
    [anon_sym_function] = ACTIONS(1341),
    [anon_sym_stop] = ACTIONS(1341),
    [anon_sym_add] = ACTIONS(1341),
    [anon_sym_sub] = ACTIONS(1341),
    [anon_sym_mul] = ACTIONS(1341),
    [anon_sym_div] = ACTIONS(1341),
    [anon_sym_sdiv] = ACTIONS(1341),
    [anon_sym_mod] = ACTIONS(1341),
    [anon_sym_smod] = ACTIONS(1341),
    [anon_sym_exp] = ACTIONS(1341),
    [anon_sym_not] = ACTIONS(1341),
    [anon_sym_lt] = ACTIONS(1341),
    [anon_sym_gt] = ACTIONS(1341),
    [anon_sym_slt] = ACTIONS(1341),
    [anon_sym_sgt] = ACTIONS(1341),
    [anon_sym_eq] = ACTIONS(1341),
    [anon_sym_iszero] = ACTIONS(1341),
    [anon_sym_and] = ACTIONS(1341),
    [anon_sym_or] = ACTIONS(1341),
    [anon_sym_xor] = ACTIONS(1341),
    [anon_sym_byte] = ACTIONS(1341),
    [anon_sym_shl] = ACTIONS(1341),
    [anon_sym_shr] = ACTIONS(1341),
    [anon_sym_sar] = ACTIONS(1341),
    [anon_sym_addmod] = ACTIONS(1341),
    [anon_sym_mulmod] = ACTIONS(1341),
    [anon_sym_signextend] = ACTIONS(1341),
    [anon_sym_keccak256] = ACTIONS(1341),
    [anon_sym_pop] = ACTIONS(1341),
    [anon_sym_mload] = ACTIONS(1341),
    [anon_sym_mstore] = ACTIONS(1341),
    [anon_sym_mstore8] = ACTIONS(1341),
    [anon_sym_sload] = ACTIONS(1341),
    [anon_sym_sstore] = ACTIONS(1341),
    [anon_sym_msize] = ACTIONS(1341),
    [anon_sym_gas] = ACTIONS(1341),
    [anon_sym_address] = ACTIONS(1341),
    [anon_sym_balance] = ACTIONS(1341),
    [anon_sym_selfbalance] = ACTIONS(1341),
    [anon_sym_caller] = ACTIONS(1341),
    [anon_sym_callvalue] = ACTIONS(1341),
    [anon_sym_calldataload] = ACTIONS(1341),
    [anon_sym_calldatasize] = ACTIONS(1341),
    [anon_sym_calldatacopy] = ACTIONS(1341),
    [anon_sym_extcodesize] = ACTIONS(1341),
    [anon_sym_extcodecopy] = ACTIONS(1341),
    [anon_sym_returndatasize] = ACTIONS(1341),
    [anon_sym_returndatacopy] = ACTIONS(1341),
    [anon_sym_extcodehash] = ACTIONS(1341),
    [anon_sym_create] = ACTIONS(1341),
    [anon_sym_create2] = ACTIONS(1341),
    [anon_sym_call] = ACTIONS(1341),
    [anon_sym_callcode] = ACTIONS(1341),
    [anon_sym_delegatecall] = ACTIONS(1341),
    [anon_sym_staticcall] = ACTIONS(1341),
    [anon_sym_return] = ACTIONS(1341),
    [anon_sym_revert] = ACTIONS(1341),
    [anon_sym_selfdestruct] = ACTIONS(1341),
    [anon_sym_invalid] = ACTIONS(1341),
    [anon_sym_log0] = ACTIONS(1341),
    [anon_sym_log1] = ACTIONS(1341),
    [anon_sym_log2] = ACTIONS(1341),
    [anon_sym_log3] = ACTIONS(1341),
    [anon_sym_log4] = ACTIONS(1341),
    [anon_sym_chainid] = ACTIONS(1341),
    [anon_sym_origin] = ACTIONS(1341),
    [anon_sym_gasprice] = ACTIONS(1341),
    [anon_sym_blockhash] = ACTIONS(1341),
    [anon_sym_coinbase] = ACTIONS(1341),
    [anon_sym_timestamp] = ACTIONS(1341),
    [anon_sym_number] = ACTIONS(1341),
    [anon_sym_difficulty] = ACTIONS(1341),
    [anon_sym_gaslimit] = ACTIONS(1341),
    [anon_sym_hex] = ACTIONS(1341),
    [anon_sym_DQUOTE] = ACTIONS(1343),
    [anon_sym_SQUOTE] = ACTIONS(1343),
    [sym_comment] = ACTIONS(3),
  },
  [371] = {
    [sym_identifier] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(1347),
    [anon_sym_RBRACE] = ACTIONS(1347),
    [anon_sym_for] = ACTIONS(1345),
    [sym_yul_leave] = ACTIONS(1345),
    [anon_sym_break] = ACTIONS(1345),
    [anon_sym_continue] = ACTIONS(1345),
    [sym_yul_decimal_number] = ACTIONS(1345),
    [sym_yul_hex_number] = ACTIONS(1347),
    [anon_sym_true] = ACTIONS(1345),
    [anon_sym_false] = ACTIONS(1345),
    [anon_sym_let] = ACTIONS(1345),
    [anon_sym_if] = ACTIONS(1345),
    [anon_sym_switch] = ACTIONS(1345),
    [anon_sym_function] = ACTIONS(1345),
    [anon_sym_stop] = ACTIONS(1345),
    [anon_sym_add] = ACTIONS(1345),
    [anon_sym_sub] = ACTIONS(1345),
    [anon_sym_mul] = ACTIONS(1345),
    [anon_sym_div] = ACTIONS(1345),
    [anon_sym_sdiv] = ACTIONS(1345),
    [anon_sym_mod] = ACTIONS(1345),
    [anon_sym_smod] = ACTIONS(1345),
    [anon_sym_exp] = ACTIONS(1345),
    [anon_sym_not] = ACTIONS(1345),
    [anon_sym_lt] = ACTIONS(1345),
    [anon_sym_gt] = ACTIONS(1345),
    [anon_sym_slt] = ACTIONS(1345),
    [anon_sym_sgt] = ACTIONS(1345),
    [anon_sym_eq] = ACTIONS(1345),
    [anon_sym_iszero] = ACTIONS(1345),
    [anon_sym_and] = ACTIONS(1345),
    [anon_sym_or] = ACTIONS(1345),
    [anon_sym_xor] = ACTIONS(1345),
    [anon_sym_byte] = ACTIONS(1345),
    [anon_sym_shl] = ACTIONS(1345),
    [anon_sym_shr] = ACTIONS(1345),
    [anon_sym_sar] = ACTIONS(1345),
    [anon_sym_addmod] = ACTIONS(1345),
    [anon_sym_mulmod] = ACTIONS(1345),
    [anon_sym_signextend] = ACTIONS(1345),
    [anon_sym_keccak256] = ACTIONS(1345),
    [anon_sym_pop] = ACTIONS(1345),
    [anon_sym_mload] = ACTIONS(1345),
    [anon_sym_mstore] = ACTIONS(1345),
    [anon_sym_mstore8] = ACTIONS(1345),
    [anon_sym_sload] = ACTIONS(1345),
    [anon_sym_sstore] = ACTIONS(1345),
    [anon_sym_msize] = ACTIONS(1345),
    [anon_sym_gas] = ACTIONS(1345),
    [anon_sym_address] = ACTIONS(1345),
    [anon_sym_balance] = ACTIONS(1345),
    [anon_sym_selfbalance] = ACTIONS(1345),
    [anon_sym_caller] = ACTIONS(1345),
    [anon_sym_callvalue] = ACTIONS(1345),
    [anon_sym_calldataload] = ACTIONS(1345),
    [anon_sym_calldatasize] = ACTIONS(1345),
    [anon_sym_calldatacopy] = ACTIONS(1345),
    [anon_sym_extcodesize] = ACTIONS(1345),
    [anon_sym_extcodecopy] = ACTIONS(1345),
    [anon_sym_returndatasize] = ACTIONS(1345),
    [anon_sym_returndatacopy] = ACTIONS(1345),
    [anon_sym_extcodehash] = ACTIONS(1345),
    [anon_sym_create] = ACTIONS(1345),
    [anon_sym_create2] = ACTIONS(1345),
    [anon_sym_call] = ACTIONS(1345),
    [anon_sym_callcode] = ACTIONS(1345),
    [anon_sym_delegatecall] = ACTIONS(1345),
    [anon_sym_staticcall] = ACTIONS(1345),
    [anon_sym_return] = ACTIONS(1345),
    [anon_sym_revert] = ACTIONS(1345),
    [anon_sym_selfdestruct] = ACTIONS(1345),
    [anon_sym_invalid] = ACTIONS(1345),
    [anon_sym_log0] = ACTIONS(1345),
    [anon_sym_log1] = ACTIONS(1345),
    [anon_sym_log2] = ACTIONS(1345),
    [anon_sym_log3] = ACTIONS(1345),
    [anon_sym_log4] = ACTIONS(1345),
    [anon_sym_chainid] = ACTIONS(1345),
    [anon_sym_origin] = ACTIONS(1345),
    [anon_sym_gasprice] = ACTIONS(1345),
    [anon_sym_blockhash] = ACTIONS(1345),
    [anon_sym_coinbase] = ACTIONS(1345),
    [anon_sym_timestamp] = ACTIONS(1345),
    [anon_sym_number] = ACTIONS(1345),
    [anon_sym_difficulty] = ACTIONS(1345),
    [anon_sym_gaslimit] = ACTIONS(1345),
    [anon_sym_hex] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_SQUOTE] = ACTIONS(1347),
    [sym_comment] = ACTIONS(3),
  },
  [372] = {
    [sym_identifier] = ACTIONS(1349),
    [anon_sym_LBRACE] = ACTIONS(1351),
    [anon_sym_RBRACE] = ACTIONS(1351),
    [anon_sym_for] = ACTIONS(1349),
    [sym_yul_leave] = ACTIONS(1349),
    [anon_sym_break] = ACTIONS(1349),
    [anon_sym_continue] = ACTIONS(1349),
    [sym_yul_decimal_number] = ACTIONS(1349),
    [sym_yul_hex_number] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1349),
    [anon_sym_false] = ACTIONS(1349),
    [anon_sym_let] = ACTIONS(1349),
    [anon_sym_if] = ACTIONS(1349),
    [anon_sym_switch] = ACTIONS(1349),
    [anon_sym_function] = ACTIONS(1349),
    [anon_sym_stop] = ACTIONS(1349),
    [anon_sym_add] = ACTIONS(1349),
    [anon_sym_sub] = ACTIONS(1349),
    [anon_sym_mul] = ACTIONS(1349),
    [anon_sym_div] = ACTIONS(1349),
    [anon_sym_sdiv] = ACTIONS(1349),
    [anon_sym_mod] = ACTIONS(1349),
    [anon_sym_smod] = ACTIONS(1349),
    [anon_sym_exp] = ACTIONS(1349),
    [anon_sym_not] = ACTIONS(1349),
    [anon_sym_lt] = ACTIONS(1349),
    [anon_sym_gt] = ACTIONS(1349),
    [anon_sym_slt] = ACTIONS(1349),
    [anon_sym_sgt] = ACTIONS(1349),
    [anon_sym_eq] = ACTIONS(1349),
    [anon_sym_iszero] = ACTIONS(1349),
    [anon_sym_and] = ACTIONS(1349),
    [anon_sym_or] = ACTIONS(1349),
    [anon_sym_xor] = ACTIONS(1349),
    [anon_sym_byte] = ACTIONS(1349),
    [anon_sym_shl] = ACTIONS(1349),
    [anon_sym_shr] = ACTIONS(1349),
    [anon_sym_sar] = ACTIONS(1349),
    [anon_sym_addmod] = ACTIONS(1349),
    [anon_sym_mulmod] = ACTIONS(1349),
    [anon_sym_signextend] = ACTIONS(1349),
    [anon_sym_keccak256] = ACTIONS(1349),
    [anon_sym_pop] = ACTIONS(1349),
    [anon_sym_mload] = ACTIONS(1349),
    [anon_sym_mstore] = ACTIONS(1349),
    [anon_sym_mstore8] = ACTIONS(1349),
    [anon_sym_sload] = ACTIONS(1349),
    [anon_sym_sstore] = ACTIONS(1349),
    [anon_sym_msize] = ACTIONS(1349),
    [anon_sym_gas] = ACTIONS(1349),
    [anon_sym_address] = ACTIONS(1349),
    [anon_sym_balance] = ACTIONS(1349),
    [anon_sym_selfbalance] = ACTIONS(1349),
    [anon_sym_caller] = ACTIONS(1349),
    [anon_sym_callvalue] = ACTIONS(1349),
    [anon_sym_calldataload] = ACTIONS(1349),
    [anon_sym_calldatasize] = ACTIONS(1349),
    [anon_sym_calldatacopy] = ACTIONS(1349),
    [anon_sym_extcodesize] = ACTIONS(1349),
    [anon_sym_extcodecopy] = ACTIONS(1349),
    [anon_sym_returndatasize] = ACTIONS(1349),
    [anon_sym_returndatacopy] = ACTIONS(1349),
    [anon_sym_extcodehash] = ACTIONS(1349),
    [anon_sym_create] = ACTIONS(1349),
    [anon_sym_create2] = ACTIONS(1349),
    [anon_sym_call] = ACTIONS(1349),
    [anon_sym_callcode] = ACTIONS(1349),
    [anon_sym_delegatecall] = ACTIONS(1349),
    [anon_sym_staticcall] = ACTIONS(1349),
    [anon_sym_return] = ACTIONS(1349),
    [anon_sym_revert] = ACTIONS(1349),
    [anon_sym_selfdestruct] = ACTIONS(1349),
    [anon_sym_invalid] = ACTIONS(1349),
    [anon_sym_log0] = ACTIONS(1349),
    [anon_sym_log1] = ACTIONS(1349),
    [anon_sym_log2] = ACTIONS(1349),
    [anon_sym_log3] = ACTIONS(1349),
    [anon_sym_log4] = ACTIONS(1349),
    [anon_sym_chainid] = ACTIONS(1349),
    [anon_sym_origin] = ACTIONS(1349),
    [anon_sym_gasprice] = ACTIONS(1349),
    [anon_sym_blockhash] = ACTIONS(1349),
    [anon_sym_coinbase] = ACTIONS(1349),
    [anon_sym_timestamp] = ACTIONS(1349),
    [anon_sym_number] = ACTIONS(1349),
    [anon_sym_difficulty] = ACTIONS(1349),
    [anon_sym_gaslimit] = ACTIONS(1349),
    [anon_sym_hex] = ACTIONS(1349),
    [anon_sym_DQUOTE] = ACTIONS(1351),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [sym_comment] = ACTIONS(3),
  },
  [373] = {
    [sym_identifier] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_RBRACE] = ACTIONS(1355),
    [anon_sym_for] = ACTIONS(1353),
    [sym_yul_leave] = ACTIONS(1353),
    [anon_sym_break] = ACTIONS(1353),
    [anon_sym_continue] = ACTIONS(1353),
    [sym_yul_decimal_number] = ACTIONS(1353),
    [sym_yul_hex_number] = ACTIONS(1355),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [anon_sym_let] = ACTIONS(1353),
    [anon_sym_if] = ACTIONS(1353),
    [anon_sym_switch] = ACTIONS(1353),
    [anon_sym_function] = ACTIONS(1353),
    [anon_sym_stop] = ACTIONS(1353),
    [anon_sym_add] = ACTIONS(1353),
    [anon_sym_sub] = ACTIONS(1353),
    [anon_sym_mul] = ACTIONS(1353),
    [anon_sym_div] = ACTIONS(1353),
    [anon_sym_sdiv] = ACTIONS(1353),
    [anon_sym_mod] = ACTIONS(1353),
    [anon_sym_smod] = ACTIONS(1353),
    [anon_sym_exp] = ACTIONS(1353),
    [anon_sym_not] = ACTIONS(1353),
    [anon_sym_lt] = ACTIONS(1353),
    [anon_sym_gt] = ACTIONS(1353),
    [anon_sym_slt] = ACTIONS(1353),
    [anon_sym_sgt] = ACTIONS(1353),
    [anon_sym_eq] = ACTIONS(1353),
    [anon_sym_iszero] = ACTIONS(1353),
    [anon_sym_and] = ACTIONS(1353),
    [anon_sym_or] = ACTIONS(1353),
    [anon_sym_xor] = ACTIONS(1353),
    [anon_sym_byte] = ACTIONS(1353),
    [anon_sym_shl] = ACTIONS(1353),
    [anon_sym_shr] = ACTIONS(1353),
    [anon_sym_sar] = ACTIONS(1353),
    [anon_sym_addmod] = ACTIONS(1353),
    [anon_sym_mulmod] = ACTIONS(1353),
    [anon_sym_signextend] = ACTIONS(1353),
    [anon_sym_keccak256] = ACTIONS(1353),
    [anon_sym_pop] = ACTIONS(1353),
    [anon_sym_mload] = ACTIONS(1353),
    [anon_sym_mstore] = ACTIONS(1353),
    [anon_sym_mstore8] = ACTIONS(1353),
    [anon_sym_sload] = ACTIONS(1353),
    [anon_sym_sstore] = ACTIONS(1353),
    [anon_sym_msize] = ACTIONS(1353),
    [anon_sym_gas] = ACTIONS(1353),
    [anon_sym_address] = ACTIONS(1353),
    [anon_sym_balance] = ACTIONS(1353),
    [anon_sym_selfbalance] = ACTIONS(1353),
    [anon_sym_caller] = ACTIONS(1353),
    [anon_sym_callvalue] = ACTIONS(1353),
    [anon_sym_calldataload] = ACTIONS(1353),
    [anon_sym_calldatasize] = ACTIONS(1353),
    [anon_sym_calldatacopy] = ACTIONS(1353),
    [anon_sym_extcodesize] = ACTIONS(1353),
    [anon_sym_extcodecopy] = ACTIONS(1353),
    [anon_sym_returndatasize] = ACTIONS(1353),
    [anon_sym_returndatacopy] = ACTIONS(1353),
    [anon_sym_extcodehash] = ACTIONS(1353),
    [anon_sym_create] = ACTIONS(1353),
    [anon_sym_create2] = ACTIONS(1353),
    [anon_sym_call] = ACTIONS(1353),
    [anon_sym_callcode] = ACTIONS(1353),
    [anon_sym_delegatecall] = ACTIONS(1353),
    [anon_sym_staticcall] = ACTIONS(1353),
    [anon_sym_return] = ACTIONS(1353),
    [anon_sym_revert] = ACTIONS(1353),
    [anon_sym_selfdestruct] = ACTIONS(1353),
    [anon_sym_invalid] = ACTIONS(1353),
    [anon_sym_log0] = ACTIONS(1353),
    [anon_sym_log1] = ACTIONS(1353),
    [anon_sym_log2] = ACTIONS(1353),
    [anon_sym_log3] = ACTIONS(1353),
    [anon_sym_log4] = ACTIONS(1353),
    [anon_sym_chainid] = ACTIONS(1353),
    [anon_sym_origin] = ACTIONS(1353),
    [anon_sym_gasprice] = ACTIONS(1353),
    [anon_sym_blockhash] = ACTIONS(1353),
    [anon_sym_coinbase] = ACTIONS(1353),
    [anon_sym_timestamp] = ACTIONS(1353),
    [anon_sym_number] = ACTIONS(1353),
    [anon_sym_difficulty] = ACTIONS(1353),
    [anon_sym_gaslimit] = ACTIONS(1353),
    [anon_sym_hex] = ACTIONS(1353),
    [anon_sym_DQUOTE] = ACTIONS(1355),
    [anon_sym_SQUOTE] = ACTIONS(1355),
    [sym_comment] = ACTIONS(3),
  },
  [374] = {
    [sym_identifier] = ACTIONS(1357),
    [anon_sym_LBRACE] = ACTIONS(1360),
    [anon_sym_RBRACE] = ACTIONS(1360),
    [anon_sym_for] = ACTIONS(1357),
    [sym_yul_leave] = ACTIONS(1357),
    [anon_sym_break] = ACTIONS(1357),
    [anon_sym_continue] = ACTIONS(1357),
    [sym_yul_decimal_number] = ACTIONS(1357),
    [sym_yul_hex_number] = ACTIONS(1360),
    [anon_sym_true] = ACTIONS(1357),
    [anon_sym_false] = ACTIONS(1357),
    [anon_sym_let] = ACTIONS(1357),
    [anon_sym_if] = ACTIONS(1357),
    [anon_sym_switch] = ACTIONS(1357),
    [anon_sym_function] = ACTIONS(1357),
    [anon_sym_stop] = ACTIONS(1357),
    [anon_sym_add] = ACTIONS(1357),
    [anon_sym_sub] = ACTIONS(1357),
    [anon_sym_mul] = ACTIONS(1357),
    [anon_sym_div] = ACTIONS(1357),
    [anon_sym_sdiv] = ACTIONS(1357),
    [anon_sym_mod] = ACTIONS(1357),
    [anon_sym_smod] = ACTIONS(1357),
    [anon_sym_exp] = ACTIONS(1357),
    [anon_sym_not] = ACTIONS(1357),
    [anon_sym_lt] = ACTIONS(1357),
    [anon_sym_gt] = ACTIONS(1357),
    [anon_sym_slt] = ACTIONS(1357),
    [anon_sym_sgt] = ACTIONS(1357),
    [anon_sym_eq] = ACTIONS(1357),
    [anon_sym_iszero] = ACTIONS(1357),
    [anon_sym_and] = ACTIONS(1357),
    [anon_sym_or] = ACTIONS(1357),
    [anon_sym_xor] = ACTIONS(1357),
    [anon_sym_byte] = ACTIONS(1357),
    [anon_sym_shl] = ACTIONS(1357),
    [anon_sym_shr] = ACTIONS(1357),
    [anon_sym_sar] = ACTIONS(1357),
    [anon_sym_addmod] = ACTIONS(1357),
    [anon_sym_mulmod] = ACTIONS(1357),
    [anon_sym_signextend] = ACTIONS(1357),
    [anon_sym_keccak256] = ACTIONS(1357),
    [anon_sym_pop] = ACTIONS(1357),
    [anon_sym_mload] = ACTIONS(1357),
    [anon_sym_mstore] = ACTIONS(1357),
    [anon_sym_mstore8] = ACTIONS(1357),
    [anon_sym_sload] = ACTIONS(1357),
    [anon_sym_sstore] = ACTIONS(1357),
    [anon_sym_msize] = ACTIONS(1357),
    [anon_sym_gas] = ACTIONS(1357),
    [anon_sym_address] = ACTIONS(1357),
    [anon_sym_balance] = ACTIONS(1357),
    [anon_sym_selfbalance] = ACTIONS(1357),
    [anon_sym_caller] = ACTIONS(1357),
    [anon_sym_callvalue] = ACTIONS(1357),
    [anon_sym_calldataload] = ACTIONS(1357),
    [anon_sym_calldatasize] = ACTIONS(1357),
    [anon_sym_calldatacopy] = ACTIONS(1357),
    [anon_sym_extcodesize] = ACTIONS(1357),
    [anon_sym_extcodecopy] = ACTIONS(1357),
    [anon_sym_returndatasize] = ACTIONS(1357),
    [anon_sym_returndatacopy] = ACTIONS(1357),
    [anon_sym_extcodehash] = ACTIONS(1357),
    [anon_sym_create] = ACTIONS(1357),
    [anon_sym_create2] = ACTIONS(1357),
    [anon_sym_call] = ACTIONS(1357),
    [anon_sym_callcode] = ACTIONS(1357),
    [anon_sym_delegatecall] = ACTIONS(1357),
    [anon_sym_staticcall] = ACTIONS(1357),
    [anon_sym_return] = ACTIONS(1357),
    [anon_sym_revert] = ACTIONS(1357),
    [anon_sym_selfdestruct] = ACTIONS(1357),
    [anon_sym_invalid] = ACTIONS(1357),
    [anon_sym_log0] = ACTIONS(1357),
    [anon_sym_log1] = ACTIONS(1357),
    [anon_sym_log2] = ACTIONS(1357),
    [anon_sym_log3] = ACTIONS(1357),
    [anon_sym_log4] = ACTIONS(1357),
    [anon_sym_chainid] = ACTIONS(1357),
    [anon_sym_origin] = ACTIONS(1357),
    [anon_sym_gasprice] = ACTIONS(1357),
    [anon_sym_blockhash] = ACTIONS(1357),
    [anon_sym_coinbase] = ACTIONS(1357),
    [anon_sym_timestamp] = ACTIONS(1357),
    [anon_sym_number] = ACTIONS(1357),
    [anon_sym_difficulty] = ACTIONS(1357),
    [anon_sym_gaslimit] = ACTIONS(1357),
    [anon_sym_hex] = ACTIONS(1357),
    [anon_sym_DQUOTE] = ACTIONS(1360),
    [anon_sym_SQUOTE] = ACTIONS(1360),
    [sym_comment] = ACTIONS(3),
  },
  [375] = {
    [sym_identifier] = ACTIONS(1363),
    [anon_sym_LBRACE] = ACTIONS(1365),
    [anon_sym_RBRACE] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1363),
    [sym_yul_leave] = ACTIONS(1363),
    [anon_sym_break] = ACTIONS(1363),
    [anon_sym_continue] = ACTIONS(1363),
    [sym_yul_decimal_number] = ACTIONS(1363),
    [sym_yul_hex_number] = ACTIONS(1365),
    [anon_sym_true] = ACTIONS(1363),
    [anon_sym_false] = ACTIONS(1363),
    [anon_sym_let] = ACTIONS(1363),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_switch] = ACTIONS(1363),
    [anon_sym_function] = ACTIONS(1363),
    [anon_sym_stop] = ACTIONS(1363),
    [anon_sym_add] = ACTIONS(1363),
    [anon_sym_sub] = ACTIONS(1363),
    [anon_sym_mul] = ACTIONS(1363),
    [anon_sym_div] = ACTIONS(1363),
    [anon_sym_sdiv] = ACTIONS(1363),
    [anon_sym_mod] = ACTIONS(1363),
    [anon_sym_smod] = ACTIONS(1363),
    [anon_sym_exp] = ACTIONS(1363),
    [anon_sym_not] = ACTIONS(1363),
    [anon_sym_lt] = ACTIONS(1363),
    [anon_sym_gt] = ACTIONS(1363),
    [anon_sym_slt] = ACTIONS(1363),
    [anon_sym_sgt] = ACTIONS(1363),
    [anon_sym_eq] = ACTIONS(1363),
    [anon_sym_iszero] = ACTIONS(1363),
    [anon_sym_and] = ACTIONS(1363),
    [anon_sym_or] = ACTIONS(1363),
    [anon_sym_xor] = ACTIONS(1363),
    [anon_sym_byte] = ACTIONS(1363),
    [anon_sym_shl] = ACTIONS(1363),
    [anon_sym_shr] = ACTIONS(1363),
    [anon_sym_sar] = ACTIONS(1363),
    [anon_sym_addmod] = ACTIONS(1363),
    [anon_sym_mulmod] = ACTIONS(1363),
    [anon_sym_signextend] = ACTIONS(1363),
    [anon_sym_keccak256] = ACTIONS(1363),
    [anon_sym_pop] = ACTIONS(1363),
    [anon_sym_mload] = ACTIONS(1363),
    [anon_sym_mstore] = ACTIONS(1363),
    [anon_sym_mstore8] = ACTIONS(1363),
    [anon_sym_sload] = ACTIONS(1363),
    [anon_sym_sstore] = ACTIONS(1363),
    [anon_sym_msize] = ACTIONS(1363),
    [anon_sym_gas] = ACTIONS(1363),
    [anon_sym_address] = ACTIONS(1363),
    [anon_sym_balance] = ACTIONS(1363),
    [anon_sym_selfbalance] = ACTIONS(1363),
    [anon_sym_caller] = ACTIONS(1363),
    [anon_sym_callvalue] = ACTIONS(1363),
    [anon_sym_calldataload] = ACTIONS(1363),
    [anon_sym_calldatasize] = ACTIONS(1363),
    [anon_sym_calldatacopy] = ACTIONS(1363),
    [anon_sym_extcodesize] = ACTIONS(1363),
    [anon_sym_extcodecopy] = ACTIONS(1363),
    [anon_sym_returndatasize] = ACTIONS(1363),
    [anon_sym_returndatacopy] = ACTIONS(1363),
    [anon_sym_extcodehash] = ACTIONS(1363),
    [anon_sym_create] = ACTIONS(1363),
    [anon_sym_create2] = ACTIONS(1363),
    [anon_sym_call] = ACTIONS(1363),
    [anon_sym_callcode] = ACTIONS(1363),
    [anon_sym_delegatecall] = ACTIONS(1363),
    [anon_sym_staticcall] = ACTIONS(1363),
    [anon_sym_return] = ACTIONS(1363),
    [anon_sym_revert] = ACTIONS(1363),
    [anon_sym_selfdestruct] = ACTIONS(1363),
    [anon_sym_invalid] = ACTIONS(1363),
    [anon_sym_log0] = ACTIONS(1363),
    [anon_sym_log1] = ACTIONS(1363),
    [anon_sym_log2] = ACTIONS(1363),
    [anon_sym_log3] = ACTIONS(1363),
    [anon_sym_log4] = ACTIONS(1363),
    [anon_sym_chainid] = ACTIONS(1363),
    [anon_sym_origin] = ACTIONS(1363),
    [anon_sym_gasprice] = ACTIONS(1363),
    [anon_sym_blockhash] = ACTIONS(1363),
    [anon_sym_coinbase] = ACTIONS(1363),
    [anon_sym_timestamp] = ACTIONS(1363),
    [anon_sym_number] = ACTIONS(1363),
    [anon_sym_difficulty] = ACTIONS(1363),
    [anon_sym_gaslimit] = ACTIONS(1363),
    [anon_sym_hex] = ACTIONS(1363),
    [anon_sym_DQUOTE] = ACTIONS(1365),
    [anon_sym_SQUOTE] = ACTIONS(1365),
    [sym_comment] = ACTIONS(3),
  },
  [376] = {
    [sym_identifier] = ACTIONS(1101),
    [anon_sym_LBRACE] = ACTIONS(1103),
    [anon_sym_RBRACE] = ACTIONS(1103),
    [anon_sym_for] = ACTIONS(1101),
    [sym_yul_leave] = ACTIONS(1101),
    [anon_sym_break] = ACTIONS(1101),
    [anon_sym_continue] = ACTIONS(1101),
    [sym_yul_decimal_number] = ACTIONS(1101),
    [sym_yul_hex_number] = ACTIONS(1103),
    [anon_sym_true] = ACTIONS(1101),
    [anon_sym_false] = ACTIONS(1101),
    [anon_sym_let] = ACTIONS(1101),
    [anon_sym_if] = ACTIONS(1101),
    [anon_sym_switch] = ACTIONS(1101),
    [anon_sym_function] = ACTIONS(1101),
    [anon_sym_stop] = ACTIONS(1101),
    [anon_sym_add] = ACTIONS(1101),
    [anon_sym_sub] = ACTIONS(1101),
    [anon_sym_mul] = ACTIONS(1101),
    [anon_sym_div] = ACTIONS(1101),
    [anon_sym_sdiv] = ACTIONS(1101),
    [anon_sym_mod] = ACTIONS(1101),
    [anon_sym_smod] = ACTIONS(1101),
    [anon_sym_exp] = ACTIONS(1101),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_lt] = ACTIONS(1101),
    [anon_sym_gt] = ACTIONS(1101),
    [anon_sym_slt] = ACTIONS(1101),
    [anon_sym_sgt] = ACTIONS(1101),
    [anon_sym_eq] = ACTIONS(1101),
    [anon_sym_iszero] = ACTIONS(1101),
    [anon_sym_and] = ACTIONS(1101),
    [anon_sym_or] = ACTIONS(1101),
    [anon_sym_xor] = ACTIONS(1101),
    [anon_sym_byte] = ACTIONS(1101),
    [anon_sym_shl] = ACTIONS(1101),
    [anon_sym_shr] = ACTIONS(1101),
    [anon_sym_sar] = ACTIONS(1101),
    [anon_sym_addmod] = ACTIONS(1101),
    [anon_sym_mulmod] = ACTIONS(1101),
    [anon_sym_signextend] = ACTIONS(1101),
    [anon_sym_keccak256] = ACTIONS(1101),
    [anon_sym_pop] = ACTIONS(1101),
    [anon_sym_mload] = ACTIONS(1101),
    [anon_sym_mstore] = ACTIONS(1101),
    [anon_sym_mstore8] = ACTIONS(1101),
    [anon_sym_sload] = ACTIONS(1101),
    [anon_sym_sstore] = ACTIONS(1101),
    [anon_sym_msize] = ACTIONS(1101),
    [anon_sym_gas] = ACTIONS(1101),
    [anon_sym_address] = ACTIONS(1101),
    [anon_sym_balance] = ACTIONS(1101),
    [anon_sym_selfbalance] = ACTIONS(1101),
    [anon_sym_caller] = ACTIONS(1101),
    [anon_sym_callvalue] = ACTIONS(1101),
    [anon_sym_calldataload] = ACTIONS(1101),
    [anon_sym_calldatasize] = ACTIONS(1101),
    [anon_sym_calldatacopy] = ACTIONS(1101),
    [anon_sym_extcodesize] = ACTIONS(1101),
    [anon_sym_extcodecopy] = ACTIONS(1101),
    [anon_sym_returndatasize] = ACTIONS(1101),
    [anon_sym_returndatacopy] = ACTIONS(1101),
    [anon_sym_extcodehash] = ACTIONS(1101),
    [anon_sym_create] = ACTIONS(1101),
    [anon_sym_create2] = ACTIONS(1101),
    [anon_sym_call] = ACTIONS(1101),
    [anon_sym_callcode] = ACTIONS(1101),
    [anon_sym_delegatecall] = ACTIONS(1101),
    [anon_sym_staticcall] = ACTIONS(1101),
    [anon_sym_return] = ACTIONS(1101),
    [anon_sym_revert] = ACTIONS(1101),
    [anon_sym_selfdestruct] = ACTIONS(1101),
    [anon_sym_invalid] = ACTIONS(1101),
    [anon_sym_log0] = ACTIONS(1101),
    [anon_sym_log1] = ACTIONS(1101),
    [anon_sym_log2] = ACTIONS(1101),
    [anon_sym_log3] = ACTIONS(1101),
    [anon_sym_log4] = ACTIONS(1101),
    [anon_sym_chainid] = ACTIONS(1101),
    [anon_sym_origin] = ACTIONS(1101),
    [anon_sym_gasprice] = ACTIONS(1101),
    [anon_sym_blockhash] = ACTIONS(1101),
    [anon_sym_coinbase] = ACTIONS(1101),
    [anon_sym_timestamp] = ACTIONS(1101),
    [anon_sym_number] = ACTIONS(1101),
    [anon_sym_difficulty] = ACTIONS(1101),
    [anon_sym_gaslimit] = ACTIONS(1101),
    [anon_sym_hex] = ACTIONS(1101),
    [anon_sym_DQUOTE] = ACTIONS(1103),
    [anon_sym_SQUOTE] = ACTIONS(1103),
    [sym_comment] = ACTIONS(3),
  },
  [377] = {
    [sym_identifier] = ACTIONS(1367),
    [anon_sym_LBRACE] = ACTIONS(1369),
    [anon_sym_RBRACE] = ACTIONS(1369),
    [anon_sym_for] = ACTIONS(1367),
    [sym_yul_leave] = ACTIONS(1367),
    [anon_sym_break] = ACTIONS(1367),
    [anon_sym_continue] = ACTIONS(1367),
    [sym_yul_decimal_number] = ACTIONS(1367),
    [sym_yul_hex_number] = ACTIONS(1369),
    [anon_sym_true] = ACTIONS(1367),
    [anon_sym_false] = ACTIONS(1367),
    [anon_sym_let] = ACTIONS(1367),
    [anon_sym_if] = ACTIONS(1367),
    [anon_sym_switch] = ACTIONS(1367),
    [anon_sym_function] = ACTIONS(1367),
    [anon_sym_stop] = ACTIONS(1367),
    [anon_sym_add] = ACTIONS(1367),
    [anon_sym_sub] = ACTIONS(1367),
    [anon_sym_mul] = ACTIONS(1367),
    [anon_sym_div] = ACTIONS(1367),
    [anon_sym_sdiv] = ACTIONS(1367),
    [anon_sym_mod] = ACTIONS(1367),
    [anon_sym_smod] = ACTIONS(1367),
    [anon_sym_exp] = ACTIONS(1367),
    [anon_sym_not] = ACTIONS(1367),
    [anon_sym_lt] = ACTIONS(1367),
    [anon_sym_gt] = ACTIONS(1367),
    [anon_sym_slt] = ACTIONS(1367),
    [anon_sym_sgt] = ACTIONS(1367),
    [anon_sym_eq] = ACTIONS(1367),
    [anon_sym_iszero] = ACTIONS(1367),
    [anon_sym_and] = ACTIONS(1367),
    [anon_sym_or] = ACTIONS(1367),
    [anon_sym_xor] = ACTIONS(1367),
    [anon_sym_byte] = ACTIONS(1367),
    [anon_sym_shl] = ACTIONS(1367),
    [anon_sym_shr] = ACTIONS(1367),
    [anon_sym_sar] = ACTIONS(1367),
    [anon_sym_addmod] = ACTIONS(1367),
    [anon_sym_mulmod] = ACTIONS(1367),
    [anon_sym_signextend] = ACTIONS(1367),
    [anon_sym_keccak256] = ACTIONS(1367),
    [anon_sym_pop] = ACTIONS(1367),
    [anon_sym_mload] = ACTIONS(1367),
    [anon_sym_mstore] = ACTIONS(1367),
    [anon_sym_mstore8] = ACTIONS(1367),
    [anon_sym_sload] = ACTIONS(1367),
    [anon_sym_sstore] = ACTIONS(1367),
    [anon_sym_msize] = ACTIONS(1367),
    [anon_sym_gas] = ACTIONS(1367),
    [anon_sym_address] = ACTIONS(1367),
    [anon_sym_balance] = ACTIONS(1367),
    [anon_sym_selfbalance] = ACTIONS(1367),
    [anon_sym_caller] = ACTIONS(1367),
    [anon_sym_callvalue] = ACTIONS(1367),
    [anon_sym_calldataload] = ACTIONS(1367),
    [anon_sym_calldatasize] = ACTIONS(1367),
    [anon_sym_calldatacopy] = ACTIONS(1367),
    [anon_sym_extcodesize] = ACTIONS(1367),
    [anon_sym_extcodecopy] = ACTIONS(1367),
    [anon_sym_returndatasize] = ACTIONS(1367),
    [anon_sym_returndatacopy] = ACTIONS(1367),
    [anon_sym_extcodehash] = ACTIONS(1367),
    [anon_sym_create] = ACTIONS(1367),
    [anon_sym_create2] = ACTIONS(1367),
    [anon_sym_call] = ACTIONS(1367),
    [anon_sym_callcode] = ACTIONS(1367),
    [anon_sym_delegatecall] = ACTIONS(1367),
    [anon_sym_staticcall] = ACTIONS(1367),
    [anon_sym_return] = ACTIONS(1367),
    [anon_sym_revert] = ACTIONS(1367),
    [anon_sym_selfdestruct] = ACTIONS(1367),
    [anon_sym_invalid] = ACTIONS(1367),
    [anon_sym_log0] = ACTIONS(1367),
    [anon_sym_log1] = ACTIONS(1367),
    [anon_sym_log2] = ACTIONS(1367),
    [anon_sym_log3] = ACTIONS(1367),
    [anon_sym_log4] = ACTIONS(1367),
    [anon_sym_chainid] = ACTIONS(1367),
    [anon_sym_origin] = ACTIONS(1367),
    [anon_sym_gasprice] = ACTIONS(1367),
    [anon_sym_blockhash] = ACTIONS(1367),
    [anon_sym_coinbase] = ACTIONS(1367),
    [anon_sym_timestamp] = ACTIONS(1367),
    [anon_sym_number] = ACTIONS(1367),
    [anon_sym_difficulty] = ACTIONS(1367),
    [anon_sym_gaslimit] = ACTIONS(1367),
    [anon_sym_hex] = ACTIONS(1367),
    [anon_sym_DQUOTE] = ACTIONS(1369),
    [anon_sym_SQUOTE] = ACTIONS(1369),
    [sym_comment] = ACTIONS(3),
  },
  [378] = {
    [sym_identifier] = ACTIONS(1371),
    [anon_sym_LBRACE] = ACTIONS(1373),
    [anon_sym_RBRACE] = ACTIONS(1373),
    [anon_sym_for] = ACTIONS(1371),
    [sym_yul_leave] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_continue] = ACTIONS(1371),
    [sym_yul_decimal_number] = ACTIONS(1371),
    [sym_yul_hex_number] = ACTIONS(1373),
    [anon_sym_true] = ACTIONS(1371),
    [anon_sym_false] = ACTIONS(1371),
    [anon_sym_let] = ACTIONS(1371),
    [anon_sym_if] = ACTIONS(1371),
    [anon_sym_switch] = ACTIONS(1371),
    [anon_sym_function] = ACTIONS(1371),
    [anon_sym_stop] = ACTIONS(1371),
    [anon_sym_add] = ACTIONS(1371),
    [anon_sym_sub] = ACTIONS(1371),
    [anon_sym_mul] = ACTIONS(1371),
    [anon_sym_div] = ACTIONS(1371),
    [anon_sym_sdiv] = ACTIONS(1371),
    [anon_sym_mod] = ACTIONS(1371),
    [anon_sym_smod] = ACTIONS(1371),
    [anon_sym_exp] = ACTIONS(1371),
    [anon_sym_not] = ACTIONS(1371),
    [anon_sym_lt] = ACTIONS(1371),
    [anon_sym_gt] = ACTIONS(1371),
    [anon_sym_slt] = ACTIONS(1371),
    [anon_sym_sgt] = ACTIONS(1371),
    [anon_sym_eq] = ACTIONS(1371),
    [anon_sym_iszero] = ACTIONS(1371),
    [anon_sym_and] = ACTIONS(1371),
    [anon_sym_or] = ACTIONS(1371),
    [anon_sym_xor] = ACTIONS(1371),
    [anon_sym_byte] = ACTIONS(1371),
    [anon_sym_shl] = ACTIONS(1371),
    [anon_sym_shr] = ACTIONS(1371),
    [anon_sym_sar] = ACTIONS(1371),
    [anon_sym_addmod] = ACTIONS(1371),
    [anon_sym_mulmod] = ACTIONS(1371),
    [anon_sym_signextend] = ACTIONS(1371),
    [anon_sym_keccak256] = ACTIONS(1371),
    [anon_sym_pop] = ACTIONS(1371),
    [anon_sym_mload] = ACTIONS(1371),
    [anon_sym_mstore] = ACTIONS(1371),
    [anon_sym_mstore8] = ACTIONS(1371),
    [anon_sym_sload] = ACTIONS(1371),
    [anon_sym_sstore] = ACTIONS(1371),
    [anon_sym_msize] = ACTIONS(1371),
    [anon_sym_gas] = ACTIONS(1371),
    [anon_sym_address] = ACTIONS(1371),
    [anon_sym_balance] = ACTIONS(1371),
    [anon_sym_selfbalance] = ACTIONS(1371),
    [anon_sym_caller] = ACTIONS(1371),
    [anon_sym_callvalue] = ACTIONS(1371),
    [anon_sym_calldataload] = ACTIONS(1371),
    [anon_sym_calldatasize] = ACTIONS(1371),
    [anon_sym_calldatacopy] = ACTIONS(1371),
    [anon_sym_extcodesize] = ACTIONS(1371),
    [anon_sym_extcodecopy] = ACTIONS(1371),
    [anon_sym_returndatasize] = ACTIONS(1371),
    [anon_sym_returndatacopy] = ACTIONS(1371),
    [anon_sym_extcodehash] = ACTIONS(1371),
    [anon_sym_create] = ACTIONS(1371),
    [anon_sym_create2] = ACTIONS(1371),
    [anon_sym_call] = ACTIONS(1371),
    [anon_sym_callcode] = ACTIONS(1371),
    [anon_sym_delegatecall] = ACTIONS(1371),
    [anon_sym_staticcall] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1371),
    [anon_sym_revert] = ACTIONS(1371),
    [anon_sym_selfdestruct] = ACTIONS(1371),
    [anon_sym_invalid] = ACTIONS(1371),
    [anon_sym_log0] = ACTIONS(1371),
    [anon_sym_log1] = ACTIONS(1371),
    [anon_sym_log2] = ACTIONS(1371),
    [anon_sym_log3] = ACTIONS(1371),
    [anon_sym_log4] = ACTIONS(1371),
    [anon_sym_chainid] = ACTIONS(1371),
    [anon_sym_origin] = ACTIONS(1371),
    [anon_sym_gasprice] = ACTIONS(1371),
    [anon_sym_blockhash] = ACTIONS(1371),
    [anon_sym_coinbase] = ACTIONS(1371),
    [anon_sym_timestamp] = ACTIONS(1371),
    [anon_sym_number] = ACTIONS(1371),
    [anon_sym_difficulty] = ACTIONS(1371),
    [anon_sym_gaslimit] = ACTIONS(1371),
    [anon_sym_hex] = ACTIONS(1371),
    [anon_sym_DQUOTE] = ACTIONS(1373),
    [anon_sym_SQUOTE] = ACTIONS(1373),
    [sym_comment] = ACTIONS(3),
  },
  [379] = {
    [sym_identifier] = ACTIONS(1375),
    [sym_yul_decimal_number] = ACTIONS(1375),
    [sym_yul_hex_number] = ACTIONS(1377),
    [anon_sym_true] = ACTIONS(1375),
    [anon_sym_false] = ACTIONS(1375),
    [anon_sym_stop] = ACTIONS(1375),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_sub] = ACTIONS(1375),
    [anon_sym_mul] = ACTIONS(1375),
    [anon_sym_div] = ACTIONS(1375),
    [anon_sym_sdiv] = ACTIONS(1375),
    [anon_sym_mod] = ACTIONS(1375),
    [anon_sym_smod] = ACTIONS(1375),
    [anon_sym_exp] = ACTIONS(1375),
    [anon_sym_not] = ACTIONS(1375),
    [anon_sym_lt] = ACTIONS(1375),
    [anon_sym_gt] = ACTIONS(1375),
    [anon_sym_slt] = ACTIONS(1375),
    [anon_sym_sgt] = ACTIONS(1375),
    [anon_sym_eq] = ACTIONS(1375),
    [anon_sym_iszero] = ACTIONS(1375),
    [anon_sym_and] = ACTIONS(1375),
    [anon_sym_or] = ACTIONS(1375),
    [anon_sym_xor] = ACTIONS(1375),
    [anon_sym_byte] = ACTIONS(1375),
    [anon_sym_shl] = ACTIONS(1375),
    [anon_sym_shr] = ACTIONS(1375),
    [anon_sym_sar] = ACTIONS(1375),
    [anon_sym_addmod] = ACTIONS(1375),
    [anon_sym_mulmod] = ACTIONS(1375),
    [anon_sym_signextend] = ACTIONS(1375),
    [anon_sym_keccak256] = ACTIONS(1375),
    [anon_sym_pop] = ACTIONS(1375),
    [anon_sym_mload] = ACTIONS(1375),
    [anon_sym_mstore] = ACTIONS(1375),
    [anon_sym_mstore8] = ACTIONS(1375),
    [anon_sym_sload] = ACTIONS(1375),
    [anon_sym_sstore] = ACTIONS(1375),
    [anon_sym_msize] = ACTIONS(1375),
    [anon_sym_gas] = ACTIONS(1375),
    [anon_sym_address] = ACTIONS(1375),
    [anon_sym_balance] = ACTIONS(1375),
    [anon_sym_selfbalance] = ACTIONS(1375),
    [anon_sym_caller] = ACTIONS(1375),
    [anon_sym_callvalue] = ACTIONS(1375),
    [anon_sym_calldataload] = ACTIONS(1375),
    [anon_sym_calldatasize] = ACTIONS(1375),
    [anon_sym_calldatacopy] = ACTIONS(1375),
    [anon_sym_extcodesize] = ACTIONS(1375),
    [anon_sym_extcodecopy] = ACTIONS(1375),
    [anon_sym_returndatasize] = ACTIONS(1375),
    [anon_sym_returndatacopy] = ACTIONS(1375),
    [anon_sym_extcodehash] = ACTIONS(1375),
    [anon_sym_create] = ACTIONS(1375),
    [anon_sym_create2] = ACTIONS(1375),
    [anon_sym_call] = ACTIONS(1375),
    [anon_sym_callcode] = ACTIONS(1375),
    [anon_sym_delegatecall] = ACTIONS(1375),
    [anon_sym_staticcall] = ACTIONS(1375),
    [anon_sym_return] = ACTIONS(1375),
    [anon_sym_revert] = ACTIONS(1375),
    [anon_sym_selfdestruct] = ACTIONS(1375),
    [anon_sym_invalid] = ACTIONS(1375),
    [anon_sym_log0] = ACTIONS(1375),
    [anon_sym_log1] = ACTIONS(1375),
    [anon_sym_log2] = ACTIONS(1375),
    [anon_sym_log3] = ACTIONS(1375),
    [anon_sym_log4] = ACTIONS(1375),
    [anon_sym_chainid] = ACTIONS(1375),
    [anon_sym_origin] = ACTIONS(1375),
    [anon_sym_gasprice] = ACTIONS(1375),
    [anon_sym_blockhash] = ACTIONS(1375),
    [anon_sym_coinbase] = ACTIONS(1375),
    [anon_sym_timestamp] = ACTIONS(1375),
    [anon_sym_number] = ACTIONS(1375),
    [anon_sym_difficulty] = ACTIONS(1375),
    [anon_sym_gaslimit] = ACTIONS(1375),
    [anon_sym_hex] = ACTIONS(1375),
    [anon_sym_DQUOTE] = ACTIONS(1377),
    [anon_sym_SQUOTE] = ACTIONS(1377),
    [sym_comment] = ACTIONS(3),
  },
  [380] = {
    [sym_yul_identifier] = STATE(1003),
    [sym_yul_function_call] = STATE(357),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [sym_comment] = ACTIONS(3),
  },
  [381] = {
    [sym_yul_identifier] = STATE(1003),
    [sym_yul_function_call] = STATE(375),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [sym_comment] = ACTIONS(3),
  },
  [382] = {
    [sym_yul_identifier] = STATE(1003),
    [sym_yul_function_call] = STATE(354),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [sym_comment] = ACTIONS(3),
  },
  [383] = {
    [sym_yul_identifier] = STATE(1003),
    [sym_yul_function_call] = STATE(371),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [sym_comment] = ACTIONS(3),
  },
  [384] = {
    [sym_yul_identifier] = STATE(1003),
    [sym_yul_function_call] = STATE(373),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [sym_comment] = ACTIONS(3),
  },
  [385] = {
    [sym_yul_identifier] = STATE(1003),
    [sym_yul_function_call] = STATE(349),
    [sym_yul_evm_builtin] = STATE(312),
    [sym_identifier] = ACTIONS(1184),
    [anon_sym_stop] = ACTIONS(959),
    [anon_sym_add] = ACTIONS(959),
    [anon_sym_sub] = ACTIONS(959),
    [anon_sym_mul] = ACTIONS(959),
    [anon_sym_div] = ACTIONS(959),
    [anon_sym_sdiv] = ACTIONS(959),
    [anon_sym_mod] = ACTIONS(959),
    [anon_sym_smod] = ACTIONS(959),
    [anon_sym_exp] = ACTIONS(959),
    [anon_sym_not] = ACTIONS(959),
    [anon_sym_lt] = ACTIONS(959),
    [anon_sym_gt] = ACTIONS(959),
    [anon_sym_slt] = ACTIONS(959),
    [anon_sym_sgt] = ACTIONS(959),
    [anon_sym_eq] = ACTIONS(959),
    [anon_sym_iszero] = ACTIONS(959),
    [anon_sym_and] = ACTIONS(959),
    [anon_sym_or] = ACTIONS(959),
    [anon_sym_xor] = ACTIONS(959),
    [anon_sym_byte] = ACTIONS(959),
    [anon_sym_shl] = ACTIONS(959),
    [anon_sym_shr] = ACTIONS(959),
    [anon_sym_sar] = ACTIONS(959),
    [anon_sym_addmod] = ACTIONS(959),
    [anon_sym_mulmod] = ACTIONS(959),
    [anon_sym_signextend] = ACTIONS(959),
    [anon_sym_keccak256] = ACTIONS(959),
    [anon_sym_pop] = ACTIONS(959),
    [anon_sym_mload] = ACTIONS(959),
    [anon_sym_mstore] = ACTIONS(959),
    [anon_sym_mstore8] = ACTIONS(959),
    [anon_sym_sload] = ACTIONS(959),
    [anon_sym_sstore] = ACTIONS(959),
    [anon_sym_msize] = ACTIONS(959),
    [anon_sym_gas] = ACTIONS(959),
    [anon_sym_address] = ACTIONS(959),
    [anon_sym_balance] = ACTIONS(959),
    [anon_sym_selfbalance] = ACTIONS(959),
    [anon_sym_caller] = ACTIONS(959),
    [anon_sym_callvalue] = ACTIONS(959),
    [anon_sym_calldataload] = ACTIONS(959),
    [anon_sym_calldatasize] = ACTIONS(959),
    [anon_sym_calldatacopy] = ACTIONS(959),
    [anon_sym_extcodesize] = ACTIONS(959),
    [anon_sym_extcodecopy] = ACTIONS(959),
    [anon_sym_returndatasize] = ACTIONS(959),
    [anon_sym_returndatacopy] = ACTIONS(959),
    [anon_sym_extcodehash] = ACTIONS(959),
    [anon_sym_create] = ACTIONS(959),
    [anon_sym_create2] = ACTIONS(959),
    [anon_sym_call] = ACTIONS(959),
    [anon_sym_callcode] = ACTIONS(959),
    [anon_sym_delegatecall] = ACTIONS(959),
    [anon_sym_staticcall] = ACTIONS(959),
    [anon_sym_return] = ACTIONS(959),
    [anon_sym_revert] = ACTIONS(959),
    [anon_sym_selfdestruct] = ACTIONS(959),
    [anon_sym_invalid] = ACTIONS(959),
    [anon_sym_log0] = ACTIONS(959),
    [anon_sym_log1] = ACTIONS(959),
    [anon_sym_log2] = ACTIONS(959),
    [anon_sym_log3] = ACTIONS(959),
    [anon_sym_log4] = ACTIONS(959),
    [anon_sym_chainid] = ACTIONS(959),
    [anon_sym_origin] = ACTIONS(959),
    [anon_sym_gasprice] = ACTIONS(959),
    [anon_sym_blockhash] = ACTIONS(959),
    [anon_sym_coinbase] = ACTIONS(959),
    [anon_sym_timestamp] = ACTIONS(959),
    [anon_sym_number] = ACTIONS(959),
    [anon_sym_difficulty] = ACTIONS(959),
    [anon_sym_gaslimit] = ACTIONS(959),
    [sym_comment] = ACTIONS(3),
  },
  [386] = {
    [aux_sym__identifier_path_repeat1] = STATE(386),
    [sym_identifier] = ACTIONS(1379),
    [anon_sym_PIPE_PIPE] = ACTIONS(1381),
    [anon_sym_DASH] = ACTIONS(1379),
    [anon_sym_LT_EQ] = ACTIONS(1381),
    [anon_sym_LT] = ACTIONS(1379),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_GT] = ACTIONS(1379),
    [anon_sym_GT_EQ] = ACTIONS(1381),
    [anon_sym_EQ] = ACTIONS(1379),
    [anon_sym_STAR] = ACTIONS(1379),
    [anon_sym_LBRACE] = ACTIONS(1381),
    [anon_sym_COMMA] = ACTIONS(1381),
    [anon_sym_RBRACE] = ACTIONS(1381),
    [anon_sym_as] = ACTIONS(1379),
    [anon_sym_constant] = ACTIONS(1379),
    [anon_sym_LPAREN] = ACTIONS(1381),
    [anon_sym_RPAREN] = ACTIONS(1381),
    [anon_sym_indexed] = ACTIONS(1379),
    [anon_sym_for] = ACTIONS(1379),
    [anon_sym_global] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_PIPE] = ACTIONS(1379),
    [anon_sym_PLUS] = ACTIONS(1379),
    [anon_sym_SLASH] = ACTIONS(1379),
    [anon_sym_PERCENT] = ACTIONS(1379),
    [anon_sym_EQ_EQ] = ACTIONS(1381),
    [anon_sym_BANG_EQ] = ACTIONS(1379),
    [anon_sym_COLON] = ACTIONS(1381),
    [anon_sym_DOT] = ACTIONS(1383),
    [sym__unchecked] = ACTIONS(1379),
    [anon_sym_memory] = ACTIONS(1379),
    [anon_sym_storage] = ACTIONS(1379),
    [anon_sym_calldata] = ACTIONS(1379),
    [anon_sym_returns] = ACTIONS(1379),
    [anon_sym_public] = ACTIONS(1379),
    [anon_sym_internal] = ACTIONS(1379),
    [anon_sym_private] = ACTIONS(1379),
    [anon_sym_external] = ACTIONS(1379),
    [anon_sym_pure] = ACTIONS(1379),
    [anon_sym_view] = ACTIONS(1379),
    [anon_sym_payable] = ACTIONS(1379),
    [sym_immutable] = ACTIONS(1379),
    [anon_sym_override] = ACTIONS(1379),
    [sym_virtual] = ACTIONS(1379),
    [anon_sym_QMARK] = ACTIONS(1381),
    [anon_sym_LBRACK] = ACTIONS(1381),
    [anon_sym_RBRACK] = ACTIONS(1381),
    [anon_sym_AMP_AMP] = ACTIONS(1381),
    [anon_sym_GT_GT] = ACTIONS(1379),
    [anon_sym_GT_GT_GT] = ACTIONS(1379),
    [anon_sym_LT_LT] = ACTIONS(1379),
    [anon_sym_STAR_STAR] = ACTIONS(1381),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1381),
    [anon_sym_PLUS_PLUS] = ACTIONS(1381),
    [anon_sym_DASH_DASH] = ACTIONS(1381),
    [anon_sym_PLUS_EQ] = ACTIONS(1381),
    [anon_sym_DASH_EQ] = ACTIONS(1381),
    [anon_sym_STAR_EQ] = ACTIONS(1381),
    [anon_sym_SLASH_EQ] = ACTIONS(1381),
    [anon_sym_PERCENT_EQ] = ACTIONS(1381),
    [anon_sym_CARET_EQ] = ACTIONS(1381),
    [anon_sym_AMP_EQ] = ACTIONS(1381),
    [anon_sym_PIPE_EQ] = ACTIONS(1381),
    [anon_sym_GT_GT_EQ] = ACTIONS(1381),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1381),
    [anon_sym_LT_LT_EQ] = ACTIONS(1381),
    [anon_sym_EQ_GT] = ACTIONS(1381),
    [sym__semicolon] = ACTIONS(1381),
    [sym_comment] = ACTIONS(3),
  },
  [387] = {
    [sym_visibility] = STATE(397),
    [sym_state_mutability] = STATE(398),
    [sym__return_parameters] = STATE(414),
    [aux_sym__function_type_repeat1] = STATE(388),
    [sym_identifier] = ACTIONS(1386),
    [anon_sym_PIPE_PIPE] = ACTIONS(1388),
    [anon_sym_DASH] = ACTIONS(1386),
    [anon_sym_LT_EQ] = ACTIONS(1388),
    [anon_sym_LT] = ACTIONS(1386),
    [anon_sym_CARET] = ACTIONS(1386),
    [anon_sym_GT] = ACTIONS(1386),
    [anon_sym_GT_EQ] = ACTIONS(1388),
    [anon_sym_EQ] = ACTIONS(1386),
    [anon_sym_STAR] = ACTIONS(1386),
    [anon_sym_LBRACE] = ACTIONS(1388),
    [anon_sym_COMMA] = ACTIONS(1388),
    [anon_sym_RBRACE] = ACTIONS(1388),
    [anon_sym_constant] = ACTIONS(1386),
    [anon_sym_LPAREN] = ACTIONS(1388),
    [anon_sym_RPAREN] = ACTIONS(1388),
    [anon_sym_indexed] = ACTIONS(1386),
    [anon_sym_global] = ACTIONS(1386),
    [anon_sym_AMP] = ACTIONS(1386),
    [anon_sym_PIPE] = ACTIONS(1386),
    [anon_sym_PLUS] = ACTIONS(1386),
    [anon_sym_SLASH] = ACTIONS(1386),
    [anon_sym_PERCENT] = ACTIONS(1386),
    [anon_sym_EQ_EQ] = ACTIONS(1388),
    [anon_sym_BANG_EQ] = ACTIONS(1386),
    [anon_sym_COLON] = ACTIONS(1388),
    [anon_sym_DOT] = ACTIONS(1388),
    [sym__unchecked] = ACTIONS(1386),
    [anon_sym_memory] = ACTIONS(1386),
    [anon_sym_storage] = ACTIONS(1386),
    [anon_sym_calldata] = ACTIONS(1386),
    [anon_sym_returns] = ACTIONS(1390),
    [anon_sym_public] = ACTIONS(1392),
    [anon_sym_internal] = ACTIONS(1392),
    [anon_sym_private] = ACTIONS(1392),
    [anon_sym_external] = ACTIONS(1392),
    [anon_sym_pure] = ACTIONS(1394),
    [anon_sym_view] = ACTIONS(1394),
    [anon_sym_payable] = ACTIONS(1394),
    [sym_immutable] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_QMARK] = ACTIONS(1388),
    [anon_sym_LBRACK] = ACTIONS(1388),
    [anon_sym_RBRACK] = ACTIONS(1388),
    [anon_sym_AMP_AMP] = ACTIONS(1388),
    [anon_sym_GT_GT] = ACTIONS(1386),
    [anon_sym_GT_GT_GT] = ACTIONS(1386),
    [anon_sym_LT_LT] = ACTIONS(1386),
    [anon_sym_STAR_STAR] = ACTIONS(1388),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1388),
    [anon_sym_PLUS_PLUS] = ACTIONS(1388),
    [anon_sym_DASH_DASH] = ACTIONS(1388),
    [anon_sym_PLUS_EQ] = ACTIONS(1388),
    [anon_sym_DASH_EQ] = ACTIONS(1388),
    [anon_sym_STAR_EQ] = ACTIONS(1388),
    [anon_sym_SLASH_EQ] = ACTIONS(1388),
    [anon_sym_PERCENT_EQ] = ACTIONS(1388),
    [anon_sym_CARET_EQ] = ACTIONS(1388),
    [anon_sym_AMP_EQ] = ACTIONS(1388),
    [anon_sym_PIPE_EQ] = ACTIONS(1388),
    [anon_sym_GT_GT_EQ] = ACTIONS(1388),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1388),
    [anon_sym_LT_LT_EQ] = ACTIONS(1388),
    [sym__semicolon] = ACTIONS(1388),
    [sym_comment] = ACTIONS(3),
  },
  [388] = {
    [sym_visibility] = STATE(397),
    [sym_state_mutability] = STATE(398),
    [sym__return_parameters] = STATE(405),
    [aux_sym__function_type_repeat1] = STATE(390),
    [sym_identifier] = ACTIONS(1396),
    [anon_sym_PIPE_PIPE] = ACTIONS(1398),
    [anon_sym_DASH] = ACTIONS(1396),
    [anon_sym_LT_EQ] = ACTIONS(1398),
    [anon_sym_LT] = ACTIONS(1396),
    [anon_sym_CARET] = ACTIONS(1396),
    [anon_sym_GT] = ACTIONS(1396),
    [anon_sym_GT_EQ] = ACTIONS(1398),
    [anon_sym_EQ] = ACTIONS(1396),
    [anon_sym_STAR] = ACTIONS(1396),
    [anon_sym_LBRACE] = ACTIONS(1398),
    [anon_sym_COMMA] = ACTIONS(1398),
    [anon_sym_RBRACE] = ACTIONS(1398),
    [anon_sym_constant] = ACTIONS(1396),
    [anon_sym_LPAREN] = ACTIONS(1398),
    [anon_sym_RPAREN] = ACTIONS(1398),
    [anon_sym_indexed] = ACTIONS(1396),
    [anon_sym_global] = ACTIONS(1396),
    [anon_sym_AMP] = ACTIONS(1396),
    [anon_sym_PIPE] = ACTIONS(1396),
    [anon_sym_PLUS] = ACTIONS(1396),
    [anon_sym_SLASH] = ACTIONS(1396),
    [anon_sym_PERCENT] = ACTIONS(1396),
    [anon_sym_EQ_EQ] = ACTIONS(1398),
    [anon_sym_BANG_EQ] = ACTIONS(1396),
    [anon_sym_COLON] = ACTIONS(1398),
    [anon_sym_DOT] = ACTIONS(1398),
    [sym__unchecked] = ACTIONS(1396),
    [anon_sym_memory] = ACTIONS(1396),
    [anon_sym_storage] = ACTIONS(1396),
    [anon_sym_calldata] = ACTIONS(1396),
    [anon_sym_returns] = ACTIONS(1390),
    [anon_sym_public] = ACTIONS(1392),
    [anon_sym_internal] = ACTIONS(1392),
    [anon_sym_private] = ACTIONS(1392),
    [anon_sym_external] = ACTIONS(1392),
    [anon_sym_pure] = ACTIONS(1394),
    [anon_sym_view] = ACTIONS(1394),
    [anon_sym_payable] = ACTIONS(1394),
    [sym_immutable] = ACTIONS(1396),
    [anon_sym_override] = ACTIONS(1396),
    [anon_sym_QMARK] = ACTIONS(1398),
    [anon_sym_LBRACK] = ACTIONS(1398),
    [anon_sym_RBRACK] = ACTIONS(1398),
    [anon_sym_AMP_AMP] = ACTIONS(1398),
    [anon_sym_GT_GT] = ACTIONS(1396),
    [anon_sym_GT_GT_GT] = ACTIONS(1396),
    [anon_sym_LT_LT] = ACTIONS(1396),
    [anon_sym_STAR_STAR] = ACTIONS(1398),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1398),
    [anon_sym_PLUS_PLUS] = ACTIONS(1398),
    [anon_sym_DASH_DASH] = ACTIONS(1398),
    [anon_sym_PLUS_EQ] = ACTIONS(1398),
    [anon_sym_DASH_EQ] = ACTIONS(1398),
    [anon_sym_STAR_EQ] = ACTIONS(1398),
    [anon_sym_SLASH_EQ] = ACTIONS(1398),
    [anon_sym_PERCENT_EQ] = ACTIONS(1398),
    [anon_sym_CARET_EQ] = ACTIONS(1398),
    [anon_sym_AMP_EQ] = ACTIONS(1398),
    [anon_sym_PIPE_EQ] = ACTIONS(1398),
    [anon_sym_GT_GT_EQ] = ACTIONS(1398),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1398),
    [anon_sym_LT_LT_EQ] = ACTIONS(1398),
    [sym__semicolon] = ACTIONS(1398),
    [sym_comment] = ACTIONS(3),
  },
  [389] = {
    [sym_identifier] = ACTIONS(1379),
    [anon_sym_PIPE_PIPE] = ACTIONS(1381),
    [anon_sym_DASH] = ACTIONS(1379),
    [anon_sym_LT_EQ] = ACTIONS(1381),
    [anon_sym_LT] = ACTIONS(1379),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_GT] = ACTIONS(1379),
    [anon_sym_GT_EQ] = ACTIONS(1381),
    [anon_sym_EQ] = ACTIONS(1379),
    [anon_sym_STAR] = ACTIONS(1379),
    [anon_sym_LBRACE] = ACTIONS(1381),
    [anon_sym_COMMA] = ACTIONS(1381),
    [anon_sym_RBRACE] = ACTIONS(1381),
    [anon_sym_as] = ACTIONS(1379),
    [anon_sym_constant] = ACTIONS(1379),
    [anon_sym_LPAREN] = ACTIONS(1381),
    [anon_sym_RPAREN] = ACTIONS(1381),
    [anon_sym_indexed] = ACTIONS(1379),
    [anon_sym_for] = ACTIONS(1379),
    [anon_sym_global] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_PIPE] = ACTIONS(1379),
    [anon_sym_PLUS] = ACTIONS(1379),
    [anon_sym_SLASH] = ACTIONS(1379),
    [anon_sym_PERCENT] = ACTIONS(1379),
    [anon_sym_EQ_EQ] = ACTIONS(1381),
    [anon_sym_BANG_EQ] = ACTIONS(1379),
    [anon_sym_COLON] = ACTIONS(1381),
    [anon_sym_DOT] = ACTIONS(1381),
    [sym__unchecked] = ACTIONS(1379),
    [anon_sym_memory] = ACTIONS(1379),
    [anon_sym_storage] = ACTIONS(1379),
    [anon_sym_calldata] = ACTIONS(1379),
    [anon_sym_returns] = ACTIONS(1379),
    [anon_sym_public] = ACTIONS(1379),
    [anon_sym_internal] = ACTIONS(1379),
    [anon_sym_private] = ACTIONS(1379),
    [anon_sym_external] = ACTIONS(1379),
    [anon_sym_pure] = ACTIONS(1379),
    [anon_sym_view] = ACTIONS(1379),
    [anon_sym_payable] = ACTIONS(1379),
    [sym_immutable] = ACTIONS(1379),
    [anon_sym_override] = ACTIONS(1379),
    [sym_virtual] = ACTIONS(1379),
    [anon_sym_QMARK] = ACTIONS(1381),
    [anon_sym_LBRACK] = ACTIONS(1381),
    [anon_sym_RBRACK] = ACTIONS(1381),
    [anon_sym_AMP_AMP] = ACTIONS(1381),
    [anon_sym_GT_GT] = ACTIONS(1379),
    [anon_sym_GT_GT_GT] = ACTIONS(1379),
    [anon_sym_LT_LT] = ACTIONS(1379),
    [anon_sym_STAR_STAR] = ACTIONS(1381),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1381),
    [anon_sym_PLUS_PLUS] = ACTIONS(1381),
    [anon_sym_DASH_DASH] = ACTIONS(1381),
    [anon_sym_PLUS_EQ] = ACTIONS(1381),
    [anon_sym_DASH_EQ] = ACTIONS(1381),
    [anon_sym_STAR_EQ] = ACTIONS(1381),
    [anon_sym_SLASH_EQ] = ACTIONS(1381),
    [anon_sym_PERCENT_EQ] = ACTIONS(1381),
    [anon_sym_CARET_EQ] = ACTIONS(1381),
    [anon_sym_AMP_EQ] = ACTIONS(1381),
    [anon_sym_PIPE_EQ] = ACTIONS(1381),
    [anon_sym_GT_GT_EQ] = ACTIONS(1381),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1381),
    [anon_sym_LT_LT_EQ] = ACTIONS(1381),
    [anon_sym_EQ_GT] = ACTIONS(1381),
    [sym__semicolon] = ACTIONS(1381),
    [sym_comment] = ACTIONS(3),
  },
  [390] = {
    [sym_visibility] = STATE(397),
    [sym_state_mutability] = STATE(398),
    [aux_sym__function_type_repeat1] = STATE(390),
    [sym_identifier] = ACTIONS(1400),
    [anon_sym_PIPE_PIPE] = ACTIONS(1402),
    [anon_sym_DASH] = ACTIONS(1400),
    [anon_sym_LT_EQ] = ACTIONS(1402),
    [anon_sym_LT] = ACTIONS(1400),
    [anon_sym_CARET] = ACTIONS(1400),
    [anon_sym_GT] = ACTIONS(1400),
    [anon_sym_GT_EQ] = ACTIONS(1402),
    [anon_sym_EQ] = ACTIONS(1400),
    [anon_sym_STAR] = ACTIONS(1400),
    [anon_sym_LBRACE] = ACTIONS(1402),
    [anon_sym_COMMA] = ACTIONS(1402),
    [anon_sym_RBRACE] = ACTIONS(1402),
    [anon_sym_constant] = ACTIONS(1400),
    [anon_sym_LPAREN] = ACTIONS(1402),
    [anon_sym_RPAREN] = ACTIONS(1402),
    [anon_sym_indexed] = ACTIONS(1400),
    [anon_sym_global] = ACTIONS(1400),
    [anon_sym_AMP] = ACTIONS(1400),
    [anon_sym_PIPE] = ACTIONS(1400),
    [anon_sym_PLUS] = ACTIONS(1400),
    [anon_sym_SLASH] = ACTIONS(1400),
    [anon_sym_PERCENT] = ACTIONS(1400),
    [anon_sym_EQ_EQ] = ACTIONS(1402),
    [anon_sym_BANG_EQ] = ACTIONS(1400),
    [anon_sym_COLON] = ACTIONS(1402),
    [anon_sym_DOT] = ACTIONS(1402),
    [sym__unchecked] = ACTIONS(1400),
    [anon_sym_memory] = ACTIONS(1400),
    [anon_sym_storage] = ACTIONS(1400),
    [anon_sym_calldata] = ACTIONS(1400),
    [anon_sym_returns] = ACTIONS(1400),
    [anon_sym_public] = ACTIONS(1404),
    [anon_sym_internal] = ACTIONS(1404),
    [anon_sym_private] = ACTIONS(1404),
    [anon_sym_external] = ACTIONS(1404),
    [anon_sym_pure] = ACTIONS(1407),
    [anon_sym_view] = ACTIONS(1407),
    [anon_sym_payable] = ACTIONS(1407),
    [sym_immutable] = ACTIONS(1400),
    [anon_sym_override] = ACTIONS(1400),
    [anon_sym_QMARK] = ACTIONS(1402),
    [anon_sym_LBRACK] = ACTIONS(1402),
    [anon_sym_RBRACK] = ACTIONS(1402),
    [anon_sym_AMP_AMP] = ACTIONS(1402),
    [anon_sym_GT_GT] = ACTIONS(1400),
    [anon_sym_GT_GT_GT] = ACTIONS(1400),
    [anon_sym_LT_LT] = ACTIONS(1400),
    [anon_sym_STAR_STAR] = ACTIONS(1402),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1402),
    [anon_sym_PLUS_PLUS] = ACTIONS(1402),
    [anon_sym_DASH_DASH] = ACTIONS(1402),
    [anon_sym_PLUS_EQ] = ACTIONS(1402),
    [anon_sym_DASH_EQ] = ACTIONS(1402),
    [anon_sym_STAR_EQ] = ACTIONS(1402),
    [anon_sym_SLASH_EQ] = ACTIONS(1402),
    [anon_sym_PERCENT_EQ] = ACTIONS(1402),
    [anon_sym_CARET_EQ] = ACTIONS(1402),
    [anon_sym_AMP_EQ] = ACTIONS(1402),
    [anon_sym_PIPE_EQ] = ACTIONS(1402),
    [anon_sym_GT_GT_EQ] = ACTIONS(1402),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1402),
    [anon_sym_LT_LT_EQ] = ACTIONS(1402),
    [sym__semicolon] = ACTIONS(1402),
    [sym_comment] = ACTIONS(3),
  },
  [391] = {
    [sym_identifier] = ACTIONS(1410),
    [anon_sym_PIPE_PIPE] = ACTIONS(1412),
    [anon_sym_DASH] = ACTIONS(1410),
    [anon_sym_LT_EQ] = ACTIONS(1412),
    [anon_sym_LT] = ACTIONS(1410),
    [anon_sym_CARET] = ACTIONS(1410),
    [anon_sym_GT] = ACTIONS(1410),
    [anon_sym_GT_EQ] = ACTIONS(1412),
    [anon_sym_EQ] = ACTIONS(1410),
    [anon_sym_STAR] = ACTIONS(1410),
    [anon_sym_LBRACE] = ACTIONS(1412),
    [anon_sym_COMMA] = ACTIONS(1412),
    [anon_sym_RBRACE] = ACTIONS(1412),
    [anon_sym_constant] = ACTIONS(1410),
    [anon_sym_LPAREN] = ACTIONS(1412),
    [anon_sym_RPAREN] = ACTIONS(1412),
    [anon_sym_indexed] = ACTIONS(1410),
    [anon_sym_global] = ACTIONS(1410),
    [anon_sym_AMP] = ACTIONS(1410),
    [anon_sym_PIPE] = ACTIONS(1410),
    [anon_sym_PLUS] = ACTIONS(1410),
    [anon_sym_SLASH] = ACTIONS(1410),
    [anon_sym_PERCENT] = ACTIONS(1410),
    [anon_sym_EQ_EQ] = ACTIONS(1412),
    [anon_sym_BANG_EQ] = ACTIONS(1410),
    [anon_sym_COLON] = ACTIONS(1412),
    [anon_sym_DOT] = ACTIONS(1412),
    [sym__unchecked] = ACTIONS(1410),
    [anon_sym_memory] = ACTIONS(1410),
    [anon_sym_storage] = ACTIONS(1410),
    [anon_sym_calldata] = ACTIONS(1410),
    [anon_sym_returns] = ACTIONS(1410),
    [anon_sym_public] = ACTIONS(1410),
    [anon_sym_internal] = ACTIONS(1410),
    [anon_sym_private] = ACTIONS(1410),
    [anon_sym_external] = ACTIONS(1410),
    [anon_sym_pure] = ACTIONS(1410),
    [anon_sym_view] = ACTIONS(1410),
    [anon_sym_payable] = ACTIONS(1410),
    [sym_immutable] = ACTIONS(1410),
    [anon_sym_override] = ACTIONS(1410),
    [sym_virtual] = ACTIONS(1410),
    [anon_sym_QMARK] = ACTIONS(1412),
    [anon_sym_LBRACK] = ACTIONS(1412),
    [anon_sym_RBRACK] = ACTIONS(1412),
    [anon_sym_AMP_AMP] = ACTIONS(1412),
    [anon_sym_GT_GT] = ACTIONS(1410),
    [anon_sym_GT_GT_GT] = ACTIONS(1410),
    [anon_sym_LT_LT] = ACTIONS(1410),
    [anon_sym_STAR_STAR] = ACTIONS(1412),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1412),
    [anon_sym_PLUS_PLUS] = ACTIONS(1412),
    [anon_sym_DASH_DASH] = ACTIONS(1412),
    [anon_sym_PLUS_EQ] = ACTIONS(1412),
    [anon_sym_DASH_EQ] = ACTIONS(1412),
    [anon_sym_STAR_EQ] = ACTIONS(1412),
    [anon_sym_SLASH_EQ] = ACTIONS(1412),
    [anon_sym_PERCENT_EQ] = ACTIONS(1412),
    [anon_sym_CARET_EQ] = ACTIONS(1412),
    [anon_sym_AMP_EQ] = ACTIONS(1412),
    [anon_sym_PIPE_EQ] = ACTIONS(1412),
    [anon_sym_GT_GT_EQ] = ACTIONS(1412),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1412),
    [anon_sym_LT_LT_EQ] = ACTIONS(1412),
    [sym__semicolon] = ACTIONS(1412),
    [sym_comment] = ACTIONS(3),
  },
  [392] = {
    [sym_identifier] = ACTIONS(1414),
    [anon_sym_PIPE_PIPE] = ACTIONS(1416),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_LT_EQ] = ACTIONS(1416),
    [anon_sym_LT] = ACTIONS(1414),
    [anon_sym_CARET] = ACTIONS(1414),
    [anon_sym_GT] = ACTIONS(1414),
    [anon_sym_GT_EQ] = ACTIONS(1416),
    [anon_sym_EQ] = ACTIONS(1414),
    [anon_sym_STAR] = ACTIONS(1414),
    [anon_sym_LBRACE] = ACTIONS(1416),
    [anon_sym_COMMA] = ACTIONS(1416),
    [anon_sym_RBRACE] = ACTIONS(1416),
    [anon_sym_constant] = ACTIONS(1414),
    [anon_sym_LPAREN] = ACTIONS(1416),
    [anon_sym_RPAREN] = ACTIONS(1416),
    [anon_sym_indexed] = ACTIONS(1414),
    [anon_sym_global] = ACTIONS(1414),
    [anon_sym_AMP] = ACTIONS(1414),
    [anon_sym_PIPE] = ACTIONS(1414),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_SLASH] = ACTIONS(1414),
    [anon_sym_PERCENT] = ACTIONS(1414),
    [anon_sym_EQ_EQ] = ACTIONS(1416),
    [anon_sym_BANG_EQ] = ACTIONS(1414),
    [anon_sym_COLON] = ACTIONS(1416),
    [anon_sym_DOT] = ACTIONS(1416),
    [sym__unchecked] = ACTIONS(1414),
    [anon_sym_memory] = ACTIONS(1414),
    [anon_sym_storage] = ACTIONS(1414),
    [anon_sym_calldata] = ACTIONS(1414),
    [anon_sym_returns] = ACTIONS(1414),
    [anon_sym_public] = ACTIONS(1414),
    [anon_sym_internal] = ACTIONS(1414),
    [anon_sym_private] = ACTIONS(1414),
    [anon_sym_external] = ACTIONS(1414),
    [anon_sym_pure] = ACTIONS(1414),
    [anon_sym_view] = ACTIONS(1414),
    [anon_sym_payable] = ACTIONS(1414),
    [sym_immutable] = ACTIONS(1414),
    [anon_sym_override] = ACTIONS(1414),
    [sym_virtual] = ACTIONS(1414),
    [anon_sym_QMARK] = ACTIONS(1416),
    [anon_sym_LBRACK] = ACTIONS(1416),
    [anon_sym_RBRACK] = ACTIONS(1416),
    [anon_sym_AMP_AMP] = ACTIONS(1416),
    [anon_sym_GT_GT] = ACTIONS(1414),
    [anon_sym_GT_GT_GT] = ACTIONS(1414),
    [anon_sym_LT_LT] = ACTIONS(1414),
    [anon_sym_STAR_STAR] = ACTIONS(1416),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1416),
    [anon_sym_PLUS_PLUS] = ACTIONS(1416),
    [anon_sym_DASH_DASH] = ACTIONS(1416),
    [anon_sym_PLUS_EQ] = ACTIONS(1416),
    [anon_sym_DASH_EQ] = ACTIONS(1416),
    [anon_sym_STAR_EQ] = ACTIONS(1416),
    [anon_sym_SLASH_EQ] = ACTIONS(1416),
    [anon_sym_PERCENT_EQ] = ACTIONS(1416),
    [anon_sym_CARET_EQ] = ACTIONS(1416),
    [anon_sym_AMP_EQ] = ACTIONS(1416),
    [anon_sym_PIPE_EQ] = ACTIONS(1416),
    [anon_sym_GT_GT_EQ] = ACTIONS(1416),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1416),
    [anon_sym_LT_LT_EQ] = ACTIONS(1416),
    [sym__semicolon] = ACTIONS(1416),
    [sym_comment] = ACTIONS(3),
  },
  [393] = {
    [sym_identifier] = ACTIONS(1418),
    [anon_sym_PIPE_PIPE] = ACTIONS(1420),
    [anon_sym_DASH] = ACTIONS(1418),
    [anon_sym_LT_EQ] = ACTIONS(1420),
    [anon_sym_LT] = ACTIONS(1418),
    [anon_sym_CARET] = ACTIONS(1418),
    [anon_sym_GT] = ACTIONS(1418),
    [anon_sym_GT_EQ] = ACTIONS(1420),
    [anon_sym_EQ] = ACTIONS(1418),
    [anon_sym_STAR] = ACTIONS(1418),
    [anon_sym_LBRACE] = ACTIONS(1420),
    [anon_sym_COMMA] = ACTIONS(1420),
    [anon_sym_RBRACE] = ACTIONS(1420),
    [anon_sym_constant] = ACTIONS(1418),
    [anon_sym_LPAREN] = ACTIONS(1420),
    [anon_sym_RPAREN] = ACTIONS(1420),
    [anon_sym_indexed] = ACTIONS(1418),
    [anon_sym_global] = ACTIONS(1418),
    [anon_sym_AMP] = ACTIONS(1418),
    [anon_sym_PIPE] = ACTIONS(1418),
    [anon_sym_PLUS] = ACTIONS(1418),
    [anon_sym_SLASH] = ACTIONS(1418),
    [anon_sym_PERCENT] = ACTIONS(1418),
    [anon_sym_EQ_EQ] = ACTIONS(1420),
    [anon_sym_BANG_EQ] = ACTIONS(1418),
    [anon_sym_COLON] = ACTIONS(1420),
    [anon_sym_DOT] = ACTIONS(1420),
    [sym__unchecked] = ACTIONS(1418),
    [anon_sym_memory] = ACTIONS(1418),
    [anon_sym_storage] = ACTIONS(1418),
    [anon_sym_calldata] = ACTIONS(1418),
    [anon_sym_returns] = ACTIONS(1418),
    [anon_sym_public] = ACTIONS(1418),
    [anon_sym_internal] = ACTIONS(1418),
    [anon_sym_private] = ACTIONS(1418),
    [anon_sym_external] = ACTIONS(1418),
    [anon_sym_pure] = ACTIONS(1418),
    [anon_sym_view] = ACTIONS(1418),
    [anon_sym_payable] = ACTIONS(1418),
    [sym_immutable] = ACTIONS(1418),
    [anon_sym_override] = ACTIONS(1418),
    [sym_virtual] = ACTIONS(1418),
    [anon_sym_QMARK] = ACTIONS(1420),
    [anon_sym_LBRACK] = ACTIONS(1420),
    [anon_sym_RBRACK] = ACTIONS(1420),
    [anon_sym_AMP_AMP] = ACTIONS(1420),
    [anon_sym_GT_GT] = ACTIONS(1418),
    [anon_sym_GT_GT_GT] = ACTIONS(1418),
    [anon_sym_LT_LT] = ACTIONS(1418),
    [anon_sym_STAR_STAR] = ACTIONS(1420),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1420),
    [anon_sym_PLUS_PLUS] = ACTIONS(1420),
    [anon_sym_DASH_DASH] = ACTIONS(1420),
    [anon_sym_PLUS_EQ] = ACTIONS(1420),
    [anon_sym_DASH_EQ] = ACTIONS(1420),
    [anon_sym_STAR_EQ] = ACTIONS(1420),
    [anon_sym_SLASH_EQ] = ACTIONS(1420),
    [anon_sym_PERCENT_EQ] = ACTIONS(1420),
    [anon_sym_CARET_EQ] = ACTIONS(1420),
    [anon_sym_AMP_EQ] = ACTIONS(1420),
    [anon_sym_PIPE_EQ] = ACTIONS(1420),
    [anon_sym_GT_GT_EQ] = ACTIONS(1420),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1420),
    [anon_sym_LT_LT_EQ] = ACTIONS(1420),
    [sym__semicolon] = ACTIONS(1420),
    [sym_comment] = ACTIONS(3),
  },
  [394] = {
    [sym_identifier] = ACTIONS(1422),
    [anon_sym_PIPE_PIPE] = ACTIONS(1424),
    [anon_sym_DASH] = ACTIONS(1422),
    [anon_sym_LT_EQ] = ACTIONS(1424),
    [anon_sym_LT] = ACTIONS(1422),
    [anon_sym_CARET] = ACTIONS(1422),
    [anon_sym_GT] = ACTIONS(1422),
    [anon_sym_GT_EQ] = ACTIONS(1424),
    [anon_sym_EQ] = ACTIONS(1422),
    [anon_sym_STAR] = ACTIONS(1422),
    [anon_sym_LBRACE] = ACTIONS(1424),
    [anon_sym_COMMA] = ACTIONS(1424),
    [anon_sym_RBRACE] = ACTIONS(1424),
    [anon_sym_constant] = ACTIONS(1422),
    [anon_sym_LPAREN] = ACTIONS(1424),
    [anon_sym_RPAREN] = ACTIONS(1424),
    [anon_sym_indexed] = ACTIONS(1422),
    [anon_sym_global] = ACTIONS(1422),
    [anon_sym_AMP] = ACTIONS(1422),
    [anon_sym_PIPE] = ACTIONS(1422),
    [anon_sym_PLUS] = ACTIONS(1422),
    [anon_sym_SLASH] = ACTIONS(1422),
    [anon_sym_PERCENT] = ACTIONS(1422),
    [anon_sym_EQ_EQ] = ACTIONS(1424),
    [anon_sym_BANG_EQ] = ACTIONS(1422),
    [anon_sym_COLON] = ACTIONS(1424),
    [anon_sym_DOT] = ACTIONS(1424),
    [sym__unchecked] = ACTIONS(1422),
    [anon_sym_memory] = ACTIONS(1422),
    [anon_sym_storage] = ACTIONS(1422),
    [anon_sym_calldata] = ACTIONS(1422),
    [anon_sym_returns] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_internal] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_external] = ACTIONS(1422),
    [anon_sym_pure] = ACTIONS(1422),
    [anon_sym_view] = ACTIONS(1422),
    [anon_sym_payable] = ACTIONS(1422),
    [sym_immutable] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [sym_virtual] = ACTIONS(1422),
    [anon_sym_QMARK] = ACTIONS(1424),
    [anon_sym_LBRACK] = ACTIONS(1424),
    [anon_sym_RBRACK] = ACTIONS(1424),
    [anon_sym_AMP_AMP] = ACTIONS(1424),
    [anon_sym_GT_GT] = ACTIONS(1422),
    [anon_sym_GT_GT_GT] = ACTIONS(1422),
    [anon_sym_LT_LT] = ACTIONS(1422),
    [anon_sym_STAR_STAR] = ACTIONS(1424),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1424),
    [anon_sym_PLUS_PLUS] = ACTIONS(1424),
    [anon_sym_DASH_DASH] = ACTIONS(1424),
    [anon_sym_PLUS_EQ] = ACTIONS(1424),
    [anon_sym_DASH_EQ] = ACTIONS(1424),
    [anon_sym_STAR_EQ] = ACTIONS(1424),
    [anon_sym_SLASH_EQ] = ACTIONS(1424),
    [anon_sym_PERCENT_EQ] = ACTIONS(1424),
    [anon_sym_CARET_EQ] = ACTIONS(1424),
    [anon_sym_AMP_EQ] = ACTIONS(1424),
    [anon_sym_PIPE_EQ] = ACTIONS(1424),
    [anon_sym_GT_GT_EQ] = ACTIONS(1424),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1424),
    [anon_sym_LT_LT_EQ] = ACTIONS(1424),
    [sym__semicolon] = ACTIONS(1424),
    [sym_comment] = ACTIONS(3),
  },
  [395] = {
    [sym_identifier] = ACTIONS(1426),
    [anon_sym_PIPE_PIPE] = ACTIONS(1428),
    [anon_sym_DASH] = ACTIONS(1426),
    [anon_sym_LT_EQ] = ACTIONS(1428),
    [anon_sym_LT] = ACTIONS(1426),
    [anon_sym_CARET] = ACTIONS(1426),
    [anon_sym_GT] = ACTIONS(1426),
    [anon_sym_GT_EQ] = ACTIONS(1428),
    [anon_sym_EQ] = ACTIONS(1426),
    [anon_sym_STAR] = ACTIONS(1426),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym_COMMA] = ACTIONS(1428),
    [anon_sym_RBRACE] = ACTIONS(1428),
    [anon_sym_constant] = ACTIONS(1426),
    [anon_sym_LPAREN] = ACTIONS(1428),
    [anon_sym_RPAREN] = ACTIONS(1428),
    [anon_sym_indexed] = ACTIONS(1426),
    [anon_sym_global] = ACTIONS(1426),
    [anon_sym_AMP] = ACTIONS(1426),
    [anon_sym_PIPE] = ACTIONS(1426),
    [anon_sym_PLUS] = ACTIONS(1426),
    [anon_sym_SLASH] = ACTIONS(1426),
    [anon_sym_PERCENT] = ACTIONS(1426),
    [anon_sym_EQ_EQ] = ACTIONS(1428),
    [anon_sym_BANG_EQ] = ACTIONS(1426),
    [anon_sym_COLON] = ACTIONS(1428),
    [anon_sym_DOT] = ACTIONS(1428),
    [sym__unchecked] = ACTIONS(1426),
    [anon_sym_memory] = ACTIONS(1426),
    [anon_sym_storage] = ACTIONS(1426),
    [anon_sym_calldata] = ACTIONS(1426),
    [anon_sym_returns] = ACTIONS(1426),
    [anon_sym_public] = ACTIONS(1426),
    [anon_sym_internal] = ACTIONS(1426),
    [anon_sym_private] = ACTIONS(1426),
    [anon_sym_external] = ACTIONS(1426),
    [anon_sym_pure] = ACTIONS(1426),
    [anon_sym_view] = ACTIONS(1426),
    [anon_sym_payable] = ACTIONS(1426),
    [sym_immutable] = ACTIONS(1426),
    [anon_sym_override] = ACTIONS(1426),
    [sym_virtual] = ACTIONS(1426),
    [anon_sym_QMARK] = ACTIONS(1428),
    [anon_sym_LBRACK] = ACTIONS(1428),
    [anon_sym_RBRACK] = ACTIONS(1428),
    [anon_sym_AMP_AMP] = ACTIONS(1428),
    [anon_sym_GT_GT] = ACTIONS(1426),
    [anon_sym_GT_GT_GT] = ACTIONS(1426),
    [anon_sym_LT_LT] = ACTIONS(1426),
    [anon_sym_STAR_STAR] = ACTIONS(1428),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1428),
    [anon_sym_PLUS_PLUS] = ACTIONS(1428),
    [anon_sym_DASH_DASH] = ACTIONS(1428),
    [anon_sym_PLUS_EQ] = ACTIONS(1428),
    [anon_sym_DASH_EQ] = ACTIONS(1428),
    [anon_sym_STAR_EQ] = ACTIONS(1428),
    [anon_sym_SLASH_EQ] = ACTIONS(1428),
    [anon_sym_PERCENT_EQ] = ACTIONS(1428),
    [anon_sym_CARET_EQ] = ACTIONS(1428),
    [anon_sym_AMP_EQ] = ACTIONS(1428),
    [anon_sym_PIPE_EQ] = ACTIONS(1428),
    [anon_sym_GT_GT_EQ] = ACTIONS(1428),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1428),
    [anon_sym_LT_LT_EQ] = ACTIONS(1428),
    [sym__semicolon] = ACTIONS(1428),
    [sym_comment] = ACTIONS(3),
  },
  [396] = {
    [sym_identifier] = ACTIONS(1430),
    [anon_sym_PIPE_PIPE] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1430),
    [anon_sym_LT_EQ] = ACTIONS(1432),
    [anon_sym_LT] = ACTIONS(1430),
    [anon_sym_CARET] = ACTIONS(1430),
    [anon_sym_GT] = ACTIONS(1430),
    [anon_sym_GT_EQ] = ACTIONS(1432),
    [anon_sym_EQ] = ACTIONS(1430),
    [anon_sym_STAR] = ACTIONS(1430),
    [anon_sym_LBRACE] = ACTIONS(1432),
    [anon_sym_COMMA] = ACTIONS(1432),
    [anon_sym_RBRACE] = ACTIONS(1432),
    [anon_sym_constant] = ACTIONS(1430),
    [anon_sym_LPAREN] = ACTIONS(1432),
    [anon_sym_RPAREN] = ACTIONS(1432),
    [anon_sym_indexed] = ACTIONS(1430),
    [anon_sym_global] = ACTIONS(1430),
    [anon_sym_AMP] = ACTIONS(1430),
    [anon_sym_PIPE] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1430),
    [anon_sym_SLASH] = ACTIONS(1430),
    [anon_sym_PERCENT] = ACTIONS(1430),
    [anon_sym_EQ_EQ] = ACTIONS(1432),
    [anon_sym_BANG_EQ] = ACTIONS(1430),
    [anon_sym_COLON] = ACTIONS(1432),
    [anon_sym_DOT] = ACTIONS(1432),
    [sym__unchecked] = ACTIONS(1430),
    [anon_sym_memory] = ACTIONS(1430),
    [anon_sym_storage] = ACTIONS(1430),
    [anon_sym_calldata] = ACTIONS(1430),
    [anon_sym_returns] = ACTIONS(1430),
    [anon_sym_public] = ACTIONS(1430),
    [anon_sym_internal] = ACTIONS(1430),
    [anon_sym_private] = ACTIONS(1430),
    [anon_sym_external] = ACTIONS(1430),
    [anon_sym_pure] = ACTIONS(1430),
    [anon_sym_view] = ACTIONS(1430),
    [anon_sym_payable] = ACTIONS(1430),
    [sym_immutable] = ACTIONS(1430),
    [anon_sym_override] = ACTIONS(1430),
    [sym_virtual] = ACTIONS(1430),
    [anon_sym_QMARK] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(1432),
    [anon_sym_RBRACK] = ACTIONS(1432),
    [anon_sym_AMP_AMP] = ACTIONS(1432),
    [anon_sym_GT_GT] = ACTIONS(1430),
    [anon_sym_GT_GT_GT] = ACTIONS(1430),
    [anon_sym_LT_LT] = ACTIONS(1430),
    [anon_sym_STAR_STAR] = ACTIONS(1432),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1432),
    [anon_sym_PLUS_PLUS] = ACTIONS(1432),
    [anon_sym_DASH_DASH] = ACTIONS(1432),
    [anon_sym_PLUS_EQ] = ACTIONS(1432),
    [anon_sym_DASH_EQ] = ACTIONS(1432),
    [anon_sym_STAR_EQ] = ACTIONS(1432),
    [anon_sym_SLASH_EQ] = ACTIONS(1432),
    [anon_sym_PERCENT_EQ] = ACTIONS(1432),
    [anon_sym_CARET_EQ] = ACTIONS(1432),
    [anon_sym_AMP_EQ] = ACTIONS(1432),
    [anon_sym_PIPE_EQ] = ACTIONS(1432),
    [anon_sym_GT_GT_EQ] = ACTIONS(1432),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1432),
    [anon_sym_LT_LT_EQ] = ACTIONS(1432),
    [sym__semicolon] = ACTIONS(1432),
    [sym_comment] = ACTIONS(3),
  },
  [397] = {
    [sym_identifier] = ACTIONS(1434),
    [anon_sym_PIPE_PIPE] = ACTIONS(1436),
    [anon_sym_DASH] = ACTIONS(1434),
    [anon_sym_LT_EQ] = ACTIONS(1436),
    [anon_sym_LT] = ACTIONS(1434),
    [anon_sym_CARET] = ACTIONS(1434),
    [anon_sym_GT] = ACTIONS(1434),
    [anon_sym_GT_EQ] = ACTIONS(1436),
    [anon_sym_EQ] = ACTIONS(1434),
    [anon_sym_STAR] = ACTIONS(1434),
    [anon_sym_LBRACE] = ACTIONS(1436),
    [anon_sym_COMMA] = ACTIONS(1436),
    [anon_sym_RBRACE] = ACTIONS(1436),
    [anon_sym_constant] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1436),
    [anon_sym_RPAREN] = ACTIONS(1436),
    [anon_sym_indexed] = ACTIONS(1434),
    [anon_sym_global] = ACTIONS(1434),
    [anon_sym_AMP] = ACTIONS(1434),
    [anon_sym_PIPE] = ACTIONS(1434),
    [anon_sym_PLUS] = ACTIONS(1434),
    [anon_sym_SLASH] = ACTIONS(1434),
    [anon_sym_PERCENT] = ACTIONS(1434),
    [anon_sym_EQ_EQ] = ACTIONS(1436),
    [anon_sym_BANG_EQ] = ACTIONS(1434),
    [anon_sym_COLON] = ACTIONS(1436),
    [anon_sym_DOT] = ACTIONS(1436),
    [sym__unchecked] = ACTIONS(1434),
    [anon_sym_memory] = ACTIONS(1434),
    [anon_sym_storage] = ACTIONS(1434),
    [anon_sym_calldata] = ACTIONS(1434),
    [anon_sym_returns] = ACTIONS(1434),
    [anon_sym_public] = ACTIONS(1434),
    [anon_sym_internal] = ACTIONS(1434),
    [anon_sym_private] = ACTIONS(1434),
    [anon_sym_external] = ACTIONS(1434),
    [anon_sym_pure] = ACTIONS(1434),
    [anon_sym_view] = ACTIONS(1434),
    [anon_sym_payable] = ACTIONS(1434),
    [sym_immutable] = ACTIONS(1434),
    [anon_sym_override] = ACTIONS(1434),
    [anon_sym_QMARK] = ACTIONS(1436),
    [anon_sym_LBRACK] = ACTIONS(1436),
    [anon_sym_RBRACK] = ACTIONS(1436),
    [anon_sym_AMP_AMP] = ACTIONS(1436),
    [anon_sym_GT_GT] = ACTIONS(1434),
    [anon_sym_GT_GT_GT] = ACTIONS(1434),
    [anon_sym_LT_LT] = ACTIONS(1434),
    [anon_sym_STAR_STAR] = ACTIONS(1436),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1436),
    [anon_sym_PLUS_PLUS] = ACTIONS(1436),
    [anon_sym_DASH_DASH] = ACTIONS(1436),
    [anon_sym_PLUS_EQ] = ACTIONS(1436),
    [anon_sym_DASH_EQ] = ACTIONS(1436),
    [anon_sym_STAR_EQ] = ACTIONS(1436),
    [anon_sym_SLASH_EQ] = ACTIONS(1436),
    [anon_sym_PERCENT_EQ] = ACTIONS(1436),
    [anon_sym_CARET_EQ] = ACTIONS(1436),
    [anon_sym_AMP_EQ] = ACTIONS(1436),
    [anon_sym_PIPE_EQ] = ACTIONS(1436),
    [anon_sym_GT_GT_EQ] = ACTIONS(1436),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1436),
    [anon_sym_LT_LT_EQ] = ACTIONS(1436),
    [sym__semicolon] = ACTIONS(1436),
    [sym_comment] = ACTIONS(3),
  },
  [398] = {
    [sym_identifier] = ACTIONS(1438),
    [anon_sym_PIPE_PIPE] = ACTIONS(1440),
    [anon_sym_DASH] = ACTIONS(1438),
    [anon_sym_LT_EQ] = ACTIONS(1440),
    [anon_sym_LT] = ACTIONS(1438),
    [anon_sym_CARET] = ACTIONS(1438),
    [anon_sym_GT] = ACTIONS(1438),
    [anon_sym_GT_EQ] = ACTIONS(1440),
    [anon_sym_EQ] = ACTIONS(1438),
    [anon_sym_STAR] = ACTIONS(1438),
    [anon_sym_LBRACE] = ACTIONS(1440),
    [anon_sym_COMMA] = ACTIONS(1440),
    [anon_sym_RBRACE] = ACTIONS(1440),
    [anon_sym_constant] = ACTIONS(1438),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_RPAREN] = ACTIONS(1440),
    [anon_sym_indexed] = ACTIONS(1438),
    [anon_sym_global] = ACTIONS(1438),
    [anon_sym_AMP] = ACTIONS(1438),
    [anon_sym_PIPE] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1438),
    [anon_sym_SLASH] = ACTIONS(1438),
    [anon_sym_PERCENT] = ACTIONS(1438),
    [anon_sym_EQ_EQ] = ACTIONS(1440),
    [anon_sym_BANG_EQ] = ACTIONS(1438),
    [anon_sym_COLON] = ACTIONS(1440),
    [anon_sym_DOT] = ACTIONS(1440),
    [sym__unchecked] = ACTIONS(1438),
    [anon_sym_memory] = ACTIONS(1438),
    [anon_sym_storage] = ACTIONS(1438),
    [anon_sym_calldata] = ACTIONS(1438),
    [anon_sym_returns] = ACTIONS(1438),
    [anon_sym_public] = ACTIONS(1438),
    [anon_sym_internal] = ACTIONS(1438),
    [anon_sym_private] = ACTIONS(1438),
    [anon_sym_external] = ACTIONS(1438),
    [anon_sym_pure] = ACTIONS(1438),
    [anon_sym_view] = ACTIONS(1438),
    [anon_sym_payable] = ACTIONS(1438),
    [sym_immutable] = ACTIONS(1438),
    [anon_sym_override] = ACTIONS(1438),
    [anon_sym_QMARK] = ACTIONS(1440),
    [anon_sym_LBRACK] = ACTIONS(1440),
    [anon_sym_RBRACK] = ACTIONS(1440),
    [anon_sym_AMP_AMP] = ACTIONS(1440),
    [anon_sym_GT_GT] = ACTIONS(1438),
    [anon_sym_GT_GT_GT] = ACTIONS(1438),
    [anon_sym_LT_LT] = ACTIONS(1438),
    [anon_sym_STAR_STAR] = ACTIONS(1440),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1440),
    [anon_sym_PLUS_PLUS] = ACTIONS(1440),
    [anon_sym_DASH_DASH] = ACTIONS(1440),
    [anon_sym_PLUS_EQ] = ACTIONS(1440),
    [anon_sym_DASH_EQ] = ACTIONS(1440),
    [anon_sym_STAR_EQ] = ACTIONS(1440),
    [anon_sym_SLASH_EQ] = ACTIONS(1440),
    [anon_sym_PERCENT_EQ] = ACTIONS(1440),
    [anon_sym_CARET_EQ] = ACTIONS(1440),
    [anon_sym_AMP_EQ] = ACTIONS(1440),
    [anon_sym_PIPE_EQ] = ACTIONS(1440),
    [anon_sym_GT_GT_EQ] = ACTIONS(1440),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1440),
    [anon_sym_LT_LT_EQ] = ACTIONS(1440),
    [sym__semicolon] = ACTIONS(1440),
    [sym_comment] = ACTIONS(3),
  },
  [399] = {
    [sym_identifier] = ACTIONS(1442),
    [anon_sym_PIPE_PIPE] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1442),
    [anon_sym_LT_EQ] = ACTIONS(1444),
    [anon_sym_LT] = ACTIONS(1442),
    [anon_sym_CARET] = ACTIONS(1442),
    [anon_sym_GT] = ACTIONS(1442),
    [anon_sym_GT_EQ] = ACTIONS(1444),
    [anon_sym_EQ] = ACTIONS(1442),
    [anon_sym_STAR] = ACTIONS(1442),
    [anon_sym_LBRACE] = ACTIONS(1444),
    [anon_sym_COMMA] = ACTIONS(1444),
    [anon_sym_RBRACE] = ACTIONS(1444),
    [anon_sym_as] = ACTIONS(1442),
    [anon_sym_constant] = ACTIONS(1442),
    [anon_sym_LPAREN] = ACTIONS(1444),
    [anon_sym_RPAREN] = ACTIONS(1444),
    [anon_sym_indexed] = ACTIONS(1442),
    [anon_sym_for] = ACTIONS(1442),
    [anon_sym_global] = ACTIONS(1442),
    [anon_sym_AMP] = ACTIONS(1442),
    [anon_sym_PIPE] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1442),
    [anon_sym_SLASH] = ACTIONS(1442),
    [anon_sym_PERCENT] = ACTIONS(1442),
    [anon_sym_EQ_EQ] = ACTIONS(1444),
    [anon_sym_BANG_EQ] = ACTIONS(1442),
    [anon_sym_COLON] = ACTIONS(1444),
    [anon_sym_DOT] = ACTIONS(1444),
    [sym__unchecked] = ACTIONS(1442),
    [anon_sym_memory] = ACTIONS(1442),
    [anon_sym_storage] = ACTIONS(1442),
    [anon_sym_calldata] = ACTIONS(1442),
    [anon_sym_returns] = ACTIONS(1442),
    [anon_sym_public] = ACTIONS(1442),
    [anon_sym_internal] = ACTIONS(1442),
    [anon_sym_private] = ACTIONS(1442),
    [anon_sym_external] = ACTIONS(1442),
    [sym_immutable] = ACTIONS(1442),
    [anon_sym_override] = ACTIONS(1442),
    [anon_sym_QMARK] = ACTIONS(1444),
    [anon_sym_LBRACK] = ACTIONS(1444),
    [anon_sym_RBRACK] = ACTIONS(1444),
    [anon_sym_AMP_AMP] = ACTIONS(1444),
    [anon_sym_GT_GT] = ACTIONS(1442),
    [anon_sym_GT_GT_GT] = ACTIONS(1442),
    [anon_sym_LT_LT] = ACTIONS(1442),
    [anon_sym_STAR_STAR] = ACTIONS(1444),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1444),
    [anon_sym_DASH_DASH] = ACTIONS(1444),
    [anon_sym_PLUS_EQ] = ACTIONS(1444),
    [anon_sym_DASH_EQ] = ACTIONS(1444),
    [anon_sym_STAR_EQ] = ACTIONS(1444),
    [anon_sym_SLASH_EQ] = ACTIONS(1444),
    [anon_sym_PERCENT_EQ] = ACTIONS(1444),
    [anon_sym_CARET_EQ] = ACTIONS(1444),
    [anon_sym_AMP_EQ] = ACTIONS(1444),
    [anon_sym_PIPE_EQ] = ACTIONS(1444),
    [anon_sym_GT_GT_EQ] = ACTIONS(1444),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1444),
    [anon_sym_LT_LT_EQ] = ACTIONS(1444),
    [anon_sym_EQ_GT] = ACTIONS(1444),
    [sym__semicolon] = ACTIONS(1444),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1450), 1,
      anon_sym_payable,
    ACTIONS(1446), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1448), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_EQ_GT,
      sym__semicolon,
  [73] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1446), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1448), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_EQ_GT,
      sym__semicolon,
  [143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1452), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1454), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_EQ_GT,
      sym__semicolon,
  [213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1456), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1458), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1460), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1462), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1464), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1466), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1468), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1470), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1474), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1476), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1478), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1482), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1484), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1486), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1490), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1492), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1494), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1496), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1498), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [972] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1500), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1502), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1041] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1504), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1506), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1504), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1506), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1508), 30,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_global,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1510), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1248] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(478), 1,
      sym_number_unit,
    ACTIONS(1516), 11,
      anon_sym_wei,
      anon_sym_szabo,
      anon_sym_finney,
      anon_sym_gwei,
      anon_sym_ether,
      anon_sym_seconds,
      anon_sym_minutes,
      anon_sym_hours,
      anon_sym_days,
      anon_sym_weeks,
      anon_sym_years,
    ACTIONS(1514), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1512), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1320] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1518), 27,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1520), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1522), 27,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1524), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1452] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1526), 27,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1528), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1518] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1530), 27,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1532), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1343), 38,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_case,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
  [1645] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1305), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1307), 38,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_case,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
  [1706] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1542), 1,
      anon_sym_DOT,
    STATE(426), 1,
      aux_sym__identifier_path_repeat1,
    ACTIONS(1534), 4,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      sym_identifier,
    ACTIONS(1539), 17,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1536), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1773] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(386), 1,
      aux_sym__identifier_path_repeat1,
    ACTIONS(1546), 21,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1548), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1836] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1379), 4,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      sym_identifier,
    ACTIONS(1553), 17,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1550), 31,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1898] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1556), 1,
      anon_sym_hex,
    STATE(431), 1,
      aux_sym_hex_string_literal_repeat2,
    ACTIONS(1226), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1228), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_case,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [1962] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    STATE(430), 2,
      sym_string,
      aux_sym_string_literal_repeat1,
    ACTIONS(1560), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1558), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1566), 1,
      anon_sym_DQUOTE,
    ACTIONS(1569), 1,
      anon_sym_SQUOTE,
    STATE(430), 2,
      sym_string,
      aux_sym_string_literal_repeat1,
    ACTIONS(1564), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1562), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2094] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1572), 1,
      anon_sym_hex,
    STATE(431), 1,
      aux_sym_hex_string_literal_repeat2,
    ACTIONS(1246), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1248), 35,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_case,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1309), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1311), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_case,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
      anon_sym_hex,
  [2217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1367), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1369), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_case,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
      anon_sym_hex,
  [2276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1339), 36,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_case,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
      anon_sym_hex,
  [2335] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1579), 1,
      anon_sym_unicode,
    STATE(436), 1,
      aux_sym_unicode_string_literal_repeat3,
    ACTIONS(1577), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1575), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2397] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1585), 1,
      anon_sym_unicode,
    STATE(436), 1,
      aux_sym_unicode_string_literal_repeat3,
    ACTIONS(1583), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1581), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2459] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1590), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1588), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2520] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1598), 7,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_BANG_EQ,
    ACTIONS(1594), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2589] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1598), 4,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1594), 25,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2662] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1612), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1610), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2725] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1612), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1610), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [2788] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1616), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1614), 34,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
      anon_sym_unicode,
  [2845] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1626), 8,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_RBRACK,
      sym__semicolon,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [2936] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1598), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1594), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3001] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1598), 9,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_BANG_EQ,
    ACTIONS(1594), 29,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1642), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1640), 34,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
      anon_sym_unicode,
  [3125] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1644), 1,
      anon_sym_EQ,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1646), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3206] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    STATE(465), 1,
      sym__call_arguments,
    ACTIONS(1650), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1648), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3267] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1654), 8,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_RBRACK,
      sym__semicolon,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [3358] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1598), 3,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1594), 24,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3435] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1612), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1610), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3498] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1598), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1594), 30,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3561] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1658), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1656), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3617] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1662), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1660), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3673] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1664), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1670), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1668), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1672), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1676), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3897] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 1,
      anon_sym_LPAREN,
    ACTIONS(1682), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1680), 32,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [3955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1689), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1687), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4011] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1693), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1691), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1697), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1695), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4123] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1701), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1699), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1705), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1703), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1709), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1707), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4291] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1713), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1711), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4347] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1717), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1715), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4403] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1721), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1719), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1725), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1723), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1729), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1727), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4571] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1733), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1731), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1737), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1735), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4683] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1741), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1739), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1745), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1743), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4795] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1749), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1747), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4851] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1753), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1751), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1757), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1755), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [4963] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1761), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1759), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1765), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1763), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1769), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1767), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1773), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1771), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1777), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1775), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5243] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1781), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1779), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1785), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1783), 33,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5355] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 1,
      anon_sym_LPAREN,
    ACTIONS(1787), 1,
      anon_sym_LBRACK,
    ACTIONS(1488), 4,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      sym_identifier,
    ACTIONS(1682), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1680), 26,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5416] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1787), 1,
      anon_sym_LBRACK,
    ACTIONS(1488), 4,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      sym_identifier,
    ACTIONS(1682), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1680), 27,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5475] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1542), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_COLON,
    STATE(426), 1,
      aux_sym__identifier_path_repeat1,
    ACTIONS(1534), 4,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      sym_identifier,
    ACTIONS(1539), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1536), 25,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5538] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1792), 1,
      anon_sym_LPAREN,
    ACTIONS(1446), 19,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      sym_identifier,
    ACTIONS(1448), 25,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [5593] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1794), 1,
      anon_sym_LBRACE,
    ACTIONS(1796), 1,
      sym__unchecked,
    ACTIONS(1798), 1,
      anon_sym_returns,
    STATE(474), 1,
      sym__call_arguments,
    STATE(718), 1,
      sym_block_statement,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [5683] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    ACTIONS(1802), 1,
      anon_sym_RPAREN,
    STATE(474), 1,
      sym__call_arguments,
    STATE(714), 1,
      aux_sym_tuple_expression_repeat1,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [5773] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1804), 1,
      anon_sym_COMMA,
    ACTIONS(1806), 1,
      anon_sym_RBRACK,
    STATE(474), 1,
      sym__call_arguments,
    STATE(731), 1,
      aux_sym_inline_array_expression_repeat1,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [5863] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    ACTIONS(1802), 1,
      anon_sym_RPAREN,
    STATE(474), 1,
      sym__call_arguments,
    STATE(714), 1,
      aux_sym_tuple_expression_repeat1,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [5953] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1808), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6038] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1810), 1,
      anon_sym_COLON,
    ACTIONS(1812), 1,
      anon_sym_RBRACK,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6125] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 1,
      anon_sym_catch,
    ACTIONS(1674), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1672), 27,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      sym__unchecked,
      anon_sym_returns,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6178] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1814), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6263] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1816), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6348] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1818), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6433] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1820), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6518] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1822), 1,
      anon_sym_RPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6602] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1824), 1,
      anon_sym_RBRACK,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6686] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1826), 1,
      sym__semicolon,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6770] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1828), 1,
      sym__semicolon,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6854] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1830), 1,
      sym__semicolon,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [6938] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1832), 1,
      anon_sym_RPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7022] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1834), 1,
      anon_sym_RBRACK,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7106] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1836), 1,
      sym__semicolon,
    STATE(516), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7190] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1838), 1,
      anon_sym_RPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7274] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1840), 1,
      sym__semicolon,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7358] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1842), 1,
      sym__semicolon,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7442] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1844), 1,
      anon_sym_RPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7526] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1846), 1,
      sym__semicolon,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7610] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1848), 1,
      anon_sym_RPAREN,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7694] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1850), 1,
      anon_sym_COLON,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7778] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1852), 1,
      anon_sym_RBRACK,
    STATE(474), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7862] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1854), 1,
      sym__semicolon,
    ACTIONS(1745), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1743), 25,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [7913] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1856), 1,
      anon_sym_EQ,
    ACTIONS(1713), 14,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1711), 26,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [7964] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    ACTIONS(1602), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1618), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1622), 1,
      anon_sym_EQ,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1628), 1,
      anon_sym_AMP,
    ACTIONS(1630), 1,
      anon_sym_DOT,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    ACTIONS(1634), 1,
      anon_sym_LBRACK,
    ACTIONS(1636), 1,
      anon_sym_AMP_AMP,
    STATE(520), 1,
      sym__call_arguments,
    ACTIONS(1596), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1604), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1620), 2,
      anon_sym_CARET,
      anon_sym_PIPE,
    ACTIONS(1608), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG_EQ,
    ACTIONS(1606), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1600), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1638), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [8045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      sym__semicolon,
    ACTIONS(1713), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1711), 25,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [8096] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1858), 1,
      sym__semicolon,
    ACTIONS(1745), 15,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1743), 25,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
  [8147] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1860), 1,
      anon_sym_EQ,
    ACTIONS(1781), 14,
      anon_sym_DASH,
      anon_sym_LT,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_BANG_EQ,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(1779), 26,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_AMP_AMP,
      anon_sym_STAR_STAR,
      anon_sym_BANG_EQ_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      sym__semicolon,
  [8198] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1862), 1,
      anon_sym_DOT,
    STATE(386), 1,
      aux_sym__identifier_path_repeat1,
    ACTIONS(1548), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_EQ_GT,
      sym__semicolon,
    ACTIONS(1546), 20,
      anon_sym_as,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_for,
      anon_sym_global,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      sym_immutable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8240] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1862), 1,
      anon_sym_DOT,
    STATE(522), 1,
      aux_sym__identifier_path_repeat1,
    ACTIONS(1864), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_EQ_GT,
      sym__semicolon,
    ACTIONS(1534), 20,
      anon_sym_as,
      anon_sym_constant,
      anon_sym_indexed,
      anon_sym_for,
      anon_sym_global,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      sym_immutable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8282] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(1868), 1,
      anon_sym_returns,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1872), 1,
      sym_virtual,
    ACTIONS(1874), 1,
      sym__semicolon,
    STATE(258), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(541), 1,
      sym_visibility,
    STATE(543), 1,
      sym_state_mutability,
    STATE(703), 1,
      sym_return_type_definition,
    ACTIONS(1394), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(527), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_function_definition_repeat1,
    ACTIONS(1392), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [8335] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1868), 1,
      anon_sym_returns,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1876), 1,
      anon_sym_LBRACE,
    ACTIONS(1878), 1,
      sym_virtual,
    ACTIONS(1880), 1,
      sym__semicolon,
    STATE(187), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(541), 1,
      sym_visibility,
    STATE(543), 1,
      sym_state_mutability,
    STATE(651), 1,
      sym_return_type_definition,
    ACTIONS(1394), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(526), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_function_definition_repeat1,
    ACTIONS(1392), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [8388] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1868), 1,
      anon_sym_returns,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1876), 1,
      anon_sym_LBRACE,
    ACTIONS(1882), 1,
      sym_virtual,
    ACTIONS(1884), 1,
      sym__semicolon,
    STATE(179), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(541), 1,
      sym_visibility,
    STATE(543), 1,
      sym_state_mutability,
    STATE(695), 1,
      sym_return_type_definition,
    ACTIONS(1394), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(528), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_function_definition_repeat1,
    ACTIONS(1392), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [8441] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(1868), 1,
      anon_sym_returns,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1882), 1,
      sym_virtual,
    ACTIONS(1886), 1,
      sym__semicolon,
    STATE(286), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(541), 1,
      sym_visibility,
    STATE(543), 1,
      sym_state_mutability,
    STATE(711), 1,
      sym_return_type_definition,
    ACTIONS(1394), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(528), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_function_definition_repeat1,
    ACTIONS(1392), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [8494] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1888), 1,
      sym_identifier,
    ACTIONS(1893), 1,
      anon_sym_returns,
    ACTIONS(1901), 1,
      anon_sym_override,
    ACTIONS(1904), 1,
      sym_virtual,
    STATE(535), 1,
      sym__identifier_path,
    STATE(541), 1,
      sym_visibility,
    STATE(543), 1,
      sym_state_mutability,
    ACTIONS(1891), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1898), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(528), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_function_definition_repeat1,
    ACTIONS(1895), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [8539] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(1868), 1,
      anon_sym_returns,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1907), 1,
      anon_sym_external,
    ACTIONS(1909), 1,
      sym_virtual,
    ACTIONS(1911), 1,
      sym__semicolon,
    STATE(247), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(555), 1,
      sym_state_mutability,
    STATE(758), 1,
      sym_return_type_definition,
    ACTIONS(1394), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(530), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_fallback_definition_repeat1,
  [8586] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(1868), 1,
      anon_sym_returns,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1907), 1,
      anon_sym_external,
    ACTIONS(1913), 1,
      sym_virtual,
    ACTIONS(1915), 1,
      sym__semicolon,
    STATE(222), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(555), 1,
      sym_state_mutability,
    STATE(784), 1,
      sym_return_type_definition,
    ACTIONS(1394), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(537), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_fallback_definition_repeat1,
  [8633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(775), 1,
      sym_user_definable_operator,
    ACTIONS(1919), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(1917), 12,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8659] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(858), 1,
      sym_user_definable_operator,
    ACTIONS(1919), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(1917), 12,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8685] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(678), 1,
      sym_user_definable_operator,
    ACTIONS(1919), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(1917), 12,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8711] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 1,
      anon_sym_LPAREN,
    ACTIONS(1923), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1921), 13,
      anon_sym_constant,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      sym_immutable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8737] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(542), 1,
      sym__call_arguments,
    ACTIONS(1929), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1927), 11,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8764] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1933), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1931), 13,
      anon_sym_constant,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      sym_immutable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8787] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      sym_identifier,
    ACTIONS(1940), 1,
      anon_sym_returns,
    ACTIONS(1942), 1,
      anon_sym_external,
    ACTIONS(1948), 1,
      anon_sym_override,
    ACTIONS(1951), 1,
      sym_virtual,
    STATE(535), 1,
      sym__identifier_path,
    STATE(555), 1,
      sym_state_mutability,
    ACTIONS(1938), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1945), 3,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
    STATE(537), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_fallback_definition_repeat1,
  [8826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1956), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1954), 13,
      anon_sym_constant,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      sym_immutable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1960), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1958), 13,
      anon_sym_constant,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      sym_immutable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8872] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    ACTIONS(1556), 1,
      anon_sym_hex,
    ACTIONS(1962), 1,
      sym_yul_decimal_number,
    ACTIONS(1964), 1,
      sym_yul_hex_number,
    STATE(318), 1,
      sym_string,
    STATE(428), 1,
      aux_sym_hex_string_literal_repeat2,
    ACTIONS(1966), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(788), 4,
      sym__yul_literal,
      sym_yul_string_literal,
      sym_yul_boolean,
      sym_hex_string_literal,
  [8907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1970), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1968), 11,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8928] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1974), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1972), 11,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1978), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(1976), 11,
      anon_sym_returns,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [8970] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1980), 1,
      sym_identifier,
    STATE(562), 1,
      sym_visibility,
    ACTIONS(1982), 2,
      anon_sym_constant,
      sym_immutable,
    STATE(551), 2,
      sym_override_specifier,
      aux_sym_state_variable_declaration_repeat1,
    ACTIONS(1392), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [9000] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1984), 1,
      anon_sym_external,
    ACTIONS(1988), 1,
      sym__semicolon,
    STATE(218), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    ACTIONS(1986), 2,
      anon_sym_payable,
      sym_virtual,
    STATE(547), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_receive_definition_repeat1,
  [9034] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1990), 1,
      sym_solidity_version,
    ACTIONS(1996), 1,
      sym__semicolon,
    STATE(548), 1,
      aux_sym_solidity_pragma_token_repeat1,
    STATE(550), 1,
      sym__pragma_version_constraint,
    STATE(976), 1,
      sym_solidity_version_comparison_operator,
    ACTIONS(1994), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1992), 5,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_EQ,
  [9064] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(1984), 1,
      anon_sym_external,
    ACTIONS(2000), 1,
      sym__semicolon,
    STATE(256), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    ACTIONS(1998), 2,
      anon_sym_payable,
      sym_virtual,
    STATE(553), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_receive_definition_repeat1,
  [9098] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1990), 1,
      sym_solidity_version,
    ACTIONS(2002), 1,
      sym__semicolon,
    STATE(549), 1,
      aux_sym_solidity_pragma_token_repeat1,
    STATE(550), 1,
      sym__pragma_version_constraint,
    STATE(976), 1,
      sym_solidity_version_comparison_operator,
    ACTIONS(1994), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1992), 5,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_EQ,
  [9128] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2004), 1,
      sym_solidity_version,
    ACTIONS(2013), 1,
      sym__semicolon,
    STATE(549), 1,
      aux_sym_solidity_pragma_token_repeat1,
    STATE(550), 1,
      sym__pragma_version_constraint,
    STATE(976), 1,
      sym_solidity_version_comparison_operator,
    ACTIONS(2010), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2007), 5,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_EQ,
  [9158] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2015), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH,
    ACTIONS(2019), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2017), 7,
      sym_solidity_version,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_EQ,
      sym__semicolon,
  [9179] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1870), 1,
      anon_sym_override,
    ACTIONS(2021), 1,
      sym_identifier,
    STATE(562), 1,
      sym_visibility,
    ACTIONS(2023), 2,
      anon_sym_constant,
      sym_immutable,
    STATE(554), 2,
      sym_override_specifier,
      aux_sym_state_variable_declaration_repeat1,
    ACTIONS(1392), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [9206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2027), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2025), 9,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH,
      sym_solidity_version,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_EQ,
      sym__semicolon,
  [9225] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      anon_sym_external,
    ACTIONS(2040), 1,
      anon_sym_override,
    STATE(535), 1,
      sym__identifier_path,
    ACTIONS(2032), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(2037), 2,
      anon_sym_payable,
      sym_virtual,
    STATE(553), 3,
      sym_override_specifier,
      sym_modifier_invocation,
      aux_sym_receive_definition_repeat1,
  [9254] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2043), 1,
      sym_identifier,
    ACTIONS(2051), 1,
      anon_sym_override,
    STATE(562), 1,
      sym_visibility,
    ACTIONS(2045), 2,
      anon_sym_constant,
      sym_immutable,
    STATE(554), 2,
      sym_override_specifier,
      aux_sym_state_variable_declaration_repeat1,
    ACTIONS(2048), 4,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
  [9281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2056), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(2054), 8,
      anon_sym_returns,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [9299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2060), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(2058), 8,
      anon_sym_returns,
      anon_sym_external,
      anon_sym_pure,
      anon_sym_view,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [9317] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    ACTIONS(2062), 1,
      sym_identifier,
    ACTIONS(2064), 1,
      anon_sym_STAR,
    ACTIONS(2066), 1,
      anon_sym_LBRACE,
    STATE(751), 1,
      sym_string,
    STATE(793), 1,
      sym__import_clause,
    STATE(1001), 1,
      sym__multiple_import,
    STATE(1002), 1,
      sym__single_import,
    STATE(1004), 1,
      sym__source_import,
  [9351] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    ACTIONS(2070), 1,
      anon_sym_override,
    ACTIONS(2072), 1,
      sym_virtual,
    ACTIONS(2074), 1,
      sym__semicolon,
    STATE(237), 1,
      sym_function_body,
    STATE(568), 1,
      sym__parameter_list,
    STATE(566), 2,
      sym_override_specifier,
      aux_sym_modifier_definition_repeat1,
  [9380] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    STATE(228), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(563), 2,
      sym_modifier_invocation,
      aux_sym_constructor_definition_repeat1,
    ACTIONS(2076), 3,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_payable,
  [9405] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    STATE(242), 1,
      sym_function_body,
    STATE(535), 1,
      sym__identifier_path,
    STATE(559), 2,
      sym_modifier_invocation,
      aux_sym_constructor_definition_repeat1,
    ACTIONS(2078), 3,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_payable,
  [9430] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2080), 7,
      sym_solidity_version,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      anon_sym_GT_EQ,
      anon_sym_TILDE,
      anon_sym_EQ,
      sym__semicolon,
  [9447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2084), 8,
      anon_sym_constant,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_private,
      anon_sym_external,
      sym_immutable,
      anon_sym_override,
      sym_identifier,
  [9461] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2086), 1,
      sym_identifier,
    ACTIONS(2089), 1,
      anon_sym_LBRACE,
    STATE(535), 1,
      sym__identifier_path,
    STATE(563), 2,
      sym_modifier_invocation,
      aux_sym_constructor_definition_repeat1,
    ACTIONS(2091), 3,
      anon_sym_public,
      anon_sym_internal,
      anon_sym_payable,
  [9483] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2094), 1,
      sym_identifier,
    STATE(653), 1,
      sym__storage_location,
    ACTIONS(2096), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(2098), 3,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
  [9505] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    STATE(869), 1,
      sym__storage_location,
    ACTIONS(2100), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(2102), 3,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
  [9524] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2070), 1,
      anon_sym_override,
    ACTIONS(2104), 1,
      sym_virtual,
    ACTIONS(2106), 1,
      sym__semicolon,
    STATE(230), 1,
      sym_function_body,
    STATE(571), 2,
      sym_override_specifier,
      aux_sym_modifier_definition_repeat1,
  [9547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2110), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    ACTIONS(2108), 5,
      anon_sym_external,
      anon_sym_payable,
      anon_sym_override,
      sym_virtual,
      sym_identifier,
  [9562] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2070), 1,
      anon_sym_override,
    ACTIONS(2106), 1,
      sym__semicolon,
    ACTIONS(2112), 1,
      sym_virtual,
    STATE(230), 1,
      sym_function_body,
    STATE(569), 2,
      sym_override_specifier,
      aux_sym_modifier_definition_repeat1,
  [9585] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2070), 1,
      anon_sym_override,
    ACTIONS(2104), 1,
      sym_virtual,
    ACTIONS(2114), 1,
      sym__semicolon,
    STATE(269), 1,
      sym_function_body,
    STATE(571), 2,
      sym_override_specifier,
      aux_sym_modifier_definition_repeat1,
  [9608] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACE,
    ACTIONS(73), 1,
      sym__unchecked,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    ACTIONS(2116), 1,
      sym_identifier,
    STATE(84), 1,
      sym_block_statement,
    STATE(756), 1,
      sym__parameter_list,
  [9630] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2120), 1,
      anon_sym_override,
    ACTIONS(2123), 1,
      sym_virtual,
    ACTIONS(2118), 2,
      anon_sym_LBRACE,
      sym__semicolon,
    STATE(571), 2,
      sym_override_specifier,
      aux_sym_modifier_definition_repeat1,
  [9648] = 5,
    ACTIONS(2126), 1,
      anon_sym_SQUOTE,
    ACTIONS(2128), 1,
      sym__escape_sequence,
    ACTIONS(2131), 1,
      aux_sym__single_quoted_unicode_char_token1,
    ACTIONS(2134), 1,
      sym_comment,
    STATE(572), 2,
      sym__string_immediate_elt_inside_quote,
      aux_sym_string_repeat2,
  [9665] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2136), 1,
      sym_identifier,
    ACTIONS(2140), 1,
      anon_sym_indexed,
    ACTIONS(2138), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [9682] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2142), 1,
      anon_sym_DQUOTE,
    ACTIONS(2144), 1,
      sym__escape_sequence,
    ACTIONS(2146), 1,
      aux_sym__double_quoted_unicode_char_token1,
    STATE(578), 2,
      sym__string_immediate_elt_inside_double_quote,
      aux_sym_string_repeat1,
  [9699] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2150), 1,
      anon_sym_LBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(629), 1,
      sym_user_defined_type,
    STATE(881), 1,
      sym_inheritance_specifier,
  [9718] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2142), 1,
      anon_sym_SQUOTE,
    ACTIONS(2152), 1,
      sym__escape_sequence,
    ACTIONS(2154), 1,
      aux_sym__single_quoted_unicode_char_token1,
    STATE(581), 2,
      sym__string_immediate_elt_inside_quote,
      aux_sym_string_repeat2,
  [9735] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2156), 1,
      anon_sym_DQUOTE,
    ACTIONS(2158), 1,
      sym__escape_sequence,
    ACTIONS(2160), 1,
      aux_sym__double_quoted_unicode_char_token1,
    STATE(584), 2,
      sym__string_immediate_elt_inside_double_quote,
      aux_sym_string_repeat1,
  [9752] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2162), 1,
      anon_sym_DQUOTE,
    ACTIONS(2164), 1,
      sym__escape_sequence,
    ACTIONS(2166), 1,
      aux_sym__double_quoted_unicode_char_token1,
    STATE(582), 2,
      sym__string_immediate_elt_inside_double_quote,
      aux_sym_string_repeat1,
  [9769] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2156), 1,
      anon_sym_SQUOTE,
    ACTIONS(2168), 1,
      sym__escape_sequence,
    ACTIONS(2170), 1,
      aux_sym__single_quoted_unicode_char_token1,
    STATE(587), 2,
      sym__string_immediate_elt_inside_quote,
      aux_sym_string_repeat2,
  [9786] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2172), 1,
      anon_sym_LBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(629), 1,
      sym_user_defined_type,
    STATE(881), 1,
      sym_inheritance_specifier,
  [9805] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2162), 1,
      anon_sym_SQUOTE,
    ACTIONS(2174), 1,
      sym__escape_sequence,
    ACTIONS(2176), 1,
      aux_sym__single_quoted_unicode_char_token1,
    STATE(572), 2,
      sym__string_immediate_elt_inside_quote,
      aux_sym_string_repeat2,
  [9822] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2178), 1,
      anon_sym_DQUOTE,
    ACTIONS(2180), 1,
      sym__escape_sequence,
    ACTIONS(2183), 1,
      aux_sym__double_quoted_unicode_char_token1,
    STATE(582), 2,
      sym__string_immediate_elt_inside_double_quote,
      aux_sym_string_repeat1,
  [9839] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2186), 1,
      sym_identifier,
    ACTIONS(2188), 3,
      anon_sym_memory,
      anon_sym_storage,
      anon_sym_calldata,
  [9854] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2164), 1,
      sym__escape_sequence,
    ACTIONS(2166), 1,
      aux_sym__double_quoted_unicode_char_token1,
    ACTIONS(2190), 1,
      anon_sym_DQUOTE,
    STATE(582), 2,
      sym__string_immediate_elt_inside_double_quote,
      aux_sym_string_repeat1,
  [9871] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2192), 1,
      sym__hex_digit,
    ACTIONS(2197), 1,
      anon_sym__,
    STATE(585), 1,
      aux_sym_hex_string_literal_repeat1,
    ACTIONS(2195), 2,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
  [9888] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2200), 1,
      sym_identifier,
    ACTIONS(2202), 1,
      anon_sym_solidity,
    STATE(546), 1,
      sym__solidity,
    STATE(1006), 2,
      sym_solidity_pragma_token,
      sym_any_pragma_token,
  [9905] = 5,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2174), 1,
      sym__escape_sequence,
    ACTIONS(2176), 1,
      aux_sym__single_quoted_unicode_char_token1,
    ACTIONS(2190), 1,
      anon_sym_SQUOTE,
    STATE(572), 2,
      sym__string_immediate_elt_inside_quote,
      aux_sym_string_repeat2,
  [9922] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2204), 1,
      sym__hex_digit,
    ACTIONS(2206), 1,
      anon_sym_DQUOTE,
    ACTIONS(2208), 1,
      anon_sym__,
    STATE(592), 1,
      aux_sym_hex_string_literal_repeat1,
  [9938] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2206), 1,
      anon_sym_SQUOTE,
    ACTIONS(2208), 1,
      anon_sym__,
    ACTIONS(2210), 1,
      sym__hex_digit,
    STATE(591), 1,
      aux_sym_hex_string_literal_repeat1,
  [9954] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(328), 1,
      sym_yul_identifier,
    STATE(378), 1,
      sym_yul_block,
  [9970] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 1,
      anon_sym__,
    ACTIONS(2214), 1,
      sym__hex_digit,
    ACTIONS(2216), 1,
      anon_sym_SQUOTE,
    STATE(585), 1,
      aux_sym_hex_string_literal_repeat1,
  [9986] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 1,
      anon_sym__,
    ACTIONS(2214), 1,
      sym__hex_digit,
    ACTIONS(2216), 1,
      anon_sym_DQUOTE,
    STATE(585), 1,
      aux_sym_hex_string_literal_repeat1,
  [10002] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 1,
      anon_sym__,
    ACTIONS(2218), 1,
      sym__hex_digit,
    ACTIONS(2220), 1,
      anon_sym_DQUOTE,
    STATE(594), 1,
      aux_sym_hex_string_literal_repeat1,
  [10018] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 1,
      anon_sym__,
    ACTIONS(2214), 1,
      sym__hex_digit,
    ACTIONS(2222), 1,
      anon_sym_DQUOTE,
    STATE(585), 1,
      aux_sym_hex_string_literal_repeat1,
  [10034] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 1,
      anon_sym__,
    ACTIONS(2214), 1,
      sym__hex_digit,
    ACTIONS(2222), 1,
      anon_sym_SQUOTE,
    STATE(585), 1,
      aux_sym_hex_string_literal_repeat1,
  [10050] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2226), 1,
      anon_sym_as,
    STATE(889), 1,
      sym__import_alias,
    ACTIONS(2224), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [10064] = 4,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2228), 1,
      anon_sym_DQUOTE,
    ACTIONS(2230), 1,
      aux_sym__double_quoted_unicode_char_token1,
    STATE(624), 2,
      sym__double_quoted_unicode_char,
      aux_sym_unicode_string_literal_repeat1,
  [10078] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2232), 1,
      anon_sym_COMMA,
    STATE(316), 1,
      aux_sym_yul_variable_declaration_repeat1,
    STATE(350), 1,
      sym_yul_block,
  [10094] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2234), 4,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      sym__semicolon,
  [10104] = 4,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2228), 1,
      anon_sym_SQUOTE,
    ACTIONS(2236), 1,
      aux_sym__single_quoted_unicode_char_token1,
    STATE(625), 2,
      sym__single_quoted_unicode_char,
      aux_sym_unicode_string_literal_repeat2,
  [10118] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_LBRACE,
    ACTIONS(2240), 1,
      anon_sym_is,
    STATE(158), 1,
      sym_contract_body,
    STATE(861), 1,
      sym__class_heritage,
  [10134] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(328), 1,
      sym_yul_identifier,
    STATE(350), 1,
      sym_yul_block,
  [10150] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    ACTIONS(2242), 1,
      anon_sym_RPAREN,
    STATE(799), 1,
      sym_string,
  [10166] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2244), 4,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__semicolon,
  [10176] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2246), 1,
      anon_sym_COMMA,
    STATE(356), 1,
      sym_yul_block,
    STATE(644), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [10192] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(328), 1,
      sym_yul_identifier,
    STATE(372), 1,
      sym_yul_block,
  [10208] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2248), 1,
      anon_sym_RPAREN,
    STATE(399), 1,
      sym__identifier_path,
    STATE(820), 1,
      sym_user_defined_type,
  [10224] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_LBRACE,
    ACTIONS(2240), 1,
      anon_sym_is,
    STATE(186), 1,
      sym_contract_body,
    STATE(824), 1,
      sym__class_heritage,
  [10240] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2250), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10256] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_LBRACE,
    ACTIONS(2240), 1,
      anon_sym_is,
    STATE(154), 1,
      sym_contract_body,
    STATE(823), 1,
      sym__class_heritage,
  [10272] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    STATE(399), 1,
      sym__identifier_path,
    STATE(629), 1,
      sym_user_defined_type,
    STATE(663), 1,
      sym_inheritance_specifier,
  [10288] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2252), 4,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__semicolon,
  [10298] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2254), 1,
      anon_sym_RPAREN,
    STATE(399), 1,
      sym__identifier_path,
    STATE(820), 1,
      sym_user_defined_type,
  [10314] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2256), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10330] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2258), 1,
      anon_sym_COMMA,
    ACTIONS(2260), 1,
      anon_sym_RBRACE,
    ACTIONS(2262), 1,
      anon_sym_as,
    STATE(655), 1,
      aux_sym_using_directive_repeat1,
  [10346] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 1,
      anon_sym__,
    ACTIONS(2220), 1,
      anon_sym_SQUOTE,
    ACTIONS(2264), 1,
      sym__hex_digit,
    STATE(595), 1,
      aux_sym_hex_string_literal_repeat1,
  [10362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2195), 4,
      sym__hex_digit,
      anon_sym_DQUOTE,
      anon_sym__,
      anon_sym_SQUOTE,
  [10372] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2266), 1,
      anon_sym_LBRACE,
    ACTIONS(2268), 1,
      anon_sym_LPAREN,
    ACTIONS(2270), 1,
      anon_sym_DQUOTEevmasm_DQUOTE,
    STATE(918), 1,
      sym__assembly_flags,
  [10388] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2272), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10404] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2274), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10420] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2276), 1,
      anon_sym_COMMA,
    STATE(316), 1,
      aux_sym_yul_variable_declaration_repeat1,
    STATE(372), 1,
      sym_yul_block,
  [10436] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2278), 1,
      anon_sym_LBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(1010), 1,
      sym_user_defined_type,
  [10452] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2276), 1,
      anon_sym_COMMA,
    STATE(372), 1,
      sym_yul_block,
    STATE(630), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [10468] = 4,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2280), 1,
      anon_sym_DQUOTE,
    ACTIONS(2282), 1,
      aux_sym__double_quoted_unicode_char_token1,
    STATE(624), 2,
      sym__double_quoted_unicode_char,
      aux_sym_unicode_string_literal_repeat1,
  [10482] = 4,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2285), 1,
      anon_sym_SQUOTE,
    ACTIONS(2287), 1,
      aux_sym__single_quoted_unicode_char_token1,
    STATE(625), 2,
      sym__single_quoted_unicode_char,
      aux_sym_unicode_string_literal_repeat2,
  [10496] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2290), 1,
      anon_sym_COMMA,
    STATE(355), 1,
      sym_yul_block,
    STATE(621), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [10512] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2292), 1,
      anon_sym_COMMA,
    ACTIONS(2294), 1,
      anon_sym_RBRACE,
    ACTIONS(2296), 1,
      anon_sym_as,
    STATE(774), 1,
      aux_sym_using_directive_repeat1,
  [10528] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2298), 1,
      anon_sym_COMMA,
    STATE(360), 1,
      sym_yul_block,
    STATE(598), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [10544] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(886), 1,
      sym__call_arguments,
    ACTIONS(2300), 2,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [10558] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2246), 1,
      anon_sym_COMMA,
    STATE(316), 1,
      aux_sym_yul_variable_declaration_repeat1,
    STATE(356), 1,
      sym_yul_block,
  [10574] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2302), 1,
      sym_identifier,
    ACTIONS(2304), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [10588] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2306), 1,
      sym_identifier,
    ACTIONS(2308), 1,
      anon_sym_COMMA,
    ACTIONS(2310), 1,
      anon_sym_RPAREN,
    STATE(723), 1,
      aux_sym_variable_declaration_tuple_repeat2,
  [10604] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2312), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10620] = 4,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2314), 1,
      anon_sym_SQUOTE,
    ACTIONS(2316), 1,
      aux_sym__single_quoted_unicode_char_token1,
    STATE(600), 2,
      sym__single_quoted_unicode_char,
      aux_sym_unicode_string_literal_repeat2,
  [10634] = 4,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2314), 1,
      anon_sym_DQUOTE,
    ACTIONS(2318), 1,
      aux_sym__double_quoted_unicode_char_token1,
    STATE(597), 2,
      sym__double_quoted_unicode_char,
      aux_sym_unicode_string_literal_repeat1,
  [10648] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2320), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10664] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2322), 1,
      anon_sym_LBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(994), 1,
      sym_user_defined_type,
  [10680] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2324), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10696] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2326), 1,
      anon_sym_RBRACE,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [10712] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    ACTIONS(2328), 1,
      anon_sym_RPAREN,
    STATE(799), 1,
      sym_string,
  [10728] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(328), 1,
      sym_yul_identifier,
    STATE(356), 1,
      sym_yul_block,
  [10744] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(328), 1,
      sym_yul_identifier,
    STATE(360), 1,
      sym_yul_block,
  [10760] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    STATE(399), 1,
      sym__identifier_path,
    STATE(629), 1,
      sym_user_defined_type,
    STATE(881), 1,
      sym_inheritance_specifier,
  [10776] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2298), 1,
      anon_sym_COMMA,
    STATE(316), 1,
      aux_sym_yul_variable_declaration_repeat1,
    STATE(360), 1,
      sym_yul_block,
  [10792] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2254), 1,
      anon_sym_RPAREN,
    ACTIONS(2330), 1,
      anon_sym_COMMA,
    STATE(680), 1,
      aux_sym_override_specifier_repeat1,
  [10805] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2332), 1,
      anon_sym_COMMA,
    ACTIONS(2334), 1,
      anon_sym_RBRACE,
    STATE(691), 1,
      aux_sym_struct_expression_repeat1,
  [10818] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(276), 1,
      anon_sym_RPAREN,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(716), 1,
      aux_sym_tuple_expression_repeat1,
  [10831] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    ACTIONS(2336), 1,
      anon_sym_RPAREN,
    STATE(328), 1,
      sym_yul_identifier,
  [10844] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2338), 1,
      anon_sym_default,
    ACTIONS(2340), 1,
      anon_sym_case,
    STATE(329), 1,
      aux_sym_yul_switch_statement_repeat1,
  [10857] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2334), 1,
      anon_sym_RBRACE,
    ACTIONS(2342), 1,
      sym_identifier,
    STATE(840), 1,
      sym_struct_field_assignment,
  [10870] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1876), 1,
      anon_sym_LBRACE,
    ACTIONS(2344), 1,
      sym__semicolon,
    STATE(181), 1,
      sym_function_body,
  [10883] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_RPAREN,
    ACTIONS(2346), 1,
      anon_sym_COMMA,
    STATE(681), 1,
      aux_sym__parameter_list_repeat1,
  [10896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2348), 1,
      sym_identifier,
    ACTIONS(2350), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [10907] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2352), 1,
      anon_sym_global,
    ACTIONS(2354), 1,
      sym__semicolon,
  [10920] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2356), 1,
      anon_sym_COMMA,
    ACTIONS(2358), 1,
      anon_sym_RBRACE,
    STATE(679), 1,
      aux_sym_using_directive_repeat1,
  [10933] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2328), 1,
      anon_sym_RPAREN,
    ACTIONS(2360), 1,
      anon_sym_COMMA,
    STATE(743), 1,
      aux_sym__assembly_flags_repeat1,
  [10946] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2336), 1,
      anon_sym_RPAREN,
    ACTIONS(2362), 1,
      anon_sym_COMMA,
    STATE(316), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [10959] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2364), 1,
      anon_sym_DASH_GT,
    STATE(366), 1,
      sym_yul_block,
  [10972] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2366), 1,
      anon_sym_COMMA,
    ACTIONS(2368), 1,
      anon_sym_RBRACE,
    STATE(747), 1,
      aux_sym_enum_declaration_repeat1,
  [10985] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2342), 1,
      sym_identifier,
    ACTIONS(2370), 1,
      anon_sym_RBRACE,
    STATE(741), 1,
      sym_struct_field_assignment,
  [10998] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2372), 1,
      anon_sym_COMMA,
    ACTIONS(2374), 1,
      anon_sym_RPAREN,
    STATE(676), 1,
      aux_sym_error_declaration_repeat1,
  [11011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2376), 1,
      sym_identifier,
    ACTIONS(2378), 1,
      anon_sym_RPAREN,
  [11024] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      anon_sym_LBRACE,
    ACTIONS(2382), 1,
      anon_sym_COMMA,
    STATE(675), 1,
      aux_sym__class_heritage_repeat1,
  [11037] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    ACTIONS(2384), 1,
      anon_sym_RPAREN,
    STATE(328), 1,
      sym_yul_identifier,
  [11050] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(564), 1,
      anon_sym_RPAREN,
    ACTIONS(2386), 1,
      sym_identifier,
    ACTIONS(2388), 1,
      anon_sym_COMMA,
  [11063] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(564), 1,
      anon_sym_RPAREN,
    ACTIONS(2390), 1,
      anon_sym_COMMA,
    STATE(667), 1,
      aux_sym_variable_declaration_tuple_repeat2,
  [11076] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2392), 1,
      anon_sym_COMMA,
    ACTIONS(2395), 1,
      anon_sym_RPAREN,
    STATE(667), 1,
      aux_sym_variable_declaration_tuple_repeat2,
  [11089] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2397), 1,
      anon_sym_COMMA,
    ACTIONS(2399), 1,
      anon_sym_RPAREN,
    STATE(686), 1,
      aux_sym__event_parameter_list_repeat1,
  [11102] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2401), 1,
      sym_identifier,
    ACTIONS(2403), 1,
      anon_sym_RBRACE,
    STATE(875), 1,
      sym__import_declaration,
  [11115] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2405), 1,
      anon_sym_global,
    ACTIONS(2407), 1,
      sym__semicolon,
  [11128] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2409), 1,
      anon_sym_COMMA,
    ACTIONS(2412), 1,
      anon_sym_RPAREN,
    STATE(671), 1,
      aux_sym_yul_function_call_repeat1,
  [11141] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACE,
    ACTIONS(1796), 1,
      sym__unchecked,
    STATE(753), 1,
      sym_block_statement,
  [11154] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2414), 1,
      anon_sym_COMMA,
    ACTIONS(2417), 1,
      anon_sym_RBRACE,
    STATE(673), 1,
      aux_sym__multiple_import_repeat1,
  [11167] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2419), 1,
      anon_sym_global,
    ACTIONS(2421), 1,
      sym__semicolon,
  [11180] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2150), 1,
      anon_sym_LBRACE,
    ACTIONS(2423), 1,
      anon_sym_COMMA,
    STATE(754), 1,
      aux_sym__class_heritage_repeat1,
  [11193] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(591), 1,
      anon_sym_RPAREN,
    ACTIONS(2425), 1,
      anon_sym_COMMA,
    STATE(755), 1,
      aux_sym_error_declaration_repeat1,
  [11206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2429), 1,
      anon_sym_as,
    ACTIONS(2427), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [11217] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2431), 1,
      anon_sym_COMMA,
    ACTIONS(2433), 1,
      anon_sym_RBRACE,
    STATE(769), 1,
      aux_sym_using_directive_repeat1,
  [11230] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2435), 1,
      anon_sym_COMMA,
    ACTIONS(2438), 1,
      anon_sym_RBRACE,
    STATE(679), 1,
      aux_sym_using_directive_repeat1,
  [11243] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2440), 1,
      anon_sym_COMMA,
    ACTIONS(2443), 1,
      anon_sym_RPAREN,
    STATE(680), 1,
      aux_sym_override_specifier_repeat1,
  [11256] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2445), 1,
      anon_sym_COMMA,
    ACTIONS(2448), 1,
      anon_sym_RPAREN,
    STATE(681), 1,
      aux_sym__parameter_list_repeat1,
  [11269] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2450), 1,
      anon_sym_COMMA,
    ACTIONS(2452), 1,
      anon_sym_RBRACE,
    STATE(673), 1,
      aux_sym__multiple_import_repeat1,
  [11282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2454), 1,
      sym_identifier,
    ACTIONS(2456), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [11293] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2458), 1,
      anon_sym_COMMA,
    ACTIONS(2460), 1,
      anon_sym_RPAREN,
    STATE(645), 1,
      aux_sym_override_specifier_repeat1,
  [11306] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2401), 1,
      sym_identifier,
    ACTIONS(2462), 1,
      anon_sym_RBRACE,
    STATE(875), 1,
      sym__import_declaration,
  [11319] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 1,
      anon_sym_RPAREN,
    ACTIONS(2464), 1,
      anon_sym_COMMA,
    STATE(697), 1,
      aux_sym__event_parameter_list_repeat1,
  [11332] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2466), 1,
      sym_identifier,
    ACTIONS(2468), 1,
      anon_sym_RBRACE,
    STATE(818), 1,
      sym_call_struct_argument,
  [11345] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2470), 1,
      anon_sym_COMMA,
    ACTIONS(2473), 1,
      anon_sym_RBRACE,
    STATE(688), 1,
      aux_sym_call_argument_repeat1,
  [11358] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2310), 1,
      anon_sym_RPAREN,
    ACTIONS(2475), 1,
      anon_sym_COMMA,
    STATE(752), 1,
      aux_sym_variable_declaration_tuple_repeat1,
  [11371] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2477), 1,
      anon_sym_COMMA,
    ACTIONS(2479), 1,
      anon_sym_RPAREN,
    STATE(713), 1,
      aux_sym__return_parameters_repeat1,
  [11384] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2481), 1,
      anon_sym_COMMA,
    ACTIONS(2484), 1,
      anon_sym_RBRACE,
    STATE(691), 1,
      aux_sym_struct_expression_repeat1,
  [11397] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2342), 1,
      sym_identifier,
    ACTIONS(2486), 1,
      anon_sym_RBRACE,
    STATE(840), 1,
      sym_struct_field_assignment,
  [11410] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    STATE(399), 1,
      sym__identifier_path,
    STATE(684), 1,
      sym_user_defined_type,
  [11423] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2310), 1,
      anon_sym_RPAREN,
    ACTIONS(2475), 1,
      anon_sym_COMMA,
    STATE(748), 1,
      aux_sym_variable_declaration_tuple_repeat1,
  [11436] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1876), 1,
      anon_sym_LBRACE,
    ACTIONS(2488), 1,
      sym__semicolon,
    STATE(163), 1,
      sym_function_body,
  [11449] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    ACTIONS(2493), 1,
      anon_sym_RPAREN,
    STATE(696), 1,
      aux_sym__call_arguments_repeat1,
  [11462] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2495), 1,
      anon_sym_COMMA,
    ACTIONS(2498), 1,
      anon_sym_RPAREN,
    STATE(697), 1,
      aux_sym__event_parameter_list_repeat1,
  [11475] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2500), 1,
      anon_sym_COMMA,
    ACTIONS(2502), 1,
      anon_sym_RBRACE,
    STATE(705), 1,
      aux_sym_enum_declaration_repeat1,
  [11488] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2504), 1,
      anon_sym_global,
    ACTIONS(2506), 1,
      sym__semicolon,
  [11501] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1818), 1,
      anon_sym_RBRACK,
    ACTIONS(2508), 1,
      anon_sym_COMMA,
    STATE(700), 1,
      aux_sym_inline_array_expression_repeat1,
  [11514] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2511), 1,
      anon_sym_COMMA,
    ACTIONS(2513), 1,
      anon_sym_RPAREN,
    STATE(690), 1,
      aux_sym__return_parameters_repeat1,
  [11527] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2515), 1,
      anon_sym_global,
    ACTIONS(2517), 1,
      sym__semicolon,
  [11540] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2519), 1,
      sym__semicolon,
    STATE(277), 1,
      sym_function_body,
  [11553] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2521), 1,
      anon_sym_COMMA,
    ACTIONS(2523), 1,
      anon_sym_RBRACE,
    STATE(688), 1,
      aux_sym_call_argument_repeat1,
  [11566] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2525), 1,
      anon_sym_COMMA,
    ACTIONS(2527), 1,
      anon_sym_RBRACE,
    STATE(776), 1,
      aux_sym_enum_declaration_repeat1,
  [11579] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2529), 1,
      sym_identifier,
    ACTIONS(2531), 1,
      anon_sym_RPAREN,
  [11592] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2533), 1,
      anon_sym_global,
    ACTIONS(2535), 1,
      sym__semicolon,
  [11605] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACE,
    ACTIONS(1796), 1,
      sym__unchecked,
    STATE(85), 1,
      sym_block_statement,
  [11618] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2537), 1,
      anon_sym_COMMA,
    ACTIONS(2539), 1,
      anon_sym_RPAREN,
    STATE(652), 1,
      aux_sym__parameter_list_repeat1,
  [11631] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2466), 1,
      sym_identifier,
    ACTIONS(2523), 1,
      anon_sym_RBRACE,
    STATE(818), 1,
      sym_call_struct_argument,
  [11644] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2541), 1,
      sym__semicolon,
    STATE(272), 1,
      sym_function_body,
  [11657] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(252), 1,
      anon_sym_RPAREN,
    ACTIONS(2543), 1,
      anon_sym_COMMA,
    STATE(696), 1,
      aux_sym__call_arguments_repeat1,
  [11670] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2545), 1,
      anon_sym_COMMA,
    ACTIONS(2548), 1,
      anon_sym_RPAREN,
    STATE(713), 1,
      aux_sym__return_parameters_repeat1,
  [11683] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(272), 1,
      anon_sym_RPAREN,
    ACTIONS(2550), 1,
      anon_sym_COMMA,
    STATE(716), 1,
      aux_sym_tuple_expression_repeat1,
  [11696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2552), 1,
      anon_sym_global,
    ACTIONS(2554), 1,
      sym__semicolon,
  [11709] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1820), 1,
      anon_sym_RPAREN,
    ACTIONS(2556), 1,
      anon_sym_COMMA,
    STATE(716), 1,
      aux_sym_tuple_expression_repeat1,
  [11722] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2466), 1,
      sym_identifier,
    ACTIONS(2559), 1,
      anon_sym_RBRACE,
    STATE(781), 1,
      sym_call_struct_argument,
  [11735] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2561), 1,
      anon_sym_catch,
    STATE(71), 2,
      sym_catch_clause,
      aux_sym_try_statement_repeat1,
  [11746] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2563), 1,
      anon_sym_COMMA,
    ACTIONS(2565), 1,
      anon_sym_RPAREN,
    STATE(779), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [11759] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2567), 1,
      anon_sym_DASH_GT,
    STATE(355), 1,
      sym_yul_block,
  [11772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2569), 1,
      anon_sym_COMMA,
    ACTIONS(2571), 1,
      anon_sym_RPAREN,
    STATE(712), 1,
      aux_sym__call_arguments_repeat1,
  [11785] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    STATE(933), 1,
      sym_string,
  [11798] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(585), 1,
      anon_sym_RPAREN,
    ACTIONS(2573), 1,
      anon_sym_COMMA,
    STATE(667), 1,
      aux_sym_variable_declaration_tuple_repeat2,
  [11811] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    STATE(799), 1,
      sym_string,
  [11824] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(585), 1,
      anon_sym_RPAREN,
    ACTIONS(2573), 1,
      anon_sym_COMMA,
    STATE(666), 1,
      aux_sym_variable_declaration_tuple_repeat2,
  [11837] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(585), 1,
      anon_sym_RPAREN,
    ACTIONS(2386), 1,
      sym_identifier,
    ACTIONS(2388), 1,
      anon_sym_COMMA,
  [11850] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    ACTIONS(2575), 1,
      anon_sym_RPAREN,
    STATE(764), 1,
      sym_yul_identifier,
  [11863] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2577), 1,
      anon_sym_global,
    ACTIONS(2579), 1,
      sym__semicolon,
  [11876] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2581), 1,
      anon_sym_COMMA,
    ACTIONS(2583), 1,
      anon_sym_RPAREN,
    STATE(760), 1,
      aux_sym_yul_function_call_repeat1,
  [11889] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2585), 1,
      anon_sym_COMMA,
    ACTIONS(2587), 1,
      anon_sym_RBRACE,
    STATE(682), 1,
      aux_sym__multiple_import_repeat1,
  [11902] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(292), 1,
      anon_sym_RBRACK,
    ACTIONS(2589), 1,
      anon_sym_COMMA,
    STATE(700), 1,
      aux_sym_inline_array_expression_repeat1,
  [11915] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2591), 1,
      anon_sym_global,
    ACTIONS(2593), 1,
      sym__semicolon,
  [11928] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2595), 1,
      anon_sym_global,
    ACTIONS(2597), 1,
      sym__semicolon,
  [11941] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2599), 1,
      anon_sym_global,
    ACTIONS(2601), 1,
      sym__semicolon,
  [11954] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    ACTIONS(2603), 1,
      anon_sym_RPAREN,
    STATE(328), 1,
      sym_yul_identifier,
  [11967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2605), 1,
      anon_sym_global,
    ACTIONS(2607), 1,
      sym__semicolon,
  [11980] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2609), 1,
      anon_sym_COMMA,
    ACTIONS(2611), 1,
      anon_sym_RPAREN,
    STATE(656), 1,
      aux_sym__assembly_flags_repeat1,
  [11993] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2613), 1,
      anon_sym_global,
    ACTIONS(2615), 1,
      sym__semicolon,
  [12006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2617), 1,
      anon_sym_global,
    ACTIONS(2619), 1,
      sym__semicolon,
  [12019] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(311), 1,
      sym_yul_identifier,
    STATE(327), 1,
      sym_yul_path,
  [12032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2621), 1,
      anon_sym_COMMA,
    ACTIONS(2623), 1,
      anon_sym_RBRACE,
    STATE(646), 1,
      aux_sym_struct_expression_repeat1,
  [12045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    ACTIONS(2625), 1,
      anon_sym_LPAREN,
    STATE(325), 1,
      sym_yul_identifier,
  [12058] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2627), 1,
      anon_sym_COMMA,
    ACTIONS(2630), 1,
      anon_sym_RPAREN,
    STATE(743), 1,
      aux_sym__assembly_flags_repeat1,
  [12071] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2632), 1,
      anon_sym_COMMA,
    ACTIONS(2634), 1,
      anon_sym_RPAREN,
    STATE(746), 1,
      aux_sym_error_declaration_repeat1,
  [12084] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    STATE(399), 1,
      sym__identifier_path,
    STATE(615), 1,
      sym_user_defined_type,
  [12097] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 1,
      anon_sym_RPAREN,
    ACTIONS(2636), 1,
      anon_sym_COMMA,
    STATE(755), 1,
      aux_sym_error_declaration_repeat1,
  [12110] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2638), 1,
      anon_sym_COMMA,
    ACTIONS(2640), 1,
      anon_sym_RBRACE,
    STATE(776), 1,
      aux_sym_enum_declaration_repeat1,
  [12123] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2642), 1,
      anon_sym_COMMA,
    ACTIONS(2645), 1,
      anon_sym_RPAREN,
    STATE(748), 1,
      aux_sym_variable_declaration_tuple_repeat1,
  [12136] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2386), 1,
      sym_identifier,
    ACTIONS(2388), 1,
      anon_sym_COMMA,
    ACTIONS(2647), 1,
      anon_sym_RPAREN,
  [12149] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2386), 1,
      sym_identifier,
    ACTIONS(2388), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12160] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2226), 1,
      anon_sym_as,
    ACTIONS(2649), 1,
      sym__semicolon,
    STATE(958), 1,
      sym__import_alias,
  [12173] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(585), 1,
      anon_sym_RPAREN,
    ACTIONS(2651), 1,
      anon_sym_COMMA,
    STATE(748), 1,
      aux_sym_variable_declaration_tuple_repeat1,
  [12186] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2561), 1,
      anon_sym_catch,
    STATE(73), 2,
      sym_catch_clause,
      aux_sym_try_statement_repeat1,
  [12197] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2653), 1,
      anon_sym_LBRACE,
    ACTIONS(2655), 1,
      anon_sym_COMMA,
    STATE(754), 1,
      aux_sym__class_heritage_repeat1,
  [12210] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2658), 1,
      anon_sym_COMMA,
    ACTIONS(2661), 1,
      anon_sym_RPAREN,
    STATE(755), 1,
      aux_sym_error_declaration_repeat1,
  [12223] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACE,
    ACTIONS(1796), 1,
      sym__unchecked,
    STATE(83), 1,
      sym_block_statement,
  [12236] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2226), 1,
      anon_sym_as,
    ACTIONS(2663), 1,
      anon_sym_from,
    STATE(964), 1,
      sym__import_alias,
  [12249] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2665), 1,
      sym__semicolon,
    STATE(224), 1,
      sym_function_body,
  [12262] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    STATE(399), 1,
      sym__identifier_path,
    STATE(820), 1,
      sym_user_defined_type,
  [12275] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 1,
      anon_sym_RPAREN,
    ACTIONS(2667), 1,
      anon_sym_COMMA,
    STATE(671), 1,
      aux_sym_yul_function_call_repeat1,
  [12288] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2401), 1,
      sym_identifier,
    ACTIONS(2669), 1,
      anon_sym_RBRACE,
    STATE(730), 1,
      sym__import_declaration,
  [12301] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2226), 1,
      anon_sym_as,
    ACTIONS(2671), 1,
      anon_sym_from,
    STATE(969), 1,
      sym__import_alias,
  [12314] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2673), 1,
      anon_sym_global,
    ACTIONS(2675), 1,
      sym__semicolon,
  [12327] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(2679), 1,
      anon_sym_RPAREN,
    STATE(657), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [12340] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    ACTIONS(2681), 1,
      sym_identifier,
    STATE(387), 1,
      sym__parameter_list,
  [12353] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2683), 1,
      anon_sym_global,
    ACTIONS(2685), 1,
      sym__semicolon,
  [12366] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2687), 1,
      anon_sym_DASH_GT,
    STATE(368), 1,
      sym_yul_block,
  [12379] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2689), 1,
      anon_sym_global,
    ACTIONS(2691), 1,
      sym__semicolon,
  [12392] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2693), 1,
      anon_sym_COMMA,
    ACTIONS(2695), 1,
      anon_sym_RBRACE,
    STATE(679), 1,
      aux_sym_using_directive_repeat1,
  [12405] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(2697), 1,
      anon_sym_DASH_GT,
    STATE(372), 1,
      sym_yul_block,
  [12418] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2699), 1,
      anon_sym_global,
    ACTIONS(2701), 1,
      sym__semicolon,
  [12431] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    ACTIONS(2703), 1,
      sym_identifier,
    STATE(387), 1,
      sym__parameter_list,
  [12444] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    STATE(399), 1,
      sym__identifier_path,
    STATE(677), 1,
      sym_user_defined_type,
  [12457] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2705), 1,
      anon_sym_COMMA,
    ACTIONS(2707), 1,
      anon_sym_RBRACE,
    STATE(679), 1,
      aux_sym_using_directive_repeat1,
  [12470] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2709), 1,
      anon_sym_COMMA,
    ACTIONS(2711), 1,
      anon_sym_RBRACE,
    STATE(780), 1,
      aux_sym_using_directive_repeat1,
  [12483] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2713), 1,
      anon_sym_COMMA,
    ACTIONS(2716), 1,
      anon_sym_RBRACE,
    STATE(776), 1,
      aux_sym_enum_declaration_repeat1,
  [12496] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    ACTIONS(2718), 1,
      anon_sym_RPAREN,
    STATE(328), 1,
      sym_yul_identifier,
  [12509] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2268), 1,
      anon_sym_LPAREN,
    ACTIONS(2720), 1,
      anon_sym_LBRACE,
    STATE(944), 1,
      sym__assembly_flags,
  [12522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2718), 1,
      anon_sym_RPAREN,
    ACTIONS(2722), 1,
      anon_sym_COMMA,
    STATE(316), 1,
      aux_sym_yul_variable_declaration_repeat1,
  [12535] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2724), 1,
      anon_sym_COMMA,
    ACTIONS(2726), 1,
      anon_sym_RBRACE,
    STATE(679), 1,
      aux_sym_using_directive_repeat1,
  [12548] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2728), 1,
      anon_sym_COMMA,
    ACTIONS(2730), 1,
      anon_sym_RBRACE,
    STATE(704), 1,
      aux_sym_call_argument_repeat1,
  [12561] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      sym_identifier,
    STATE(399), 1,
      sym__identifier_path,
    STATE(627), 1,
      sym_user_defined_type,
  [12574] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(101), 1,
      anon_sym_DQUOTE,
    ACTIONS(103), 1,
      anon_sym_SQUOTE,
    STATE(737), 1,
      sym_string,
  [12587] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LBRACE,
    ACTIONS(2732), 1,
      sym__semicolon,
    STATE(265), 1,
      sym_function_body,
  [12600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2734), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12608] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2736), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(307), 1,
      sym_yul_identifier,
  [12626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    STATE(335), 1,
      sym_yul_block,
  [12636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    STATE(367), 1,
      sym_yul_block,
  [12646] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2738), 1,
      anon_sym_constant,
  [12656] = 3,
    ACTIONS(2134), 1,
      sym_comment,
    ACTIONS(2740), 1,
      aux_sym_pragma_value_token1,
    STATE(988), 1,
      sym_pragma_value,
  [12666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2742), 1,
      anon_sym_global,
    ACTIONS(2744), 1,
      sym__semicolon,
  [12676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2746), 1,
      anon_sym_from,
    STATE(961), 1,
      sym__from_clause,
  [12686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2748), 2,
      anon_sym_anonymous,
      sym__semicolon,
  [12694] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2466), 1,
      sym_identifier,
    STATE(818), 1,
      sym_call_struct_argument,
  [12704] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_LBRACE,
    STATE(188), 1,
      sym_contract_body,
  [12714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2750), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12722] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(708), 1,
      sym__parameter_list,
  [12732] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2630), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12740] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(525), 1,
      sym__parameter_list,
  [12750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2752), 1,
      anon_sym_DQUOTE,
    ACTIONS(2754), 1,
      anon_sym_SQUOTE,
  [12760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    STATE(359), 1,
      sym_yul_block,
  [12770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    STATE(847), 1,
      sym_yul_block,
  [12780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(524), 1,
      sym__parameter_list,
  [12790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2756), 1,
      anon_sym_global,
    ACTIONS(2758), 1,
      sym__semicolon,
  [12800] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2760), 1,
      anon_sym_global,
    ACTIONS(2762), 1,
      sym__semicolon,
  [12810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2605), 1,
      anon_sym_global,
    ACTIONS(2607), 1,
      sym__semicolon,
  [12820] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2764), 1,
      anon_sym_global,
    ACTIONS(2766), 1,
      sym__semicolon,
  [12830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2768), 1,
      anon_sym_global,
    ACTIONS(2770), 1,
      sym__semicolon,
  [12840] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2595), 1,
      anon_sym_global,
    ACTIONS(2597), 1,
      sym__semicolon,
  [12850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2772), 1,
      anon_sym_global,
    ACTIONS(2774), 1,
      sym__semicolon,
  [12860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2577), 1,
      anon_sym_global,
    ACTIONS(2579), 1,
      sym__semicolon,
  [12870] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2515), 1,
      anon_sym_global,
    ACTIONS(2517), 1,
      sym__semicolon,
  [12880] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2776), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2498), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2778), 2,
      anon_sym_anonymous,
      sym__semicolon,
  [12904] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2342), 1,
      sym_identifier,
    STATE(840), 1,
      sym_struct_field_assignment,
  [12914] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [12922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2780), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2443), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2395), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [12946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(328), 1,
      sym_yul_identifier,
  [12956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_LBRACE,
    STATE(164), 1,
      sym_contract_body,
  [12966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_LBRACE,
    STATE(167), 1,
      sym_contract_body,
  [12976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(626), 1,
      sym_yul_identifier,
  [12986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2782), 1,
      anon_sym_global,
    ACTIONS(2784), 1,
      sym__semicolon,
  [12996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2552), 1,
      anon_sym_global,
    ACTIONS(2554), 1,
      sym__semicolon,
  [13006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    STATE(363), 1,
      sym_yul_block,
  [13016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(719), 1,
      sym_yul_identifier,
  [13026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2786), 1,
      sym_identifier,
    ACTIONS(2788), 1,
      anon_sym_RBRACE,
  [13036] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2412), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13044] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_RBRACE,
  [13054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(387), 1,
      sym__parameter_list,
  [13064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2794), 1,
      anon_sym_global,
    ACTIONS(2796), 1,
      sym__semicolon,
  [13074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2798), 1,
      sym_identifier,
    ACTIONS(2800), 1,
      anon_sym_EQ_GT,
  [13084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2419), 1,
      anon_sym_global,
    ACTIONS(2421), 1,
      sym__semicolon,
  [13094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2527), 1,
      anon_sym_RBRACE,
    ACTIONS(2786), 1,
      sym_identifier,
  [13104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2802), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2804), 2,
      anon_sym_anonymous,
      sym__semicolon,
  [13120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2484), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [13128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2493), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13136] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2806), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2808), 1,
      sym__hex_digit,
    ACTIONS(2810), 1,
      anon_sym_SQUOTE,
  [13154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2812), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(623), 1,
      sym_yul_identifier,
  [13172] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(672), 1,
      sym__parameter_list,
  [13182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym_yul_block,
  [13192] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2810), 1,
      anon_sym_DQUOTE,
    ACTIONS(2814), 1,
      sym__hex_digit,
  [13202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(956), 1,
      sym_yul_identifier,
  [13212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    STATE(341), 1,
      sym_yul_block,
  [13222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1592), 1,
      anon_sym_LPAREN,
    STATE(468), 1,
      sym__call_arguments,
  [13232] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2645), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2683), 1,
      anon_sym_global,
    ACTIONS(2685), 1,
      sym__semicolon,
  [13250] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      anon_sym_DQUOTE,
    ACTIONS(2818), 1,
      anon_sym_SQUOTE,
  [13260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(605), 1,
      sym_yul_identifier,
  [13270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      anon_sym_DQUOTE,
    ACTIONS(2822), 1,
      anon_sym_SQUOTE,
  [13280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2504), 1,
      anon_sym_global,
    ACTIONS(2506), 1,
      sym__semicolon,
  [13290] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2824), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [13298] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2699), 1,
      anon_sym_global,
    ACTIONS(2701), 1,
      sym__semicolon,
  [13308] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2826), 1,
      sym_identifier,
    ACTIONS(2828), 1,
      anon_sym_RBRACE,
  [13318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_LBRACE,
    STATE(208), 1,
      sym_contract_body,
  [13328] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(560), 1,
      sym__parameter_list,
  [13338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_identifier,
    STATE(628), 1,
      sym_yul_identifier,
  [13348] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2830), 2,
      anon_sym_anonymous,
      sym__semicolon,
  [13356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(529), 1,
      sym__parameter_list,
  [13366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2832), 1,
      sym_identifier,
  [13376] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2834), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2836), 2,
      anon_sym_global,
      sym__semicolon,
  [13392] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2838), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2352), 1,
      anon_sym_global,
    ACTIONS(2354), 1,
      sym__semicolon,
  [13410] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2840), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_LPAREN,
    STATE(888), 1,
      sym__parameter_list,
  [13428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2842), 1,
      sym__hex_digit,
    ACTIONS(2844), 1,
      anon_sym_DQUOTE,
  [13438] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2844), 1,
      anon_sym_SQUOTE,
    ACTIONS(2846), 1,
      sym__hex_digit,
  [13448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2848), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [13456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2640), 1,
      anon_sym_RBRACE,
    ACTIONS(2786), 1,
      sym_identifier,
  [13466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2786), 1,
      sym_identifier,
    ACTIONS(2850), 1,
      anon_sym_RBRACE,
  [13476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2852), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [13484] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2661), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2854), 1,
      anon_sym_LPAREN,
    STATE(883), 1,
      sym__event_parameter_list,
  [13502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2653), 2,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [13510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2856), 1,
      anon_sym_EQ,
    ACTIONS(2858), 1,
      sym__semicolon,
  [13520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2860), 1,
      anon_sym_anonymous,
    ACTIONS(2862), 1,
      sym__semicolon,
  [13530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2401), 1,
      sym_identifier,
    STATE(875), 1,
      sym__import_declaration,
  [13540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      anon_sym_EQ,
    ACTIONS(2866), 1,
      sym__semicolon,
  [13550] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2868), 2,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [13558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1652), 1,
      anon_sym_LBRACK,
    ACTIONS(2870), 1,
      anon_sym_RPAREN,
  [13568] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2872), 2,
      anon_sym_LBRACE,
      sym__semicolon,
  [13576] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2874), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [13584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2876), 1,
      anon_sym_EQ,
    ACTIONS(2878), 1,
      sym__semicolon,
  [13594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2880), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [13602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2448), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13610] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2882), 1,
      anon_sym_LPAREN,
  [13617] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2884), 1,
      sym__semicolon,
  [13624] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2876), 1,
      anon_sym_EQ,
  [13631] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2886), 1,
      anon_sym_LPAREN,
  [13638] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2888), 1,
      anon_sym_LBRACE,
  [13645] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2890), 1,
      anon_sym_LPAREN,
  [13652] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2892), 1,
      sym__semicolon,
  [13659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2894), 1,
      sym__semicolon,
  [13666] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2896), 1,
      anon_sym_LPAREN,
  [13673] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2898), 1,
      sym__semicolon,
  [13680] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2900), 1,
      anon_sym_for,
  [13687] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_for,
  [13694] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2904), 1,
      sym__semicolon,
  [13701] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2906), 1,
      sym__semicolon,
  [13708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2908), 1,
      sym__semicolon,
  [13715] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2910), 1,
      anon_sym_RPAREN,
  [13722] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2912), 1,
      anon_sym_from,
  [13729] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2914), 1,
      anon_sym_from,
  [13736] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2916), 1,
      sym__semicolon,
  [13743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2918), 1,
      anon_sym_from,
  [13750] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2920), 1,
      sym_identifier,
  [13757] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2922), 1,
      anon_sym_for,
  [13764] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2924), 1,
      anon_sym_for,
  [13771] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2926), 1,
      sym_identifier,
  [13778] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2928), 1,
      anon_sym_EQ_GT,
  [13785] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2930), 1,
      anon_sym_LBRACE,
  [13792] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2932), 1,
      sym__semicolon,
  [13799] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2934), 1,
      anon_sym_while,
  [13806] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 1,
      sym_identifier,
  [13813] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2938), 1,
      anon_sym_for,
  [13820] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2940), 1,
      anon_sym_RPAREN,
  [13827] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2942), 1,
      sym__semicolon,
  [13834] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2944), 1,
      anon_sym_LPAREN,
  [13841] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2946), 1,
      anon_sym_COLON,
  [13848] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2948), 1,
      sym__hex_digit,
  [13855] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2950), 1,
      sym_identifier,
  [13862] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2952), 1,
      sym_identifier,
  [13869] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2954), 1,
      sym__semicolon,
  [13876] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2956), 1,
      sym__semicolon,
  [13883] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2958), 1,
      sym__semicolon,
  [13890] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2960), 1,
      sym__semicolon,
  [13897] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2962), 1,
      sym__semicolon,
  [13904] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2964), 1,
      sym__semicolon,
  [13911] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2966), 1,
      anon_sym_from,
  [13918] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2968), 1,
      sym_identifier,
  [13925] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2786), 1,
      sym_identifier,
  [13932] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2970), 1,
      sym__semicolon,
  [13939] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2972), 1,
      anon_sym_for,
  [13946] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2974), 1,
      anon_sym_for,
  [13953] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2976), 1,
      anon_sym_LPAREN,
  [13960] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2978), 1,
      anon_sym_EQ,
  [13967] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2980), 1,
      anon_sym_LBRACE,
  [13974] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2982), 1,
      sym__semicolon,
  [13981] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2984), 1,
      anon_sym_RPAREN,
  [13988] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2986), 1,
      anon_sym_EQ,
  [13995] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2988), 1,
      sym__semicolon,
  [14002] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2990), 1,
      sym__semicolon,
  [14009] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2992), 1,
      anon_sym_LPAREN,
  [14016] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2994), 1,
      anon_sym_for,
  [14023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2996), 1,
      sym__semicolon,
  [14030] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2998), 1,
      sym__semicolon,
  [14037] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3000), 1,
      sym__semicolon,
  [14044] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3002), 1,
      anon_sym_EQ,
  [14051] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3004), 1,
      anon_sym_LPAREN,
  [14058] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3006), 1,
      anon_sym_EQ,
  [14065] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3008), 1,
      sym__semicolon,
  [14072] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3010), 1,
      sym__semicolon,
  [14079] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3012), 1,
      anon_sym_LBRACE,
  [14086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3014), 1,
      sym__semicolon,
  [14093] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1790), 1,
      anon_sym_COLON,
  [14100] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3016), 1,
      sym__semicolon,
  [14107] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3018), 1,
      anon_sym_from,
  [14114] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3020), 1,
      sym__semicolon,
  [14121] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3022), 1,
      sym__semicolon,
  [14128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3024), 1,
      anon_sym_from,
  [14135] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3026), 1,
      sym__semicolon,
  [14142] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3028), 1,
      anon_sym_from,
  [14149] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3030), 1,
      sym__semicolon,
  [14156] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3032), 1,
      sym__semicolon,
  [14163] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3034), 1,
      sym__semicolon,
  [14170] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3036), 1,
      sym_identifier,
  [14177] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3038), 1,
      sym__semicolon,
  [14184] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3040), 1,
      sym__semicolon,
  [14191] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3042), 1,
      sym_solidity_version,
  [14198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3044), 1,
      sym__semicolon,
  [14205] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3046), 1,
      sym__semicolon,
  [14212] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3048), 1,
      sym__semicolon,
  [14219] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3050), 1,
      anon_sym_EQ,
  [14226] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3052), 1,
      sym_solidity_version,
  [14233] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3054), 1,
      sym__semicolon,
  [14240] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3056), 1,
      sym__semicolon,
  [14247] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3058), 1,
      sym__semicolon,
  [14254] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3060), 1,
      sym__semicolon,
  [14261] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3062), 1,
      anon_sym_LBRACE,
  [14268] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3064), 1,
      sym__semicolon,
  [14275] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3066), 1,
      sym__semicolon,
  [14282] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3068), 1,
      sym__semicolon,
  [14289] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3070), 1,
      sym_identifier,
  [14296] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3072), 1,
      sym_identifier,
  [14303] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3074), 1,
      anon_sym_EQ,
  [14310] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3076), 1,
      anon_sym_LBRACE,
  [14317] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3078), 1,
      anon_sym_for,
  [14324] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3080), 1,
      anon_sym_LBRACE,
  [14331] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3082), 1,
      anon_sym_LBRACE,
  [14338] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
  [14345] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3086), 1,
      anon_sym_LPAREN,
  [14352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3088), 1,
      sym_identifier,
  [14359] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3090), 1,
      anon_sym_is,
  [14366] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3092), 1,
      anon_sym_from,
  [14373] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3092), 1,
      anon_sym_from,
  [14380] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 1,
      anon_sym_LPAREN,
  [14387] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3094), 1,
      sym__semicolon,
  [14394] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3096), 1,
      sym_identifier,
  [14401] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3098), 1,
      sym__semicolon,
  [14408] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3100), 1,
      anon_sym_is,
  [14415] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3102), 1,
      anon_sym_LPAREN,
  [14422] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3104), 1,
      anon_sym_LBRACE,
  [14429] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3106), 1,
      anon_sym_for,
  [14436] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3108), 1,
      anon_sym_for,
  [14443] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3110), 1,
      anon_sym_for,
  [14450] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3112), 1,
      anon_sym_for,
  [14457] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3114), 1,
      anon_sym_for,
  [14464] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3116), 1,
      anon_sym_for,
  [14471] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3118), 1,
      anon_sym_for,
  [14478] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3120), 1,
      anon_sym_for,
  [14485] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3122), 1,
      anon_sym_for,
  [14492] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3124), 1,
      sym_identifier,
  [14499] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3126), 1,
      sym_identifier,
  [14506] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3128), 1,
      sym_identifier,
  [14513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3130), 1,
      sym__semicolon,
  [14520] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3132), 1,
      sym__semicolon,
  [14527] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3134), 1,
      ts_builtin_sym_end,
  [14534] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3136), 1,
      anon_sym_LPAREN,
  [14541] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3138), 1,
      sym_identifier,
  [14548] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3140), 1,
      sym_identifier,
  [14555] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3142), 1,
      sym_identifier,
  [14562] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3144), 1,
      sym_identifier,
  [14569] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3146), 1,
      sym_identifier,
  [14576] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3148), 1,
      sym_identifier,
  [14583] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3150), 1,
      anon_sym_contract,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(400)] = 0,
  [SMALL_STATE(401)] = 73,
  [SMALL_STATE(402)] = 143,
  [SMALL_STATE(403)] = 213,
  [SMALL_STATE(404)] = 282,
  [SMALL_STATE(405)] = 351,
  [SMALL_STATE(406)] = 420,
  [SMALL_STATE(407)] = 489,
  [SMALL_STATE(408)] = 558,
  [SMALL_STATE(409)] = 627,
  [SMALL_STATE(410)] = 696,
  [SMALL_STATE(411)] = 765,
  [SMALL_STATE(412)] = 834,
  [SMALL_STATE(413)] = 903,
  [SMALL_STATE(414)] = 972,
  [SMALL_STATE(415)] = 1041,
  [SMALL_STATE(416)] = 1110,
  [SMALL_STATE(417)] = 1179,
  [SMALL_STATE(418)] = 1248,
  [SMALL_STATE(419)] = 1320,
  [SMALL_STATE(420)] = 1386,
  [SMALL_STATE(421)] = 1452,
  [SMALL_STATE(422)] = 1518,
  [SMALL_STATE(423)] = 1584,
  [SMALL_STATE(424)] = 1645,
  [SMALL_STATE(425)] = 1706,
  [SMALL_STATE(426)] = 1773,
  [SMALL_STATE(427)] = 1836,
  [SMALL_STATE(428)] = 1898,
  [SMALL_STATE(429)] = 1962,
  [SMALL_STATE(430)] = 2028,
  [SMALL_STATE(431)] = 2094,
  [SMALL_STATE(432)] = 2158,
  [SMALL_STATE(433)] = 2217,
  [SMALL_STATE(434)] = 2276,
  [SMALL_STATE(435)] = 2335,
  [SMALL_STATE(436)] = 2397,
  [SMALL_STATE(437)] = 2459,
  [SMALL_STATE(438)] = 2520,
  [SMALL_STATE(439)] = 2589,
  [SMALL_STATE(440)] = 2662,
  [SMALL_STATE(441)] = 2725,
  [SMALL_STATE(442)] = 2788,
  [SMALL_STATE(443)] = 2845,
  [SMALL_STATE(444)] = 2936,
  [SMALL_STATE(445)] = 3001,
  [SMALL_STATE(446)] = 3068,
  [SMALL_STATE(447)] = 3125,
  [SMALL_STATE(448)] = 3206,
  [SMALL_STATE(449)] = 3267,
  [SMALL_STATE(450)] = 3358,
  [SMALL_STATE(451)] = 3435,
  [SMALL_STATE(452)] = 3498,
  [SMALL_STATE(453)] = 3561,
  [SMALL_STATE(454)] = 3617,
  [SMALL_STATE(455)] = 3673,
  [SMALL_STATE(456)] = 3729,
  [SMALL_STATE(457)] = 3785,
  [SMALL_STATE(458)] = 3841,
  [SMALL_STATE(459)] = 3897,
  [SMALL_STATE(460)] = 3955,
  [SMALL_STATE(461)] = 4011,
  [SMALL_STATE(462)] = 4067,
  [SMALL_STATE(463)] = 4123,
  [SMALL_STATE(464)] = 4179,
  [SMALL_STATE(465)] = 4235,
  [SMALL_STATE(466)] = 4291,
  [SMALL_STATE(467)] = 4347,
  [SMALL_STATE(468)] = 4403,
  [SMALL_STATE(469)] = 4459,
  [SMALL_STATE(470)] = 4515,
  [SMALL_STATE(471)] = 4571,
  [SMALL_STATE(472)] = 4627,
  [SMALL_STATE(473)] = 4683,
  [SMALL_STATE(474)] = 4739,
  [SMALL_STATE(475)] = 4795,
  [SMALL_STATE(476)] = 4851,
  [SMALL_STATE(477)] = 4907,
  [SMALL_STATE(478)] = 4963,
  [SMALL_STATE(479)] = 5019,
  [SMALL_STATE(480)] = 5075,
  [SMALL_STATE(481)] = 5131,
  [SMALL_STATE(482)] = 5187,
  [SMALL_STATE(483)] = 5243,
  [SMALL_STATE(484)] = 5299,
  [SMALL_STATE(485)] = 5355,
  [SMALL_STATE(486)] = 5416,
  [SMALL_STATE(487)] = 5475,
  [SMALL_STATE(488)] = 5538,
  [SMALL_STATE(489)] = 5593,
  [SMALL_STATE(490)] = 5683,
  [SMALL_STATE(491)] = 5773,
  [SMALL_STATE(492)] = 5863,
  [SMALL_STATE(493)] = 5953,
  [SMALL_STATE(494)] = 6038,
  [SMALL_STATE(495)] = 6125,
  [SMALL_STATE(496)] = 6178,
  [SMALL_STATE(497)] = 6263,
  [SMALL_STATE(498)] = 6348,
  [SMALL_STATE(499)] = 6433,
  [SMALL_STATE(500)] = 6518,
  [SMALL_STATE(501)] = 6602,
  [SMALL_STATE(502)] = 6686,
  [SMALL_STATE(503)] = 6770,
  [SMALL_STATE(504)] = 6854,
  [SMALL_STATE(505)] = 6938,
  [SMALL_STATE(506)] = 7022,
  [SMALL_STATE(507)] = 7106,
  [SMALL_STATE(508)] = 7190,
  [SMALL_STATE(509)] = 7274,
  [SMALL_STATE(510)] = 7358,
  [SMALL_STATE(511)] = 7442,
  [SMALL_STATE(512)] = 7526,
  [SMALL_STATE(513)] = 7610,
  [SMALL_STATE(514)] = 7694,
  [SMALL_STATE(515)] = 7778,
  [SMALL_STATE(516)] = 7862,
  [SMALL_STATE(517)] = 7913,
  [SMALL_STATE(518)] = 7964,
  [SMALL_STATE(519)] = 8045,
  [SMALL_STATE(520)] = 8096,
  [SMALL_STATE(521)] = 8147,
  [SMALL_STATE(522)] = 8198,
  [SMALL_STATE(523)] = 8240,
  [SMALL_STATE(524)] = 8282,
  [SMALL_STATE(525)] = 8335,
  [SMALL_STATE(526)] = 8388,
  [SMALL_STATE(527)] = 8441,
  [SMALL_STATE(528)] = 8494,
  [SMALL_STATE(529)] = 8539,
  [SMALL_STATE(530)] = 8586,
  [SMALL_STATE(531)] = 8633,
  [SMALL_STATE(532)] = 8659,
  [SMALL_STATE(533)] = 8685,
  [SMALL_STATE(534)] = 8711,
  [SMALL_STATE(535)] = 8737,
  [SMALL_STATE(536)] = 8764,
  [SMALL_STATE(537)] = 8787,
  [SMALL_STATE(538)] = 8826,
  [SMALL_STATE(539)] = 8849,
  [SMALL_STATE(540)] = 8872,
  [SMALL_STATE(541)] = 8907,
  [SMALL_STATE(542)] = 8928,
  [SMALL_STATE(543)] = 8949,
  [SMALL_STATE(544)] = 8970,
  [SMALL_STATE(545)] = 9000,
  [SMALL_STATE(546)] = 9034,
  [SMALL_STATE(547)] = 9064,
  [SMALL_STATE(548)] = 9098,
  [SMALL_STATE(549)] = 9128,
  [SMALL_STATE(550)] = 9158,
  [SMALL_STATE(551)] = 9179,
  [SMALL_STATE(552)] = 9206,
  [SMALL_STATE(553)] = 9225,
  [SMALL_STATE(554)] = 9254,
  [SMALL_STATE(555)] = 9281,
  [SMALL_STATE(556)] = 9299,
  [SMALL_STATE(557)] = 9317,
  [SMALL_STATE(558)] = 9351,
  [SMALL_STATE(559)] = 9380,
  [SMALL_STATE(560)] = 9405,
  [SMALL_STATE(561)] = 9430,
  [SMALL_STATE(562)] = 9447,
  [SMALL_STATE(563)] = 9461,
  [SMALL_STATE(564)] = 9483,
  [SMALL_STATE(565)] = 9505,
  [SMALL_STATE(566)] = 9524,
  [SMALL_STATE(567)] = 9547,
  [SMALL_STATE(568)] = 9562,
  [SMALL_STATE(569)] = 9585,
  [SMALL_STATE(570)] = 9608,
  [SMALL_STATE(571)] = 9630,
  [SMALL_STATE(572)] = 9648,
  [SMALL_STATE(573)] = 9665,
  [SMALL_STATE(574)] = 9682,
  [SMALL_STATE(575)] = 9699,
  [SMALL_STATE(576)] = 9718,
  [SMALL_STATE(577)] = 9735,
  [SMALL_STATE(578)] = 9752,
  [SMALL_STATE(579)] = 9769,
  [SMALL_STATE(580)] = 9786,
  [SMALL_STATE(581)] = 9805,
  [SMALL_STATE(582)] = 9822,
  [SMALL_STATE(583)] = 9839,
  [SMALL_STATE(584)] = 9854,
  [SMALL_STATE(585)] = 9871,
  [SMALL_STATE(586)] = 9888,
  [SMALL_STATE(587)] = 9905,
  [SMALL_STATE(588)] = 9922,
  [SMALL_STATE(589)] = 9938,
  [SMALL_STATE(590)] = 9954,
  [SMALL_STATE(591)] = 9970,
  [SMALL_STATE(592)] = 9986,
  [SMALL_STATE(593)] = 10002,
  [SMALL_STATE(594)] = 10018,
  [SMALL_STATE(595)] = 10034,
  [SMALL_STATE(596)] = 10050,
  [SMALL_STATE(597)] = 10064,
  [SMALL_STATE(598)] = 10078,
  [SMALL_STATE(599)] = 10094,
  [SMALL_STATE(600)] = 10104,
  [SMALL_STATE(601)] = 10118,
  [SMALL_STATE(602)] = 10134,
  [SMALL_STATE(603)] = 10150,
  [SMALL_STATE(604)] = 10166,
  [SMALL_STATE(605)] = 10176,
  [SMALL_STATE(606)] = 10192,
  [SMALL_STATE(607)] = 10208,
  [SMALL_STATE(608)] = 10224,
  [SMALL_STATE(609)] = 10240,
  [SMALL_STATE(610)] = 10256,
  [SMALL_STATE(611)] = 10272,
  [SMALL_STATE(612)] = 10288,
  [SMALL_STATE(613)] = 10298,
  [SMALL_STATE(614)] = 10314,
  [SMALL_STATE(615)] = 10330,
  [SMALL_STATE(616)] = 10346,
  [SMALL_STATE(617)] = 10362,
  [SMALL_STATE(618)] = 10372,
  [SMALL_STATE(619)] = 10388,
  [SMALL_STATE(620)] = 10404,
  [SMALL_STATE(621)] = 10420,
  [SMALL_STATE(622)] = 10436,
  [SMALL_STATE(623)] = 10452,
  [SMALL_STATE(624)] = 10468,
  [SMALL_STATE(625)] = 10482,
  [SMALL_STATE(626)] = 10496,
  [SMALL_STATE(627)] = 10512,
  [SMALL_STATE(628)] = 10528,
  [SMALL_STATE(629)] = 10544,
  [SMALL_STATE(630)] = 10558,
  [SMALL_STATE(631)] = 10574,
  [SMALL_STATE(632)] = 10588,
  [SMALL_STATE(633)] = 10604,
  [SMALL_STATE(634)] = 10620,
  [SMALL_STATE(635)] = 10634,
  [SMALL_STATE(636)] = 10648,
  [SMALL_STATE(637)] = 10664,
  [SMALL_STATE(638)] = 10680,
  [SMALL_STATE(639)] = 10696,
  [SMALL_STATE(640)] = 10712,
  [SMALL_STATE(641)] = 10728,
  [SMALL_STATE(642)] = 10744,
  [SMALL_STATE(643)] = 10760,
  [SMALL_STATE(644)] = 10776,
  [SMALL_STATE(645)] = 10792,
  [SMALL_STATE(646)] = 10805,
  [SMALL_STATE(647)] = 10818,
  [SMALL_STATE(648)] = 10831,
  [SMALL_STATE(649)] = 10844,
  [SMALL_STATE(650)] = 10857,
  [SMALL_STATE(651)] = 10870,
  [SMALL_STATE(652)] = 10883,
  [SMALL_STATE(653)] = 10896,
  [SMALL_STATE(654)] = 10907,
  [SMALL_STATE(655)] = 10920,
  [SMALL_STATE(656)] = 10933,
  [SMALL_STATE(657)] = 10946,
  [SMALL_STATE(658)] = 10959,
  [SMALL_STATE(659)] = 10972,
  [SMALL_STATE(660)] = 10985,
  [SMALL_STATE(661)] = 10998,
  [SMALL_STATE(662)] = 11011,
  [SMALL_STATE(663)] = 11024,
  [SMALL_STATE(664)] = 11037,
  [SMALL_STATE(665)] = 11050,
  [SMALL_STATE(666)] = 11063,
  [SMALL_STATE(667)] = 11076,
  [SMALL_STATE(668)] = 11089,
  [SMALL_STATE(669)] = 11102,
  [SMALL_STATE(670)] = 11115,
  [SMALL_STATE(671)] = 11128,
  [SMALL_STATE(672)] = 11141,
  [SMALL_STATE(673)] = 11154,
  [SMALL_STATE(674)] = 11167,
  [SMALL_STATE(675)] = 11180,
  [SMALL_STATE(676)] = 11193,
  [SMALL_STATE(677)] = 11206,
  [SMALL_STATE(678)] = 11217,
  [SMALL_STATE(679)] = 11230,
  [SMALL_STATE(680)] = 11243,
  [SMALL_STATE(681)] = 11256,
  [SMALL_STATE(682)] = 11269,
  [SMALL_STATE(683)] = 11282,
  [SMALL_STATE(684)] = 11293,
  [SMALL_STATE(685)] = 11306,
  [SMALL_STATE(686)] = 11319,
  [SMALL_STATE(687)] = 11332,
  [SMALL_STATE(688)] = 11345,
  [SMALL_STATE(689)] = 11358,
  [SMALL_STATE(690)] = 11371,
  [SMALL_STATE(691)] = 11384,
  [SMALL_STATE(692)] = 11397,
  [SMALL_STATE(693)] = 11410,
  [SMALL_STATE(694)] = 11423,
  [SMALL_STATE(695)] = 11436,
  [SMALL_STATE(696)] = 11449,
  [SMALL_STATE(697)] = 11462,
  [SMALL_STATE(698)] = 11475,
  [SMALL_STATE(699)] = 11488,
  [SMALL_STATE(700)] = 11501,
  [SMALL_STATE(701)] = 11514,
  [SMALL_STATE(702)] = 11527,
  [SMALL_STATE(703)] = 11540,
  [SMALL_STATE(704)] = 11553,
  [SMALL_STATE(705)] = 11566,
  [SMALL_STATE(706)] = 11579,
  [SMALL_STATE(707)] = 11592,
  [SMALL_STATE(708)] = 11605,
  [SMALL_STATE(709)] = 11618,
  [SMALL_STATE(710)] = 11631,
  [SMALL_STATE(711)] = 11644,
  [SMALL_STATE(712)] = 11657,
  [SMALL_STATE(713)] = 11670,
  [SMALL_STATE(714)] = 11683,
  [SMALL_STATE(715)] = 11696,
  [SMALL_STATE(716)] = 11709,
  [SMALL_STATE(717)] = 11722,
  [SMALL_STATE(718)] = 11735,
  [SMALL_STATE(719)] = 11746,
  [SMALL_STATE(720)] = 11759,
  [SMALL_STATE(721)] = 11772,
  [SMALL_STATE(722)] = 11785,
  [SMALL_STATE(723)] = 11798,
  [SMALL_STATE(724)] = 11811,
  [SMALL_STATE(725)] = 11824,
  [SMALL_STATE(726)] = 11837,
  [SMALL_STATE(727)] = 11850,
  [SMALL_STATE(728)] = 11863,
  [SMALL_STATE(729)] = 11876,
  [SMALL_STATE(730)] = 11889,
  [SMALL_STATE(731)] = 11902,
  [SMALL_STATE(732)] = 11915,
  [SMALL_STATE(733)] = 11928,
  [SMALL_STATE(734)] = 11941,
  [SMALL_STATE(735)] = 11954,
  [SMALL_STATE(736)] = 11967,
  [SMALL_STATE(737)] = 11980,
  [SMALL_STATE(738)] = 11993,
  [SMALL_STATE(739)] = 12006,
  [SMALL_STATE(740)] = 12019,
  [SMALL_STATE(741)] = 12032,
  [SMALL_STATE(742)] = 12045,
  [SMALL_STATE(743)] = 12058,
  [SMALL_STATE(744)] = 12071,
  [SMALL_STATE(745)] = 12084,
  [SMALL_STATE(746)] = 12097,
  [SMALL_STATE(747)] = 12110,
  [SMALL_STATE(748)] = 12123,
  [SMALL_STATE(749)] = 12136,
  [SMALL_STATE(750)] = 12149,
  [SMALL_STATE(751)] = 12160,
  [SMALL_STATE(752)] = 12173,
  [SMALL_STATE(753)] = 12186,
  [SMALL_STATE(754)] = 12197,
  [SMALL_STATE(755)] = 12210,
  [SMALL_STATE(756)] = 12223,
  [SMALL_STATE(757)] = 12236,
  [SMALL_STATE(758)] = 12249,
  [SMALL_STATE(759)] = 12262,
  [SMALL_STATE(760)] = 12275,
  [SMALL_STATE(761)] = 12288,
  [SMALL_STATE(762)] = 12301,
  [SMALL_STATE(763)] = 12314,
  [SMALL_STATE(764)] = 12327,
  [SMALL_STATE(765)] = 12340,
  [SMALL_STATE(766)] = 12353,
  [SMALL_STATE(767)] = 12366,
  [SMALL_STATE(768)] = 12379,
  [SMALL_STATE(769)] = 12392,
  [SMALL_STATE(770)] = 12405,
  [SMALL_STATE(771)] = 12418,
  [SMALL_STATE(772)] = 12431,
  [SMALL_STATE(773)] = 12444,
  [SMALL_STATE(774)] = 12457,
  [SMALL_STATE(775)] = 12470,
  [SMALL_STATE(776)] = 12483,
  [SMALL_STATE(777)] = 12496,
  [SMALL_STATE(778)] = 12509,
  [SMALL_STATE(779)] = 12522,
  [SMALL_STATE(780)] = 12535,
  [SMALL_STATE(781)] = 12548,
  [SMALL_STATE(782)] = 12561,
  [SMALL_STATE(783)] = 12574,
  [SMALL_STATE(784)] = 12587,
  [SMALL_STATE(785)] = 12600,
  [SMALL_STATE(786)] = 12608,
  [SMALL_STATE(787)] = 12616,
  [SMALL_STATE(788)] = 12626,
  [SMALL_STATE(789)] = 12636,
  [SMALL_STATE(790)] = 12646,
  [SMALL_STATE(791)] = 12656,
  [SMALL_STATE(792)] = 12666,
  [SMALL_STATE(793)] = 12676,
  [SMALL_STATE(794)] = 12686,
  [SMALL_STATE(795)] = 12694,
  [SMALL_STATE(796)] = 12704,
  [SMALL_STATE(797)] = 12714,
  [SMALL_STATE(798)] = 12722,
  [SMALL_STATE(799)] = 12732,
  [SMALL_STATE(800)] = 12740,
  [SMALL_STATE(801)] = 12750,
  [SMALL_STATE(802)] = 12760,
  [SMALL_STATE(803)] = 12770,
  [SMALL_STATE(804)] = 12780,
  [SMALL_STATE(805)] = 12790,
  [SMALL_STATE(806)] = 12800,
  [SMALL_STATE(807)] = 12810,
  [SMALL_STATE(808)] = 12820,
  [SMALL_STATE(809)] = 12830,
  [SMALL_STATE(810)] = 12840,
  [SMALL_STATE(811)] = 12850,
  [SMALL_STATE(812)] = 12860,
  [SMALL_STATE(813)] = 12870,
  [SMALL_STATE(814)] = 12880,
  [SMALL_STATE(815)] = 12888,
  [SMALL_STATE(816)] = 12896,
  [SMALL_STATE(817)] = 12904,
  [SMALL_STATE(818)] = 12914,
  [SMALL_STATE(819)] = 12922,
  [SMALL_STATE(820)] = 12930,
  [SMALL_STATE(821)] = 12938,
  [SMALL_STATE(822)] = 12946,
  [SMALL_STATE(823)] = 12956,
  [SMALL_STATE(824)] = 12966,
  [SMALL_STATE(825)] = 12976,
  [SMALL_STATE(826)] = 12986,
  [SMALL_STATE(827)] = 12996,
  [SMALL_STATE(828)] = 13006,
  [SMALL_STATE(829)] = 13016,
  [SMALL_STATE(830)] = 13026,
  [SMALL_STATE(831)] = 13036,
  [SMALL_STATE(832)] = 13044,
  [SMALL_STATE(833)] = 13054,
  [SMALL_STATE(834)] = 13064,
  [SMALL_STATE(835)] = 13074,
  [SMALL_STATE(836)] = 13084,
  [SMALL_STATE(837)] = 13094,
  [SMALL_STATE(838)] = 13104,
  [SMALL_STATE(839)] = 13112,
  [SMALL_STATE(840)] = 13120,
  [SMALL_STATE(841)] = 13128,
  [SMALL_STATE(842)] = 13136,
  [SMALL_STATE(843)] = 13144,
  [SMALL_STATE(844)] = 13154,
  [SMALL_STATE(845)] = 13162,
  [SMALL_STATE(846)] = 13172,
  [SMALL_STATE(847)] = 13182,
  [SMALL_STATE(848)] = 13192,
  [SMALL_STATE(849)] = 13202,
  [SMALL_STATE(850)] = 13212,
  [SMALL_STATE(851)] = 13222,
  [SMALL_STATE(852)] = 13232,
  [SMALL_STATE(853)] = 13240,
  [SMALL_STATE(854)] = 13250,
  [SMALL_STATE(855)] = 13260,
  [SMALL_STATE(856)] = 13270,
  [SMALL_STATE(857)] = 13280,
  [SMALL_STATE(858)] = 13290,
  [SMALL_STATE(859)] = 13298,
  [SMALL_STATE(860)] = 13308,
  [SMALL_STATE(861)] = 13318,
  [SMALL_STATE(862)] = 13328,
  [SMALL_STATE(863)] = 13338,
  [SMALL_STATE(864)] = 13348,
  [SMALL_STATE(865)] = 13356,
  [SMALL_STATE(866)] = 13366,
  [SMALL_STATE(867)] = 13376,
  [SMALL_STATE(868)] = 13384,
  [SMALL_STATE(869)] = 13392,
  [SMALL_STATE(870)] = 13400,
  [SMALL_STATE(871)] = 13410,
  [SMALL_STATE(872)] = 13418,
  [SMALL_STATE(873)] = 13428,
  [SMALL_STATE(874)] = 13438,
  [SMALL_STATE(875)] = 13448,
  [SMALL_STATE(876)] = 13456,
  [SMALL_STATE(877)] = 13466,
  [SMALL_STATE(878)] = 13476,
  [SMALL_STATE(879)] = 13484,
  [SMALL_STATE(880)] = 13492,
  [SMALL_STATE(881)] = 13502,
  [SMALL_STATE(882)] = 13510,
  [SMALL_STATE(883)] = 13520,
  [SMALL_STATE(884)] = 13530,
  [SMALL_STATE(885)] = 13540,
  [SMALL_STATE(886)] = 13550,
  [SMALL_STATE(887)] = 13558,
  [SMALL_STATE(888)] = 13568,
  [SMALL_STATE(889)] = 13576,
  [SMALL_STATE(890)] = 13584,
  [SMALL_STATE(891)] = 13594,
  [SMALL_STATE(892)] = 13602,
  [SMALL_STATE(893)] = 13610,
  [SMALL_STATE(894)] = 13617,
  [SMALL_STATE(895)] = 13624,
  [SMALL_STATE(896)] = 13631,
  [SMALL_STATE(897)] = 13638,
  [SMALL_STATE(898)] = 13645,
  [SMALL_STATE(899)] = 13652,
  [SMALL_STATE(900)] = 13659,
  [SMALL_STATE(901)] = 13666,
  [SMALL_STATE(902)] = 13673,
  [SMALL_STATE(903)] = 13680,
  [SMALL_STATE(904)] = 13687,
  [SMALL_STATE(905)] = 13694,
  [SMALL_STATE(906)] = 13701,
  [SMALL_STATE(907)] = 13708,
  [SMALL_STATE(908)] = 13715,
  [SMALL_STATE(909)] = 13722,
  [SMALL_STATE(910)] = 13729,
  [SMALL_STATE(911)] = 13736,
  [SMALL_STATE(912)] = 13743,
  [SMALL_STATE(913)] = 13750,
  [SMALL_STATE(914)] = 13757,
  [SMALL_STATE(915)] = 13764,
  [SMALL_STATE(916)] = 13771,
  [SMALL_STATE(917)] = 13778,
  [SMALL_STATE(918)] = 13785,
  [SMALL_STATE(919)] = 13792,
  [SMALL_STATE(920)] = 13799,
  [SMALL_STATE(921)] = 13806,
  [SMALL_STATE(922)] = 13813,
  [SMALL_STATE(923)] = 13820,
  [SMALL_STATE(924)] = 13827,
  [SMALL_STATE(925)] = 13834,
  [SMALL_STATE(926)] = 13841,
  [SMALL_STATE(927)] = 13848,
  [SMALL_STATE(928)] = 13855,
  [SMALL_STATE(929)] = 13862,
  [SMALL_STATE(930)] = 13869,
  [SMALL_STATE(931)] = 13876,
  [SMALL_STATE(932)] = 13883,
  [SMALL_STATE(933)] = 13890,
  [SMALL_STATE(934)] = 13897,
  [SMALL_STATE(935)] = 13904,
  [SMALL_STATE(936)] = 13911,
  [SMALL_STATE(937)] = 13918,
  [SMALL_STATE(938)] = 13925,
  [SMALL_STATE(939)] = 13932,
  [SMALL_STATE(940)] = 13939,
  [SMALL_STATE(941)] = 13946,
  [SMALL_STATE(942)] = 13953,
  [SMALL_STATE(943)] = 13960,
  [SMALL_STATE(944)] = 13967,
  [SMALL_STATE(945)] = 13974,
  [SMALL_STATE(946)] = 13981,
  [SMALL_STATE(947)] = 13988,
  [SMALL_STATE(948)] = 13995,
  [SMALL_STATE(949)] = 14002,
  [SMALL_STATE(950)] = 14009,
  [SMALL_STATE(951)] = 14016,
  [SMALL_STATE(952)] = 14023,
  [SMALL_STATE(953)] = 14030,
  [SMALL_STATE(954)] = 14037,
  [SMALL_STATE(955)] = 14044,
  [SMALL_STATE(956)] = 14051,
  [SMALL_STATE(957)] = 14058,
  [SMALL_STATE(958)] = 14065,
  [SMALL_STATE(959)] = 14072,
  [SMALL_STATE(960)] = 14079,
  [SMALL_STATE(961)] = 14086,
  [SMALL_STATE(962)] = 14093,
  [SMALL_STATE(963)] = 14100,
  [SMALL_STATE(964)] = 14107,
  [SMALL_STATE(965)] = 14114,
  [SMALL_STATE(966)] = 14121,
  [SMALL_STATE(967)] = 14128,
  [SMALL_STATE(968)] = 14135,
  [SMALL_STATE(969)] = 14142,
  [SMALL_STATE(970)] = 14149,
  [SMALL_STATE(971)] = 14156,
  [SMALL_STATE(972)] = 14163,
  [SMALL_STATE(973)] = 14170,
  [SMALL_STATE(974)] = 14177,
  [SMALL_STATE(975)] = 14184,
  [SMALL_STATE(976)] = 14191,
  [SMALL_STATE(977)] = 14198,
  [SMALL_STATE(978)] = 14205,
  [SMALL_STATE(979)] = 14212,
  [SMALL_STATE(980)] = 14219,
  [SMALL_STATE(981)] = 14226,
  [SMALL_STATE(982)] = 14233,
  [SMALL_STATE(983)] = 14240,
  [SMALL_STATE(984)] = 14247,
  [SMALL_STATE(985)] = 14254,
  [SMALL_STATE(986)] = 14261,
  [SMALL_STATE(987)] = 14268,
  [SMALL_STATE(988)] = 14275,
  [SMALL_STATE(989)] = 14282,
  [SMALL_STATE(990)] = 14289,
  [SMALL_STATE(991)] = 14296,
  [SMALL_STATE(992)] = 14303,
  [SMALL_STATE(993)] = 14310,
  [SMALL_STATE(994)] = 14317,
  [SMALL_STATE(995)] = 14324,
  [SMALL_STATE(996)] = 14331,
  [SMALL_STATE(997)] = 14338,
  [SMALL_STATE(998)] = 14345,
  [SMALL_STATE(999)] = 14352,
  [SMALL_STATE(1000)] = 14359,
  [SMALL_STATE(1001)] = 14366,
  [SMALL_STATE(1002)] = 14373,
  [SMALL_STATE(1003)] = 14380,
  [SMALL_STATE(1004)] = 14387,
  [SMALL_STATE(1005)] = 14394,
  [SMALL_STATE(1006)] = 14401,
  [SMALL_STATE(1007)] = 14408,
  [SMALL_STATE(1008)] = 14415,
  [SMALL_STATE(1009)] = 14422,
  [SMALL_STATE(1010)] = 14429,
  [SMALL_STATE(1011)] = 14436,
  [SMALL_STATE(1012)] = 14443,
  [SMALL_STATE(1013)] = 14450,
  [SMALL_STATE(1014)] = 14457,
  [SMALL_STATE(1015)] = 14464,
  [SMALL_STATE(1016)] = 14471,
  [SMALL_STATE(1017)] = 14478,
  [SMALL_STATE(1018)] = 14485,
  [SMALL_STATE(1019)] = 14492,
  [SMALL_STATE(1020)] = 14499,
  [SMALL_STATE(1021)] = 14506,
  [SMALL_STATE(1022)] = 14513,
  [SMALL_STATE(1023)] = 14520,
  [SMALL_STATE(1024)] = 14527,
  [SMALL_STATE(1025)] = 14534,
  [SMALL_STATE(1026)] = 14541,
  [SMALL_STATE(1027)] = 14548,
  [SMALL_STATE(1028)] = 14555,
  [SMALL_STATE(1029)] = 14562,
  [SMALL_STATE(1030)] = 14569,
  [SMALL_STATE(1031)] = 14576,
  [SMALL_STATE(1032)] = 14583,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1032),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1031),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1027),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(637),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(942),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(455),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(458),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(36),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(26),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(488),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(418),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(856),
  [107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(425),
  [110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(54),
  [113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(56),
  [116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(4),
  [119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2),
  [121] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(942),
  [124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(19),
  [127] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(901),
  [130] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(618),
  [133] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(900),
  [136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(899),
  [139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(455),
  [142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(458),
  [145] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(898),
  [148] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(833),
  [151] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(401),
  [154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(400),
  [157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(36),
  [160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(26),
  [163] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(897),
  [166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(488),
  [169] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(896),
  [172] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(12),
  [175] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(49),
  [178] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(63),
  [181] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(851),
  [184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(211),
  [187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(35),
  [190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(66),
  [193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(64),
  [196] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(1025),
  [199] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(418),
  [202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(418),
  [205] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(854),
  [208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(577),
  [211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(579),
  [214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2), SHIFT_REPEAT(856),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_tuple_repeat1, 1), REDUCE(aux_sym_tuple_expression_repeat1, 1),
  [244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 1),
  [270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2),
  [296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(523),
  [299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(586),
  [302] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(557),
  [305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(937),
  [308] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1032),
  [311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1031),
  [314] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1030),
  [317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1029),
  [320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1028),
  [323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1027),
  [326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1026),
  [329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(637),
  [332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(772),
  [335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(401),
  [338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(400),
  [341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(1025),
  [344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1),
  [346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, .production_id = 86),
  [348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, .production_id = 86),
  [350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(570),
  [352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2), SHIFT_REPEAT(570),
  [359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 6, .production_id = 103),
  [361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 6, .production_id = 103),
  [363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2),
  [365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2),
  [367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_statement, 3),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_statement, 3),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(622),
  [385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(928),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(925),
  [395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_statement, 2),
  [397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_statement, 2),
  [399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 2),
  [401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 2),
  [403] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(523),
  [406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_contract_body_repeat1, 2),
  [408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(1019),
  [411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(1020),
  [414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(1021),
  [417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(1005),
  [420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(929),
  [423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(622),
  [426] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(765),
  [429] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(401),
  [432] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(400),
  [435] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(928),
  [438] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(862),
  [441] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(865),
  [444] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(925),
  [447] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_contract_body_repeat1, 2), SHIFT_REPEAT(1025),
  [450] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 4, .production_id = 87),
  [452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 4, .production_id = 87),
  [454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_statement, 4),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_statement, 4),
  [458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, .production_id = 50),
  [462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, .production_id = 50),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, .production_id = 97),
  [466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2, .production_id = 97),
  [468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 4, .production_id = 59),
  [470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, .production_id = 59),
  [472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_revert_statement, 4, .production_id = 85),
  [478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_revert_statement, 4, .production_id = 85),
  [480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 96),
  [482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 96),
  [484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, .production_id = 96),
  [488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, .production_id = 96),
  [490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_revert_statement, 3, .production_id = 67),
  [492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_revert_statement, 3, .production_id = 67),
  [494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_statement, 4, .production_id = 84),
  [496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_statement, 4, .production_id = 84),
  [498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_statement, 5, .production_id = 84),
  [500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_statement, 5, .production_id = 84),
  [502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2),
  [504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2),
  [506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_statement, 4),
  [508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_statement, 4),
  [510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2),
  [512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2),
  [514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_emit_statement, 4, .production_id = 26),
  [516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_emit_statement, 4, .production_id = 26),
  [518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_statement, 5, .production_id = 95),
  [520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_statement, 5, .production_id = 95),
  [522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, .production_id = 100),
  [524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, .production_id = 100),
  [526] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_revert_statement, 2),
  [528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_revert_statement, 2),
  [530] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2),
  [532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2),
  [534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_statement, 5),
  [536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_statement, 5),
  [538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, .production_id = 108),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, .production_id = 108),
  [542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_statement, 6, .production_id = 95),
  [544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_statement, 6, .production_id = 95),
  [546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_revert_statement, 3, .production_id = 68),
  [548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_revert_statement, 3, .production_id = 68),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 105),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 105),
  [554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_while_statement, 7, .production_id = 109),
  [556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_while_statement, 7, .production_id = 109),
  [558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assembly_statement, 3),
  [560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assembly_statement, 3),
  [562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_tuple_repeat1, 1),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [566] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_declaration_repeat1, 2), SHIFT_REPEAT(523),
  [569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_declaration_repeat1, 2),
  [571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_declaration_repeat1, 2), SHIFT_REPEAT(833),
  [574] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_declaration_repeat1, 2), SHIFT_REPEAT(401),
  [577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_declaration_repeat1, 2), SHIFT_REPEAT(400),
  [580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_declaration_repeat1, 2), SHIFT_REPEAT(1025),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 9, .production_id = 81),
  [621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 9, .production_id = 81),
  [623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contract_declaration, 3, .production_id = 13),
  [625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_contract_declaration, 3, .production_id = 13),
  [627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_error_declaration, 7, .production_id = 26),
  [629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_error_declaration, 7, .production_id = 26),
  [631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 10, .production_id = 93),
  [633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 10, .production_id = 93),
  [635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_directive, 4, .production_id = 22),
  [637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_directive, 4, .production_id = 22),
  [639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contract_declaration, 4, .production_id = 23),
  [641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_contract_declaration, 4, .production_id = 23),
  [643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contract_body, 2),
  [645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_contract_body, 2),
  [647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 10, .production_id = 99),
  [649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 10, .production_id = 99),
  [651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constant_variable_declaration, 6, .production_id = 57),
  [653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constant_variable_declaration, 6, .production_id = 57),
  [655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, .production_id = 54),
  [657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, .production_id = 54),
  [659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contract_declaration, 4, .production_id = 25),
  [661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_contract_declaration, 4, .production_id = 25),
  [663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, .production_id = 53),
  [665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, .production_id = 53),
  [667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_body, 3),
  [669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_body, 3),
  [671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, .production_id = 25),
  [673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, .production_id = 25),
  [675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 4, .production_id = 26),
  [677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 4, .production_id = 26),
  [679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 10, .production_id = 92),
  [681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 10, .production_id = 92),
  [683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 10, .production_id = 98),
  [685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 10, .production_id = 98),
  [687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 6, .production_id = 40),
  [689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 6, .production_id = 40),
  [691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 7, .production_id = 66),
  [693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 7, .production_id = 66),
  [695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pragma_directive, 3),
  [697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pragma_directive, 3),
  [699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 6, .production_id = 37),
  [701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 6, .production_id = 37),
  [703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_error_declaration, 6, .production_id = 26),
  [705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_error_declaration, 6, .production_id = 26),
  [707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_directive, 3, .production_id = 11),
  [709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_directive, 3, .production_id = 11),
  [711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, .production_id = 45),
  [713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, .production_id = 45),
  [715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, .production_id = 44),
  [717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, .production_id = 44),
  [719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, .production_id = 43),
  [721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, .production_id = 43),
  [723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, .production_id = 42),
  [725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, .production_id = 42),
  [727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, .production_id = 26),
  [729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, .production_id = 26),
  [731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 9, .production_id = 82),
  [733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 9, .production_id = 82),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 12, .production_id = 104),
  [737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 12, .production_id = 104),
  [739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 3, .production_id = 13),
  [741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 3, .production_id = 13),
  [743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, .production_id = 25),
  [745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, .production_id = 25),
  [747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_library_declaration, 3, .production_id = 13),
  [749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_library_declaration, 3, .production_id = 13),
  [751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 9, .production_id = 93),
  [753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 9, .production_id = 93),
  [755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_body, 2),
  [757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_body, 2),
  [759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 5, .production_id = 40),
  [761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 5, .production_id = 40),
  [763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 5, .production_id = 37),
  [765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 5, .production_id = 37),
  [767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 5, .production_id = 26),
  [769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 5, .production_id = 26),
  [771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 9, .production_id = 92),
  [773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 9, .production_id = 92),
  [775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_error_declaration, 5, .production_id = 26),
  [777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_error_declaration, 5, .production_id = 26),
  [779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_error_declaration, 8, .production_id = 26),
  [781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_error_declaration, 8, .production_id = 26),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contract_body, 3),
  [785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_contract_body, 3),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 11, .production_id = 98),
  [789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 11, .production_id = 98),
  [791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 8, .production_id = 81),
  [793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 8, .production_id = 81),
  [795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 8, .production_id = 66),
  [797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 8, .production_id = 66),
  [799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 11, .production_id = 104),
  [801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 11, .production_id = 104),
  [803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 7, .production_id = 37),
  [805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 7, .production_id = 37),
  [807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contract_declaration, 5, .production_id = 35),
  [809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_contract_declaration, 5, .production_id = 35),
  [811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_defined_type_definition, 5, .production_id = 26),
  [813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_defined_type_definition, 5, .production_id = 26),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 8, .production_id = 82),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 8, .production_id = 82),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 11, .production_id = 99),
  [823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 11, .production_id = 99),
  [825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_receive_definition, 4, .production_id = 59),
  [827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receive_definition, 4, .production_id = 59),
  [829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_receive_definition, 4),
  [831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receive_definition, 4),
  [833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 4, .production_id = 63),
  [835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 4, .production_id = 63),
  [837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 4, .production_id = 62),
  [839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 4, .production_id = 62),
  [841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 4, .production_id = 61),
  [843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 4, .production_id = 61),
  [845] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 4, .production_id = 60),
  [847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 4, .production_id = 60),
  [849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_definition, 4, .production_id = 59),
  [851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_definition, 4, .production_id = 59),
  [853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_definition, 3, .production_id = 26),
  [855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_definition, 3, .production_id = 26),
  [857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_definition, 4, .production_id = 25),
  [859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_definition, 4, .production_id = 25),
  [861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_definition, 4, .production_id = 26),
  [863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_definition, 4, .production_id = 26),
  [865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_definition, 4, .production_id = 26),
  [867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_definition, 4, .production_id = 26),
  [869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_variable_declaration, 6, .production_id = 91),
  [871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_variable_declaration, 6, .production_id = 91),
  [873] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_definition, 3, .production_id = 13),
  [875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_definition, 3, .production_id = 13),
  [877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_definition, 3, .production_id = 50),
  [879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_definition, 3, .production_id = 50),
  [881] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 3),
  [883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 3),
  [885] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 3, .production_id = 50),
  [887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 3, .production_id = 50),
  [889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_variable_declaration, 5, .production_id = 80),
  [891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_variable_declaration, 5, .production_id = 80),
  [893] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_receive_definition, 5, .production_id = 79),
  [895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receive_definition, 5, .production_id = 79),
  [897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_variable_declaration, 3, .production_id = 27),
  [899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_variable_declaration, 3, .production_id = 27),
  [901] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_receive_definition, 5, .production_id = 78),
  [903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receive_definition, 5, .production_id = 78),
  [905] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 5, .production_id = 77),
  [907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 5, .production_id = 77),
  [909] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallback_definition, 5, .production_id = 76),
  [911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallback_definition, 5, .production_id = 76),
  [913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_definition, 5, .production_id = 75),
  [915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_definition, 5, .production_id = 75),
  [917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_definition, 5, .production_id = 26),
  [919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_definition, 5, .production_id = 26),
  [921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_definition, 5, .production_id = 26),
  [923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_definition, 5, .production_id = 26),
  [925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_variable_declaration, 4, .production_id = 64),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_variable_declaration, 4, .production_id = 64),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(309),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(339),
  [955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(347),
  [957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_member, 3, .production_id = 27),
  [987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_member, 3, .production_id = 27),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [997] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(309),
  [1000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(298),
  [1003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_assembly_statement_repeat1, 2),
  [1005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(850),
  [1008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(300),
  [1011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(365),
  [1014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(364),
  [1017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(300),
  [1020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(323),
  [1023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(742),
  [1026] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(339),
  [1029] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(347),
  [1032] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(849),
  [1035] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(308),
  [1038] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(801),
  [1041] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(574),
  [1044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assembly_statement_repeat1, 2), SHIFT_REPEAT(576),
  [1047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [1053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [1055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_path, 1),
  [1059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_path, 1),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [1065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_path, 2),
  [1067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_path, 2),
  [1069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_identifier, 1),
  [1071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_identifier, 1),
  [1073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_yul_path_repeat1, 2),
  [1075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_yul_path_repeat1, 2),
  [1077] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_yul_path_repeat1, 2), SHIFT_REPEAT(787),
  [1080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_evm_builtin, 1),
  [1082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_evm_builtin, 1),
  [1084] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_yul_identifier, 1), SHIFT(358),
  [1087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_assignment, 1),
  [1089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_assignment, 1),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_call, 1, .production_id = 32),
  [1099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_call, 1, .production_id = 32),
  [1101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_assignment, 3),
  [1103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_assignment, 3),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [1107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_assignment, 2),
  [1109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_assignment, 2),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [1115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_yul_variable_declaration_repeat1, 2),
  [1117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_yul_variable_declaration_repeat1, 2),
  [1119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_yul_variable_declaration_repeat1, 2), SHIFT_REPEAT(822),
  [1122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_call, 6, .production_id = 32),
  [1124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_call, 6, .production_id = 32),
  [1126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_string_literal, 1),
  [1128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_string_literal, 1),
  [1130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_call, 5, .production_id = 32),
  [1132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_call, 5, .production_id = 32),
  [1134] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_call, 3, .production_id = 32),
  [1136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_call, 3, .production_id = 32),
  [1138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_yul_assignment_repeat1, 2),
  [1140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_yul_assignment_repeat1, 2),
  [1142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_yul_assignment_repeat1, 2), SHIFT_REPEAT(740),
  [1145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_call, 4, .production_id = 32),
  [1147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_call, 4, .production_id = 32),
  [1149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_boolean, 1),
  [1151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_boolean, 1),
  [1153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_yul_switch_statement_repeat1, 2),
  [1155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_yul_switch_statement_repeat1, 2),
  [1157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_yul_switch_statement_repeat1, 2), SHIFT_REPEAT(540),
  [1160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 2, .production_id = 83),
  [1162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 2, .production_id = 83),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 3, .production_id = 94),
  [1170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 3, .production_id = 94),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_switch_statement, 3),
  [1178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_switch_statement, 3),
  [1180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [1182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [1184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(305),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [1192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 4, .production_id = 101),
  [1194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 4, .production_id = 101),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_block, 2),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_block, 2),
  [1202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_block, 3),
  [1204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_block, 3),
  [1206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_yul_switch_statement_repeat1, 3),
  [1208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_yul_switch_statement_repeat1, 3),
  [1210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [1216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [1218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [1220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [1222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [1224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [1226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hex_string_literal, 1),
  [1228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hex_string_literal, 1),
  [1230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [1234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 6, .production_id = 111),
  [1236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 6, .production_id = 111),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [1240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 5, .production_id = 106),
  [1242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 5, .production_id = 106),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hex_string_literal_repeat2, 2),
  [1248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat2, 2),
  [1250] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_hex_string_literal_repeat2, 2), SHIFT_REPEAT(801),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [1261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 5, .production_id = 107),
  [1263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 5, .production_id = 107),
  [1265] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 11),
  [1267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 11),
  [1269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 4, .production_id = 102),
  [1271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 4, .production_id = 102),
  [1273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_for_statement, 5),
  [1275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_for_statement, 5),
  [1277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_assignment, 5),
  [1279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_assignment, 5),
  [1281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 7),
  [1283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 7),
  [1285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 9),
  [1287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 9),
  [1289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 8, .production_id = 113),
  [1291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 8, .production_id = 113),
  [1293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_label, 2),
  [1295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_label, 2),
  [1297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_switch_statement, 4),
  [1299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_switch_statement, 4),
  [1301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 10),
  [1303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 10),
  [1305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3),
  [1307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3),
  [1309] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hex_string_literal_repeat2, 5),
  [1311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat2, 5),
  [1313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_if_statement, 3),
  [1315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_if_statement, 3),
  [1317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_continue, 1),
  [1319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_continue, 1),
  [1321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_break, 1),
  [1323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_break, 1),
  [1325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 6),
  [1327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 6),
  [1329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_switch_statement, 5),
  [1331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_switch_statement, 5),
  [1333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 5),
  [1335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 5),
  [1337] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hex_string_literal_repeat2, 4),
  [1339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat2, 4),
  [1341] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2),
  [1343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2),
  [1345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_assignment, 4),
  [1347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_assignment, 4),
  [1349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 8),
  [1351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 8),
  [1353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 6, .production_id = 110),
  [1355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 6, .production_id = 110),
  [1357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__yul_expression, 1), REDUCE(sym_yul_assignment, 3),
  [1360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__yul_expression, 1), REDUCE(sym_yul_assignment, 3),
  [1363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_variable_declaration, 7, .production_id = 112),
  [1365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_variable_declaration, 7, .production_id = 112),
  [1367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hex_string_literal_repeat2, 3),
  [1369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat2, 3),
  [1371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yul_function_definition, 12),
  [1373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yul_function_definition, 12),
  [1375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__yul_assignment_operator, 2),
  [1377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__yul_assignment_operator, 2),
  [1379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__identifier_path_repeat1, 2),
  [1381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__identifier_path_repeat1, 2),
  [1383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__identifier_path_repeat1, 2), SHIFT_REPEAT(991),
  [1386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_type, 2, .production_id = 6),
  [1388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_type, 2, .production_id = 6),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(950),
  [1392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(392),
  [1394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [1396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_type, 3, .production_id = 17),
  [1398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_type, 3, .production_id = 17),
  [1400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__function_type_repeat1, 2, .production_id = 29),
  [1402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_type_repeat1, 2, .production_id = 29),
  [1404] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__function_type_repeat1, 2, .production_id = 29), SHIFT_REPEAT(392),
  [1407] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__function_type_repeat1, 2, .production_id = 29), SHIFT_REPEAT(395),
  [1410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_list, 5),
  [1412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 5),
  [1414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_visibility, 1),
  [1416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visibility, 1),
  [1418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_list, 4),
  [1420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 4),
  [1422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_list, 3),
  [1424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 3),
  [1426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_mutability, 1),
  [1428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_mutability, 1),
  [1430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_list, 2),
  [1432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 2),
  [1434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__function_type_repeat1, 1, .production_id = 15),
  [1436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_type_repeat1, 1, .production_id = 15),
  [1438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__function_type_repeat1, 1, .production_id = 16),
  [1440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_type_repeat1, 1, .production_id = 16),
  [1442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_defined_type, 1),
  [1444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_defined_type, 1),
  [1446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primitive_type, 1),
  [1448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primitive_type, 1),
  [1450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [1452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primitive_type, 2),
  [1454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primitive_type, 2),
  [1456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_name, 1, .production_id = 2),
  [1458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_name, 1, .production_id = 2),
  [1460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__array_type, 4),
  [1462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__array_type, 4),
  [1464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_type, 4, .production_id = 17),
  [1466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_type, 4, .production_id = 17),
  [1468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__mapping, 6, .production_id = 56),
  [1470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__mapping, 6, .production_id = 56),
  [1472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__array_type, 3),
  [1474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__array_type, 3),
  [1476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__mapping, 8, .production_id = 88),
  [1478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__mapping, 8, .production_id = 88),
  [1480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_name, 1, .production_id = 1),
  [1482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_name, 1, .production_id = 1),
  [1484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__mapping, 7, .production_id = 71),
  [1486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__mapping, 7, .production_id = 71),
  [1488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_name, 1),
  [1490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_name, 1),
  [1492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__return_parameters, 4, .production_id = 55),
  [1494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__return_parameters, 4, .production_id = 55),
  [1496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__mapping, 7, .production_id = 70),
  [1498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__mapping, 7, .production_id = 70),
  [1500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_type, 3, .production_id = 6),
  [1502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_type, 3, .production_id = 6),
  [1504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__return_parameters, 5, .production_id = 55),
  [1506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__return_parameters, 5, .production_id = 55),
  [1508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__return_parameters, 6, .production_id = 55),
  [1510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__return_parameters, 6, .production_id = 55),
  [1512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number_literal, 1),
  [1514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number_literal, 1),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [1518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__call_arguments, 5),
  [1520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_arguments, 5),
  [1522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__call_arguments, 4),
  [1524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_arguments, 4),
  [1526] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__call_arguments, 3),
  [1528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_arguments, 3),
  [1530] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__call_arguments, 2),
  [1532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_arguments, 2),
  [1534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__identifier_path, 1),
  [1536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__primary_expression, 1), REDUCE(sym__identifier_path, 1),
  [1539] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__primary_expression, 1), REDUCE(sym__identifier_path, 1),
  [1542] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__primary_expression, 1), REDUCE(sym__identifier_path, 1), SHIFT(916),
  [1546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__identifier_path, 2),
  [1548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__identifier_path, 2),
  [1550] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__identifier_path_repeat1, 2), REDUCE(sym_member_expression, 3, .dynamic_precedence = 1, .production_id = 46),
  [1553] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__identifier_path_repeat1, 2), REDUCE(sym_member_expression, 3, .dynamic_precedence = 1, .production_id = 46),
  [1556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [1558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 1),
  [1560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 1),
  [1562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2),
  [1564] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2),
  [1566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2), SHIFT_REPEAT(577),
  [1569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2), SHIFT_REPEAT(579),
  [1572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat2, 2), SHIFT_REPEAT(854),
  [1575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unicode_string_literal, 1),
  [1577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unicode_string_literal, 1),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [1581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unicode_string_literal_repeat3, 2),
  [1583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unicode_string_literal_repeat3, 2),
  [1585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unicode_string_literal_repeat3, 2), SHIFT_REPEAT(856),
  [1588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, .production_id = 30),
  [1590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, .production_id = 30),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, .production_id = 47),
  [1596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [1598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, .production_id = 47),
  [1600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [1604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [1608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [1610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, .production_id = 30),
  [1612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, .production_id = 30),
  [1614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unicode_string_literal_repeat3, 4),
  [1616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unicode_string_literal_repeat3, 4),
  [1618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(53),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [1624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, .production_id = 48),
  [1628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [1630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [1640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unicode_string_literal_repeat3, 3),
  [1642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unicode_string_literal_repeat3, 3),
  [1644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5),
  [1646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5),
  [1648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, .production_id = 26),
  [1650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, .production_id = 26),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [1654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_augmented_assignment_expression, 3, .production_id = 48),
  [1656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_array_expression, 5),
  [1658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_array_expression, 5),
  [1660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 5),
  [1662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 5),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_true, 1),
  [1666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_true, 1),
  [1668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_array_expression, 4),
  [1670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_array_expression, 4),
  [1672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_expression, 3, .production_id = 14),
  [1674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_expression, 3, .production_id = 14),
  [1676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_false, 1),
  [1678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_false, 1),
  [1680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__primary_expression, 1),
  [1682] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__primary_expression, 1),
  [1684] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__primary_expression, 1), SHIFT(42),
  [1687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1),
  [1689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_literal, 1),
  [1691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_access, 6, .production_id = 89),
  [1693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_access, 6, .production_id = 89),
  [1695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_expression, 6, .production_id = 14),
  [1697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_expression, 6, .production_id = 14),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, .dynamic_precedence = 1, .production_id = 46),
  [1701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, .dynamic_precedence = 1, .production_id = 46),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 4),
  [1705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 4),
  [1707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, .production_id = 26),
  [1709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, .production_id = 26),
  [1711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 2),
  [1713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 2),
  [1715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_access, 3, .production_id = 49),
  [1717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_access, 3, .production_id = 49),
  [1719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_payable_conversion_expression, 2),
  [1721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_payable_conversion_expression, 2),
  [1723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_expression, 4, .production_id = 14),
  [1725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_expression, 4, .production_id = 14),
  [1727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_array_expression, 2),
  [1729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_array_expression, 2),
  [1731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_meta_type_expression, 4),
  [1733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_meta_type_expression, 4),
  [1735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_access, 4, .production_id = 49),
  [1737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_access, 4, .production_id = 49),
  [1739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, .production_id = 31),
  [1741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, .production_id = 31),
  [1743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, .production_id = 32),
  [1745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, .production_id = 32),
  [1747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_access, 4, .production_id = 58),
  [1749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_access, 4, .production_id = 58),
  [1751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_cast_expression, 4),
  [1753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_cast_expression, 4),
  [1755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number_unit, 1),
  [1757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number_unit, 1),
  [1759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number_literal, 2),
  [1761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number_literal, 2),
  [1763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3),
  [1765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3),
  [1767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_access, 5, .production_id = 74),
  [1769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_access, 5, .production_id = 74),
  [1771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_access, 5, .production_id = 73),
  [1773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_access, 5, .production_id = 73),
  [1775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_array_expression, 3),
  [1777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_array_expression, 3),
  [1779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 3),
  [1781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 3),
  [1783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_expression, 5, .production_id = 14),
  [1785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_expression, 5, .production_id = 14),
  [1787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__primary_expression, 1), REDUCE(sym_type_name, 1),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [1800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [1802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [1806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [1808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field_assignment, 3, .production_id = 72),
  [1810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [1814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_struct_argument, 3, .production_id = 72),
  [1816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_argument, 1),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inline_array_expression_repeat1, 2),
  [1820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [1834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [1840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1856] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_tuple, 2),
  [1858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [1860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_tuple, 3),
  [1862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [1864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__identifier_path, 1),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [1868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(872),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [1872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [1878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(528),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(523),
  [1891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, .production_id = 29),
  [1893] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, .production_id = 29),
  [1895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(392),
  [1898] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(395),
  [1901] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(534),
  [1904] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(528),
  [1907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [1909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(537),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [1919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [1921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_override_specifier, 1),
  [1923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_override_specifier, 1),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [1927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_invocation, 1),
  [1929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_invocation, 1),
  [1931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_override_specifier, 4),
  [1933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_override_specifier, 4),
  [1935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(523),
  [1938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fallback_definition_repeat1, 2, .production_id = 29),
  [1940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 2, .production_id = 29),
  [1942] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(556),
  [1945] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(395),
  [1948] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(534),
  [1951] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 2, .production_id = 29), SHIFT_REPEAT(537),
  [1954] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_override_specifier, 6),
  [1956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_override_specifier, 6),
  [1958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_override_specifier, 5),
  [1960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_override_specifier, 5),
  [1962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [1964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [1966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 1, .production_id = 15),
  [1970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 1, .production_id = 15),
  [1972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_invocation, 2),
  [1974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_invocation, 2),
  [1976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 1, .production_id = 16),
  [1978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 1, .production_id = 16),
  [1980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [1982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(551),
  [1984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [1986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [1988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [1994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [1996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_solidity_pragma_token, 1),
  [1998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [2000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [2002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_solidity_pragma_token, 2, .production_id = 8),
  [2004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 2, .production_id = 18), SHIFT_REPEAT(550),
  [2007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 2, .production_id = 18), SHIFT_REPEAT(981),
  [2010] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 2, .production_id = 18), SHIFT_REPEAT(981),
  [2013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 2, .production_id = 18),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [2017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 1, .production_id = 7),
  [2019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 1, .production_id = 7),
  [2021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [2023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [2025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pragma_version_constraint, 2),
  [2027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pragma_version_constraint, 2),
  [2029] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_receive_definition_repeat1, 2, .production_id = 51), SHIFT_REPEAT(523),
  [2032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_receive_definition_repeat1, 2, .production_id = 51),
  [2034] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_receive_definition_repeat1, 2, .production_id = 51), SHIFT_REPEAT(567),
  [2037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_receive_definition_repeat1, 2, .production_id = 51), SHIFT_REPEAT(553),
  [2040] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_receive_definition_repeat1, 2, .production_id = 51), SHIFT_REPEAT(534),
  [2043] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_state_variable_declaration_repeat1, 2, .production_id = 51),
  [2045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_variable_declaration_repeat1, 2, .production_id = 51), SHIFT_REPEAT(554),
  [2048] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_variable_declaration_repeat1, 2, .production_id = 51), SHIFT_REPEAT(392),
  [2051] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_variable_declaration_repeat1, 2, .production_id = 51), SHIFT_REPEAT(534),
  [2054] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 1, .production_id = 16),
  [2056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fallback_definition_repeat1, 1, .production_id = 16),
  [2058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_fallback_definition_repeat1, 1, .production_id = 15),
  [2060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fallback_definition_repeat1, 1, .production_id = 15),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [2068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [2070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [2072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [2076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [2078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(559),
  [2080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 2, .production_id = 7),
  [2082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_solidity_pragma_token_repeat1, 2, .production_id = 7),
  [2084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_state_variable_declaration_repeat1, 1, .production_id = 15),
  [2086] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_definition_repeat1, 2), SHIFT_REPEAT(523),
  [2089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constructor_definition_repeat1, 2),
  [2091] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_definition_repeat1, 2), SHIFT_REPEAT(563),
  [2094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [2096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, .production_id = 14),
  [2098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [2100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__nameless_parameter, 1, .production_id = 14),
  [2102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [2104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [2108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_receive_definition_repeat1, 1, .production_id = 15),
  [2110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_receive_definition_repeat1, 1, .production_id = 15),
  [2112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [2114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [2116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [2118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modifier_definition_repeat1, 2),
  [2120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_modifier_definition_repeat1, 2), SHIFT_REPEAT(534),
  [2123] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_modifier_definition_repeat1, 2), SHIFT_REPEAT(571),
  [2126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat2, 2),
  [2128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat2, 2), SHIFT_REPEAT(572),
  [2131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat2, 2), SHIFT_REPEAT(572),
  [2134] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [2136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [2138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_paramater, 1, .production_id = 14),
  [2140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [2142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [2144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_heritage, 3),
  [2152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [2156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [2158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [2162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [2164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [2168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(587),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [2172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_heritage, 4),
  [2174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(572),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [2178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2),
  [2180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(582),
  [2183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(582),
  [2186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [2188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [2190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [2192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat1, 2), SHIFT_REPEAT(585),
  [2195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat1, 2),
  [2197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hex_string_literal_repeat1, 2), SHIFT_REPEAT(927),
  [2200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [2202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [2208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [2212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_declaration, 1, .production_id = 3),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [2228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [2234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_alias, 2, .production_id = 19),
  [2236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [2240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [2242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [2244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 2, .production_id = 27),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [2248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [2250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [2252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 3, .production_id = 41),
  [2254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [2272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [2280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unicode_string_literal_repeat1, 2),
  [2282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unicode_string_literal_repeat1, 2), SHIFT_REPEAT(624),
  [2285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unicode_string_literal_repeat2, 2),
  [2287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unicode_string_literal_repeat2, 2), SHIFT_REPEAT(625),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [2292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [2300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_specifier, 1, .production_id = 24),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [2304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_error_parameter, 1, .production_id = 14),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [2316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [2332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [2336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [2342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [2350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, .production_id = 28),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [2362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [2380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_heritage, 2),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [2386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [2388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_tuple_repeat2, 1),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [2392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_tuple_repeat2, 2), SHIFT_REPEAT(750),
  [2395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_tuple_repeat2, 2),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [2409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_yul_function_call_repeat1, 2), SHIFT_REPEAT(348),
  [2412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_yul_function_call_repeat1, 2),
  [2414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__multiple_import_repeat1, 2, .production_id = 34), SHIFT_REPEAT(884),
  [2417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__multiple_import_repeat1, 2, .production_id = 34),
  [2419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [2421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [2425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [2427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_using_directive_repeat1, 2, .production_id = 38),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [2433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [2435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_using_directive_repeat1, 2, .production_id = 39), SHIFT_REPEAT(773),
  [2438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_using_directive_repeat1, 2, .production_id = 39),
  [2440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_override_specifier_repeat1, 2), SHIFT_REPEAT(759),
  [2443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_override_specifier_repeat1, 2),
  [2445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__parameter_list_repeat1, 2), SHIFT_REPEAT(152),
  [2448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__parameter_list_repeat1, 2),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [2456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_paramater, 2, .production_id = 14),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [2470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_call_argument_repeat1, 2), SHIFT_REPEAT(795),
  [2473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_argument_repeat1, 2),
  [2475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [2477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [2479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [2481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_expression_repeat1, 2), SHIFT_REPEAT(817),
  [2484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_expression_repeat1, 2),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [2490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__call_arguments_repeat1, 2), SHIFT_REPEAT(28),
  [2493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__call_arguments_repeat1, 2),
  [2495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__event_parameter_list_repeat1, 2), SHIFT_REPEAT(149),
  [2498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__event_parameter_list_repeat1, 2),
  [2500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inline_array_expression_repeat1, 2), SHIFT_REPEAT(44),
  [2511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [2513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [2515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [2517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [2521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [2525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [2527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [2529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [2531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [2533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [2535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [2537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [2539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [2541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [2543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [2545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__return_parameters_repeat1, 2), SHIFT_REPEAT(150),
  [2548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__return_parameters_repeat1, 2),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [2556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2), SHIFT_REPEAT(30),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [2567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [2569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [2573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [2575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [2583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [2587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [2591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [2593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [2599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [2619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [2627] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__assembly_flags_repeat1, 2), SHIFT_REPEAT(724),
  [2630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__assembly_flags_repeat1, 2),
  [2632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [2642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_tuple_repeat1, 2), SHIFT_REPEAT(109),
  [2645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_tuple_repeat1, 2),
  [2647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [2649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__source_import, 1, .production_id = 5),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [2653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__class_heritage_repeat1, 2),
  [2655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_heritage_repeat1, 2), SHIFT_REPEAT(643),
  [2658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_error_declaration_repeat1, 2), SHIFT_REPEAT(151),
  [2661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_error_declaration_repeat1, 2),
  [2663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_import, 1, .production_id = 3),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [2671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_import, 1),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [2713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_declaration_repeat1, 2), SHIFT_REPEAT(938),
  [2716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_declaration_repeat1, 2),
  [2718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [2720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [2722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [2724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [2726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [2728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [2730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [2732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [2734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_error_parameter, 2, .production_id = 27),
  [2736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, .production_id = 41),
  [2738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [2740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [2742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [2744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [2746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [2748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__event_parameter_list, 5),
  [2750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_argument, 5),
  [2752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [2754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [2756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [2760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [2762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [2764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [2766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [2770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [2772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [2776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_paramater, 3, .production_id = 90),
  [2778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__event_parameter_list, 4),
  [2780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_argument, 4),
  [2782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [2784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [2786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [2788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [2790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [2792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [2796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [2802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_paramater, 2, .production_id = 27),
  [2804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__event_parameter_list, 3),
  [2806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_argument, 3),
  [2808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [2810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [2812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__return_parameters_repeat1, 2, .production_id = 69),
  [2814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [2816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [2822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [2824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_using_directive_repeat1, 4, .production_id = 65),
  [2826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [2828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__event_parameter_list, 2),
  [2832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [2834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_argument, 2),
  [2836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_any_source_type, 1),
  [2838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__nameless_parameter, 2, .production_id = 28),
  [2840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, .production_id = 27),
  [2842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [2844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [2846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__multiple_import_repeat1, 2, .production_id = 20),
  [2850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [2852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_declaration_repeat1, 2, .production_id = 52),
  [2854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [2856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [2858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [2862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [2866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [2868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inheritance_specifier, 2, .production_id = 36),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [2872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_type_definition, 2),
  [2874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_declaration, 2, .production_id = 10),
  [2876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [2878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [2880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_definable_operator, 1),
  [2882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [2890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [2894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [2898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [2902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [2904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [2906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [2908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [2910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [2912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiple_import, 5, .production_id = 33),
  [2914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiple_import, 4, .production_id = 33),
  [2916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiple_import, 4, .production_id = 20),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [2922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [2926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [2928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [2930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [2932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [2936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [2942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [2944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [2948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [2950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [2952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [2956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [2960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__from_clause, 2, .production_id = 21),
  [2962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [2964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [2966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiple_import, 3, .production_id = 20),
  [2968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [2974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [2976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [2978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_tuple, 3),
  [2980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [2982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [2984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [2986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [2990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [2992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [2994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [3000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [3002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_tuple, 4),
  [3004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [3006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [3008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__source_import, 2, .production_id = 12),
  [3010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [3012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assembly_flags, 3),
  [3014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [3016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [3018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_import, 2, .production_id = 10),
  [3020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [3022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [3024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiple_import, 2),
  [3026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [3028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_import, 2, .production_id = 9),
  [3030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [3032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [3034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [3036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [3038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [3042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [3046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [3048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [3050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_tuple, 5),
  [3052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_solidity_version_comparison_operator, 1),
  [3054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [3058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [3060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [3062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [3064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [3066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_any_pragma_token, 2),
  [3068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pragma_value, 1),
  [3070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [3072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [3074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_tuple, 6),
  [3076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assembly_flags, 4),
  [3078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [3080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [3082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [3084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assembly_flags, 5),
  [3086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [3088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [3090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [3092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_clause, 1, .production_id = 4),
  [3094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [3096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [3098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [3100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [3102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [3104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [3106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [3108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [3110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [3112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [3114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [3116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [3118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [3120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [3122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [3124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [3126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [3128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [3130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [3132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [3134] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [3136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [3138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [3140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [3142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [3144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [3146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [3148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [3150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_solidity(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
